(* ***

Ancillary file of 

    "Top Quark Mass Effects in Next-To-Next-To-Next-To-Leading Order Higgs Boson Production: Virtual Corrections" 
    Joshua Davies, Florian Herren and Matthias Steinhauser
    arXiv:1911.10214, TTP19-039, P3H-19-045

The file ancillary.m contains four expressions:
hMS    - the quantity h(rho), as defined in Eqs. (1) and (3), with the top quark mass renormalized in the MSbar scheme
hOS    - the quantity h(rho), as defined in Eqs. (1) and (3), with the top quark mass renormalized in the on-shell scheme
LogFMS - the logarithm of F, as defined in Eq. (5), with the top quark mass renormalized in the MSbar scheme
LogFOS - the logarithm of F, as defined in Eq. (5), with the top quark mass renormalized in the on-shell scheme

These expressions contain the following variables:
api5          - alphas_s(mu^2)/Pi, five flavour version
ep            - dimensional regularization parameter (d = 4 - 2*ep)
lmuH          - Log[mu^2/Mh^2] + I*Pi
lmmMS         - Log[mu^2/mt^2], mt in the MSbar scheme
lmmOS         - Log[mu^2/mt^2], mt in the on-shell scheme
rhoMS         - Mh^2/mt^2, mt in the MSbar scheme
rhoOS         - Mh^2/mt^2, mt in the on-shell scheme
nh            - label for closed top quark loops, an overall factor of nh is contained in A0 (nh = 1)
nl            - label for closed light quark loops (nl = 5)
cA            - quadratic Casimir of the adjoint representation (cA = 3)
cR            - quadratic Casimir of the fundamental representation (cR = 4/3)
NA            - dimension of the adjoint representation (NA = 8)
d44[pR1, pA1] - contraction of two symmetric quartic tensors, fundamental - adjoint (d44[pR1, pA1] = 15/2)
d44[pR1, pR2] - contraction of two symmetric quartic tensors, fundamental - fundamental (d44[pR1, pR2] = 5/12)


*** *)


hMS = 1 + ep*lmmMS + ep^2*(lmmMS^2/2 + Pi^2/12) + 
     ep^3*(lmmMS^3/6 + (lmmMS*Pi^2)/12 - Zeta[3]/3) + 
     ep^4*(lmmMS^4/24 + (lmmMS^2*Pi^2)/24 + Pi^4/160 - (lmmMS*Zeta[3])/3) + 
     ep^5*(lmmMS^5/120 + (lmmMS^3*Pi^2)/72 + (lmmMS*Pi^4)/160 - 
       (lmmMS^2*Zeta[3])/6 - (Pi^2*Zeta[3])/36 - Zeta[5]/5) + 
     ep^6*(lmmMS^6/720 + (lmmMS^4*Pi^2)/288 + (lmmMS^2*Pi^4)/320 + 
       (61*Pi^6)/120960 - (lmmMS^3*Zeta[3])/18 - (lmmMS*Pi^2*Zeta[3])/36 + 
       Zeta[3]^2/18 - (lmmMS*Zeta[5])/5) + 
     rhoMS*(7/120 + ep*(7/120 + (7*lmmMS)/120) + 
       ep^2*((7*lmmMS)/120 + (7*lmmMS^2)/240 + (7*Pi^2)/1440) + 
       ep^3*((7*lmmMS^2)/240 + (7*lmmMS^3)/720 + (7*Pi^2)/1440 + 
         (7*lmmMS*Pi^2)/1440 - (7*Zeta[3])/360) + 
       ep^4*((7*lmmMS^3)/720 + (7*lmmMS^4)/2880 + (7*lmmMS*Pi^2)/1440 + 
         (7*lmmMS^2*Pi^2)/2880 + (7*Pi^4)/19200 - (7*Zeta[3])/360 - 
         (7*lmmMS*Zeta[3])/360) + ep^5*((7*lmmMS^4)/2880 + 
         (7*lmmMS^5)/14400 + (7*lmmMS^2*Pi^2)/2880 + (7*lmmMS^3*Pi^2)/8640 + 
         (7*Pi^4)/19200 + (7*lmmMS*Pi^4)/19200 - (7*lmmMS*Zeta[3])/360 - 
         (7*lmmMS^2*Zeta[3])/720 - (7*Pi^2*Zeta[3])/4320 - (7*Zeta[5])/600) + 
       ep^6*((7*lmmMS^5)/14400 + (7*lmmMS^6)/86400 + (7*lmmMS^3*Pi^2)/8640 + 
         (7*lmmMS^4*Pi^2)/34560 + (7*lmmMS*Pi^4)/19200 + 
         (7*lmmMS^2*Pi^4)/38400 + (61*Pi^6)/2073600 - (7*lmmMS^2*Zeta[3])/
          720 - (7*lmmMS^3*Zeta[3])/2160 - (7*Pi^2*Zeta[3])/4320 - 
         (7*lmmMS*Pi^2*Zeta[3])/4320 + (7*Zeta[3]^2)/2160 - (7*Zeta[5])/600 - 
         (7*lmmMS*Zeta[5])/600)) + rhoMS^2*(1/168 + ep*(1/112 + lmmMS/168) + 
       ep^2*(1/336 + lmmMS/112 + lmmMS^2/336 + Pi^2/2016) + 
       ep^3*(lmmMS/336 + lmmMS^2/224 + lmmMS^3/1008 + Pi^2/1344 + 
         (lmmMS*Pi^2)/2016 - Zeta[3]/504) + ep^4*(lmmMS^2/672 + lmmMS^3/672 + 
         lmmMS^4/4032 + Pi^2/4032 + (lmmMS*Pi^2)/1344 + (lmmMS^2*Pi^2)/4032 + 
         Pi^4/26880 - Zeta[3]/336 - (lmmMS*Zeta[3])/504) + 
       ep^5*(lmmMS^3/2016 + lmmMS^4/2688 + lmmMS^5/20160 + 
         (lmmMS*Pi^2)/4032 + (lmmMS^2*Pi^2)/2688 + (lmmMS^3*Pi^2)/12096 + 
         Pi^4/17920 + (lmmMS*Pi^4)/26880 - Zeta[3]/1008 - 
         (lmmMS*Zeta[3])/336 - (lmmMS^2*Zeta[3])/1008 - (Pi^2*Zeta[3])/6048 - 
         Zeta[5]/840) + ep^6*(lmmMS^4/8064 + lmmMS^5/13440 + lmmMS^6/120960 + 
         (lmmMS^2*Pi^2)/8064 + (lmmMS^3*Pi^2)/8064 + (lmmMS^4*Pi^2)/48384 + 
         Pi^4/53760 + (lmmMS*Pi^4)/17920 + (lmmMS^2*Pi^4)/53760 + 
         (61*Pi^6)/20321280 - (lmmMS*Zeta[3])/1008 - (lmmMS^2*Zeta[3])/672 - 
         (lmmMS^3*Zeta[3])/3024 - (Pi^2*Zeta[3])/4032 - (lmmMS*Pi^2*Zeta[3])/
          6048 + Zeta[3]^2/3024 - Zeta[5]/560 - (lmmMS*Zeta[5])/840)) + 
     api5^3*((-77678557*cA^3)/6718464 - (97705*cA^2*cR)/27648 + 
       (4997*cA*cR^2)/384 - (471*cR^3)/128 - cA^3/(48*ep^6) - 
       (8166983*cA^3*lmmMS)/1119744 + (5659*cA^2*cR*lmmMS)/288 - 
       (275*cA*cR^2*lmmMS)/128 - (230845*cA^3*lmmMS^2)/62208 + 
       (697*cA^2*cR*lmmMS^2)/64 - (1011*cA*cR^2*lmmMS^2)/128 + 
       (18089*cA^3*lmmMS^3)/186624 - (61*cA^2*cR*lmmMS^3)/384 + 
       (16841*cA^3*lmmMS^4)/248832 - (23*cA^2*cR*lmmMS^4)/128 - 
       (11*cA^3*lmmMS^5)/4608 - (cA^3*lmmMS^6)/34560 - 
       (5019773*cA^3*lmuH)/373248 + (3961*cA^2*cR*lmuH)/1152 - 
       (19*cA*cR^2*lmuH)/64 - (85507*cA^3*lmmMS*lmuH)/10368 + 
       (749*cA^2*cR*lmmMS*lmuH)/96 - (219*cA*cR^2*lmmMS*lmuH)/64 + 
       (9283*cA^3*lmmMS^2*lmuH)/10368 - (9*cA^2*cR*lmmMS^2*lmuH)/16 + 
       (449*cA^3*lmmMS^3*lmuH)/1296 - (11*cA^2*cR*lmmMS^3*lmuH)/16 - 
       (11*cA^3*lmmMS^4*lmuH)/512 - (cA^3*lmmMS^5*lmuH)/1920 - 
       (15553*cA^3*lmuH^2)/2304 + (89*cA^2*cR*lmuH^2)/128 - 
       (27*cA*cR^2*lmuH^2)/128 + (283*cA^3*lmmMS*lmuH^2)/864 + 
       (19*cA^2*cR*lmmMS*lmuH^2)/64 + (1801*cA^3*lmmMS^2*lmuH^2)/2304 - 
       (15*cA^2*cR*lmmMS^2*lmuH^2)/16 - (55*cA^3*lmmMS^3*lmuH^2)/768 - 
       (cA^3*lmmMS^4*lmuH^2)/256 - (85*cA^3*lmuH^3)/288 + 
       (13*cA^2*cR*lmuH^3)/48 + (361*cA^3*lmmMS*lmuH^3)/384 - 
       (cA^2*cR*lmmMS*lmuH^3)/2 - (77*cA^3*lmmMS^2*lmuH^3)/768 - 
       (cA^3*lmmMS^3*lmuH^3)/64 + (763*cA^3*lmuH^4)/1536 - 
       (cA^2*cR*lmuH^4)/16 - (55*cA^3*lmmMS*lmuH^4)/1536 - 
       (9*cA^3*lmmMS^2*lmuH^4)/256 + (187*cA^3*lmuH^5)/7680 - 
       (27*cA^3*lmmMS*lmuH^5)/640 - (27*cA^3*lmuH^6)/1280 - 
       (61*cA^2*nh)/6912 + (17453*cA*cR*nh)/6912 - (5*cR^2*nh)/24 + 
       (739*cA^2*lmmMS*nh)/1152 + (127*cA*cR*lmmMS*nh)/1152 + 
       (15*cA^2*lmmMS^2*nh)/256 + (cA*cR*lmmMS^3*nh)/8 + 
       (1423*cA^2*lmuH*nh)/6912 + (101*cA*cR*lmuH*nh)/1152 + 
       (5*cA^2*lmmMS*lmuH*nh)/128 - (cA*cR*lmmMS*lmuH*nh)/24 + 
       (cA*cR*lmmMS^2*lmuH*nh)/16 + (5*cA^2*lmuH^2*nh)/768 + 
       (cA*cR*lmuH^2*nh)/96 + (cA*nh^2)/54 + (113*cR*nh^2)/1728 + 
       ((-55*cA^3)/192 - (cA^3*lmmMS)/48 - (cA^3*lmuH)/16 + (5*cA^2*nl)/96)/
        ep^5 + (27427*cA^3*Pi^2)/139968 + (505*cA^2*cR*Pi^2)/1536 - 
       (cA*cR^2*Pi^2)/4 + (1019*cA^3*lmmMS*Pi^2)/41472 - 
       (61*cA^2*cR*lmmMS*Pi^2)/256 - (8171*cA^3*lmmMS^2*Pi^2)/248832 - 
       (3*cA^2*cR*lmmMS^2*Pi^2)/64 - (209*cA^3*lmmMS^3*Pi^2)/62208 - 
       (cA^3*lmmMS^4*Pi^2)/13824 + (1445*cA^3*lmuH*Pi^2)/6912 - 
       (53*cA^2*cR*lmuH*Pi^2)/384 - (3523*cA^3*lmmMS*lmuH*Pi^2)/20736 - 
       (3*cA^2*cR*lmmMS*lmuH*Pi^2)/32 - (209*cA^3*lmmMS^2*lmuH*Pi^2)/6912 - 
       (cA^3*lmmMS^3*lmuH*Pi^2)/1152 - (607*cA^3*lmuH^2*Pi^2)/3456 - 
       (3*cA^2*cR*lmuH^2*Pi^2)/64 - (209*cA^3*lmmMS*lmuH^2*Pi^2)/2304 - 
       (cA^3*lmmMS^2*lmuH^2*Pi^2)/256 - (209*cA^3*lmuH^3*Pi^2)/2304 - 
       (cA^3*lmmMS*lmuH^3*Pi^2)/128 - (3*cA^3*lmuH^4*Pi^2)/512 + 
       (5*cA^2*nh*Pi^2)/2304 - (cA*cR*nh*Pi^2)/192 + (cA*cR*lmmMS*nh*Pi^2)/
        96 - (324007*cA^3*Pi^4)/14929920 + (8263*cA^2*cR*Pi^4)/15360 - 
       (811*cA*cR^2*Pi^4)/3840 + (17479*cA^3*lmmMS*Pi^4)/1244160 + 
       (11*cA^3*lmmMS^2*Pi^4)/20736 + (1133*cA^3*lmuH*Pi^4)/51840 + 
       (11*cA^3*lmmMS*lmuH*Pi^4)/3456 + (11*cA^3*lmuH^2*Pi^4)/2304 + 
       (51*cA^2*nh*Pi^4)/5120 + (51*cA*cR*nh*Pi^4)/2560 - 
       (77671*cA^3*Pi^6)/13063680 + ((-7459*cA^3)/10368 - (3*cA^2*cR)/32 - 
         (55*cA^3*lmmMS)/192 - (cA^3*lmmMS^2)/96 - (33*cA^3*lmuH)/64 - 
         (cA^3*lmmMS*lmuH)/16 - (3*cA^3*lmuH^2)/32 + 
         ((445*cA^2)/1296 + (5*cA^2*lmmMS)/96 + (3*cA^2*lmuH)/32)*nl - 
         (85*cA*nl^2)/2592 - (cA^3*Pi^2)/576)/ep^4 - (4*d44[pR1, pA1])/
        (3*NA) + (11*nh*d44[pR1, pR2])/(6*NA) - (263*cA^3*Pi^2*Log[2]^2)/
        512 + (381*cA^2*cR*Pi^2*Log[2]^2)/256 - (59*cA*cR^2*Pi^2*Log[2]^2)/
        64 + (9*cA^2*nh*Pi^2*Log[2]^2)/256 + (9*cA*cR*nh*Pi^2*Log[2]^2)/128 + 
       (263*cA^3*Log[2]^4)/512 - (381*cA^2*cR*Log[2]^4)/256 + 
       (59*cA*cR^2*Log[2]^4)/64 - (9*cA^2*nh*Log[2]^4)/256 - 
       (9*cA*cR*nh*Log[2]^4)/128 + (789*cA^3*PolyLog[4, 1/2])/64 - 
       (1143*cA^2*cR*PolyLog[4, 1/2])/32 + (177*cA*cR^2*PolyLog[4, 1/2])/8 - 
       (27*cA^2*nh*PolyLog[4, 1/2])/32 - (27*cA*cR*nh*PolyLog[4, 1/2])/16 + 
       nl^3*(lmmMS^3/1296 + (lmmMS*Pi^2)/2592 - Zeta[3]/648) + 
       (1151449*cA^3*Zeta[3])/373248 - (51317*cA^2*cR*Zeta[3])/1536 + 
       (1049*cA*cR^2*Zeta[3])/256 + (469505*cA^3*lmmMS*Zeta[3])/248832 - 
       (10497*cA^2*cR*lmmMS*Zeta[3])/512 + (855*cA*cR^2*lmmMS*Zeta[3])/128 + 
       (2431*cA^3*lmmMS^2*Zeta[3])/3456 + (35*cA^3*lmmMS^3*Zeta[3])/1728 + 
       (198353*cA^3*lmuH*Zeta[3])/82944 - (3291*cA^2*cR*lmuH*Zeta[3])/512 + 
       (285*cA*cR^2*lmuH*Zeta[3])/128 + (385*cA^3*lmmMS*lmuH*Zeta[3])/144 + 
       (35*cA^3*lmmMS^2*lmuH*Zeta[3])/192 + (473*cA^3*lmuH^2*Zeta[3])/192 + 
       (35*cA^3*lmmMS*lmuH^2*Zeta[3])/64 + (35*cA^3*lmuH^3*Zeta[3])/64 - 
       (311*cA^2*nh*Zeta[3])/384 - (339*cA*cR*nh*Zeta[3])/128 + 
       (13*cR^2*nh*Zeta[3])/64 - (189*cA^2*lmmMS*nh*Zeta[3])/512 - 
       (189*cA*cR*lmmMS*nh*Zeta[3])/256 - (63*cA^2*lmuH*nh*Zeta[3])/512 - 
       (63*cA*cR*lmuH*nh*Zeta[3])/256 - (7*cA*nh^2*Zeta[3])/256 - 
       (7*cR*nh^2*Zeta[3])/128 - (5753*cA^3*Pi^2*Zeta[3])/62208 - 
       (25*cA^3*lmmMS*Pi^2*Zeta[3])/1728 - (25*cA^3*lmuH*Pi^2*Zeta[3])/576 + 
       (13*d44[pR1, pA1]*Zeta[3])/NA - (4*nh*d44[pR1, pR2]*Zeta[3])/NA - 
       (2683*cA^3*Zeta[3]^2)/864 + ((15727*cA^3)/15552 - (51*cA^2*cR)/128 - 
         (5839*cA^3*lmmMS)/10368 - (3*cA^2*cR*lmmMS)/8 - 
         (55*cA^3*lmmMS^2)/384 - (cA^3*lmmMS^3)/288 - (47*cA^3*lmuH)/432 - 
         (3*cA^2*cR*lmuH)/16 - (33*cA^3*lmmMS*lmuH)/64 - 
         (cA^3*lmmMS^2*lmuH)/32 - (55*cA^3*lmuH^2)/128 - 
         (3*cA^3*lmmMS*lmuH^2)/32 - (3*cA^3*lmuH^3)/32 + 
         ((-499*cA)/7776 - (85*cA*lmmMS)/2592 - (11*cA*lmuH)/432)*nl^2 + 
         nl^3/216 - (209*cA^3*Pi^2)/10368 - (cA^3*lmmMS*Pi^2)/576 - 
         (cA^3*lmuH*Pi^2)/192 + nl*((-491*cA^2)/15552 + (29*cA*cR)/576 + 
           (445*cA^2*lmmMS)/1296 + (5*cA^2*lmmMS^2)/192 + 
           (197*cA^2*lmuH)/864 + (3*cA^2*lmmMS*lmuH)/32 + 
           (5*cA^2*lmuH^2)/64 + (19*cA^2*Pi^2)/5184) + (35*cA^3*Zeta[3])/288)/
        ep^3 + nl^2*((140125*cA)/839808 + (265*cR)/864 - 
         (67913*cA*lmmMS)/279936 - (185*cR*lmmMS)/1728 + 
         (17*cA*lmmMS^2)/216 - (11*cR*lmmMS^2)/576 - (499*cA*lmmMS^3)/46656 - 
         (85*cA*lmmMS^4)/62208 + (3065*cA*lmuH)/46656 + (11*cR*lmuH)/288 - 
         (cA*lmmMS*lmuH)/54 - (cR*lmmMS*lmuH)/48 + (25*cA*lmmMS^2*lmuH)/
          2592 - (11*cA*lmmMS^3*lmuH)/2592 + (cA*lmuH^2)/432 + 
         (5*cA*lmmMS*lmuH^2)/432 - (cA*lmmMS^2*lmuH^2)/288 + 
         (43*cA*Pi^2)/5184 - (11*cR*Pi^2)/3456 - (709*cA*lmmMS*Pi^2)/93312 - 
         (79*cA*lmmMS^2*Pi^2)/62208 + (55*cA*lmuH*Pi^2)/15552 - 
         (17*cA*lmmMS*lmuH*Pi^2)/5184 - (cA*lmuH^2*Pi^2)/1728 - 
         (863*cA*Pi^4)/1244160 + (cR*Pi^4)/720 + (1927*cA*Zeta[3])/23328 - 
         (19*cR*Zeta[3])/72 - (161*cA*lmmMS*Zeta[3])/7776 + 
         (cR*lmmMS*Zeta[3])/12 - (31*cA*lmuH*Zeta[3])/1296) + 
       ((-18803*cA^3)/15552 + (1241*cA^2*cR)/768 - (27*cA*cR^2)/64 + 
         (50651*cA^3*lmmMS)/31104 - (53*cA^2*cR*lmmMS)/32 - 
         (2599*cA^3*lmmMS^2)/20736 - (15*cA^2*cR*lmmMS^2)/32 - 
         (55*cA^3*lmmMS^3)/1152 - (cA^3*lmmMS^4)/1152 + (269*cA^3*lmuH)/162 - 
         (7*cA^2*cR*lmuH)/64 + (11*cA^3*lmmMS*lmuH)/54 - 
         (3*cA^2*cR*lmmMS*lmuH)/4 - (33*cA^3*lmmMS^2*lmuH)/128 - 
         (cA^3*lmmMS^3*lmuH)/96 + (721*cA^3*lmuH^2)/1152 - 
         (3*cA^2*cR*lmuH^2)/16 - (55*cA^3*lmmMS*lmuH^2)/128 - 
         (3*cA^3*lmmMS^2*lmuH^2)/64 - (77*cA^3*lmuH^3)/384 - 
         (3*cA^3*lmmMS*lmuH^3)/32 - (9*cA^3*lmuH^4)/128 + (5*cA^2*nh)/384 + 
         (cA*cR*nh)/48 + (lmmMS*nl^3)/216 - (13031*cA^3*Pi^2)/124416 - 
         (3*cA^2*cR*Pi^2)/128 - (209*cA^3*lmmMS*Pi^2)/10368 - 
         (cA^3*lmmMS^2*Pi^2)/1152 - (209*cA^3*lmuH*Pi^2)/3456 - 
         (cA^3*lmmMS*lmuH*Pi^2)/192 - (cA^3*lmuH^2*Pi^2)/128 + 
         (11*cA^3*Pi^4)/10368 + nl^2*((19*cA)/216 + cR/288 - 
           (499*cA*lmmMS)/7776 - (85*cA*lmmMS^2)/5184 + (25*cA*lmuH)/1296 - 
           (11*cA*lmmMS*lmuH)/432 - (cA*lmuH^2)/144 - (79*cA*Pi^2)/31104) + 
         (2431*cA^3*Zeta[3])/1728 + (35*cA^3*lmmMS*Zeta[3])/288 + 
         (35*cA^3*lmuH*Zeta[3])/96 + nl*((-1253*cA^2)/7776 + 
           (1007*cA*cR)/3456 - (1663*cA^2*lmmMS)/7776 + (73*cA*cR*lmmMS)/
            288 + (445*cA^2*lmmMS^2)/2592 + (5*cA^2*lmmMS^3)/576 - 
           (1141*cA^2*lmuH)/2592 + (5*cA*cR*lmuH)/48 + (197*cA^2*lmmMS*lmuH)/
            864 + (3*cA^2*lmmMS^2*lmuH)/64 - (cA^2*lmuH^2)/576 + 
           (5*cA^2*lmmMS*lmuH^2)/64 + (7*cA^2*lmuH^3)/192 + 
           (353*cA^2*Pi^2)/10368 + (19*cA^2*lmmMS*Pi^2)/5184 + 
           (19*cA^2*lmuH*Pi^2)/1728 + (19*cA^2*Zeta[3])/864 - 
           (5*cA*cR*Zeta[3])/18))/ep^2 + (14047*cA^3*Zeta[5])/2880 - 
       (437*cA^3*lmmMS*Zeta[5])/480 - (437*cA^3*lmuH*Zeta[5])/160 + 
       ((-10422185*cA^3)/1119744 + (3521*cA^2*cR)/512 - (137*cA*cR^2)/128 - 
         (88825*cA^3*lmmMS)/31104 + (785*cA^2*cR*lmmMS)/128 - 
         (219*cA*cR^2*lmmMS)/64 + (64421*cA^3*lmmMS^2)/62208 - 
         (179*cA^2*cR*lmmMS^2)/128 + (3881*cA^3*lmmMS^3)/62208 - 
         (11*cA^2*cR*lmmMS^3)/32 - (55*cA^3*lmmMS^4)/4608 - 
         (cA^3*lmmMS^5)/5760 - (63367*cA^3*lmuH)/10368 + 
         (251*cA^2*cR*lmuH)/128 - (27*cA*cR^2*lmuH)/64 + 
         (10201*cA^3*lmmMS*lmuH)/5184 - (29*cA^2*cR*lmmMS*lmuH)/32 + 
         (179*cA^3*lmmMS^2*lmuH)/432 - (15*cA^2*cR*lmmMS^2*lmuH)/16 - 
         (11*cA^3*lmmMS^3*lmuH)/128 - (cA^3*lmmMS^4*lmuH)/384 + 
         (209*cA^3*lmuH^2)/432 + (15*cA^2*cR*lmuH^2)/64 + 
         (1081*cA^3*lmmMS*lmuH^2)/1152 - (3*cA^2*cR*lmmMS*lmuH^2)/4 - 
         (55*cA^3*lmmMS^2*lmuH^2)/256 - (cA^3*lmmMS^3*lmuH^2)/64 + 
         (281*cA^3*lmuH^3)/384 - (cA^2*cR*lmuH^3)/8 - (77*cA^3*lmmMS*lmuH^3)/
          384 - (3*cA^3*lmmMS^2*lmuH^3)/64 - (55*cA^3*lmuH^4)/1536 - 
         (9*cA^3*lmmMS*lmuH^4)/128 - (27*cA^3*lmuH^5)/640 + 
         (397*cA^2*nh)/1728 + (145*cA*cR*nh)/1152 + (5*cA^2*lmmMS*nh)/128 - 
         (cA*cR*lmmMS*nh)/24 + (cA*cR*lmmMS^2*nh)/16 + (5*cA^2*lmuH*nh)/384 + 
         (cA*cR*lmuH*nh)/48 - (853*cA^3*Pi^2)/41472 - (9*cA^2*cR*Pi^2)/64 - 
         (11411*cA^3*lmmMS*Pi^2)/124416 - (3*cA^2*cR*lmmMS*Pi^2)/64 - 
         (209*cA^3*lmmMS^2*Pi^2)/20736 - (cA^3*lmmMS^3*Pi^2)/3456 - 
         (4063*cA^3*lmuH*Pi^2)/20736 - (3*cA^2*cR*lmuH*Pi^2)/64 - 
         (209*cA^3*lmmMS*lmuH*Pi^2)/3456 - (cA^3*lmmMS^2*lmuH*Pi^2)/384 - 
         (209*cA^3*lmuH^2*Pi^2)/2304 - (cA^3*lmmMS*lmuH^2*Pi^2)/128 - 
         (cA^3*lmuH^3*Pi^2)/128 + (17479*cA^3*Pi^4)/1244160 + 
         (11*cA^3*lmmMS*Pi^4)/10368 + (11*cA^3*lmuH*Pi^4)/3456 + 
         nl^3*(lmmMS^2/432 + Pi^2/2592) + (664715*cA^3*Zeta[3])/248832 - 
         (3555*cA^2*cR*Zeta[3])/512 + (285*cA*cR^2*Zeta[3])/128 + 
         (2431*cA^3*lmmMS*Zeta[3])/1728 + (35*cA^3*lmmMS^2*Zeta[3])/576 + 
         (385*cA^3*lmuH*Zeta[3])/144 + (35*cA^3*lmmMS*lmuH*Zeta[3])/96 + 
         (35*cA^3*lmuH^2*Zeta[3])/64 - (63*cA^2*nh*Zeta[3])/512 - 
         (63*cA*cR*nh*Zeta[3])/256 - (25*cA^3*Pi^2*Zeta[3])/1728 + 
         nl^2*((-55115*cA)/279936 - (179*cR)/1728 + (53*cA*lmmMS)/432 - 
           (5*cR*lmmMS)/288 - (499*cA*lmmMS^2)/15552 - (85*cA*lmmMS^3)/
            15552 - (cA*lmuH)/54 - (cR*lmuH)/48 + (25*cA*lmmMS*lmuH)/1296 - 
           (11*cA*lmmMS^2*lmuH)/864 + (5*cA*lmuH^2)/432 - (cA*lmmMS*lmuH^2)/
            144 - (709*cA*Pi^2)/93312 - (79*cA*lmmMS*Pi^2)/31104 - 
           (17*cA*lmuH*Pi^2)/5184 - (161*cA*Zeta[3])/7776 + 
           (cR*Zeta[3])/12) + nl*((8324*cA^2)/2187 + (33497*cA*cR)/20736 + 
           (17*cR^2)/192 - (2803*cA^2*lmmMS)/15552 + (877*cA*cR*lmmMS)/1728 - 
           (461*cA^2*lmmMS^2)/1944 + (25*cA*cR*lmmMS^2)/144 + 
           (445*cA^2*lmmMS^3)/7776 + (5*cA^2*lmmMS^4)/2304 + 
           (8549*cA^2*lmuH)/5184 + (311*cA*cR*lmuH)/288 - 
           (773*cA^2*lmmMS*lmuH)/1296 + (25*cA*cR*lmmMS*lmuH)/96 + 
           (197*cA^2*lmmMS^2*lmuH)/1728 + (cA^2*lmmMS^3*lmuH)/64 - 
           (95*cA^2*lmuH^2)/864 + (9*cA*cR*lmuH^2)/64 - (cA^2*lmmMS*lmuH^2)/
            576 + (5*cA^2*lmmMS^2*lmuH^2)/128 - (5*cA^2*lmuH^3)/64 + 
           (7*cA^2*lmmMS*lmuH^3)/192 + (5*cA^2*lmuH^4)/768 - (5*cA*nh)/1152 - 
           (cR*nh)/144 + (1139*cA^2*Pi^2)/46656 + (25*cA*cR*Pi^2)/3456 + 
           (353*cA^2*lmmMS*Pi^2)/10368 + (19*cA^2*lmmMS^2*Pi^2)/10368 + 
           (47*cA^2*lmuH*Pi^2)/864 + (19*cA^2*lmmMS*lmuH*Pi^2)/1728 + 
           (19*cA^2*lmuH^2*Pi^2)/1152 + (1579*cA^2*Pi^4)/622080 - 
           (11*cA*cR*Pi^4)/2160 + (3613*cA^2*Zeta[3])/7776 - 
           (325*cA*cR*Zeta[3])/216 + (19*cA^2*lmmMS*Zeta[3])/864 - 
           (5*cA*cR*lmmMS*Zeta[3])/18 + (25*cA^2*lmuH*Zeta[3])/72 - 
           (5*cA*cR*lmuH*Zeta[3])/6) - (437*cA^3*Zeta[5])/480)/ep + 
       nl*((-496475*cA^2)/3359232 + (781415*cA*cR)/124416 + (9*cR^2)/8 + 
         (336757*cA^2*lmmMS)/69984 - (5855*cA*cR*lmmMS)/10368 + 
         (25*cR^2*lmmMS)/96 + (491*cA^2*lmmMS^2)/31104 + 
         (397*cA*cR*lmmMS^2)/864 - (1327*cA^2*lmmMS^3)/11664 - 
         (29*cA*cR*lmmMS^3)/432 + (445*cA^2*lmmMS^4)/31104 + 
         (cA^2*lmmMS^5)/2304 + (347497*cA^2*lmuH)/93312 + 
         (2207*cA*cR*lmuH)/432 + (cR^2*lmuH)/8 + (10133*cA^2*lmmMS*lmuH)/
          5184 + (523*cA*cR*lmmMS*lmuH)/576 - (1043*cA^2*lmmMS^2*lmuH)/2592 + 
         (25*cA*cR*lmmMS^2*lmuH)/192 + (197*cA^2*lmmMS^3*lmuH)/5184 + 
         (cA^2*lmmMS^4*lmuH)/256 + (6601*cA^2*lmuH^2)/3456 + 
         (209*cA*cR*lmuH^2)/128 - (35*cA^2*lmmMS*lmuH^2)/216 + 
         (11*cA*cR*lmmMS*lmuH^2)/64 - (cA^2*lmmMS^2*lmuH^2)/1152 + 
         (5*cA^2*lmmMS^3*lmuH^2)/384 + (13*cA^2*lmuH^3)/96 + 
         (9*cA*cR*lmuH^3)/64 - (5*cA^2*lmmMS*lmuH^3)/64 + 
         (7*cA^2*lmmMS^2*lmuH^3)/384 - (15*cA^2*lmuH^4)/256 + 
         (5*cA^2*lmmMS*lmuH^4)/768 - (17*cA^2*lmuH^5)/3840 - 
         (1255*cA*nh)/20736 - (275*cR*nh)/3456 - (5*cA*lmmMS*nh)/1152 + 
         (cR*lmmMS*nh)/36 - (cR*lmmMS^2*nh)/48 - (19919*cA^2*Pi^2)/279936 - 
         (995*cA*cR*Pi^2)/20736 + (329*cA^2*lmmMS*Pi^2)/46656 + 
         (61*cA*cR*lmmMS*Pi^2)/3456 + (353*cA^2*lmmMS^2*Pi^2)/20736 + 
         (19*cA^2*lmmMS^3*Pi^2)/31104 - (149*cA^2*lmuH*Pi^2)/1944 - 
         (13*cA*cR*lmuH*Pi^2)/576 + (47*cA^2*lmmMS*lmuH*Pi^2)/864 + 
         (19*cA^2*lmmMS^2*lmuH*Pi^2)/3456 + (13*cA^2*lmuH^2*Pi^2)/384 + 
         (19*cA^2*lmmMS*lmuH^2*Pi^2)/1152 + (19*cA^2*lmuH^3*Pi^2)/1152 + 
         (52387*cA^2*Pi^4)/3732480 - (29*cA*cR*Pi^4)/1080 + 
         (1579*cA^2*lmmMS*Pi^4)/622080 - (11*cA*cR*lmmMS*Pi^4)/2160 + 
         (293*cA^2*lmuH*Pi^4)/25920 - (11*cA*cR*lmuH*Pi^4)/720 + 
         (11*d44[pR1, pR2])/(3*NA) + (1863647*cA^2*Zeta[3])/746496 - 
         (99437*cA*cR*Zeta[3])/41472 + (139*cR^2*Zeta[3])/128 + 
         (3613*cA^2*lmmMS*Zeta[3])/7776 - (325*cA*cR*lmmMS*Zeta[3])/216 + 
         (19*cA^2*lmmMS^2*Zeta[3])/1728 - (5*cA*cR*lmmMS^2*Zeta[3])/36 + 
         (761*cA^2*lmuH*Zeta[3])/324 - (113*cA*cR*lmuH*Zeta[3])/36 + 
         (25*cA^2*lmmMS*lmuH*Zeta[3])/72 - (5*cA*cR*lmmMS*lmuH*Zeta[3])/6 + 
         (77*cA^2*lmuH^2*Zeta[3])/96 - (5*cA*cR*lmuH^2*Zeta[3])/4 + 
         (7*cA*nh*Zeta[3])/512 + (7*cR*nh*Zeta[3])/256 - 
         (2645*cA^2*Pi^2*Zeta[3])/31104 + (11*cA*cR*Pi^2*Zeta[3])/108 - 
         (8*d44[pR1, pR2]*Zeta[3])/NA + (2243*cA^2*Zeta[5])/1440 + 
         (cA*cR*Zeta[5])/18 - (5*cR^2*Zeta[5])/2) + 
       rhoMS*((1057509884915591*cA^3)/310393036800000 + (98224469111*cA^2*cR)/
          57480192000 + (79518493*cA*cR^2)/4505600 + (9854729*cR^3)/1209600 - 
         (7*cA^3)/(5760*ep^6) - (900884439323*cA^3*lmmMS)/134369280000 - 
         (349088449*cA^2*cR*lmmMS)/62208000 + (2694377*cA*cR^2*lmmMS)/
          368640 + (35801*cR^3*lmmMS)/10240 + (1884413603*cA^3*lmmMS^2)/
          1492992000 + (1855753*cA^2*cR*lmmMS^2)/276480 + 
         (928199*cA*cR^2*lmmMS^2)/184320 - (31*cR^3*lmmMS^2)/256 + 
         (1032571*cA^3*lmmMS^3)/27993600 + (10171*cA^2*cR*lmmMS^3)/414720 - 
         (7549*cA*cR^2*lmmMS^3)/23040 - (21*cR^3*lmmMS^3)/640 - 
         (34231*cA^3*lmmMS^4)/29859840 - (6283*cA^2*cR*lmmMS^4)/552960 - 
         (35*cA*cR^2*lmmMS^4)/512 - (413*cA^3*lmmMS^5)/2764800 - 
         (217*cA^2*cR*lmmMS^5)/76800 - (7*cA^3*lmmMS^6)/4147200 - 
         (147249771281*cA^3*lmuH)/44789760000 - (47997751*cA^2*cR*lmuH)/
          16588800 + (27349*cA*cR^2*lmuH)/73728 + (168765011*cA^3*lmmMS*lmuH)/
          248832000 + (8756147*cA^2*cR*lmmMS*lmuH)/2073600 + 
         (36157*cA*cR^2*lmmMS*lmuH)/10240 + (635969*cA^3*lmmMS^2*lmuH)/
          6220800 - (619*cA^2*cR*lmmMS^2*lmuH)/69120 - 
         (293*cA*cR^2*lmmMS^2*lmuH)/1920 - (2981*cA^3*lmmMS^3*lmuH)/1244160 - 
         (4391*cA^2*cR*lmmMS^3*lmuH)/69120 - (21*cA*cR^2*lmmMS^3*lmuH)/320 - 
         (259*cA^3*lmmMS^4*lmuH)/184320 - (7*cA^2*cR*lmmMS^4*lmuH)/512 - 
         (7*cA^3*lmmMS^5*lmuH)/230400 - (21523733*cA^3*lmuH^2)/165888000 + 
         (35791*cA^2*cR*lmuH^2)/55296 + (112711*cA*cR^2*lmuH^2)/184320 + 
         (226133*cA^3*lmmMS*lmuH^2)/2073600 - (2539*cA^2*cR*lmmMS*lmuH^2)/
          69120 - (79*cA*cR^2*lmmMS*lmuH^2)/7680 + (923*cA^3*lmmMS^2*lmuH^2)/
          138240 - (683*cA^2*cR*lmmMS^2*lmuH^2)/11520 - 
         (21*cA*cR^2*lmmMS^2*lmuH^2)/1280 - (469*cA^3*lmmMS^3*lmuH^2)/92160 - 
         (49*cA^2*cR*lmmMS^3*lmuH^2)/1920 - (7*cA^3*lmmMS^4*lmuH^2)/30720 + 
         (96311*cA^3*lmuH^3)/2073600 - (31*cA^2*cR*lmuH^3)/1440 + 
         (883*cA^3*lmmMS*lmuH^3)/34560 - (5*cA^2*cR*lmmMS*lmuH^3)/432 - 
         (791*cA^3*lmmMS^2*lmuH^3)/92160 - (7*cA^2*cR*lmmMS^2*lmuH^3)/320 - 
         (7*cA^3*lmmMS^3*lmuH^3)/7680 + (3109*cA^3*lmuH^4)/138240 + 
         (19*cA^2*cR*lmuH^4)/4320 - (1141*cA^3*lmmMS*lmuH^4)/184320 - 
         (7*cA^2*cR*lmmMS*lmuH^4)/960 - (21*cA^3*lmmMS^2*lmuH^4)/10240 - 
         (959*cA^3*lmuH^5)/921600 - (63*cA^3*lmmMS*lmuH^5)/25600 - 
         (63*cA^3*lmuH^6)/51200 + (294520898393*cA^2*nh)/6584094720000 + 
         (771710530441*cA*cR*nh)/724250419200 - (1646173*cR^2*nh)/1161216 - 
         (33393487*cA^2*lmmMS*nh)/497664000 + (30006533*cA*cR*lmmMS*nh)/
          49766400 + (4567*cR^2*lmmMS*nh)/34560 + (71897*cA^2*lmmMS^2*nh)/
          3686400 + (19141*cA*cR*lmmMS^2*nh)/138240 + (cR^2*lmmMS^2*nh)/
          1440 - (19*cA^2*lmmMS^3*nh)/5760 + (119*cA*cR*lmmMS^3*nh)/11520 + 
         (7*cR^2*lmmMS^3*nh)/640 + (35*cA*cR*lmmMS^4*nh)/4608 - 
         (9065117*cA^2*lmuH*nh)/248832000 + (139643*cA*cR*lmuH*nh)/829440 + 
         (80537*cA^2*lmmMS*lmuH*nh)/5529600 + (8191*cA*cR*lmmMS*lmuH*nh)/
          69120 - (cA^2*lmmMS^2*lmuH*nh)/1920 - (7*cA*cR*lmmMS^2*lmuH*nh)/
          1440 + (7*cA*cR*lmmMS^3*lmuH*nh)/960 + (96857*cA^2*lmuH^2*nh)/
          33177600 + (1763*cA*cR*lmuH^2*nh)/82944 + (cA^2*lmmMS*lmuH^2*nh)/
          384 - (7*cA*cR*lmmMS*lmuH^2*nh)/2304 + (7*cA*cR*lmmMS^2*lmuH^2*nh)/
          3840 + (7*cA^2*lmuH^3*nh)/5760 - (6779603*cA*nh^2)/627056640 + 
         (4428589*cR*nh^2)/39191040 + (49*cR*lmmMS*nh^2)/20736 + 
         (7*cR*lmmMS^2*nh^2)/3456 - (7*cR*lmmMS^3*nh^2)/8640 + 
         ((-413*cA^3)/23040 - (7*cA^3*lmmMS)/5760 - (7*cA^3*lmuH)/1920 + 
           (7*cA^2*nl)/2304)/ep^5 + (760415093*cA^3*Pi^2)/13436928000 + 
         (342199*cA^2*cR*Pi^2)/1382400 + (34871*cA*cR^2*Pi^2)/184320 - 
         (269279*cA^3*lmmMS*Pi^2)/37324800 - (19177*cA^2*cR*lmmMS*Pi^2)/
          829440 - (311*cA*cR^2*lmmMS*Pi^2)/9216 - (21517*cA^3*lmmMS^2*Pi^2)/
          5971968 - (6721*cA^2*cR*lmmMS^2*Pi^2)/552960 - 
         (7*cA*cR^2*lmmMS^2*Pi^2)/512 - (1589*cA^3*lmmMS^3*Pi^2)/7464960 - 
         (7*cA^2*cR*lmmMS^3*Pi^2)/5760 - (7*cA^3*lmmMS^4*Pi^2)/1658880 - 
         (14147*cA^3*lmuH*Pi^2)/3110400 + (37*cA^2*cR*lmuH*Pi^2)/34560 - 
         (79*cA*cR^2*lmuH*Pi^2)/46080 - (38911*cA^3*lmmMS*lmuH*Pi^2)/
          2488320 - (2783*cA^2*cR*lmmMS*lmuH*Pi^2)/138240 - 
         (7*cA*cR^2*lmmMS*lmuH*Pi^2)/1280 - (1589*cA^3*lmmMS^2*lmuH*Pi^2)/
          829440 - (7*cA^2*cR*lmmMS^2*lmuH*Pi^2)/1920 - 
         (7*cA^3*lmmMS^3*lmuH*Pi^2)/138240 - (13799*cA^3*lmuH^2*Pi^2)/
          829440 - (583*cA^2*cR*lmuH^2*Pi^2)/138240 - 
         (1589*cA^3*lmmMS*lmuH^2*Pi^2)/276480 - (7*cA^2*cR*lmmMS*lmuH^2*Pi^2)/
          1920 - (7*cA^3*lmmMS^2*lmuH^2*Pi^2)/30720 - (1589*cA^3*lmuH^3*Pi^2)/
          276480 - (7*cA^2*cR*lmuH^3*Pi^2)/5760 - (7*cA^3*lmmMS*lmuH^3*Pi^2)/
          15360 - (7*cA^3*lmuH^4*Pi^2)/20480 + (114137*cA^2*nh*Pi^2)/
          99532800 + (5*cA*cR*nh*Pi^2)/972 - (cA^2*lmmMS*nh*Pi^2)/1920 + 
         (7*cA*cR*lmmMS*nh*Pi^2)/8640 + (7*cA*cR*lmmMS^2*nh*Pi^2)/4608 - 
         (cA^2*lmuH*nh*Pi^2)/5760 - (7*cA*cR*lmuH*nh*Pi^2)/13824 + 
         (7*cA*cR*lmmMS*lmuH*nh*Pi^2)/11520 + (31497396737*cA^3*Pi^4)/
          110361968640 + (119266487*cA^2*cR*Pi^4)/510935040 - 
         (310678733*cA*cR^2*Pi^4)/340623360 + (6250669*cR^3*Pi^4)/58060800 + 
         (23131447*cA^3*lmmMS*Pi^4)/597196800 + (19547*cA^2*cR*lmmMS*Pi^4)/
          115200 + (93659*cA*cR^2*lmmMS*Pi^4)/614400 + (77*cA^3*lmmMS^2*Pi^4)/
          2488320 + (2802427*cA^3*lmuH*Pi^4)/199065600 + 
         (17281*cA^2*cR*lmuH*Pi^4)/307200 + (93659*cA*cR^2*lmuH*Pi^4)/
          1843200 + (77*cA^3*lmmMS*lmuH*Pi^4)/414720 + (77*cA^3*lmuH^2*Pi^4)/
          276480 - (46476481*cA^2*nh*Pi^4)/2786918400 + 
         (8507641*cA*cR*nh*Pi^4)/139345920 + (94099*cR^2*nh*Pi^4)/518400 + 
         (187*cA^2*lmmMS*nh*Pi^4)/491520 + (187*cA*cR*lmmMS*nh*Pi^4)/15360 + 
         (187*cA^2*lmuH*nh*Pi^4)/1474560 + (187*cA*cR*lmuH*nh*Pi^4)/46080 - 
         (77671*cA^3*Pi^6)/223948800 + ((-81211*cA^3)/1244160 + 
           (19*cA^2*cR)/2880 - (413*cA^3*lmmMS)/23040 - (7*cA^2*cR*lmmMS)/
            640 - (7*cA^3*lmmMS^2)/11520 - (259*cA^3*lmuH)/7680 - 
           (7*cA^3*lmmMS*lmuH)/1920 - (7*cA^3*lmuH^2)/1280 + 
           ((1435*cA^2)/62208 + (7*cA^2*lmmMS)/2304 + (7*cA^2*lmuH)/1280)*
            nl - (119*cA*nl^2)/62208 - (7*cA^3*Pi^2)/69120)/ep^4 - 
         (35085319*d44[pR1, pA1])/(13305600*NA) + 
         (76339381*Pi^4*d44[pR1, pA1])/(63866880*NA) + 
         (24226021*nh*d44[pR1, pR2])/(15966720*NA) + 
         (1489*nh*Pi^4*d44[pR1, pR2])/(17280*NA) - 
         (27392147*cA^3*Pi^4*Log[2])/510935040 + 
         (15046033*cA^2*cR*Pi^4*Log[2])/35481600 + 
         (37644137*cA*cR^2*Pi^4*Log[2])/212889600 - (7249*cR^3*Pi^4*Log[2])/
          5040 - (187*cA^2*nh*Pi^4*Log[2])/245760 - 
         (187*cA*cR*nh*Pi^4*Log[2])/7680 - (911441*Pi^4*d44[pR1, pA1]*Log[2])/
          (831600*NA) + (1198094819*cA^3*Pi^2*Log[2]^2)/1021870080 - 
         (4955029*cA^2*cR*Pi^2*Log[2]^2)/85155840 - 
         (49251199*cA*cR^2*Pi^2*Log[2]^2)/9461760 + 
         (197917*cR^3*Pi^2*Log[2]^2)/483840 + (157*cA^3*lmmMS*Pi^2*Log[2]^2)/
          8192 - (111*cA^2*cR*lmmMS*Pi^2*Log[2]^2)/5120 - 
         (341*cA*cR^2*lmmMS*Pi^2*Log[2]^2)/10240 + 
         (157*cA^3*lmuH*Pi^2*Log[2]^2)/24576 - 
         (37*cA^2*cR*lmuH*Pi^2*Log[2]^2)/5120 - 
         (341*cA*cR^2*lmuH*Pi^2*Log[2]^2)/30720 - 
         (2640857*cA^2*nh*Pi^2*Log[2]^2)/46448640 + 
         (663493*cA*cR*nh*Pi^2*Log[2]^2)/2903040 + 
         (5459*cR^2*nh*Pi^2*Log[2]^2)/8640 + (11*cA^2*lmmMS*nh*Pi^2*Log[2]^2)/
          8192 + (11*cA*cR*lmmMS*nh*Pi^2*Log[2]^2)/256 + 
         (11*cA^2*lmuH*nh*Pi^2*Log[2]^2)/24576 + 
         (11*cA*cR*lmuH*nh*Pi^2*Log[2]^2)/768 + (2729191*Pi^2*d44[pR1, pA1]*
           Log[2]^2)/(532224*NA) + (151*nh*Pi^2*d44[pR1, pR2]*Log[2]^2)/
          (360*NA) - (2278723*cA^3*Pi^2*Log[2]^3)/25546752 + 
         (820409*cA^2*cR*Pi^2*Log[2]^3)/1774080 + 
         (4966681*cA*cR^2*Pi^2*Log[2]^3)/10644480 - (113*cR^3*Pi^2*Log[2]^3)/
          63 - (11*cA^2*nh*Pi^2*Log[2]^3)/12288 - (11*cA*cR*nh*Pi^2*Log[2]^3)/
          384 - (17197*Pi^2*d44[pR1, pA1]*Log[2]^3)/(10395*NA) - 
         (1198094819*cA^3*Log[2]^4)/1021870080 + (4955029*cA^2*cR*Log[2]^4)/
          85155840 + (49251199*cA*cR^2*Log[2]^4)/9461760 - 
         (197917*cR^3*Log[2]^4)/483840 - (157*cA^3*lmmMS*Log[2]^4)/8192 + 
         (111*cA^2*cR*lmmMS*Log[2]^4)/5120 + (341*cA*cR^2*lmmMS*Log[2]^4)/
          10240 - (157*cA^3*lmuH*Log[2]^4)/24576 + (37*cA^2*cR*lmuH*Log[2]^4)/
          5120 + (341*cA*cR^2*lmuH*Log[2]^4)/30720 + 
         (2640857*cA^2*nh*Log[2]^4)/46448640 - (663493*cA*cR*nh*Log[2]^4)/
          2903040 - (5459*cR^2*nh*Log[2]^4)/8640 - 
         (11*cA^2*lmmMS*nh*Log[2]^4)/8192 - (11*cA*cR*lmmMS*nh*Log[2]^4)/
          256 - (11*cA^2*lmuH*nh*Log[2]^4)/24576 - 
         (11*cA*cR*lmuH*nh*Log[2]^4)/768 - (2729191*d44[pR1, pA1]*Log[2]^4)/
          (532224*NA) - (151*nh*d44[pR1, pR2]*Log[2]^4)/(360*NA) + 
         (2278723*cA^3*Log[2]^5)/42577920 - (820409*cA^2*cR*Log[2]^5)/
          2956800 - (4966681*cA*cR^2*Log[2]^5)/17740800 + 
         (113*cR^3*Log[2]^5)/105 + (11*cA^2*nh*Log[2]^5)/20480 + 
         (11*cA*cR*nh*Log[2]^5)/640 + (17197*d44[pR1, pA1]*Log[2]^5)/
          (17325*NA) - (1198094819*cA^3*PolyLog[4, 1/2])/42577920 + 
         (4955029*cA^2*cR*PolyLog[4, 1/2])/3548160 + 
         (49251199*cA*cR^2*PolyLog[4, 1/2])/394240 - 
         (197917*cR^3*PolyLog[4, 1/2])/20160 - 
         (471*cA^3*lmmMS*PolyLog[4, 1/2])/1024 + 
         (333*cA^2*cR*lmmMS*PolyLog[4, 1/2])/640 + 
         (1023*cA*cR^2*lmmMS*PolyLog[4, 1/2])/1280 - 
         (157*cA^3*lmuH*PolyLog[4, 1/2])/1024 + 
         (111*cA^2*cR*lmuH*PolyLog[4, 1/2])/640 + 
         (341*cA*cR^2*lmuH*PolyLog[4, 1/2])/1280 + 
         (2640857*cA^2*nh*PolyLog[4, 1/2])/1935360 - 
         (663493*cA*cR*nh*PolyLog[4, 1/2])/120960 - 
         (5459*cR^2*nh*PolyLog[4, 1/2])/360 - 
         (33*cA^2*lmmMS*nh*PolyLog[4, 1/2])/1024 - 
         (33*cA*cR*lmmMS*nh*PolyLog[4, 1/2])/32 - 
         (11*cA^2*lmuH*nh*PolyLog[4, 1/2])/1024 - 
         (11*cA*cR*lmuH*nh*PolyLog[4, 1/2])/32 - 
         (2729191*d44[pR1, pA1]*PolyLog[4, 1/2])/(22176*NA) - 
         (151*nh*d44[pR1, pR2]*PolyLog[4, 1/2])/(15*NA) - 
         (2278723*cA^3*PolyLog[5, 1/2])/354816 + 
         (820409*cA^2*cR*PolyLog[5, 1/2])/24640 + 
         (4966681*cA*cR^2*PolyLog[5, 1/2])/147840 - 
         (904*cR^3*PolyLog[5, 1/2])/7 - (33*cA^2*nh*PolyLog[5, 1/2])/512 - 
         (33*cA*cR*nh*PolyLog[5, 1/2])/16 - (137576*d44[pR1, pA1]*
           PolyLog[5, 1/2])/(1155*NA) + nl^3*((7*lmmMS^2)/51840 + 
           (7*lmmMS^3)/155520 + (7*Pi^2)/311040 + (7*lmmMS*Pi^2)/311040 - 
           (7*Zeta[3])/77760) - (1915218245209*cA^3*Zeta[3])/137952460800 - 
         (1767288707*cA^2*cR*Zeta[3])/464486400 + (598941997*cA*cR^2*Zeta[3])/
          11059200 - (244991*cR^3*Zeta[3])/16800 + 
         (543990757*cA^3*lmmMS*Zeta[3])/238878720 - 
         (9555103*cA^2*cR*lmmMS*Zeta[3])/1105920 - 
         (2767915*cA*cR^2*lmmMS*Zeta[3])/147456 - (63917*cR^3*lmmMS*Zeta[3])/
          20480 - (13651861*cA^3*lmmMS^2*Zeta[3])/13271040 - 
         (311159*cA^2*cR*lmmMS^2*Zeta[3])/61440 - 
         (191751*cA*cR^2*lmmMS^2*Zeta[3])/40960 + (49*cA^3*lmmMS^3*Zeta[3])/
          41472 + (93861319*cA^3*lmuH*Zeta[3])/79626240 - 
         (4572647*cA^2*cR*lmuH*Zeta[3])/2211840 - 
         (220453*cA*cR^2*lmuH*Zeta[3])/49152 - (238121*cA^3*lmmMS*lmuH*
           Zeta[3])/442368 - (101909*cA^2*cR*lmmMS*lmuH*Zeta[3])/30720 - 
         (63917*cA*cR^2*lmmMS*lmuH*Zeta[3])/20480 + 
         (49*cA^3*lmmMS^2*lmuH*Zeta[3])/4608 + (83099*cA^3*lmuH^2*Zeta[3])/
          1474560 - (34679*cA^2*cR*lmuH^2*Zeta[3])/61440 - 
         (63917*cA*cR^2*lmuH^2*Zeta[3])/122880 + 
         (49*cA^3*lmmMS*lmuH^2*Zeta[3])/1536 + (49*cA^3*lmuH^3*Zeta[3])/
          1536 + (12222962477*cA^2*nh*Zeta[3])/13005619200 - 
         (21810570029*cA*cR*nh*Zeta[3])/5960908800 - 
         (35975243*cR^2*nh*Zeta[3])/3870720 + (16247*cA^2*lmmMS*nh*Zeta[3])/
          294912 - (279223*cA*cR*lmmMS*nh*Zeta[3])/245760 - 
         (497*cR^2*lmmMS*nh*Zeta[3])/2560 - (231*cA^2*lmmMS^2*nh*Zeta[3])/
          32768 - (231*cA*cR*lmmMS^2*nh*Zeta[3])/1024 + 
         (2849*cA^2*lmuH*nh*Zeta[3])/147456 - (66409*cA*cR*lmuH*nh*Zeta[3])/
          184320 - (77*cA^2*lmmMS*lmuH*nh*Zeta[3])/16384 - 
         (77*cA*cR*lmmMS*lmuH*nh*Zeta[3])/512 - (77*cA^2*lmuH^2*nh*Zeta[3])/
          98304 - (77*cA*cR*lmuH^2*nh*Zeta[3])/3072 + (40091*cA*nh^2*Zeta[3])/
          5160960 - (14257*cR*nh^2*Zeta[3])/161280 - 
         (5492951*cA^3*Pi^2*Zeta[3])/119439360 - (6863*cA^2*cR*Pi^2*Zeta[3])/
          36864 - (63917*cA*cR^2*Pi^2*Zeta[3])/368640 - 
         (35*cA^3*lmmMS*Pi^2*Zeta[3])/41472 - (35*cA^3*lmuH*Pi^2*Zeta[3])/
          13824 - (77*cA^2*nh*Pi^2*Zeta[3])/294912 - 
         (77*cA*cR*nh*Pi^2*Zeta[3])/9216 - (1062005899*d44[pR1, pA1]*Zeta[3])/
          (17740800*NA) - (59351603*nh*d44[pR1, pR2]*Zeta[3])/(10644480*NA) - 
         (18781*cA^3*Zeta[3]^2)/103680 + ((-273497*cA^3)/18662400 + 
           (181*cA^2*cR)/6912 - (78079*cA^3*lmmMS)/1244160 - 
           (1817*cA^2*cR*lmmMS)/23040 - (413*cA^3*lmmMS^2)/46080 - 
           (21*cA^2*cR*lmmMS^2)/1280 - (7*cA^3*lmmMS^3)/34560 - 
           (10289*cA^3*lmuH)/207360 + (19*cA^2*cR*lmuH)/1440 - 
           (259*cA^3*lmmMS*lmuH)/7680 - (7*cA^2*cR*lmmMS*lmuH)/320 - 
           (7*cA^3*lmmMS^2*lmuH)/3840 - (469*cA^3*lmuH^2)/15360 - 
           (7*cA^3*lmmMS*lmuH^2)/1280 - (7*cA^3*lmuH^3)/1280 + 
           ((-2639*cA)/466560 - (119*cA*lmmMS)/62208 - (77*cA*lmuH)/51840)*
            nl^2 + (7*nl^3)/25920 - (1589*cA^3*Pi^2)/1244160 - 
           (7*cA^2*cR*Pi^2)/7680 - (7*cA^3*lmmMS*Pi^2)/69120 - 
           (7*cA^3*lmuH*Pi^2)/23040 + nl*((48307*cA^2)/1866240 - 
             (77*cA*cR)/6912 + (1435*cA^2*lmmMS)/62208 + (49*cA*cR*lmmMS)/
              3840 + (7*cA^2*lmmMS^2)/4608 + (973*cA^2*lmuH)/51840 + 
             (7*cA^2*lmmMS*lmuH)/1280 + (7*cA^2*lmuH^2)/1536 + 
             (133*cA^2*Pi^2)/622080) + (49*cA^3*Zeta[3])/6912)/ep^3 + 
         nl^2*((-2175179*cA)/1007769600 - (36913*cR)/18662400 + 
           (431153*cA*lmmMS)/167961600 + (10007*cR*lmmMS)/1555200 + 
           (1529*cA*lmmMS^2)/1866240 - (71*cR*lmmMS^2)/69120 - 
           (2639*cA*lmmMS^3)/2799360 - (7*cR*lmmMS^3)/5760 - 
           (119*cA*lmmMS^4)/1492992 + (9989*cA*lmuH)/5598720 - 
           (cR*lmuH)/720 + (377*cA*lmmMS*lmuH)/311040 - (19*cR*lmmMS*lmuH)/
            51840 - (7*cA*lmmMS^2*lmuH)/38880 - (77*cA*lmmMS^3*lmuH)/311040 + 
           (7*cA*lmuH^2)/8640 + (7*cA*lmmMS*lmuH^2)/25920 - 
           (7*cA*lmmMS^2*lmuH^2)/34560 - (913*cA*Pi^2)/11197440 + 
           (cR*Pi^2)/248832 - (3311*cA*lmmMS*Pi^2)/5598720 - 
           (7*cR*lmmMS*Pi^2)/17280 - (553*cA*lmmMS^2*Pi^2)/7464960 + 
           (7*cA*lmuH*Pi^2)/466560 - (119*cA*lmmMS*lmuH*Pi^2)/622080 - 
           (7*cA*lmuH^2*Pi^2)/207360 - (6041*cA*Pi^4)/149299200 + 
           (7*cR*Pi^4)/86400 + (2381*cA*Zeta[3])/1399680 - 
           (13*cR*Zeta[3])/1728 - (1127*cA*lmmMS*Zeta[3])/933120 + 
           (7*cR*lmmMS*Zeta[3])/1440 - (217*cA*lmuH*Zeta[3])/155520) + 
         ((250433507*cA^3)/746496000 + (547487*cA^2*cR)/414720 + 
           (112711*cA*cR^2)/92160 + (185213*cA^3*lmmMS)/9331200 - 
           (7067*cA^2*cR*lmmMS)/69120 - (79*cA*cR^2*lmmMS)/3840 - 
           (14363*cA^3*lmmMS^2)/497664 - (4831*cA^2*cR*lmmMS^2)/46080 - 
           (21*cA*cR^2*lmmMS^2)/640 - (413*cA^3*lmmMS^3)/138240 - 
           (49*cA^2*cR*lmmMS^3)/3840 - (7*cA^3*lmmMS^4)/138240 + 
           (61169*cA^3*lmuH)/777600 + (23*cA^2*cR*lmuH)/5760 - 
           (1849*cA^3*lmmMS*lmuH)/41472 - (893*cA^2*cR*lmmMS*lmuH)/11520 - 
           (259*cA^3*lmmMS^2*lmuH)/15360 - (21*cA^2*cR*lmmMS^2*lmuH)/640 - 
           (7*cA^3*lmmMS^3*lmuH)/11520 - (121*cA^3*lmuH^2)/69120 + 
           (19*cA^2*cR*lmuH^2)/1440 - (469*cA^3*lmmMS*lmuH^2)/15360 - 
           (7*cA^2*cR*lmmMS*lmuH^2)/320 - (7*cA^3*lmmMS^2*lmuH^2)/2560 - 
           (791*cA^3*lmuH^3)/46080 - (7*cA^3*lmmMS*lmuH^3)/1280 - 
           (21*cA^3*lmuH^4)/5120 + (76697*cA^2*nh)/16588800 + 
           (1763*cA*cR*nh)/41472 - (cA^2*lmmMS*nh)/960 - (7*cA*cR*lmmMS*nh)/
            1152 + (7*cA*cR*lmmMS^2*nh)/1920 + (cA^2*lmuH*nh)/960 + 
           (7/25920 + (7*lmmMS)/25920)*nl^3 - (116981*cA^3*Pi^2)/14929920 - 
           (1969*cA^2*cR*Pi^2)/276480 - (1589*cA^3*lmmMS*Pi^2)/1244160 - 
           (7*cA^2*cR*lmmMS*Pi^2)/3840 - (7*cA^3*lmmMS^2*Pi^2)/138240 - 
           (1589*cA^3*lmuH*Pi^2)/414720 - (7*cA^2*cR*lmuH*Pi^2)/3840 - 
           (7*cA^3*lmmMS*lmuH*Pi^2)/23040 - (7*cA^3*lmuH^2*Pi^2)/15360 + 
           (77*cA^3*Pi^4)/1244160 + nl^2*((-73*cA)/933120 + (299*cR)/103680 - 
             (2639*cA*lmmMS)/466560 - (7*cR*lmmMS)/2880 - (119*cA*lmmMS^2)/
              124416 - (7*cA*lmuH)/19440 - (77*cA*lmmMS*lmuH)/51840 - 
             (7*cA*lmuH^2)/17280 - (553*cA*Pi^2)/3732480) - 
           (991021*cA^3*Zeta[3])/6635520 - (7003*cA^2*cR*Zeta[3])/6144 - 
           (63917*cA*cR^2*Zeta[3])/61440 + (49*cA^3*lmmMS*Zeta[3])/6912 + 
           (49*cA^3*lmuH*Zeta[3])/2304 - (77*cA^2*nh*Zeta[3])/49152 - 
           (77*cA*cR*nh*Zeta[3])/1536 + nl*((-2909*cA^2)/103680 - 
             (16229*cA*cR)/1036800 + (643*cA^2*lmmMS)/29160 + 
             (53*cA*cR*lmmMS)/1920 + (1435*cA^2*lmmMS^2)/124416 + 
             (119*cA*cR*lmmMS^2)/7680 + (7*cA^2*lmmMS^3)/13824 - 
             (2887*cA^2*lmuH)/311040 - (59*cA*cR*lmuH)/6912 + 
             (973*cA^2*lmmMS*lmuH)/51840 + (7*cA*cR*lmmMS*lmuH)/640 + 
             (7*cA^2*lmmMS^2*lmuH)/2560 + (77*cA^2*lmuH^2)/17280 + 
             (7*cA^2*lmmMS*lmuH^2)/1536 + (49*cA^2*lmuH^3)/23040 + 
             (2737*cA^2*Pi^2)/1244160 + (49*cA*cR*Pi^2)/46080 + 
             (133*cA^2*lmmMS*Pi^2)/622080 + (133*cA^2*lmuH*Pi^2)/207360 + 
             (133*cA^2*Zeta[3])/103680 - (7*cA*cR*Zeta[3])/432))/ep^2 + 
         (115455281*cA^3*Zeta[5])/68124672 - (1539178951*cA^2*cR*Zeta[5])/
          23654400 - (119416301*cA*cR^2*Zeta[5])/1892352 + 
         (221161*cR^3*Zeta[5])/1344 - (3059*cA^3*lmmMS*Zeta[5])/57600 - 
         (3059*cA^3*lmuH*Zeta[5])/19200 + (1705*cA^2*nh*Zeta[5])/32768 + 
         (1961*cA*cR*nh*Zeta[5])/1024 + (4961977*d44[pR1, pA1]*Zeta[5])/
          (36960*NA) + ((-294810691589*cA^3)/134369280000 - 
           (26527433*cA^2*cR)/49766400 + (2889877*cA*cR^2)/1105920 + 
           (686547569*cA^3*lmmMS)/746496000 + (8831207*cA^2*cR*lmmMS)/
            2073600 + (321937*cA*cR^2*lmmMS)/92160 + (51281*cA^3*lmmMS^2)/
            1166400 - (11377*cA^2*cR*lmmMS^2)/138240 - (817*cA*cR^2*lmmMS^2)/
            3840 - (59287*cA^3*lmmMS^3)/7464960 - (8087*cA^2*cR*lmmMS^3)/
            138240 - (21*cA*cR^2*lmmMS^3)/320 - (413*cA^3*lmmMS^4)/552960 - 
           (7*cA^2*cR*lmmMS^4)/1024 - (7*cA^3*lmmMS^5)/691200 + 
           (38064113*cA^3*lmuH)/248832000 + (106337*cA^2*cR*lmuH)/82944 + 
           (112711*cA*cR^2*lmuH)/92160 + (376067*cA^3*lmmMS*lmuH)/3110400 - 
           (377*cA^2*cR*lmmMS*lmuH)/8640 - (79*cA*cR^2*lmmMS*lmuH)/3840 - 
           (7157*cA^3*lmmMS^2*lmuH)/414720 - (2521*cA^2*cR*lmmMS^2*lmuH)/
            23040 - (21*cA*cR^2*lmmMS^2*lmuH)/640 - (259*cA^3*lmmMS^3*lmuH)/
            46080 - (49*cA^2*cR*lmmMS^3*lmuH)/1920 - (7*cA^3*lmmMS^4*lmuH)/
            46080 + (166289*cA^3*lmuH^2)/2073600 - (349*cA^2*cR*lmuH^2)/
            17280 + (227*cA^3*lmmMS*lmuH^2)/69120 - 
           (431*cA^2*cR*lmmMS*lmuH^2)/11520 - (469*cA^3*lmmMS^2*lmuH^2)/
            30720 - (21*cA^2*cR*lmmMS^2*lmuH^2)/640 - (7*cA^3*lmmMS^3*lmuH^2)/
            7680 + (767*cA^3*lmuH^3)/34560 + (19*cA^2*cR*lmuH^3)/2160 - 
           (791*cA^3*lmmMS*lmuH^3)/46080 - (7*cA^2*cR*lmmMS*lmuH^3)/480 - 
           (7*cA^3*lmmMS^2*lmuH^3)/2560 - (1141*cA^3*lmuH^4)/184320 - 
           (21*cA^3*lmmMS*lmuH^4)/5120 - (63*cA^3*lmuH^5)/25600 - 
           (9717179*cA^2*nh)/497664000 + (615883*cA*cR*nh)/2488320 + 
           (66137*cA^2*lmmMS*nh)/5529600 + (1441*cA*cR*lmmMS*nh)/13824 - 
           (cA^2*lmmMS^2*nh)/384 + (7*cA*cR*lmmMS^2*nh)/3840 + 
           (7*cA*cR*lmmMS^3*nh)/960 + (108377*cA^2*lmuH*nh)/16588800 + 
           (1763*cA*cR*lmuH*nh)/41472 + (cA^2*lmmMS*lmuH*nh)/960 - 
           (7*cA*cR*lmmMS*lmuH*nh)/1152 + (7*cA*cR*lmmMS^2*lmuH*nh)/1920 + 
           (cA^2*lmuH^2*nh)/640 - (409607*cA^3*Pi^2)/37324800 - 
           (6787*cA^2*cR*Pi^2)/829440 - (79*cA*cR^2*Pi^2)/46080 - 
           (113849*cA^3*lmmMS*Pi^2)/14929920 - (4169*cA^2*cR*lmmMS*Pi^2)/
            276480 - (7*cA*cR^2*lmmMS*Pi^2)/1280 - (1589*cA^3*lmmMS^2*Pi^2)/
            2488320 - (7*cA^2*cR*lmmMS^2*Pi^2)/3840 - (7*cA^3*lmmMS^3*Pi^2)/
            414720 - (7991*cA^3*lmuH*Pi^2)/497664 - (209*cA^2*cR*lmuH*Pi^2)/
            27648 - (1589*cA^3*lmmMS*lmuH*Pi^2)/414720 - 
           (7*cA^2*cR*lmmMS*lmuH*Pi^2)/1920 - (7*cA^3*lmmMS^2*lmuH*Pi^2)/
            46080 - (1589*cA^3*lmuH^2*Pi^2)/276480 - (7*cA^2*cR*lmuH^2*Pi^2)/
            3840 - (7*cA^3*lmmMS*lmuH^2*Pi^2)/15360 - (7*cA^3*lmuH^3*Pi^2)/
            15360 - (cA^2*nh*Pi^2)/5760 - (7*cA*cR*nh*Pi^2)/13824 + 
           (7*cA*cR*lmmMS*nh*Pi^2)/11520 + (8061397*cA^3*Pi^4)/597196800 + 
           (8651*cA^2*cR*Pi^4)/153600 + (93659*cA*cR^2*Pi^4)/1843200 + 
           (77*cA^3*lmmMS*Pi^4)/1244160 + (77*cA^3*lmuH*Pi^4)/414720 + 
           (187*cA^2*nh*Pi^4)/1474560 + (187*cA*cR*nh*Pi^4)/46080 + 
           nl^3*((7*lmmMS)/25920 + (7*lmmMS^2)/51840 + (7*Pi^2)/311040) + 
           (157*cA^3*Pi^2*Log[2]^2)/24576 - (37*cA^2*cR*Pi^2*Log[2]^2)/5120 - 
           (341*cA*cR^2*Pi^2*Log[2]^2)/30720 + (11*cA^2*nh*Pi^2*Log[2]^2)/
            24576 + (11*cA*cR*nh*Pi^2*Log[2]^2)/768 - (157*cA^3*Log[2]^4)/
            24576 + (37*cA^2*cR*Log[2]^4)/5120 + (341*cA*cR^2*Log[2]^4)/
            30720 - (11*cA^2*nh*Log[2]^4)/24576 - (11*cA*cR*nh*Log[2]^4)/
            768 - (157*cA^3*PolyLog[4, 1/2])/1024 + 
           (111*cA^2*cR*PolyLog[4, 1/2])/640 + (341*cA*cR^2*PolyLog[4, 1/2])/
            1280 - (11*cA^2*nh*PolyLog[4, 1/2])/1024 - 
           (11*cA*cR*nh*PolyLog[4, 1/2])/32 + (155763643*cA^3*Zeta[3])/
            238878720 - (9147619*cA^2*cR*Zeta[3])/2211840 - 
           (4712969*cA*cR^2*Zeta[3])/737280 - (4156231*cA^3*lmmMS*Zeta[3])/
            6635520 - (20729*cA^2*cR*lmmMS*Zeta[3])/6144 - 
           (63917*cA*cR^2*lmmMS*Zeta[3])/20480 + (49*cA^3*lmmMS^2*Zeta[3])/
            13824 - (27107*cA^3*lmuH*Zeta[3])/442368 - 
           (34903*cA^2*cR*lmuH*Zeta[3])/30720 - (63917*cA*cR^2*lmuH*Zeta[3])/
            61440 + (49*cA^3*lmmMS*lmuH*Zeta[3])/2304 + 
           (49*cA^3*lmuH^2*Zeta[3])/1536 + (539*cA^2*nh*Zeta[3])/32768 - 
           (9261*cA*cR*nh*Zeta[3])/20480 - (77*cA^2*lmmMS*nh*Zeta[3])/16384 - 
           (77*cA*cR*lmmMS*nh*Zeta[3])/512 - (77*cA^2*lmuH*nh*Zeta[3])/
            49152 - (77*cA*cR*lmuH*nh*Zeta[3])/1536 - (35*cA^3*Pi^2*Zeta[3])/
            41472 + nl^2*((376343*cA)/167961600 + (413*cR)/388800 + 
             (91*cA*lmmMS)/116640 + (43*cR*lmmMS)/103680 - (2639*cA*lmmMS^2)/
              933120 - (7*cR*lmmMS^2)/2880 - (119*cA*lmmMS^3)/373248 + 
             (377*cA*lmuH)/311040 - (19*cR*lmuH)/51840 - (7*cA*lmmMS*lmuH)/
              19440 - (77*cA*lmmMS^2*lmuH)/103680 + (7*cA*lmuH^2)/25920 - 
             (7*cA*lmmMS*lmuH^2)/17280 - (3311*cA*Pi^2)/5598720 - 
             (7*cR*Pi^2)/34560 - (553*cA*lmmMS*Pi^2)/3732480 - 
             (119*cA*lmuH*Pi^2)/622080 - (1127*cA*Zeta[3])/933120 + 
             (7*cR*Zeta[3])/1440) + nl*((-300626857*cA^2)/6718464000 - 
             (1086271*cA*cR)/3456000 - (111883*cR^2)/276480 - 
             (3937*cA^2*lmmMS)/86400 - (6593*cA*cR*lmmMS)/115200 + 
             (cR^2*lmmMS)/720 + (1415*cA^2*lmmMS^2)/186624 + 
             (113*cA*cR*lmmMS^2)/3456 + (7*cR^2*lmmMS^2)/640 + 
             (1435*cA^2*lmmMS^3)/373248 + (35*cA*cR*lmmMS^3)/4608 + 
             (7*cA^2*lmmMS^4)/55296 - (107*cA^2*lmuH)/86400 + 
             (21053*cA*cR*lmuH)/518400 - (3949*cA^2*lmmMS*lmuH)/311040 - 
             (73*cA*cR*lmmMS*lmuH)/34560 + (973*cA^2*lmmMS^2*lmuH)/103680 + 
             (49*cA*cR*lmmMS^2*lmuH)/3840 + (7*cA^2*lmmMS^3*lmuH)/7680 - 
             (2347*cA^2*lmuH^2)/207360 - (7*cA*cR*lmuH^2)/7680 + 
             (77*cA^2*lmmMS*lmuH^2)/17280 + (7*cA*cR*lmmMS*lmuH^2)/1920 + 
             (7*cA^2*lmmMS^2*lmuH^2)/3072 - (7*cA^2*lmuH^3)/2880 + 
             (49*cA^2*lmmMS*lmuH^3)/23040 + (7*cA^2*lmuH^4)/18432 - 
             (76697*cA*nh)/49766400 - (1763*cR*nh)/124416 + 
             (cA*lmmMS*nh)/2880 + (7*cR*lmmMS*nh)/3456 - (7*cR*lmmMS^2*nh)/
              5760 - (cA*lmuH*nh)/2880 + (52927*cA^2*Pi^2)/11197440 + 
             (169*cA*cR*Pi^2)/82944 + (2737*cA^2*lmmMS*Pi^2)/1244160 + 
             (7*cA*cR*lmmMS*Pi^2)/3072 + (133*cA^2*lmmMS^2*Pi^2)/1244160 + 
             (791*cA^2*lmuH*Pi^2)/207360 + (7*cA*cR*lmuH*Pi^2)/7680 + 
             (133*cA^2*lmmMS*lmuH*Pi^2)/207360 + (133*cA^2*lmuH^2*Pi^2)/
              138240 + (11053*cA^2*Pi^4)/74649600 - (77*cA*cR*Pi^4)/259200 + 
             (6443047*cA^2*Zeta[3])/59719680 + (202183*cA*cR*Zeta[3])/
              829440 + (63917*cR^2*Zeta[3])/184320 + (133*cA^2*lmmMS*Zeta[3])/
              103680 - (7*cA*cR*lmmMS*Zeta[3])/432 + (35*cA^2*lmuH*Zeta[3])/
              1728 - (7*cA*cR*lmuH*Zeta[3])/144 + (77*cA*nh*Zeta[3])/147456 + 
             (77*cR*nh*Zeta[3])/4608) - (3059*cA^3*Zeta[5])/57600)/ep + 
         nl*((273043555669*cA^2)/403107840000 + (529274891*cA*cR)/414720000 + 
           (410942291*cR^2)/746496000 - (6497713*cA^2*lmmMS)/6718464000 - 
           (7872097*cA*cR*lmmMS)/31104000 - (4522403*cR^2*lmmMS)/12441600 - 
           (851*cA^2*lmmMS^2)/25920 - (261521*cA*cR*lmmMS^2)/2073600 + 
           (2843*cR^2*lmmMS^2)/207360 + (697*cA^2*lmmMS^3)/1119744 + 
           (217*cA*cR*lmmMS^3)/17280 + (7*cR^2*lmmMS^3)/640 + 
           (1435*cA^2*lmmMS^4)/1492992 + (7*cA*cR*lmmMS^4)/18432 + 
           (7*cA^2*lmmMS^5)/276480 + (16081489*cA^2*lmuH)/279936000 + 
           (4134923*cA*cR*lmuH)/15552000 - (24077*cR^2*lmuH)/1555200 + 
           (211*cA^2*lmmMS*lmuH)/345600 - (1571*cA*cR*lmmMS*lmuH)/518400 + 
           (347*cR^2*lmmMS*lmuH)/51840 - (583*cA^2*lmmMS^2*lmuH)/62208 - 
           (77*cA*cR*lmmMS^2*lmuH)/69120 + (973*cA^2*lmmMS^3*lmuH)/311040 + 
           (7*cA*cR*lmmMS^3*lmuH)/1280 + (7*cA^2*lmmMS^4*lmuH)/30720 + 
           (11737*cA^2*lmuH^2)/518400 + (62773*cA*cR*lmuH^2)/1036800 - 
           (11*cR^2*lmuH^2)/6480 - (1307*cA^2*lmmMS*lmuH^2)/103680 - 
           (227*cA*cR*lmmMS*lmuH^2)/69120 + (77*cA^2*lmmMS^2*lmuH^2)/34560 + 
           (7*cA*cR*lmmMS^2*lmuH^2)/1920 + (7*cA^2*lmmMS^3*lmuH^2)/9216 - 
           (11*cA^2*lmuH^3)/2592 + (557*cA*cR*lmuH^3)/207360 - 
           (7*cA^2*lmmMS*lmuH^3)/2880 + (49*cA^2*lmmMS^2*lmuH^3)/46080 - 
           (7*cA^2*lmuH^4)/2304 + (7*cA^2*lmmMS*lmuH^4)/18432 - 
           (119*cA^2*lmuH^5)/460800 - (9357947*cA*nh)/746496000 - 
           (1350473*cR*nh)/37324800 - (82457*cA*lmmMS*nh)/49766400 - 
           (2203*cR*lmmMS*nh)/622080 + (cA*lmmMS^2*nh)/1920 + 
           (7*cR*lmmMS^2*nh)/4320 - (7*cR*lmmMS^3*nh)/4320 + 
           (cA*lmuH*nh)/8640 - (cR*lmuH*nh)/540 - (cA*lmmMS*lmuH*nh)/1440 + 
           (cA*lmuH^2*nh)/5760 + (24731*cA^2*Pi^2)/167961600 - 
           (95843*cA*cR*Pi^2)/12441600 + (53*cR^2*Pi^2)/77760 + 
           (48121*cA^2*lmmMS*Pi^2)/11197440 + (2701*cA*cR*lmmMS*Pi^2)/
            414720 + (7*cR^2*lmmMS*Pi^2)/3840 + (2737*cA^2*lmmMS^2*Pi^2)/
            2488320 + (161*cA*cR*lmmMS^2*Pi^2)/92160 + 
           (133*cA^2*lmmMS^3*Pi^2)/3732480 + (113*cA^2*lmuH*Pi^2)/116640 - 
           (107*cA*cR*lmuH*Pi^2)/41472 + (791*cA^2*lmmMS*lmuH*Pi^2)/207360 + 
           (7*cA*cR*lmmMS*lmuH*Pi^2)/2560 + (133*cA^2*lmmMS^2*lmuH*Pi^2)/
            414720 + (203*cA^2*lmuH^2*Pi^2)/69120 + (7*cA*cR*lmuH^2*Pi^2)/
            23040 + (133*cA^2*lmmMS*lmuH^2*Pi^2)/138240 + 
           (133*cA^2*lmuH^3*Pi^2)/138240 + (cA*nh*Pi^2)/17280 + 
           (7*cR*nh*Pi^2)/41472 - (7*cR*lmmMS*nh*Pi^2)/34560 + 
           (548507*cA^2*Pi^4)/895795200 + (35807*cA*cR*Pi^4)/5529600 + 
           (48053*cR^2*Pi^4)/8294400 + (11053*cA^2*lmmMS*Pi^4)/74649600 - 
           (77*cA*cR*lmmMS*Pi^4)/259200 + (2051*cA^2*lmuH*Pi^4)/3110400 - 
           (77*cA*cR*lmuH*Pi^4)/86400 - (11*cA*nh*Pi^4)/6635520 - 
           (11*cR*nh*Pi^4)/207360 + (709*d44[pR1, pR2])/(288*NA) - 
           (17*Pi^4*d44[pR1, pR2])/(270*NA) - (157*cA^2*Pi^2*Log[2]^2)/
            221184 + (37*cA*cR*Pi^2*Log[2]^2)/46080 + 
           (341*cR^2*Pi^2*Log[2]^2)/276480 - (11*cA*nh*Pi^2*Log[2]^2)/
            221184 - (11*cR*nh*Pi^2*Log[2]^2)/6912 + (157*cA^2*Log[2]^4)/
            221184 - (37*cA*cR*Log[2]^4)/46080 - (341*cR^2*Log[2]^4)/276480 + 
           (11*cA*nh*Log[2]^4)/221184 + (11*cR*nh*Log[2]^4)/6912 + 
           (157*cA^2*PolyLog[4, 1/2])/9216 - (37*cA*cR*PolyLog[4, 1/2])/
            1920 - (341*cR^2*PolyLog[4, 1/2])/11520 + 
           (11*cA*nh*PolyLog[4, 1/2])/9216 + (11*cR*nh*PolyLog[4, 1/2])/288 - 
           (265864211*cA^2*Zeta[3])/716636160 - (7882933*cA*cR*Zeta[3])/
            3981312 - (351455*cR^2*Zeta[3])/442368 + 
           (6443047*cA^2*lmmMS*Zeta[3])/59719680 + 
           (194119*cA*cR*lmmMS*Zeta[3])/829440 + (47789*cR^2*lmmMS*Zeta[3])/
            184320 + (133*cA^2*lmmMS^2*Zeta[3])/207360 - 
           (7*cA*cR*lmmMS^2*Zeta[3])/864 + (12229*cA^2*lmuH*Zeta[3])/77760 - 
           (4571*cA*cR*lmuH*Zeta[3])/17280 + (35*cA^2*lmmMS*lmuH*Zeta[3])/
            1728 - (7*cA*cR*lmmMS*lmuH*Zeta[3])/144 + 
           (539*cA^2*lmuH^2*Zeta[3])/11520 - (7*cA*cR*lmuH^2*Zeta[3])/96 + 
           (1043*cA*nh*Zeta[3])/442368 + (6013*cR*nh*Zeta[3])/552960 + 
           (77*cA*lmmMS*nh*Zeta[3])/147456 + (77*cR*lmmMS*nh*Zeta[3])/4608 - 
           (3703*cA^2*Pi^2*Zeta[3])/746496 + (77*cA*cR*Pi^2*Zeta[3])/12960 + 
           (49*d44[pR1, pR2]*Zeta[3])/(18*NA) + (15701*cA^2*Zeta[5])/172800 + 
           (7*cA*cR*Zeta[5])/2160 - (7*cR^2*Zeta[5])/48)) + 
       rhoMS^2*((-1693230705064916383469*cA^3)/2480204251555430400000 - 
         (93296412142332641083*cA^2*cR)/14060114804736000000 - 
         (25158906940323869*cA*cR^2)/10042939146240000 + 
         (48257052259303*cR^3)/9299017728000 - cA^3/(8064*ep^6) + 
         (22200604413284767*cA^3*lmmMS)/41295442083840000 + 
         (10616073073516783*cA^2*cR*lmmMS)/1638708019200000 + 
         (3546466915781*cA*cR^2*lmmMS)/278691840000 + (1636459*cR^3*lmmMS)/
          552960 + (3429583668463*cA^3*lmmMS^2)/16387080192000 + 
         (1192585740019*cA^2*cR*lmmMS^2)/650280960000 + 
         (164988947*cA*cR^2*lmmMS^2)/77414400 - (1643*cR^3*lmmMS^2)/33600 + 
         (9285023*cA^3*lmmMS^3)/2194698240 - (7997*cA^2*cR*lmmMS^3)/
          13608000 - (127459*cA*cR^2*lmmMS^3)/1209600 - 
         (3*cR^3*lmmMS^3)/112 - (33241*cA^3*lmmMS^4)/104509440 - 
         (80063*cA^2*cR*lmmMS^4)/29030400 - (25*cA*cR^2*lmmMS^4)/896 - 
         (61*cA^3*lmmMS^5)/3870720 - (31*cA^2*cR*lmmMS^5)/53760 - 
         (cA^3*lmmMS^6)/5806080 + (510352200969343*cA^3*lmuH)/
          13765147361280000 + (429180378836219*cA^2*cR*lmuH)/
          234101145600000 + (530893191821*cA*cR^2*lmuH)/167215104000 + 
         (343801815607*cA^3*lmmMS*lmuH)/2731180032000 + 
         (1152961591667*cA^2*cR*lmmMS*lmuH)/975421440000 + 
         (40429667*cA*cR^2*lmmMS*lmuH)/27648000 + (201323*cA^3*lmmMS^2*lmuH)/
          24385536 - (45679*cA^2*cR*lmmMS^2*lmuH)/9072000 - 
         (127*cA*cR^2*lmmMS^2*lmuH)/2880 - (20609*cA^3*lmmMS^3*lmuH)/
          17418240 - (53419*cA^2*cR*lmmMS^3*lmuH)/3628800 - 
         (3*cA*cR^2*lmmMS^3*lmuH)/112 - (13*cA^3*lmmMS^4*lmuH)/86016 - 
         (5*cA^2*cR*lmmMS^4*lmuH)/1792 - (cA^3*lmmMS^5*lmuH)/322560 - 
         (8443254977*cA^3*lmuH^2)/1820786688000 + 
         (17307474637*cA^2*cR*lmuH^2)/92897280000 + (57949169*cA*cR^2*lmuH^2)/
          232243200 + (94153*cA^3*lmmMS*lmuH^2)/10160640 - 
         (77633*cA^2*cR*lmmMS*lmuH^2)/18144000 - (811*cA*cR^2*lmmMS*lmuH^2)/
          403200 - (4163*cA^3*lmmMS^2*lmuH^2)/3870720 - 
         (1273*cA^2*cR*lmmMS^2*lmuH^2)/86400 - (3*cA*cR^2*lmmMS^2*lmuH^2)/
          448 - (73*cA^3*lmmMS^3*lmuH^2)/129024 - (cA^2*cR*lmmMS^3*lmuH^2)/
          192 - (cA^3*lmmMS^4*lmuH^2)/43008 + (100333*cA^3*lmuH^3)/20321280 - 
         (27997*cA^2*cR*lmuH^3)/13608000 + (2089*cA^3*lmmMS*lmuH^3)/1935360 - 
         (467*cA^2*cR*lmmMS*lmuH^3)/113400 - (131*cA^3*lmmMS^2*lmuH^3)/
          129024 - (cA^2*cR*lmmMS^2*lmuH^3)/224 - (cA^3*lmmMS^3*lmuH^3)/
          10752 + (14059*cA^3*lmuH^4)/7741440 + (13*cA^2*cR*lmuH^4)/28350 - 
         (31*cA^3*lmmMS*lmuH^4)/36864 - (cA^2*cR*lmmMS*lmuH^4)/672 - 
         (3*cA^3*lmmMS^2*lmuH^4)/14336 - (299*cA^3*lmuH^5)/1290240 - 
         (9*cA^3*lmmMS*lmuH^5)/35840 - (9*cA^3*lmuH^6)/71680 + 
         (14678335674706727809*cA^2*nh)/129915460795760640000 + 
         (2064700580363372047*cA*cR*nh)/3977003901911040000 - 
         (14257871555639*cR^2*nh)/11588006707200 - 
         (99949443569*cA^2*lmmMS*nh)/13655900160000 + 
         (127880006459*cA*cR*lmmMS*nh)/936404582400 + 
         (41161189*cR^2*lmmMS*nh)/928972800 - (131150851*cA^2*lmmMS^2*nh)/
          57802752000 + (1112407*cA*cR*lmmMS^2*nh)/35389440 + 
         (799*cR^2*lmmMS^2*nh)/302400 - (817*cA^2*lmmMS^3*nh)/1612800 + 
         (109*cA*cR*lmmMS^3*nh)/20160 + (cR^2*lmmMS^3*nh)/224 + 
         (25*cA*cR*lmmMS^4*nh)/16128 - (62547925369*cA^2*lmuH*nh)/
          18207866880000 + (1205444449*cA*cR*lmuH*nh)/24772608000 - 
         (49*cR^2*lmuH*nh)/25920 + (102257149*cA^2*lmmMS*lmuH*nh)/
          86704128000 + (721069*cA*cR*lmmMS*lmuH*nh)/74317824 - 
         (cR^2*lmmMS*lmuH*nh)/160 - (43*cA^2*lmmMS^2*lmuH*nh)/537600 - 
         (19*cA*cR*lmmMS^2*lmuH*nh)/40320 + (cA*cR*lmmMS^3*lmuH*nh)/672 + 
         (413796349*cA^2*lmuH^2*nh)/520224768000 - (22479131*cA*cR*lmuH^2*nh)/
          11147673600 + (43*cA^2*lmmMS*lmuH^2*nh)/107520 - 
         (13*cA*cR*lmmMS*lmuH^2*nh)/4032 + (cA*cR*lmmMS^2*lmuH^2*nh)/2688 + 
         (43*cA^2*lmuH^3*nh)/230400 - (7*cA*cR*lmuH^3*nh)/5760 - 
         (67355344787*cA*nh^2)/15941173248000 + (5190943231*cR*nh^2)/
          110361968640 - (cA*lmmMS*nh^2)/345600 + (5*cR*lmmMS*nh^2)/10368 + 
         (5*cR*lmmMS^2*nh^2)/12096 - (cR*lmmMS^3*nh^2)/6048 + 
         (cA*lmuH*nh^2)/345600 + ((-61*cA^3)/32256 - (cA^3*lmmMS)/8064 - 
           (cA^3*lmuH)/2688 + (5*cA^2*nl)/16128)/ep^5 + 
         (1172859885221*cA^3*Pi^2)/147483721728000 + 
         (394141139569*cA^2*cR*Pi^2)/5852528640000 + (277497541*cA*cR^2*Pi^2)/
          3483648000 - (202193*cA^3*lmmMS*Pi^2)/162570240 - 
         (61169*cA^2*cR*lmmMS*Pi^2)/10368000 - (26869*cA*cR^2*lmmMS*Pi^2)/
          2419200 - (92173*cA^3*lmmMS^2*Pi^2)/209018880 - 
         (75197*cA^2*cR*lmmMS^2*Pi^2)/29030400 - (5*cA*cR^2*lmmMS^2*Pi^2)/
          896 - (59*cA^3*lmmMS^3*Pi^2)/2612736 - (cA^2*cR*lmmMS^3*Pi^2)/
          4032 - (cA^3*lmmMS^4*Pi^2)/2322432 - (40007*cA^3*lmuH*Pi^2)/
          27095040 - (23441*cA^2*cR*lmuH*Pi^2)/54432000 - 
         (811*cA*cR^2*lmuH*Pi^2)/2419200 - (16309*cA^3*lmmMS*lmuH*Pi^2)/
          8709120 - (31411*cA^2*cR*lmmMS*lmuH*Pi^2)/7257600 - 
         (cA*cR^2*lmmMS*lmuH*Pi^2)/448 - (59*cA^3*lmmMS^2*lmuH*Pi^2)/290304 - 
         (cA^2*cR*lmmMS^2*lmuH*Pi^2)/1344 - (cA^3*lmmMS^3*lmuH*Pi^2)/193536 - 
         (23591*cA^3*lmuH^2*Pi^2)/11612160 - (7043*cA^2*cR*lmuH^2*Pi^2)/
          7257600 - (59*cA^3*lmmMS*lmuH^2*Pi^2)/96768 - 
         (cA^2*cR*lmmMS*lmuH^2*Pi^2)/1344 - (cA^3*lmmMS^2*lmuH^2*Pi^2)/
          43008 - (59*cA^3*lmuH^3*Pi^2)/96768 - (cA^2*cR*lmuH^3*Pi^2)/4032 - 
         (cA^3*lmmMS*lmuH^3*Pi^2)/21504 - (cA^3*lmuH^4*Pi^2)/28672 - 
         (272288771*cA^2*nh*Pi^2)/1560674304000 + (55879909*cA*cR*nh*Pi^2)/
          33443020800 - (43*cA^2*lmmMS*nh*Pi^2)/537600 + 
         (83*cA*cR*lmmMS*nh*Pi^2)/120960 + (5*cA*cR*lmmMS^2*nh*Pi^2)/16128 - 
         (43*cA^2*lmuH*nh*Pi^2)/1612800 + (17*cA*cR*lmuH*nh*Pi^2)/241920 + 
         (cA*cR*lmmMS*lmuH*nh*Pi^2)/8064 - (445166279297893*cA^3*Pi^4)/
          4591057895424000 + (7067707224577*cA^2*cR*Pi^4)/255058771968000 + 
         (27413782101703*cA*cR^2*Pi^4)/31882346496000 + 
         (1275956879047*cR^3*Pi^4)/7970586624000 + 
         (790058539*cA^3*lmmMS*Pi^4)/133772083200 + 
         (40389437*cA^2*cR*lmmMS*Pi^4)/825753600 + 
         (3202289*cA*cR^2*lmmMS*Pi^4)/51609600 + (11*cA^3*lmmMS^2*Pi^4)/
          3483648 + (93468691*cA^3*lmuH*Pi^4)/44590694400 + 
         (13411519*cA^2*cR*lmuH*Pi^4)/825753600 + (3202289*cA*cR^2*lmuH*Pi^4)/
          154828800 + (11*cA^3*lmmMS*lmuH*Pi^4)/580608 + 
         (11*cA^3*lmuH^2*Pi^4)/387072 - (440018935541*cA^2*nh*Pi^4)/
          58859716608000 + (2412227996693*cA*cR*nh*Pi^4)/29429858304000 + 
         (812023139*cR^2*nh*Pi^4)/2786918400 - (1921*cA^2*lmmMS*nh*Pi^4)/
          31457280 + (48773*cA*cR*lmmMS*nh*Pi^4)/23592960 - 
         (1921*cA^2*lmuH*nh*Pi^4)/94371840 + (48773*cA*cR*lmuH*nh*Pi^4)/
          70778880 - (77671*cA^3*Pi^6)/2194698240 + 
         ((-34051*cA^3)/4354560 + (13*cA^2*cR)/18900 - (61*cA^3*lmmMS)/
            32256 - (cA^2*cR*lmmMS)/448 - (cA^3*lmmMS^2)/16128 - 
           (13*cA^3*lmuH)/3584 - (cA^3*lmmMS*lmuH)/2688 - 
           (cA^3*lmuH^2)/1792 + ((2185*cA^2)/870912 + (5*cA^2*lmmMS)/16128 + 
             (cA^2*lmuH)/1792)*nl - (85*cA*nl^2)/435456 - (cA^3*Pi^2)/96768)/
          ep^4 + (271161840307*d44[pR1, pA1])/(105670656000*NA) - 
         (19*lmmMS*d44[pR1, pA1])/(13824*NA) + (19*lmuH*d44[pR1, pA1])/
          (13824*NA) - (622593692081*Pi^4*d44[pR1, pA1])/(3985293312000*NA) + 
         (1234082295799*nh*d44[pR1, pR2])/(2789705318400*NA) - 
         (16542457*nh*Pi^4*d44[pR1, pR2])/(1857945600*NA) - 
         (11639217467*cA^3*Pi^4*Log[2])/151820697600 + 
         (759509266601*cA^2*cR*Pi^4*Log[2])/2656862208000 - 
         (32838049331*cA*cR^2*Pi^4*Log[2])/166053888000 - 
         (952373*cR^3*Pi^4*Log[2])/15444000 + (1921*cA^2*nh*Pi^4*Log[2])/
          15728640 - (48773*cA*cR*nh*Pi^4*Log[2])/11796480 - 
         (2629807*Pi^4*d44[pR1, pA1]*Log[2])/(6006000*NA) - 
         (8843322877177*cA^3*Pi^2*Log[2]^2)/25505877196800 - 
         (1680324271*cA^2*cR*Pi^2*Log[2]^2)/2699034624 + 
         (1194859565147*cA*cR^2*Pi^2*Log[2]^2)/531372441600 + 
         (53924189227*cR^3*Pi^2*Log[2]^2)/66421555200 + 
         (8029*cA^3*lmmMS*Pi^2*Log[2]^2)/3932160 + 
         (1731*cA^2*cR*lmmMS*Pi^2*Log[2]^2)/917504 - 
         (10271*cA*cR^2*lmmMS*Pi^2*Log[2]^2)/860160 + 
         (8029*cA^3*lmuH*Pi^2*Log[2]^2)/11796480 + 
         (577*cA^2*cR*lmuH*Pi^2*Log[2]^2)/917504 - 
         (10271*cA*cR^2*lmuH*Pi^2*Log[2]^2)/2580480 - 
         (2600673247*cA^2*nh*Pi^2*Log[2]^2)/98099527680 + 
         (141867250507*cA*cR*nh*Pi^2*Log[2]^2)/490497638400 + 
         (9533399*cR^2*nh*Pi^2*Log[2]^2)/9289728 - 
         (113*cA^2*lmmMS*nh*Pi^2*Log[2]^2)/524288 + 
         (2869*cA*cR*lmmMS*nh*Pi^2*Log[2]^2)/393216 - 
         (113*cA^2*lmuH*nh*Pi^2*Log[2]^2)/1572864 + 
         (2869*cA*cR*lmuH*nh*Pi^2*Log[2]^2)/1179648 - 
         (4494400219*Pi^2*d44[pR1, pA1]*Log[2]^2)/(16605388800*NA) - 
         (1010393*nh*Pi^2*d44[pR1, pR2]*Log[2]^2)/(77414400*NA) - 
         (1228186409*cA^3*Pi^2*Log[2]^3)/10627448832 + 
         (52312528153*cA^2*cR*Pi^2*Log[2]^3)/132843110400 - 
         (1505897923*cA*cR^2*Pi^2*Log[2]^3)/8302694400 - 
         (137239*cR^3*Pi^2*Log[2]^3)/772200 + (113*cA^2*nh*Pi^2*Log[2]^3)/
          786432 - (2869*cA*cR*nh*Pi^2*Log[2]^3)/589824 - 
         (49619*Pi^2*d44[pR1, pA1]*Log[2]^3)/(75075*NA) + 
         (8843322877177*cA^3*Log[2]^4)/25505877196800 + 
         (1680324271*cA^2*cR*Log[2]^4)/2699034624 - 
         (1194859565147*cA*cR^2*Log[2]^4)/531372441600 - 
         (53924189227*cR^3*Log[2]^4)/66421555200 - (8029*cA^3*lmmMS*Log[2]^4)/
          3932160 - (1731*cA^2*cR*lmmMS*Log[2]^4)/917504 + 
         (10271*cA*cR^2*lmmMS*Log[2]^4)/860160 - (8029*cA^3*lmuH*Log[2]^4)/
          11796480 - (577*cA^2*cR*lmuH*Log[2]^4)/917504 + 
         (10271*cA*cR^2*lmuH*Log[2]^4)/2580480 + 
         (2600673247*cA^2*nh*Log[2]^4)/98099527680 - 
         (141867250507*cA*cR*nh*Log[2]^4)/490497638400 - 
         (9533399*cR^2*nh*Log[2]^4)/9289728 + (113*cA^2*lmmMS*nh*Log[2]^4)/
          524288 - (2869*cA*cR*lmmMS*nh*Log[2]^4)/393216 + 
         (113*cA^2*lmuH*nh*Log[2]^4)/1572864 - (2869*cA*cR*lmuH*nh*Log[2]^4)/
          1179648 + (4494400219*d44[pR1, pA1]*Log[2]^4)/(16605388800*NA) + 
         (1010393*nh*d44[pR1, pR2]*Log[2]^4)/(77414400*NA) + 
         (1228186409*cA^3*Log[2]^5)/17712414720 - 
         (52312528153*cA^2*cR*Log[2]^5)/221405184000 + 
         (1505897923*cA*cR^2*Log[2]^5)/13837824000 + (137239*cR^3*Log[2]^5)/
          1287000 - (113*cA^2*nh*Log[2]^5)/1310720 + (2869*cA*cR*nh*Log[2]^5)/
          983040 + (49619*d44[pR1, pA1]*Log[2]^5)/(125125*NA) + 
         (8843322877177*cA^3*PolyLog[4, 1/2])/1062744883200 + 
         (1680324271*cA^2*cR*PolyLog[4, 1/2])/112459776 - 
         (1194859565147*cA*cR^2*PolyLog[4, 1/2])/22140518400 - 
         (53924189227*cR^3*PolyLog[4, 1/2])/2767564800 - 
         (8029*cA^3*lmmMS*PolyLog[4, 1/2])/163840 - 
         (5193*cA^2*cR*lmmMS*PolyLog[4, 1/2])/114688 + 
         (10271*cA*cR^2*lmmMS*PolyLog[4, 1/2])/35840 - 
         (8029*cA^3*lmuH*PolyLog[4, 1/2])/491520 - 
         (1731*cA^2*cR*lmuH*PolyLog[4, 1/2])/114688 + 
         (10271*cA*cR^2*lmuH*PolyLog[4, 1/2])/107520 + 
         (2600673247*cA^2*nh*PolyLog[4, 1/2])/4087480320 - 
         (141867250507*cA*cR*nh*PolyLog[4, 1/2])/20437401600 - 
         (9533399*cR^2*nh*PolyLog[4, 1/2])/387072 + 
         (339*cA^2*lmmMS*nh*PolyLog[4, 1/2])/65536 - 
         (2869*cA*cR*lmmMS*nh*PolyLog[4, 1/2])/16384 + 
         (113*cA^2*lmuH*nh*PolyLog[4, 1/2])/65536 - 
         (2869*cA*cR*lmuH*nh*PolyLog[4, 1/2])/49152 + 
         (4494400219*d44[pR1, pA1]*PolyLog[4, 1/2])/(691891200*NA) + 
         (1010393*nh*d44[pR1, pR2]*PolyLog[4, 1/2])/(3225600*NA) - 
         (1228186409*cA^3*PolyLog[5, 1/2])/147603456 + 
         (52312528153*cA^2*cR*PolyLog[5, 1/2])/1845043200 - 
         (1505897923*cA*cR^2*PolyLog[5, 1/2])/115315200 - 
         (137239*cR^3*PolyLog[5, 1/2])/10725 + (339*cA^2*nh*PolyLog[5, 1/2])/
          32768 - (2869*cA*cR*nh*PolyLog[5, 1/2])/8192 - 
         (1190856*d44[pR1, pA1]*PolyLog[5, 1/2])/(25025*NA) + 
         nl^3*(lmmMS/72576 + lmmMS^2/48384 + lmmMS^3/217728 + Pi^2/290304 + 
           (lmmMS*Pi^2)/435456 - Zeta[3]/108864) + 
         (93832295889751801*cA^3*Zeta[3])/12854962107187200 + 
         (547397196453599*cA^2*cR*Zeta[3])/108206751744000 - 
         (6999757602105227*cA*cR^2*Zeta[3])/148784283648000 - 
         (6206584615927*cR^3*Zeta[3])/476872704000 - 
         (993781262683*cA^3*lmmMS*Zeta[3])/1070176665600 - 
         (15692460643*cA^2*cR*lmmMS*Zeta[3])/1698693120 - 
         (39000105743*cA*cR^2*lmmMS*Zeta[3])/2477260800 - 
         (2179367*cR^3*lmmMS*Zeta[3])/860160 - (484616413*cA^3*lmmMS^2*
           Zeta[3])/2972712960 - (79358449*cA^2*cR*lmmMS^2*Zeta[3])/
          55050240 - (2179367*cA*cR^2*lmmMS^2*Zeta[3])/1146880 + 
         (5*cA^3*lmmMS^3*Zeta[3])/41472 - (89075568187*cA^3*lmuH*Zeta[3])/
          356725555200 - (168133226123*cA^2*cR*lmuH*Zeta[3])/59454259200 - 
         (1537532983*cA*cR^2*lmuH*Zeta[3])/353894400 - 
         (6558691*cA^3*lmmMS*lmuH*Zeta[3])/70778880 - 
         (8707241*cA^2*cR*lmmMS*lmuH*Zeta[3])/9175040 - 
         (2179367*cA*cR^2*lmmMS*lmuH*Zeta[3])/1720320 + 
         (5*cA^3*lmmMS^2*lmuH*Zeta[3])/4608 + (299827*cA^3*lmuH^2*Zeta[3])/
          330301440 - (26510843*cA^2*cR*lmuH^2*Zeta[3])/165150720 - 
         (2179367*cA*cR^2*lmuH^2*Zeta[3])/10321920 + 
         (5*cA^3*lmmMS*lmuH^2*Zeta[3])/1536 + (5*cA^3*lmuH^3*Zeta[3])/1536 + 
         (13106227531090721*cA^2*nh*Zeta[3])/39279050883072000 - 
         (32711745736296251*cA*cR*nh*Zeta[3])/6546508480512000 - 
         (4526475718003*cR^2*nh*Zeta[3])/286123622400 + 
         (696661*cA^2*lmmMS*nh*Zeta[3])/47185920 - 
         (504871753*cA*cR*lmmMS*nh*Zeta[3])/1981808640 - 
         (165157*cR^2*lmmMS*nh*Zeta[3])/2752512 + 
         (2373*cA^2*lmmMS^2*nh*Zeta[3])/2097152 - 
         (20083*cA*cR*lmmMS^2*nh*Zeta[3])/524288 + 
         (449939*cA^2*lmuH*nh*Zeta[3])/94371840 - 
         (23506933*cA*cR*lmuH*nh*Zeta[3])/283115520 + 
         (791*cA^2*lmmMS*lmuH*nh*Zeta[3])/1048576 - 
         (20083*cA*cR*lmmMS*lmuH*nh*Zeta[3])/786432 + 
         (791*cA^2*lmuH^2*nh*Zeta[3])/6291456 - 
         (20083*cA*cR*lmuH^2*nh*Zeta[3])/4718592 + 
         (484038617*cA*nh^2*Zeta[3])/141699317760 - 
         (317801767*cR*nh^2*Zeta[3])/8174960640 - 
         (184408991*cA^3*Pi^2*Zeta[3])/26754416640 - 
         (26311163*cA^2*cR*Pi^2*Zeta[3])/495452160 - 
         (2179367*cA*cR^2*Pi^2*Zeta[3])/30965760 - 
         (25*cA^3*lmmMS*Pi^2*Zeta[3])/290304 - (25*cA^3*lmuH*Pi^2*Zeta[3])/
          96768 + (791*cA^2*nh*Pi^2*Zeta[3])/18874368 - 
         (20083*cA*cR*nh*Pi^2*Zeta[3])/14155776 + 
         (25424010059923*d44[pR1, pA1]*Zeta[3])/(2324754432000*NA) + 
         (5991575341*nh*d44[pR1, pR2]*Zeta[3])/(22960537600*NA) - 
         (2683*cA^3*Zeta[3]^2)/145152 + ((-2449987*cA^3)/365783040 + 
           (643*cA^2*cR)/224000 - (33997*cA^3*lmmMS)/4354560 - 
           (21061*cA^2*cR*lmmMS)/1209600 - (61*cA^3*lmmMS^2)/64512 - 
           (3*cA^2*cR*lmmMS^2)/896 - (cA^3*lmmMS^3)/48384 - 
           (21113*cA^3*lmuH)/2903040 + (13*cA^2*cR*lmuH)/9450 - 
           (13*cA^3*lmmMS*lmuH)/3584 - (cA^2*cR*lmmMS*lmuH)/224 - 
           (cA^3*lmmMS^2*lmuH)/5376 - (73*cA^3*lmuH^2)/21504 - 
           (cA^3*lmmMS*lmuH^2)/1792 - (cA^3*lmuH^3)/1792 + 
           ((-1763*cA)/2612736 - (85*cA*lmmMS)/435456 - (11*cA*lmuH)/72576)*
            nl^2 + nl^3/36288 - (59*cA^3*Pi^2)/435456 - (cA^2*cR*Pi^2)/5376 - 
           (cA^3*lmmMS*Pi^2)/96768 - (cA^3*lmuH*Pi^2)/32256 + 
           nl*((3829*cA^2)/933120 - (4187*cA*cR)/3628800 + (2185*cA^2*lmmMS)/
              870912 + (cA*cR*lmmMS)/384 + (5*cA^2*lmmMS^2)/32256 + 
             (91*cA^2*lmuH)/41472 + (cA^2*lmmMS*lmuH)/1792 + 
             (5*cA^2*lmuH^2)/10752 + (19*cA^2*Pi^2)/870912) + 
           (5*cA^3*Zeta[3])/6912)/ep^3 + nl^2*((26032591*cA)/98761420800 + 
           (10226467*cR)/21946982400 + (1448273*cA*lmmMS)/4115059200 + 
           (112859*cR*lmmMS)/67737600 - (229*cA*lmmMS^2)/2177280 - 
           (4703*cR*lmmMS^2)/10886400 - (1763*cA*lmmMS^3)/15676416 - 
           (cR*lmmMS^3)/4032 - (85*cA*lmmMS^4)/10450944 + 
           (21407*cA*lmuH)/78382080 - (1103*cR*lmuH)/5806080 + 
           (89*cA*lmmMS*lmuH)/725760 + (cR*lmmMS*lmuH)/483840 - 
           (7*cA*lmmMS^2*lmuH)/124416 - (11*cA*lmmMS^3*lmuH)/435456 + 
           (cA*lmuH^2)/10368 + (cA*lmmMS*lmuH^2)/145152 - (cA*lmmMS^2*lmuH^2)/
            48384 - (281*cA*Pi^2)/6531840 - (3061*cR*Pi^2)/130636800 - 
           (2129*cA*lmmMS*Pi^2)/31352832 - (cR*lmmMS*Pi^2)/12096 - 
           (79*cA*lmmMS^2*Pi^2)/10450944 - (43*cA*lmuH*Pi^2)/5225472 - 
           (17*cA*lmmMS*lmuH*Pi^2)/870912 - (cA*lmuH^2*Pi^2)/290304 - 
           (863*cA*Pi^4)/209018880 + (cR*Pi^4)/120960 + (10553*cA*Zeta[3])/
            195955200 - (7*cR*Zeta[3])/14400 - (23*cA*lmmMS*Zeta[3])/186624 + 
           (cR*lmmMS*Zeta[3])/2016 - (31*cA*lmuH*Zeta[3])/217728) + 
         ((386256346807*cA^3)/8193540096000 + (7642466017*cA^2*cR)/
            19906560000 + (57949169*cA*cR^2)/116121600 - (1382677*cA^3*lmmMS)/
            365783040 - (243947*cA^2*cR*lmmMS)/9072000 - (811*cA*cR^2*lmmMS)/
            201600 - (33889*cA^3*lmmMS^2)/8709120 - (54947*cA^2*cR*lmmMS^2)/
            2419200 - (3*cA*cR^2*lmmMS^2)/224 - (61*cA^3*lmmMS^3)/193536 - 
           (cA^2*cR*lmmMS^3)/384 - (cA^3*lmmMS^4)/193536 + 
           (201133*cA^3*lmuH)/60963840 + (6323*cA^2*cR*lmuH)/9072000 - 
           (21041*cA^3*lmmMS*lmuH)/2903040 - (11161*cA^2*cR*lmmMS*lmuH)/
            604800 - (13*cA^3*lmmMS^2*lmuH)/7168 - (3*cA^2*cR*lmmMS^2*lmuH)/
            448 - (cA^3*lmmMS^3*lmuH)/16128 - (4307*cA^3*lmuH^2)/1935360 + 
           (13*cA^2*cR*lmuH^2)/9450 - (73*cA^3*lmmMS*lmuH^2)/21504 - 
           (cA^2*cR*lmmMS*lmuH^2)/224 - (cA^3*lmmMS^2*lmuH^2)/3584 - 
           (131*cA^3*lmuH^3)/64512 - (cA^3*lmmMS*lmuH^3)/1792 - 
           (3*cA^3*lmuH^4)/7168 - (9563651*cA^2*nh)/260112384000 + 
           (35581669*cA*cR*nh)/5573836800 - (43*cA^2*lmmMS*nh)/268800 - 
           (cA*cR*lmmMS*nh)/5040 + (cA*cR*lmmMS^2*nh)/1344 + 
           (43*cA^2*lmuH*nh)/268800 - (cA*cR*lmuH*nh)/960 + 
           (1/24192 + lmmMS/36288)*nl^3 - (92497*cA^3*Pi^2)/104509440 - 
           (21893*cA^2*cR*Pi^2)/14515200 - (59*cA^3*lmmMS*Pi^2)/435456 - 
           (cA^2*cR*lmmMS*Pi^2)/2688 - (cA^3*lmmMS^2*Pi^2)/193536 - 
           (59*cA^3*lmuH*Pi^2)/145152 - (cA^2*cR*lmuH*Pi^2)/2688 - 
           (cA^3*lmmMS*lmuH*Pi^2)/32256 - (cA^3*lmuH^2*Pi^2)/21504 + 
           (11*cA^3*Pi^4)/1741824 + nl^2*((-191*cA)/544320 + 
             (3239*cR)/10886400 - (1763*cA*lmmMS)/2612736 - (cR*lmmMS)/2016 - 
             (85*cA*lmmMS^2)/870912 - (7*cA*lmuH)/62208 - (11*cA*lmmMS*lmuH)/
              72576 - (cA*lmuH^2)/24192 - (79*cA*Pi^2)/5225472) - 
           (41348917*cA^3*Zeta[3])/1486356480 - (26695163*cA^2*cR*Zeta[3])/
            82575360 - (2179367*cA*cR^2*Zeta[3])/5160960 + 
           (5*cA^3*lmmMS*Zeta[3])/6912 + (5*cA^3*lmuH*Zeta[3])/2304 + 
           (791*cA^2*nh*Zeta[3])/3145728 - (20083*cA*cR*nh*Zeta[3])/2359296 + 
           nl*((-20513*cA^2)/18662400 - (933851*cA*cR)/254016000 + 
             (7253*cA^2*lmmMS)/1866240 + (2123*cA*cR*lmmMS)/290304 + 
             (2185*cA^2*lmmMS^2)/1741824 + (17*cA*cR*lmmMS^2)/5376 + 
             (5*cA^2*lmmMS^3)/96768 + (221*cA^2*lmuH)/1088640 - 
             (347*cA*cR*lmuH)/345600 + (91*cA^2*lmmMS*lmuH)/41472 + 
             (cA*cR*lmmMS*lmuH)/448 + (cA^2*lmmMS^2*lmuH)/3584 + 
             (19*cA^2*lmuH^2)/27648 + (5*cA^2*lmmMS*lmuH^2)/10752 + 
             (cA^2*lmuH^3)/4608 + (205*cA^2*Pi^2)/870912 + (cA*cR*Pi^2)/
              4608 + (19*cA^2*lmmMS*Pi^2)/870912 + (19*cA^2*lmuH*Pi^2)/
              290304 + (19*cA^2*Zeta[3])/145152 - (5*cA*cR*Zeta[3])/3024))/
          ep^2 + (1139225702687*cA^3*Zeta[5])/141699317760 - 
         (4786918232417*cA^2*cR*Zeta[5])/118082764800 + 
         (13886206541*cA*cR^2*Zeta[5])/1054310400 + (38711553*cR^3*Zeta[5])/
          3203200 - (437*cA^3*lmmMS*Zeta[5])/80640 - (437*cA^3*lmuH*Zeta[5])/
          26880 - (17515*cA^2*nh*Zeta[5])/2097152 + 
         (8433379*cA*cR*nh*Zeta[5])/33030144 + (185105929*d44[pR1, pA1]*
           Zeta[5])/(3603600*NA) + ((8287965781548709*cA^3)/
            41295442083840000 + (65931028410203*cA^2*cR)/26011238400000 + 
           (683878997981*cA*cR^2)/167215104000 + (1180231426021*cA^3*lmmMS)/
            8193540096000 + (1158908141171*cA^2*cR*lmmMS)/975421440000 + 
           (31286701*cA*cR^2*lmmMS)/21504000 + (1462583*cA^3*lmmMS^2)/
            731566080 - (216617*cA^2*cR*lmmMS^2)/9072000 - 
           (173*cA*cR^2*lmmMS^2)/2520 - (33673*cA^3*lmmMS^3)/26127360 - 
           (93019*cA^2*cR*lmmMS^3)/7257600 - (3*cA*cR^2*lmmMS^3)/112 - 
           (61*cA^3*lmmMS^4)/774144 - (5*cA^2*cR*lmmMS^4)/3584 - 
           (cA^3*lmmMS^5)/967680 + (91039996669*cA^3*lmuH)/2731180032000 + 
           (52542782183*cA^2*cR*lmuH)/139345920000 + (57949169*cA*cR^2*lmuH)/
            116121600 + (430147*cA^3*lmmMS*lmuH)/60963840 - 
           (97759*cA^2*cR*lmmMS*lmuH)/9072000 - (811*cA*cR^2*lmmMS*lmuH)/
            201600 - (20897*cA^3*lmmMS^2*lmuH)/5806080 - 
           (30197*cA^2*cR*lmmMS^2*lmuH)/1209600 - (3*cA*cR^2*lmmMS^2*lmuH)/
            224 - (13*cA^3*lmmMS^3*lmuH)/21504 - (cA^2*cR*lmmMS^3*lmuH)/192 - 
           (cA^3*lmmMS^4*lmuH)/64512 + (66547*cA^3*lmuH^2)/10160640 - 
           (5519*cA^2*cR*lmuH^2)/3024000 - (4259*cA^3*lmmMS*lmuH^2)/1935360 - 
           (6211*cA^2*cR*lmmMS*lmuH^2)/604800 - (73*cA^3*lmmMS^2*lmuH^2)/
            43008 - (3*cA^2*cR*lmmMS^2*lmuH^2)/448 - (cA^3*lmmMS^3*lmuH^2)/
            10752 + (2057*cA^3*lmuH^3)/1935360 + (13*cA^2*cR*lmuH^3)/14175 - 
           (131*cA^3*lmmMS*lmuH^3)/64512 - (cA^2*cR*lmmMS*lmuH^3)/336 - 
           (cA^3*lmmMS^2*lmuH^3)/3584 - (31*cA^3*lmuH^4)/36864 - 
           (3*cA^3*lmmMS*lmuH^4)/7168 - (9*cA^3*lmuH^5)/35840 - 
           (74810945911*cA^2*nh)/27311800320000 + (37000897543*cA*cR*nh)/
            668860416000 - (91870211*cA^2*lmmMS*nh)/86704128000 + 
           (37931749*cA*cR*lmmMS*nh)/1857945600 - (43*cA^2*lmmMS^2*nh)/
            107520 + (cA*cR*lmmMS^2*nh)/336 + (cA*cR*lmmMS^3*nh)/672 + 
           (237356029*cA^2*lmuH*nh)/260112384000 + (2035429*cA*cR*lmuH*nh)/
            5573836800 + (43*cA^2*lmmMS*lmuH*nh)/268800 - 
           (23*cA*cR*lmmMS*lmuH*nh)/10080 + (cA*cR*lmmMS^2*lmuH*nh)/1344 + 
           (43*cA^2*lmuH^2*nh)/179200 - (cA*cR*lmuH^2*nh)/640 - 
           (268813*cA^3*Pi^2)/162570240 - (482777*cA^2*cR*Pi^2)/217728000 - 
           (811*cA*cR^2*Pi^2)/2419200 - (92389*cA^3*lmmMS*Pi^2)/104509440 - 
           (46261*cA^2*cR*lmmMS*Pi^2)/14515200 - (cA*cR^2*lmmMS*Pi^2)/448 - 
           (59*cA^3*lmmMS^2*Pi^2)/870912 - (cA^2*cR*lmmMS^2*Pi^2)/2688 - 
           (cA^3*lmmMS^3*Pi^2)/580608 - (16327*cA^3*lmuH*Pi^2)/8709120 - 
           (11993*cA^2*cR*lmuH*Pi^2)/7257600 - (59*cA^3*lmmMS*lmuH*Pi^2)/
            145152 - (cA^2*cR*lmmMS*lmuH*Pi^2)/1344 - 
           (cA^3*lmmMS^2*lmuH*Pi^2)/64512 - (59*cA^3*lmuH^2*Pi^2)/96768 - 
           (cA^2*cR*lmuH^2*Pi^2)/2688 - (cA^3*lmmMS*lmuH^2*Pi^2)/21504 - 
           (cA^3*lmuH^3*Pi^2)/21504 - (43*cA^2*nh*Pi^2)/1612800 + 
           (17*cA*cR*nh*Pi^2)/241920 + (cA*cR*lmmMS*nh*Pi^2)/8064 + 
           (271655353*cA^3*Pi^4)/133772083200 + (1917577*cA^2*cR*Pi^4)/
            117964800 + (3202289*cA*cR^2*Pi^4)/154828800 + 
           (11*cA^3*lmmMS*Pi^4)/1741824 + (11*cA^3*lmuH*Pi^4)/580608 - 
           (1921*cA^2*nh*Pi^4)/94371840 + (48773*cA*cR*nh*Pi^4)/70778880 + 
           nl^3*(1/72576 + lmmMS/24192 + lmmMS^2/72576 + Pi^2/435456) + 
           (8029*cA^3*Pi^2*Log[2]^2)/11796480 + (577*cA^2*cR*Pi^2*Log[2]^2)/
            917504 - (10271*cA*cR^2*Pi^2*Log[2]^2)/2580480 - 
           (113*cA^2*nh*Pi^2*Log[2]^2)/1572864 + (2869*cA*cR*nh*Pi^2*
             Log[2]^2)/1179648 - (8029*cA^3*Log[2]^4)/11796480 - 
           (577*cA^2*cR*Log[2]^4)/917504 + (10271*cA*cR^2*Log[2]^4)/2580480 + 
           (113*cA^2*nh*Log[2]^4)/1572864 - (2869*cA*cR*nh*Log[2]^4)/
            1179648 - (8029*cA^3*PolyLog[4, 1/2])/491520 - 
           (1731*cA^2*cR*PolyLog[4, 1/2])/114688 + 
           (10271*cA*cR^2*PolyLog[4, 1/2])/107520 + 
           (113*cA^2*nh*PolyLog[4, 1/2])/65536 - 
           (2869*cA*cR*nh*PolyLog[4, 1/2])/49152 - 
           (356207694841*cA^3*Zeta[3])/1070176665600 - 
           (203302208707*cA^2*cR*Zeta[3])/59454259200 - 
           (469650883*cA*cR^2*Zeta[3])/91750400 - (152165791*cA^3*lmmMS*
             Zeta[3])/1486356480 - (26439163*cA^2*cR*lmmMS*Zeta[3])/
            27525120 - (2179367*cA*cR^2*lmmMS*Zeta[3])/1720320 + 
           (5*cA^3*lmmMS^2*Zeta[3])/13824 - (1281697*cA^3*lmuH*Zeta[3])/
            70778880 - (26633723*cA^2*cR*lmuH*Zeta[3])/82575360 - 
           (2179367*cA*cR^2*lmuH*Zeta[3])/5160960 + 
           (5*cA^3*lmmMS*lmuH*Zeta[3])/2304 + (5*cA^3*lmuH^2*Zeta[3])/1536 + 
           (123361*cA^2*nh*Zeta[3])/23592960 - (27925193*cA*cR*nh*Zeta[3])/
            283115520 + (791*cA^2*lmmMS*nh*Zeta[3])/1048576 - 
           (20083*cA*cR*lmmMS*nh*Zeta[3])/786432 + (791*cA^2*lmuH*nh*Zeta[3])/
            3145728 - (20083*cA*cR*lmuH*nh*Zeta[3])/2359296 - 
           (25*cA^3*Pi^2*Zeta[3])/290304 + nl^2*((2502481*cA)/8230118400 + 
             (13331*cR)/16934400 - (611*cA*lmmMS)/2177280 - 
             (881*cR*lmmMS)/3110400 - (1763*cA*lmmMS^2)/5225472 - 
             (cR*lmmMS^2)/2016 - (85*cA*lmmMS^3)/2612736 + (89*cA*lmuH)/
              725760 + (cR*lmuH)/483840 - (7*cA*lmmMS*lmuH)/62208 - 
             (11*cA*lmmMS^2*lmuH)/145152 + (cA*lmuH^2)/145152 - 
             (cA*lmmMS*lmuH^2)/24192 - (2129*cA*Pi^2)/31352832 - 
             (cR*Pi^2)/24192 - (79*cA*lmmMS*Pi^2)/5225472 - (17*cA*lmuH*Pi^2)/
              870912 - (23*cA*Zeta[3])/186624 + (cR*Zeta[3])/2016) + 
           nl*((-1077491291557*cA^2)/73741860864000 - (164745247753*cA*cR)/
              1365590016000 - (57840161*cR^2)/348364800 - 
             (1538203*cA^2*lmmMS)/457228800 - (27134347*cA*cR*lmmMS)/
              3048192000 + (17*cR^2*lmmMS)/75600 + (42563*cA^2*lmmMS^2)/
              26127360 + (56237*cA*cR*lmmMS^2)/7257600 + (cR^2*lmmMS^2)/224 + 
             (2185*cA^2*lmmMS^3)/5225472 + (25*cA*cR*lmmMS^3)/16128 + 
             (5*cA^2*lmmMS^4)/387072 - (105731*cA^2*lmuH)/76204800 + 
             (3435667*cA*cR*lmuH)/3048192000 - (13*cA^2*lmmMS*lmuH)/1088640 + 
             (2747*cA*cR*lmmMS*lmuH)/3628800 + (91*cA^2*lmmMS^2*lmuH)/82944 + 
             (cA*cR*lmmMS^2*lmuH)/384 + (cA^2*lmmMS^3*lmuH)/10752 - 
             (197*cA^2*lmuH^2)/207360 - (347*cA*cR*lmuH^2)/1036800 + 
             (19*cA^2*lmmMS*lmuH^2)/27648 + (cA*cR*lmmMS*lmuH^2)/1344 + 
             (5*cA^2*lmmMS^2*lmuH^2)/21504 - (cA^2*lmuH^3)/7168 + 
             (cA^2*lmmMS*lmuH^3)/4608 + (5*cA^2*lmuH^4)/129024 + 
             (9563651*cA*nh)/780337152000 - (35581669*cR*nh)/16721510400 + 
             (43*cA*lmmMS*nh)/806400 + (cR*lmmMS*nh)/15120 - 
             (cR*lmmMS^2*nh)/4032 - (43*cA*lmuH*nh)/806400 + 
             (cR*lmuH*nh)/2880 + (98821*cA^2*Pi^2)/156764160 + 
             (25817*cA*cR*Pi^2)/43545600 + (205*cA^2*lmmMS*Pi^2)/870912 + 
             (5*cA*cR*lmmMS*Pi^2)/10752 + (19*cA^2*lmmMS^2*Pi^2)/1741824 + 
             (35*cA^2*lmuH*Pi^2)/82944 + (cA*cR*lmuH*Pi^2)/5376 + 
             (19*cA^2*lmmMS*lmuH*Pi^2)/290304 + (19*cA^2*lmuH^2*Pi^2)/
              193536 + (1579*cA^2*Pi^4)/104509440 - (11*cA*cR*Pi^4)/362880 + 
             (205848991*cA^2*Zeta[3])/13377208320 + (66701809*cA*cR*Zeta[3])/
              743178240 + (2179367*cR^2*Zeta[3])/15482880 + 
             (19*cA^2*lmmMS*Zeta[3])/145152 - (5*cA*cR*lmmMS*Zeta[3])/3024 + 
             (25*cA^2*lmuH*Zeta[3])/12096 - (5*cA*cR*lmuH*Zeta[3])/1008 - 
             (791*cA*nh*Zeta[3])/9437184 + (20083*cR*nh*Zeta[3])/7077888) - 
           (437*cA^3*Zeta[5])/80640)/ep + 
         nl*((6515032025335669*cA^2)/123886326251520000 + 
           (4026557298177619*cA*cR)/34412868403200000 + (2150979558703*cR^2)/
            8193540096000 - (999975940069*cA^2*lmmMS)/73741860864000 - 
           (2515378487047*cA*cR*lmmMS)/20483850240000 - (20450183*cR^2*lmmMS)/
            121927680 - (1610327*cA^2*lmmMS^2)/457228800 - 
           (232859681*cA*cR*lmmMS^2)/12192768000 + (83047*cR^2*lmmMS^2)/
            19353600 + (18533*cA^2*lmmMS^3)/78382080 + (4799*cA*cR*lmmMS^3)/
            1741824 + (cR^2*lmmMS^3)/224 + (2185*cA^2*lmmMS^4)/20901888 + 
           (5*cA*cR*lmmMS^4)/64512 + (cA^2*lmmMS^5)/387072 + 
           (199177907*cA^2*lmuH)/384072192000 + (29892403393*cA*cR*lmuH)/
            1280240640000 - (3889099*cR^2*lmuH)/2438553600 - 
           (142853*cA^2*lmmMS*lmuH)/76204800 - (13706881*cA*cR*lmmMS*lmuH)/
            2032128000 + (893*cR^2*lmmMS*lmuH)/1935360 - 
           (277*cA^2*lmmMS^2*lmuH)/870912 + (7157*cA*cR*lmmMS^2*lmuH)/
            14515200 + (91*cA^2*lmmMS^3*lmuH)/248832 + (cA*cR*lmmMS^3*lmuH)/
            896 + (cA^2*lmmMS^4*lmuH)/43008 + (52781*cA^2*lmuH^2)/101606400 + 
           (8341819*cA*cR*lmuH^2)/2438553600 - (193*cR^2*lmuH^2)/774144 - 
           (383*cA^2*lmmMS*lmuH^2)/362880 - (1459*cA*cR*lmmMS*lmuH^2)/
            2073600 + (19*cA^2*lmmMS^2*lmuH^2)/55296 + (cA*cR*lmmMS^2*lmuH^2)/
            1344 + (5*cA^2*lmmMS^3*lmuH^2)/64512 - (3*cA^2*lmuH^3)/4480 + 
           (17*cA*cR*lmuH^3)/967680 - (cA^2*lmmMS*lmuH^3)/7168 + 
           (cA^2*lmmMS^2*lmuH^3)/9216 - (25*cA^2*lmuH^4)/86016 + 
           (5*cA^2*lmmMS*lmuH^4)/129024 - (17*cA^2*lmuH^5)/645120 - 
           (75910418473*cA*nh)/40967700480000 - (10357800371*cR*nh)/
            1560674304000 + (53499011*cA*lmmMS*nh)/780337152000 + 
           (15841307*cR*lmmMS*nh)/16721510400 + (43*cA*lmmMS^2*nh)/537600 - 
           (23*cR*lmmMS^2*nh)/120960 - (cR*lmmMS^3*nh)/3024 - 
           (467*cA*lmuH*nh)/8294400 - (9319*cR*lmuH*nh)/7257600 - 
           (43*cA*lmmMS*lmuH*nh)/403200 + (cR*lmmMS*lmuH*nh)/1440 + 
           (43*cA*lmuH^2*nh)/1612800 - (cR*lmuH^2*nh)/5760 + 
           (1431041*cA^2*Pi^2)/4115059200 - (1183187*cA*cR*Pi^2)/1463132160 + 
           (73*cR^2*Pi^2)/716800 + (93313*cA^2*lmmMS*Pi^2)/156764160 + 
           (33631*cA*cR*lmmMS*Pi^2)/21772800 + (cR^2*lmmMS*Pi^2)/1344 + 
           (205*cA^2*lmmMS^2*Pi^2)/1741824 + (23*cA*cR*lmmMS^2*Pi^2)/64512 + 
           (19*cA^2*lmmMS^3*Pi^2)/5225472 + (1837*cA^2*lmuH*Pi^2)/5225472 - 
           (521*cA*cR*lmuH*Pi^2)/3628800 + (35*cA^2*lmmMS*lmuH*Pi^2)/82944 + 
           (cA*cR*lmmMS*lmuH*Pi^2)/1792 + (19*cA^2*lmmMS^2*lmuH*Pi^2)/
            580608 + (5*cA^2*lmuH^2*Pi^2)/14336 + (cA*cR*lmuH^2*Pi^2)/16128 + 
           (19*cA^2*lmmMS*lmuH^2*Pi^2)/193536 + (19*cA^2*lmuH^3*Pi^2)/
            193536 + (43*cA*nh*Pi^2)/4838400 - (17*cR*nh*Pi^2)/725760 - 
           (cR*lmmMS*nh*Pi^2)/24192 - (163199471*cA^2*Pi^4)/1003290624000 + 
           (7251697*cA*cR*Pi^4)/3715891200 + (237737*cR^2*Pi^4)/99532800 + 
           (1579*cA^2*lmmMS*Pi^4)/104509440 - (11*cA*cR*lmmMS*Pi^4)/362880 + 
           (293*cA^2*lmuH*Pi^4)/4354560 - (11*cA*cR*lmuH*Pi^4)/120960 + 
           (113*cA*nh*Pi^4)/424673280 - (2869*cR*nh*Pi^4)/318504960 + 
           (9222149*d44[pR1, pR2])/(13996800*NA) - (3137*Pi^4*d44[pR1, pR2])/
            (162000*NA) - (8029*cA^2*Pi^2*Log[2]^2)/106168320 - 
           (577*cA*cR*Pi^2*Log[2]^2)/8257536 + (10271*cR^2*Pi^2*Log[2]^2)/
            23224320 + (113*cA*nh*Pi^2*Log[2]^2)/14155776 - 
           (2869*cR*nh*Pi^2*Log[2]^2)/10616832 + (8029*cA^2*Log[2]^4)/
            106168320 + (577*cA*cR*Log[2]^4)/8257536 - (10271*cR^2*Log[2]^4)/
            23224320 - (113*cA*nh*Log[2]^4)/14155776 + (2869*cR*nh*Log[2]^4)/
            10616832 + (8029*cA^2*PolyLog[4, 1/2])/4423680 + 
           (577*cA*cR*PolyLog[4, 1/2])/344064 - (10271*cR^2*PolyLog[4, 1/2])/
            967680 - (113*cA*nh*PolyLog[4, 1/2])/589824 + 
           (2869*cR*nh*PolyLog[4, 1/2])/442368 - (4779435509*cA^2*Zeta[3])/
            642105999360 - (2607176423*cA*cR*Zeta[3])/8493465600 - 
           (2934300913*cR^2*Zeta[3])/7431782400 + (205848991*cA^2*lmmMS*
             Zeta[3])/13377208320 + (65227249*cA*cR*lmmMS*Zeta[3])/
            743178240 + (271841*cR^2*lmmMS*Zeta[3])/2211840 + 
           (19*cA^2*lmmMS^2*Zeta[3])/290304 - (5*cA*cR*lmmMS^2*Zeta[3])/
            6048 + (3719*cA^2*lmuH*Zeta[3])/217728 - (397*cA*cR*lmuH*Zeta[3])/
            12096 + (25*cA^2*lmmMS*lmuH*Zeta[3])/12096 - 
           (5*cA*cR*lmmMS*lmuH*Zeta[3])/1008 + (11*cA^2*lmuH^2*Zeta[3])/
            2304 - (5*cA*cR*lmuH^2*Zeta[3])/672 + (21875*cA*nh*Zeta[3])/
            28311552 + (1555933*cR*nh*Zeta[3])/660602880 - 
           (791*cA*lmmMS*nh*Zeta[3])/9437184 + (20083*cR*lmmMS*nh*Zeta[3])/
            7077888 - (2645*cA^2*Pi^2*Zeta[3])/5225472 + 
           (11*cA*cR*Pi^2*Zeta[3])/18144 + (2129*d44[pR1, pR2]*Zeta[3])/
            (2160*NA) + (2243*cA^2*Zeta[5])/241920 + (cA*cR*Zeta[5])/3024 - 
           (5*cR^2*Zeta[5])/336))) + api5*((5*cA)/4 - (3*cR)/4 - 
       cA/(2*ep^2) - (11*cA*lmmMS)/12 - (cA*lmmMS^2)/4 - (cA*lmmMS*lmuH)/2 - 
       (cA*lmuH^2)/4 + ((-11*cA)/12 - (cA*lmmMS)/2 - (cA*lmuH)/2 + nl/6)/ep + 
       (lmmMS*nl)/6 + ep*((-11*cA)/6 + (13*cR)/8 + (5*cA*lmmMS)/2 - 
         3*cR*lmmMS - (11*cA*lmmMS^2)/24 - (cA*lmmMS^3)/12 - 
         (cA*lmmMS^2*lmuH)/4 - (cA*lmmMS*lmuH^2)/4 - (cA*lmuH^3)/12 - 
         (11*cA*Pi^2)/144 + nl*(lmmMS^2/12 + Pi^2/72) + (4*cA*Zeta[3])/3) + 
       ep^2*((8*cA)/9 - (35*cR)/16 - (19*cA*lmmMS)/6 + (13*cR*lmmMS)/4 + 
         (5*cA*lmmMS^2)/2 - (15*cR*lmmMS^2)/4 - (11*cA*lmmMS^3)/72 - 
         (cA*lmmMS^4)/48 - (cA*lmuH)/2 - (cA*lmmMS^3*lmuH)/12 - 
         (cA*lmmMS^2*lmuH^2)/8 - (cA*lmmMS*lmuH^3)/12 - (cA*lmuH^4)/48 + 
         (5*cA*Pi^2)/24 - (cR*Pi^2)/4 - (11*cA*lmmMS*Pi^2)/144 + 
         (cA*Pi^4)/60 + nl*(lmmMS^3/36 + (lmmMS*Pi^2)/72 - Zeta[3]/18) + 
         (11*cA*Zeta[3])/36 + (4*cA*lmmMS*Zeta[3])/3 + (4*cA*lmuH*Zeta[3])/
          3) + ep^3*((-901*cA)/108 + (157*cR)/32 + (59*cA*lmmMS)/18 - 
         (35*cR*lmmMS)/8 - (35*cA*lmmMS^2)/12 + (13*cR*lmmMS^2)/4 + 
         (5*cA*lmmMS^3)/3 - (11*cR*lmmMS^3)/4 - (11*cA*lmmMS^4)/288 - 
         (cA*lmmMS^5)/240 - (3*cA*lmuH)/2 - (cA*lmmMS*lmuH)/2 - 
         (cA*lmmMS^4*lmuH)/48 - (cA*lmuH^2)/4 - (cA*lmmMS^3*lmuH^2)/24 - 
         (cA*lmmMS^2*lmuH^3)/24 - (cA*lmmMS*lmuH^4)/48 - (cA*lmuH^5)/240 - 
         (2*cA*Pi^2)/9 + (13*cR*Pi^2)/48 + (5*cA*lmmMS*Pi^2)/12 - 
         (5*cR*lmmMS*Pi^2)/8 - (11*cA*lmmMS^2*Pi^2)/288 - (11*cA*Pi^4)/1920 + 
         (cA*lmmMS*Pi^4)/60 + (cA*lmuH*Pi^4)/60 - (5*cA*Zeta[3])/6 + 
         cR*Zeta[3] + (11*cA*lmmMS*Zeta[3])/36 + (2*cA*lmmMS^2*Zeta[3])/3 + 
         (4*cA*lmmMS*lmuH*Zeta[3])/3 + (2*cA*lmuH^2*Zeta[3])/3 + 
         nl*(lmmMS^4/144 + (lmmMS^2*Pi^2)/144 + Pi^4/960 - 
           (lmmMS*Zeta[3])/18) + (16*cA*Zeta[5])/5) + 
       ep^4*((1363*cA)/648 - (611*cR)/64 - (356*cA*lmmMS)/27 + 
         (157*cR*lmmMS)/16 + (145*cA*lmmMS^2)/36 - (35*cR*lmmMS^2)/8 - 
         (67*cA*lmmMS^3)/36 + (13*cR*lmmMS^3)/6 + (5*cA*lmmMS^4)/6 - 
         (23*cR*lmmMS^4)/16 - (11*cA*lmmMS^5)/1440 - (cA*lmmMS^6)/1440 - 
         (7*cA*lmuH)/2 - (3*cA*lmmMS*lmuH)/2 - (cA*lmmMS^2*lmuH)/4 - 
         (cA*lmmMS^5*lmuH)/240 - (3*cA*lmuH^2)/4 - (cA*lmmMS*lmuH^2)/4 - 
         (cA*lmmMS^4*lmuH^2)/96 - (cA*lmuH^3)/12 - (cA*lmmMS^3*lmuH^3)/72 - 
         (cA*lmmMS^2*lmuH^4)/96 - (cA*lmmMS*lmuH^5)/240 - (cA*lmuH^6)/1440 + 
         (43*cA*Pi^2)/108 - (35*cR*Pi^2)/96 - (4*cA*lmmMS*Pi^2)/9 + 
         (13*cR*lmmMS*Pi^2)/24 + (5*cA*lmmMS^2*Pi^2)/12 - 
         (11*cR*lmmMS^2*Pi^2)/16 - (11*cA*lmmMS^3*Pi^2)/864 + 
         (7*cA*Pi^4)/288 - (11*cR*Pi^4)/320 - (11*cA*lmmMS*Pi^4)/1920 + 
         (cA*lmmMS^2*Pi^4)/120 + (cA*lmmMS*lmuH*Pi^4)/60 + 
         (cA*lmuH^2*Pi^4)/120 + (cA*Pi^6)/189 + (20*cA*Zeta[3])/9 - 
         (13*cR*Zeta[3])/12 - (5*cA*lmmMS*Zeta[3])/3 + (5*cR*lmmMS*Zeta[3])/
          2 + (11*cA*lmmMS^2*Zeta[3])/72 + (2*cA*lmmMS^3*Zeta[3])/9 + 
         (2*cA*lmmMS^2*lmuH*Zeta[3])/3 + (2*cA*lmmMS*lmuH^2*Zeta[3])/3 + 
         (2*cA*lmuH^3*Zeta[3])/9 + (11*cA*Pi^2*Zeta[3])/432 - 
         (16*cA*Zeta[3]^2)/9 + nl*(lmmMS^5/720 + (lmmMS^3*Pi^2)/432 + 
           (lmmMS*Pi^4)/960 - (lmmMS^2*Zeta[3])/36 - (Pi^2*Zeta[3])/216 - 
           Zeta[5]/30) + (11*cA*Zeta[5])/60 + (16*cA*lmmMS*Zeta[5])/5 + 
         (16*cA*lmuH*Zeta[5])/5) + rhoMS^2*((-193*cA)/20160 + (26*cR)/4725 - 
         cA/(336*ep^2) - (5*cA*lmmMS)/504 - (cR*lmmMS)/56 - 
         (cA*lmmMS^2)/672 - (cA*lmuH)/224 - (cA*lmmMS*lmuH)/336 - 
         (cA*lmuH^2)/672 + ((-5*cA)/504 - (cA*lmmMS)/336 - (cA*lmuH)/336 + 
           nl/1008)/ep + (1/672 + lmmMS/1008)*nl + 
         ep*((29*cA)/26460 - (27997*cR)/2268000 - (191*cA*lmmMS)/20160 - 
           (467*cR*lmmMS)/18900 - (5*cA*lmmMS^2)/1008 - (3*cR*lmmMS^2)/112 - 
           (cA*lmmMS^3)/2016 - (cA*lmuH)/672 - (cA*lmmMS*lmuH)/224 - 
           (cA*lmmMS^2*lmuH)/672 - (cA*lmuH^2)/448 - (cA*lmmMS*lmuH^2)/672 - 
           (cA*lmuH^3)/2016 - (11*cA*Pi^2)/24192 - (cR*Pi^2)/672 + 
           nl*(1/2016 + lmmMS/672 + lmmMS^2/2016 + Pi^2/12096) + 
           (cA*Zeta[3])/126) + ep^2*((-183263*cA)/17781120 - 
           (5139019*cR)/272160000 + (3343*cA*lmmMS)/423360 - 
           (106619*cR*lmmMS)/2268000 - (187*cA*lmmMS^2)/40320 - 
           (1609*cR*lmmMS^2)/37800 - (5*cA*lmmMS^3)/3024 - (cR*lmmMS^3)/48 - 
           (cA*lmmMS^4)/8064 - (cA*lmuH)/336 - (cA*lmmMS*lmuH)/672 - 
           (cA*lmmMS^2*lmuH)/448 - (cA*lmmMS^3*lmuH)/2016 - 
           (cA*lmuH^2)/1344 - (cA*lmmMS*lmuH^2)/448 - (cA*lmmMS^2*lmuH^2)/
            1344 - (cA*lmuH^3)/1344 - (cA*lmmMS*lmuH^3)/2016 - 
           (cA*lmuH^4)/8064 - (23*cA*Pi^2)/34560 - (467*cR*Pi^2)/226800 - 
           (11*cA*lmmMS*Pi^2)/24192 - (cR*lmmMS*Pi^2)/224 + (cA*Pi^4)/10080 + 
           nl*(lmmMS/2016 + lmmMS^2/1344 + lmmMS^3/6048 + Pi^2/8064 + 
             (lmmMS*Pi^2)/12096 - Zeta[3]/3024) + (83*cA*Zeta[3])/6048 + 
           (cR*Zeta[3])/168 + (cA*lmmMS*Zeta[3])/126 + (cA*lmuH*Zeta[3])/
            126) + ep^3*((-146341799*cA)/3734035200 + (6127081*cR)/
            16329600000 - (64193*cA*lmmMS)/8890560 - (5746519*cR*lmmMS)/
            136080000 + (9101*cA*lmmMS^2)/846720 - (263863*cR*lmmMS^2)/
            4536000 - (179*cA*lmmMS^3)/120960 - (3893*cR*lmmMS^3)/113400 - 
           (5*cA*lmmMS^4)/12096 - (5*cR*lmmMS^4)/448 - (cA*lmmMS^5)/40320 - 
           (3*cA*lmuH)/224 - (cA*lmmMS*lmuH)/336 - (cA*lmmMS^2*lmuH)/1344 - 
           (cA*lmmMS^3*lmuH)/1344 - (cA*lmmMS^4*lmuH)/8064 - 
           (cA*lmuH^2)/672 - (cA*lmmMS*lmuH^2)/1344 - (cA*lmmMS^2*lmuH^2)/
            896 - (cA*lmmMS^3*lmuH^2)/4032 - (cA*lmuH^3)/4032 - 
           (cA*lmmMS*lmuH^3)/1344 - (cA*lmmMS^2*lmuH^3)/4032 - 
           (cA*lmuH^4)/5376 - (cA*lmmMS*lmuH^4)/8064 - (cA*lmuH^5)/40320 + 
           (4603*cA*Pi^2)/5080320 - (106619*cR*Pi^2)/27216000 - 
           (157*cA*lmmMS*Pi^2)/241920 - (1609*cR*lmmMS*Pi^2)/226800 - 
           (11*cA*lmmMS^2*Pi^2)/48384 - (cR*lmmMS^2*Pi^2)/192 + 
           (37*cA*Pi^4)/322560 - (19*cR*Pi^4)/80640 + (cA*lmmMS*Pi^4)/10080 + 
           (cA*lmuH*Pi^4)/10080 + (401*cA*Zeta[3])/60480 + 
           (467*cR*Zeta[3])/56700 + (83*cA*lmmMS*Zeta[3])/6048 + 
           (cR*lmmMS*Zeta[3])/56 + (cA*lmmMS^2*Zeta[3])/252 + 
           (cA*lmuH*Zeta[3])/84 + (cA*lmmMS*lmuH*Zeta[3])/126 + 
           (cA*lmuH^2*Zeta[3])/252 + nl*(lmmMS^2/4032 + lmmMS^3/4032 + 
             lmmMS^4/24192 + Pi^2/24192 + (lmmMS*Pi^2)/8064 + 
             (lmmMS^2*Pi^2)/24192 + Pi^4/161280 - Zeta[3]/2016 - 
             (lmmMS*Zeta[3])/3024) + (2*cA*Zeta[5])/105) + 
         ep^4*((-64903349909*cA)/784147392000 + (1055521931*cR)/
            979776000000 - (79662599*cA*lmmMS)/1867017600 + 
           (6127081*cR*lmmMS)/8164800000 - (2329*cA*lmmMS^2)/4445280 - 
           (6050269*cR*lmmMS^2)/136080000 + (20617*cA*lmmMS^3)/2540160 - 
           (578351*cR*lmmMS^3)/13608000 - (163*cA*lmmMS^4)/483840 - 
           (8461*cR*lmmMS^4)/453600 - (cA*lmmMS^5)/12096 - 
           (31*cR*lmmMS^5)/6720 - (cA*lmmMS^6)/241920 - (cA*lmuH)/28 - 
           (3*cA*lmmMS*lmuH)/224 - (cA*lmmMS^2*lmuH)/672 - 
           (cA*lmmMS^3*lmuH)/4032 - (cA*lmmMS^4*lmuH)/5376 - 
           (cA*lmmMS^5*lmuH)/40320 - (3*cA*lmuH^2)/448 - (cA*lmmMS*lmuH^2)/
            672 - (cA*lmmMS^2*lmuH^2)/2688 - (cA*lmmMS^3*lmuH^2)/2688 - 
           (cA*lmmMS^4*lmuH^2)/16128 - (cA*lmuH^3)/2016 - (cA*lmmMS*lmuH^3)/
            4032 - (cA*lmmMS^2*lmuH^3)/2688 - (cA*lmmMS^3*lmuH^3)/12096 - 
           (cA*lmuH^4)/16128 - (cA*lmmMS*lmuH^4)/5376 - (cA*lmmMS^2*lmuH^4)/
            16128 - (cA*lmuH^5)/26880 - (cA*lmmMS*lmuH^5)/40320 - 
           (cA*lmuH^6)/241920 + (54877*cA*Pi^2)/106686720 - 
           (5746519*cR*Pi^2)/1632960000 + (10361*cA*lmmMS*Pi^2)/5080320 - 
           (263863*cR*lmmMS*Pi^2)/27216000 - (149*cA*lmmMS^2*Pi^2)/483840 - 
           (3893*cR*lmmMS^2*Pi^2)/453600 - (11*cA*lmmMS^3*Pi^2)/145152 - 
           (5*cR*lmmMS^3*Pi^2)/1344 + (11*cA*Pi^4)/29030400 - 
           (9913*cR*Pi^4)/27216000 + (37*cA*lmmMS*Pi^4)/322560 - 
           (47*cR*lmmMS*Pi^4)/80640 + (cA*lmmMS^2*Pi^4)/20160 + 
           (cA*lmuH*Pi^4)/6720 + (cA*lmmMS*lmuH*Pi^4)/10080 + 
           (cA*lmuH^2*Pi^4)/20160 + (cA*Pi^6)/31752 + (5477*cA*Zeta[3])/
            1270080 + (106619*cR*Zeta[3])/6804000 + (397*cA*lmmMS*Zeta[3])/
            60480 + (1609*cR*lmmMS*Zeta[3])/56700 + (83*cA*lmmMS^2*Zeta[3])/
            12096 + (cR*lmmMS^2*Zeta[3])/48 + (cA*lmmMS^3*Zeta[3])/756 + 
           (cA*lmuH*Zeta[3])/252 + (cA*lmmMS*lmuH*Zeta[3])/84 + 
           (cA*lmmMS^2*lmuH*Zeta[3])/252 + (cA*lmuH^2*Zeta[3])/168 + 
           (cA*lmmMS*lmuH^2*Zeta[3])/252 + (cA*lmuH^3*Zeta[3])/756 + 
           (11*cA*Pi^2*Zeta[3])/72576 + (cR*Pi^2*Zeta[3])/672 - 
           (2*cA*Zeta[3]^2)/189 + nl*(lmmMS^3/12096 + lmmMS^4/16128 + 
             lmmMS^5/120960 + (lmmMS*Pi^2)/24192 + (lmmMS^2*Pi^2)/16128 + 
             (lmmMS^3*Pi^2)/72576 + Pi^4/107520 + (lmmMS*Pi^4)/161280 - 
             Zeta[3]/6048 - (lmmMS*Zeta[3])/2016 - (lmmMS^2*Zeta[3])/6048 - 
             (Pi^2*Zeta[3])/36288 - Zeta[5]/5040) + (299*cA*Zeta[5])/10080 + 
           (cR*Zeta[5])/280 + (2*cA*lmmMS*Zeta[5])/105 + (2*cA*lmuH*Zeta[5])/
            105)) + rhoMS*(-cA/30 + (19*cR)/360 - (7*cA)/(240*ep^2) - 
         (119*cA*lmmMS)/1440 - (7*cR*lmmMS)/80 - (7*cA*lmmMS^2)/480 - 
         (7*cA*lmuH)/240 - (7*cA*lmmMS*lmuH)/240 - (7*cA*lmuH^2)/480 + 
         ((-119*cA)/1440 - (7*cA*lmmMS)/240 - (7*cA*lmuH)/240 + (7*nl)/720)/
          ep + (7/720 + (7*lmmMS)/720)*nl + ep*((553*cA)/10800 - 
           (31*cR)/240 - (19*cA*lmmMS)/1440 - (5*cR*lmmMS)/72 - 
           (119*cA*lmmMS^2)/2880 - (21*cR*lmmMS^2)/160 - (7*cA*lmmMS^3)/
            1440 - (7*cA*lmmMS*lmuH)/240 - (7*cA*lmmMS^2*lmuH)/480 - 
           (7*cA*lmuH^2)/480 - (7*cA*lmmMS*lmuH^2)/480 - (7*cA*lmuH^3)/1440 - 
           (77*cA*Pi^2)/17280 - (7*cR*Pi^2)/960 + 
           nl*((7*lmmMS)/720 + (7*lmmMS^2)/1440 + (7*Pi^2)/8640) + 
           (7*cA*Zeta[3])/90) + ep^2*((-31319*cA)/216000 + (193*cR)/6480 + 
           (1421*cA*lmmMS)/10800 - (83*cR*lmmMS)/240 + (13*cA*lmmMS^2)/960 - 
           (113*cR*lmmMS^2)/720 - (119*cA*lmmMS^3)/8640 - 
           (49*cR*lmmMS^3)/480 - (7*cA*lmmMS^4)/5760 - (7*cA*lmuH)/240 - 
           (7*cA*lmmMS^2*lmuH)/480 - (7*cA*lmmMS^3*lmuH)/1440 - 
           (7*cA*lmmMS*lmuH^2)/480 - (7*cA*lmmMS^2*lmuH^2)/960 - 
           (7*cA*lmuH^3)/1440 - (7*cA*lmmMS*lmuH^3)/1440 - 
           (7*cA*lmuH^4)/5760 - (19*cA*Pi^2)/17280 - (5*cR*Pi^2)/864 - 
           (77*cA*lmmMS*Pi^2)/17280 - (7*cR*lmmMS*Pi^2)/320 + 
           (7*cA*Pi^4)/7200 + nl*((7*lmmMS^2)/1440 + (7*lmmMS^3)/4320 + 
             (7*Pi^2)/8640 + (7*lmmMS*Pi^2)/8640 - (7*Zeta[3])/2160) + 
           (413*cA*Zeta[3])/4320 + (7*cR*Zeta[3])/240 + (7*cA*lmmMS*Zeta[3])/
            90 + (7*cA*lmuH*Zeta[3])/90) + ep^3*((-5622341*cA)/19440000 + 
           (721*cR)/38880 - (18719*cA*lmmMS)/108000 + (193*cR*lmmMS)/3240 + 
           (3157*cA*lmmMS^2)/21600 - (187*cR*lmmMS^2)/480 + 
           (31*cA*lmmMS^3)/1728 - (289*cR*lmmMS^3)/2160 - (119*cA*lmmMS^4)/
            34560 - (7*cR*lmmMS^4)/128 - (7*cA*lmmMS^5)/28800 - 
           (7*cA*lmuH)/60 - (7*cA*lmmMS*lmuH)/240 - (7*cA*lmmMS^3*lmuH)/
            1440 - (7*cA*lmmMS^4*lmuH)/5760 - (7*cA*lmuH^2)/480 - 
           (7*cA*lmmMS^2*lmuH^2)/960 - (7*cA*lmmMS^3*lmuH^2)/2880 - 
           (7*cA*lmmMS*lmuH^3)/1440 - (7*cA*lmmMS^2*lmuH^3)/2880 - 
           (7*cA*lmuH^4)/5760 - (7*cA*lmmMS*lmuH^4)/5760 - 
           (7*cA*lmuH^5)/28800 + (217*cA*Pi^2)/16200 - (83*cR*Pi^2)/2880 + 
           (13*cA*lmmMS*Pi^2)/5760 - (113*cR*lmmMS*Pi^2)/4320 - 
           (77*cA*lmmMS^2*Pi^2)/34560 - (49*cR*lmmMS^2*Pi^2)/1920 + 
           (49*cA*Pi^4)/76800 - (133*cR*Pi^4)/115200 + (7*cA*lmmMS*Pi^4)/
            7200 + (7*cA*lmuH*Pi^4)/7200 + (19*cA*Zeta[3])/4320 + 
           (5*cR*Zeta[3])/216 + (413*cA*lmmMS*Zeta[3])/4320 + 
           (7*cR*lmmMS*Zeta[3])/80 + (7*cA*lmmMS^2*Zeta[3])/180 + 
           (7*cA*lmuH*Zeta[3])/90 + (7*cA*lmmMS*lmuH*Zeta[3])/90 + 
           (7*cA*lmuH^2*Zeta[3])/180 + nl*((7*lmmMS^3)/4320 + 
             (7*lmmMS^4)/17280 + (7*lmmMS*Pi^2)/8640 + (7*lmmMS^2*Pi^2)/
              17280 + (7*Pi^4)/115200 - (7*Zeta[3])/2160 - (7*lmmMS*Zeta[3])/
              2160) + (14*cA*Zeta[5])/75) + ep^4*((-384163783*cA)/583200000 + 
           (709*cR)/77760 - (2787341*cA*lmmMS)/9720000 + (721*cR*lmmMS)/
            19440 - (12419*cA*lmmMS^2)/108000 + (193*cR*lmmMS^2)/3240 + 
           (6629*cA*lmmMS^3)/64800 - (79*cR*lmmMS^3)/288 + 
           (43*cA*lmmMS^4)/3840 - (641*cR*lmmMS^4)/8640 - (119*cA*lmmMS^5)/
            172800 - (217*cR*lmmMS^5)/9600 - (7*cA*lmmMS^6)/172800 - 
           (7*cA*lmuH)/24 - (7*cA*lmmMS*lmuH)/60 - (7*cA*lmmMS^2*lmuH)/480 - 
           (7*cA*lmmMS^4*lmuH)/5760 - (7*cA*lmmMS^5*lmuH)/28800 - 
           (7*cA*lmuH^2)/120 - (7*cA*lmmMS*lmuH^2)/480 - 
           (7*cA*lmmMS^3*lmuH^2)/2880 - (7*cA*lmmMS^4*lmuH^2)/11520 - 
           (7*cA*lmuH^3)/1440 - (7*cA*lmmMS^2*lmuH^3)/2880 - 
           (7*cA*lmmMS^3*lmuH^3)/8640 - (7*cA*lmmMS*lmuH^4)/5760 - 
           (7*cA*lmmMS^2*lmuH^4)/11520 - (7*cA*lmuH^5)/28800 - 
           (7*cA*lmmMS*lmuH^5)/28800 - (7*cA*lmuH^6)/172800 - 
           (6119*cA*Pi^2)/1296000 + (193*cR*Pi^2)/38880 + (217*cA*lmmMS*Pi^2)/
            8100 - (187*cR*lmmMS*Pi^2)/2880 + (31*cA*lmmMS^2*Pi^2)/6912 - 
           (289*cR*lmmMS^2*Pi^2)/8640 - (77*cA*lmmMS^3*Pi^2)/103680 - 
           (7*cR*lmmMS^3*Pi^2)/384 + (119*cA*Pi^4)/2073600 - 
           (133*cR*Pi^4)/103680 + (49*cA*lmmMS*Pi^4)/76800 - 
           (329*cR*lmmMS*Pi^4)/115200 + (7*cA*lmmMS^2*Pi^4)/14400 + 
           (7*cA*lmuH*Pi^4)/7200 + (7*cA*lmmMS*lmuH*Pi^4)/7200 + 
           (7*cA*lmuH^2*Pi^4)/14400 + (cA*Pi^6)/3240 + (49*cA*Zeta[3])/2025 + 
           (83*cR*Zeta[3])/720 - (13*cA*lmmMS*Zeta[3])/1440 + 
           (113*cR*lmmMS*Zeta[3])/1080 + (413*cA*lmmMS^2*Zeta[3])/8640 + 
           (49*cR*lmmMS^2*Zeta[3])/480 + (7*cA*lmmMS^3*Zeta[3])/540 + 
           (7*cA*lmmMS*lmuH*Zeta[3])/90 + (7*cA*lmmMS^2*lmuH*Zeta[3])/180 + 
           (7*cA*lmuH^2*Zeta[3])/180 + (7*cA*lmmMS*lmuH^2*Zeta[3])/180 + 
           (7*cA*lmuH^3*Zeta[3])/540 + (77*cA*Pi^2*Zeta[3])/51840 + 
           (7*cR*Pi^2*Zeta[3])/960 - (14*cA*Zeta[3]^2)/135 + 
           nl*((7*lmmMS^4)/17280 + (7*lmmMS^5)/86400 + (7*lmmMS^2*Pi^2)/
              17280 + (7*lmmMS^3*Pi^2)/51840 + (7*Pi^4)/115200 + 
             (7*lmmMS*Pi^4)/115200 - (7*lmmMS*Zeta[3])/2160 - 
             (7*lmmMS^2*Zeta[3])/4320 - (7*Pi^2*Zeta[3])/25920 - 
             (7*Zeta[5])/3600) + (1421*cA*Zeta[5])/7200 + 
           (7*cR*Zeta[5])/400 + (14*cA*lmmMS*Zeta[5])/75 + 
           (14*cA*lmuH*Zeta[5])/75))) + api5^2*((26185*cA^2)/5184 - 
       (119*cA*cR)/48 + (27*cR^2)/32 + cA^2/(8*ep^4) - (463*cA^2*lmmMS)/432 + 
       (7*cA*cR*lmmMS)/16 - (545*cA^2*lmmMS^2)/576 + (15*cA*cR*lmmMS^2)/8 + 
       (77*cA^2*lmmMS^3)/576 + (cA^2*lmmMS^4)/192 + (53*cA^2*lmuH)/54 - 
       (13*cA*cR*lmuH)/16 - (247*cA^2*lmmMS*lmuH)/144 + 
       (3*cA*cR*lmmMS*lmuH)/2 + (11*cA^2*lmmMS^2*lmuH)/32 + 
       (cA^2*lmmMS^3*lmuH)/24 - (7*cA^2*lmuH^2)/9 + (3*cA*cR*lmuH^2)/16 + 
       (11*cA^2*lmmMS*lmuH^2)/48 + (cA^2*lmmMS^2*lmuH^2)/8 + 
       (cA^2*lmmMS*lmuH^3)/6 + (cA^2*lmuH^4)/12 - (5*cA*nh)/192 - 
       (cR*nh)/24 + ((77*cA^2)/96 + (cA^2*lmmMS)/8 + (cA^2*lmuH)/4 - 
         (7*cA*nl)/48)/ep^3 + ((-5*cA^2)/288 + (3*cA*cR)/8 + 
         (77*cA^2*lmmMS)/96 + (cA^2*lmmMS^2)/16 + (11*cA^2*lmuH)/16 + 
         (cA^2*lmmMS*lmuH)/4 + (cA^2*lmuH^2)/4 + 
         ((-13*cA)/48 - (7*cA*lmmMS)/48 - (cA*lmuH)/8)*nl + nl^2/36)/ep^2 + 
       (397*cA^2*Pi^2)/3456 + (3*cA*cR*Pi^2)/32 + (55*cA^2*lmmMS*Pi^2)/1152 + 
       (55*cA^2*lmuH*Pi^2)/576 - (17*cA^2*Pi^4)/2304 + 
       nl^2*(lmmMS^2/72 + Pi^2/432) - (671*cA^2*Zeta[3])/288 - 
       (9*cA^2*lmmMS*Zeta[3])/16 - (9*cA^2*lmuH*Zeta[3])/8 + 
       ((-445*cA^2)/432 - (cA*cR)/8 - (185*cA^2*lmmMS)/288 + 
         (3*cA*cR*lmmMS)/2 + (77*cA^2*lmmMS^2)/192 + (cA^2*lmmMS^3)/48 - 
         (157*cA^2*lmuH)/144 + (3*cA*cR*lmuH)/8 + (11*cA^2*lmmMS*lmuH)/16 + 
         (cA^2*lmmMS^2*lmuH)/8 + (11*cA^2*lmuH^2)/48 + (cA^2*lmmMS*lmuH^2)/
          4 + (cA^2*lmuH^3)/6 + (lmmMS*nl^2)/36 + (55*cA^2*Pi^2)/1152 + 
         nl*((77*cA)/216 - cR/16 - (13*cA*lmmMS)/48 - (7*cA*lmmMS^2)/96 + 
           (5*cA*lmuH)/72 - (cA*lmmMS*lmuH)/8 - (cA*lmuH^2)/24 - 
           (5*cA*Pi^2)/576) - (9*cA^2*Zeta[3])/16)/ep + 
       nl*((-3047*cA)/2592 - (7*cR)/12 + (61*cA*lmmMS)/108 - 
         (3*cR*lmmMS)/16 - (13*cA*lmmMS^2)/96 - (7*cA*lmmMS^3)/288 - 
         (13*cA*lmuH)/108 - (cR*lmuH)/8 + (5*cA*lmmMS*lmuH)/72 - 
         (cA*lmmMS^2*lmuH)/16 + (5*cA*lmuH^2)/72 - (cA*lmmMS*lmuH^2)/24 - 
         (23*cA*Pi^2)/576 - (5*cA*lmmMS*Pi^2)/576 - (5*cA*lmuH*Pi^2)/288 - 
         (11*cA*Zeta[3])/144 + (cR*Zeta[3])/2) + 
       ep*((541139*cA^2)/62208 - (10931*cA*cR)/1152 + (19*cR^2)/32 + 
         (39127*cA^2*lmmMS)/5184 - (1087*cA*cR*lmmMS)/96 + 
         (219*cR^2*lmmMS)/32 + (185*cA^2*lmmMS^2)/864 - (19*cA*cR*lmmMS^2)/
          32 - (1265*cA^2*lmmMS^3)/1728 + (11*cA*cR*lmmMS^3)/8 + 
         (77*cA^2*lmmMS^4)/2304 + (cA^2*lmmMS^5)/960 + (5501*cA^2*lmuH)/
          1296 + (35*cA*cR*lmuH)/32 + (89*cA^2*lmmMS*lmuH)/54 - 
         (13*cA*cR*lmmMS*lmuH)/8 - (427*cA^2*lmmMS^2*lmuH)/288 + 
         (15*cA*cR*lmmMS^2*lmuH)/8 + (11*cA^2*lmmMS^3*lmuH)/96 + 
         (cA^2*lmmMS^4*lmuH)/96 + (35*cA^2*lmuH^2)/54 - 
         (13*cA*cR*lmuH^2)/32 - (157*cA^2*lmmMS*lmuH^2)/144 + 
         (3*cA*cR*lmmMS*lmuH^2)/4 + (11*cA^2*lmmMS^2*lmuH^2)/96 + 
         (cA^2*lmmMS^3*lmuH^2)/24 - (179*cA^2*lmuH^3)/432 + 
         (cA*cR*lmuH^3)/16 + (cA^2*lmmMS^2*lmuH^3)/12 - 
         (11*cA^2*lmuH^4)/288 + (cA^2*lmmMS*lmuH^4)/12 + (cA^2*lmuH^5)/30 - 
         (1423*cA*nh)/3456 - (101*cR*nh)/576 - (5*cA*lmmMS*nh)/64 + 
         (cR*lmmMS*nh)/12 - (cR*lmmMS^2*nh)/8 - (115*cA^2*Pi^2)/5184 + 
         (5*cA*cR*Pi^2)/48 + (217*cA^2*lmmMS*Pi^2)/3456 + 
         (3*cA*cR*lmmMS*Pi^2)/16 + (55*cA^2*lmmMS^2*Pi^2)/2304 + 
         (245*cA^2*lmuH*Pi^2)/1728 + (3*cA*cR*lmuH*Pi^2)/32 + 
         (55*cA^2*lmmMS*lmuH*Pi^2)/576 + (55*cA^2*lmuH^2*Pi^2)/576 - 
         (3971*cA^2*Pi^4)/138240 - (17*cA^2*lmmMS*Pi^4)/2304 - 
         (17*cA^2*lmuH*Pi^4)/1152 + nl^2*(lmmMS^3/216 + (lmmMS*Pi^2)/432 - 
           Zeta[3]/108) - (12923*cA^2*Zeta[3])/13824 + (3467*cA*cR*Zeta[3])/
          256 - (285*cR^2*Zeta[3])/64 - (671*cA^2*lmmMS*Zeta[3])/288 - 
         (9*cA^2*lmmMS^2*Zeta[3])/32 - (319*cA^2*lmuH*Zeta[3])/144 - 
         (9*cA^2*lmmMS*lmuH*Zeta[3])/8 - (9*cA^2*lmuH^2*Zeta[3])/8 + 
         (63*cA*nh*Zeta[3])/256 + (63*cR*nh*Zeta[3])/128 + 
         (7*cA^2*Pi^2*Zeta[3])/192 + nl*((-50915*cA)/15552 - (41*cR)/16 - 
           (3893*cA*lmmMS)/2592 - (11*cR*lmmMS)/16 + (167*cA*lmmMS^2)/432 + 
           (3*cR*lmmMS^2)/32 - (13*cA*lmmMS^3)/288 - (7*cA*lmmMS^4)/1152 - 
           (229*cA*lmuH)/162 - (67*cR*lmuH)/48 - (13*cA*lmmMS*lmuH)/108 - 
           (cR*lmmMS*lmuH)/8 + (5*cA*lmmMS^2*lmuH)/144 - (cA*lmmMS^3*lmuH)/
            48 - (13*cA*lmuH^2)/108 - (cR*lmuH^2)/8 + (5*cA*lmmMS*lmuH^2)/
            72 - (cA*lmmMS^2*lmuH^2)/48 + (5*cA*lmuH^3)/108 + 
           (cA*lmuH^4)/144 + (37*cA*Pi^2)/1296 + (5*cR*Pi^2)/576 - 
           (23*cA*lmmMS*Pi^2)/576 - (5*cA*lmmMS^2*Pi^2)/1152 - 
           (25*cA*lmuH*Pi^2)/864 - (5*cA*lmmMS*lmuH*Pi^2)/288 - 
           (5*cA*lmuH^2*Pi^2)/288 - (31*cA*Pi^4)/7680 + (cR*Pi^4)/108 - 
           (565*cA*Zeta[3])/432 + (23*cR*Zeta[3])/12 - (11*cA*lmmMS*Zeta[3])/
            144 + (cR*lmmMS*Zeta[3])/2 - (43*cA*lmuH*Zeta[3])/72 + 
           cR*lmuH*Zeta[3]) + (69*cA^2*Zeta[5])/80) + 
       ep^2*((10564525*cA^2)/186624 - (16271*cA*cR)/1728 - (1715*cR^2)/192 + 
         (176369*cA^2*lmmMS)/62208 - (3283*cA*cR*lmmMS)/128 - 
         (99*cR^2*lmmMS)/32 + (71473*cA^2*lmmMS^2)/10368 - 
         (1271*cA*cR*lmmMS^2)/64 + (1011*cR^2*lmmMS^2)/64 + 
         (3533*cA^2*lmmMS^3)/2592 - (203*cA*cR*lmmMS^3)/96 - 
         (2705*cA^2*lmmMS^4)/6912 + (23*cA*cR*lmmMS^4)/32 + 
         (77*cA^2*lmmMS^5)/11520 + (cA^2*lmmMS^6)/5760 + 
         (193553*cA^2*lmuH)/7776 - (133*cA*cR*lmuH)/64 + 
         (3953*cA^2*lmmMS*lmuH)/1296 + (35*cA*cR*lmmMS*lmuH)/16 + 
         (161*cA^2*lmmMS^2*lmuH)/108 - (13*cA*cR*lmmMS^2*lmuH)/8 - 
         (787*cA^2*lmmMS^3*lmuH)/864 + (11*cA*cR*lmmMS^3*lmuH)/8 + 
         (11*cA^2*lmmMS^4*lmuH)/384 + (cA^2*lmmMS^5*lmuH)/480 + 
         (5681*cA^2*lmuH^2)/1296 + (35*cA*cR*lmuH^2)/64 + 
         (53*cA^2*lmmMS*lmuH^2)/54 - (13*cA*cR*lmmMS*lmuH^2)/16 - 
         (247*cA^2*lmmMS^2*lmuH^2)/288 + (15*cA*cR*lmmMS^2*lmuH^2)/16 + 
         (11*cA^2*lmmMS^3*lmuH^2)/288 + (cA^2*lmmMS^4*lmuH^2)/96 + 
         (26*cA^2*lmuH^3)/81 - (13*cA*cR*lmuH^3)/96 - (14*cA^2*lmmMS*lmuH^3)/
          27 + (cA*cR*lmmMS*lmuH^3)/4 + (cA^2*lmmMS^3*lmuH^3)/36 - 
         (313*cA^2*lmuH^4)/1728 + (cA*cR*lmuH^4)/64 - (11*cA^2*lmmMS*lmuH^4)/
          288 + (cA^2*lmmMS^2*lmuH^4)/24 - (11*cA^2*lmuH^5)/480 + 
         (cA^2*lmmMS*lmuH^5)/30 + (cA^2*lmuH^6)/90 + (9533*cA*nh)/20736 - 
         (1817*cR*nh)/864 - (1423*cA*lmmMS*nh)/1152 - (101*cR*lmmMS*nh)/192 - 
         (15*cA*lmmMS^2*nh)/128 + (11*cR*lmmMS^2*nh)/48 - (cR*lmmMS^3*nh)/4 + 
         (46339*cA^2*Pi^2)/62208 - (149*cA*cR*Pi^2)/144 + 
         (73*cR^2*Pi^2)/128 + (245*cA^2*lmmMS*Pi^2)/5184 + 
         (7*cA*cR*lmmMS*Pi^2)/192 - (143*cA^2*lmmMS^2*Pi^2)/6912 + 
         (3*cA*cR*lmmMS^2*Pi^2)/16 + (55*cA^2*lmmMS^3*Pi^2)/6912 + 
         (53*cA^2*lmuH*Pi^2)/162 - (13*cA*cR*lmuH*Pi^2)/192 + 
         (155*cA^2*lmmMS*lmuH*Pi^2)/1728 + (3*cA*cR*lmmMS*lmuH*Pi^2)/16 + 
         (55*cA^2*lmmMS^2*lmuH*Pi^2)/1152 + (145*cA^2*lmuH^2*Pi^2)/864 + 
         (3*cA*cR*lmuH^2*Pi^2)/64 + (55*cA^2*lmmMS*lmuH^2*Pi^2)/576 + 
         (55*cA^2*lmuH^3*Pi^2)/864 - (5*cA*nh*Pi^2)/768 + (cR*nh*Pi^2)/144 - 
         (cR*lmmMS*nh*Pi^2)/48 + (121*cA^2*Pi^4)/1440 - 
         (2749*cA*cR*Pi^4)/2560 + (811*cR^2*Pi^4)/1920 - 
         (3971*cA^2*lmmMS*Pi^4)/138240 - (17*cA^2*lmmMS^2*Pi^4)/4608 - 
         (1859*cA^2*lmuH*Pi^4)/69120 - (17*cA^2*lmmMS*lmuH*Pi^4)/1152 - 
         (17*cA^2*lmuH^2*Pi^4)/1152 - (51*cA*nh*Pi^4)/2560 - 
         (51*cR*nh*Pi^4)/1280 + (4331*cA^2*Pi^6)/483840 + 
         (263*cA^2*Pi^2*Log[2]^2)/256 - (381*cA*cR*Pi^2*Log[2]^2)/128 + 
         (59*cR^2*Pi^2*Log[2]^2)/32 - (9*cA*nh*Pi^2*Log[2]^2)/128 - 
         (9*cR*nh*Pi^2*Log[2]^2)/64 - (263*cA^2*Log[2]^4)/256 + 
         (381*cA*cR*Log[2]^4)/128 - (59*cR^2*Log[2]^4)/32 + 
         (9*cA*nh*Log[2]^4)/128 + (9*cR*nh*Log[2]^4)/64 - 
         (789*cA^2*PolyLog[4, 1/2])/32 + (1143*cA*cR*PolyLog[4, 1/2])/16 - 
         (177*cR^2*PolyLog[4, 1/2])/4 + (27*cA*nh*PolyLog[4, 1/2])/16 + 
         (27*cR*nh*PolyLog[4, 1/2])/8 - (838571*cA^2*Zeta[3])/27648 + 
         (32597*cA*cR*Zeta[3])/512 - (409*cR^2*Zeta[3])/64 + 
         (13807*cA^2*lmmMS*Zeta[3])/13824 + (10241*cA*cR*lmmMS*Zeta[3])/256 - 
         (855*cR^2*lmmMS*Zeta[3])/64 - (671*cA^2*lmmMS^2*Zeta[3])/576 - 
         (3*cA^2*lmmMS^3*Zeta[3])/32 - (467*cA^2*lmuH*Zeta[3])/144 - 
         (11*cA*cR*lmuH*Zeta[3])/8 - (319*cA^2*lmmMS*lmuH*Zeta[3])/144 - 
         (9*cA^2*lmmMS^2*lmuH*Zeta[3])/16 - (143*cA^2*lmuH^2*Zeta[3])/144 - 
         (9*cA^2*lmmMS*lmuH^2*Zeta[3])/8 - (3*cA^2*lmuH^3*Zeta[3])/4 + 
         (1799*cA*nh*Zeta[3])/1536 + (665*cR*nh*Zeta[3])/256 + 
         (189*cA*lmmMS*nh*Zeta[3])/256 + (189*cR*lmmMS*nh*Zeta[3])/128 - 
         (77*cA^2*Pi^2*Zeta[3])/384 + (7*cA^2*lmmMS*Pi^2*Zeta[3])/192 + 
         (7*cA^2*lmuH*Pi^2*Zeta[3])/96 + (103*cA^2*Zeta[3]^2)/16 + 
         nl^2*(lmmMS^4/864 + (lmmMS^2*Pi^2)/864 + Pi^4/5760 - 
           (lmmMS*Zeta[3])/108) - (2123*cA^2*Zeta[5])/480 + 
         (69*cA^2*lmmMS*Zeta[5])/80 + (69*cA^2*lmuH*Zeta[5])/40 + 
         nl*((-1169153*cA)/93312 - (32263*cR)/1728 - (57053*cA*lmmMS)/15552 + 
           (23*cR*lmmMS)/288 - (5279*cA*lmmMS^2)/5184 - (37*cR*lmmMS^2)/48 + 
           (61*cA*lmmMS^3)/648 + (15*cR*lmmMS^3)/32 - (13*cA*lmmMS^4)/1152 - 
           (7*cA*lmmMS^5)/5760 - (25075*cA*lmuH)/3888 - (2027*cR*lmuH)/288 - 
           (229*cA*lmmMS*lmuH)/162 - (67*cR*lmmMS*lmuH)/48 - 
           (13*cA*lmmMS^2*lmuH)/216 - (cR*lmmMS^2*lmuH)/16 + 
           (5*cA*lmmMS^3*lmuH)/432 - (cA*lmmMS^4*lmuH)/192 - 
           (431*cA*lmuH^2)/324 - (67*cR*lmuH^2)/48 - (13*cA*lmmMS*lmuH^2)/
            108 - (cR*lmmMS*lmuH^2)/8 + (5*cA*lmmMS^2*lmuH^2)/144 - 
           (cA*lmmMS^3*lmuH^2)/144 - (13*cA*lmuH^3)/162 - (cR*lmuH^3)/12 + 
           (5*cA*lmmMS*lmuH^3)/108 + (5*cA*lmuH^4)/216 + (cA*lmmMS*lmuH^4)/
            144 + (cA*lmuH^5)/240 - (3125*cA*Pi^2)/31104 + (55*cR*Pi^2)/864 + 
           (119*cA*lmmMS*Pi^2)/2592 + (23*cR*lmmMS*Pi^2)/576 - 
           (23*cA*lmmMS^2*Pi^2)/1152 - (5*cA*lmmMS^3*Pi^2)/3456 - 
           (61*cA*lmuH*Pi^2)/1296 + (11*cR*lmuH*Pi^2)/288 - 
           (25*cA*lmmMS*lmuH*Pi^2)/864 - (5*cA*lmmMS^2*lmuH*Pi^2)/576 - 
           (25*cA*lmuH^2*Pi^2)/864 - (5*cA*lmmMS*lmuH^2*Pi^2)/288 - 
           (5*cA*lmuH^3*Pi^2)/432 - (5791*cA*Pi^4)/207360 + 
           (23*cR*Pi^4)/648 - (31*cA*lmmMS*Pi^4)/7680 + (cR*lmmMS*Pi^4)/108 - 
           (157*cA*lmuH*Pi^4)/11520 + (cR*lmuH*Pi^4)/54 - (881*cA*Zeta[3])/
            216 + (1493*cR*Zeta[3])/144 - (565*cA*lmmMS*Zeta[3])/432 + 
           (23*cR*lmmMS*Zeta[3])/12 - (11*cA*lmmMS^2*Zeta[3])/288 + 
           (cR*lmmMS^2*Zeta[3])/4 - (203*cA*lmuH*Zeta[3])/72 + 
           (23*cR*lmuH*Zeta[3])/6 - (43*cA*lmmMS*lmuH*Zeta[3])/72 + 
           cR*lmmMS*lmuH*Zeta[3] - (59*cA*lmuH^2*Zeta[3])/72 + 
           cR*lmuH^2*Zeta[3] + (77*cA*Pi^2*Zeta[3])/576 - (7*cR*Pi^2*Zeta[3])/
            72 - (287*cA*Zeta[5])/240 + 2*cR*Zeta[5])) + 
       rhoMS^2*((-108986798269*cA^2)/1365590016000 - (7613391649*cA*cR)/
          9953280000 - (57949169*cR^2)/58060800 + cA^2/(1344*ep^4) - 
         (8161*cA^2*lmmMS)/1270080 + (10147*cA*cR*lmmMS)/378000 + 
         (811*cR^2*lmmMS)/100800 + (757*cA^2*lmmMS^2)/138240 + 
         (5693*cA*cR*lmmMS^2)/151200 + (3*cR^2*lmmMS^2)/112 + 
         (95*cA^2*lmmMS^3)/96768 + (cA*cR*lmmMS^3)/96 + 
         (cA^2*lmmMS^4)/32256 - (961*cA^2*lmuH)/254016 + 
         (27997*cA*cR*lmuH)/4536000 + (971*cA^2*lmmMS*lmuH)/241920 + 
         (467*cA*cR*lmmMS*lmuH)/37800 + (17*cA^2*lmmMS^2*lmuH)/5376 + 
         (3*cA*cR*lmmMS^2*lmuH)/224 + (cA^2*lmmMS^3*lmuH)/4032 - 
         (cA^2*lmuH^2)/241920 - (13*cA*cR*lmuH^2)/9450 + 
         (29*cA^2*lmmMS*lmuH^2)/8064 + (cA*cR*lmmMS*lmuH^2)/224 + 
         (cA^2*lmmMS^2*lmuH^2)/1344 + (cA^2*lmuH^3)/672 + 
         (cA^2*lmmMS*lmuH^3)/1008 + (cA^2*lmuH^4)/2016 + 
         (9563651*cA*nh)/130056192000 - (35581669*cR*nh)/2786918400 + 
         (43*cA*lmmMS*nh)/134400 + (cR*lmmMS*nh)/2520 - (cR*lmmMS^2*nh)/672 - 
         (43*cA*lmuH*nh)/134400 + (cR*lmuH*nh)/480 + 
         ((95*cA^2)/16128 + (cA^2*lmmMS)/1344 + (cA^2*lmuH)/672 - 
           (cA*nl)/1152)/ep^3 + ((5371*cA^2)/483840 - (13*cA*cR)/4725 + 
           (95*cA^2*lmmMS)/16128 + (cA*cR*lmmMS)/112 + (cA^2*lmmMS^2)/2688 + 
           (17*cA^2*lmuH)/2688 + (cA^2*lmmMS*lmuH)/672 + (cA^2*lmuH^2)/672 + 
           ((-47*cA)/16128 - (cA*lmmMS)/1152 - (cA*lmuH)/1344)*nl + 
           nl^2/6048)/ep^2 + (8221*cA^2*Pi^2)/5806080 + 
         (4759*cA*cR*Pi^2)/1814400 + (55*cA^2*lmmMS*Pi^2)/193536 + 
         (cA*cR*lmmMS*Pi^2)/672 + (55*cA^2*lmuH*Pi^2)/96768 + 
         (cA*cR*lmuH*Pi^2)/1344 - (17*cA^2*Pi^4)/387072 + 
         nl^2*(1/12096 + lmmMS/4032 + lmmMS^2/12096 + Pi^2/72576) + 
         (13789799*cA^2*Zeta[3])/247726080 + (26633723*cA*cR*Zeta[3])/
          41287680 + (2179367*cR^2*Zeta[3])/2580480 - (3*cA^2*lmmMS*Zeta[3])/
          896 - (3*cA^2*lmuH*Zeta[3])/448 - (791*cA*nh*Zeta[3])/1572864 + 
         (20083*cR*nh*Zeta[3])/1179648 + ((2647*cA^2)/2540160 + 
           (731*cA*cR)/648000 + (5347*cA^2*lmmMS)/483840 + 
           (4343*cA*cR*lmmMS)/151200 + (95*cA^2*lmmMS^2)/32256 + 
           (3*cA*cR*lmmMS^2)/224 + (cA^2*lmmMS^3)/8064 + (983*cA^2*lmuH)/
            241920 - (13*cA*cR*lmuH)/4725 + (17*cA^2*lmmMS*lmuH)/2688 + 
           (cA*cR*lmmMS*lmuH)/112 + (cA^2*lmmMS^2*lmuH)/1344 + 
           (29*cA^2*lmuH^2)/8064 + (cA^2*lmmMS*lmuH^2)/672 + 
           (cA^2*lmuH^3)/1008 + (1/4032 + lmmMS/6048)*nl^2 + 
           (55*cA^2*Pi^2)/193536 + (cA*cR*Pi^2)/1344 + 
           nl*((-709*cA)/362880 + (2339*cR)/1814400 - (47*cA*lmmMS)/16128 - 
             (cR*lmmMS)/336 - (cA*lmmMS^2)/2304 - (17*cA*lmuH)/24192 - 
             (cA*lmmMS*lmuH)/1344 - (cA*lmuH^2)/4032 - (5*cA*Pi^2)/96768) - 
           (3*cA^2*Zeta[3])/896)/ep + nl*((3187*cA)/4762800 + 
           (17809*cR)/4233600 - (139*cA*lmmMS)/90720 - (7967*cR*lmmMS)/
            3628800 - (47*cA*lmmMS^2)/32256 - (cR*lmmMS^2)/336 - 
           (cA*lmmMS^3)/6912 + (127*cA*lmuH)/362880 + (cR*lmuH)/80640 - 
           (17*cA*lmmMS*lmuH)/24192 - (cA*lmmMS^2*lmuH)/2688 + 
           (cA*lmuH^2)/24192 - (cA*lmmMS*lmuH^2)/4032 - (61*cA*Pi^2)/193536 - 
           (cR*Pi^2)/4032 - (5*cA*lmmMS*Pi^2)/96768 - (5*cA*lmuH*Pi^2)/
            48384 - (11*cA*Zeta[3])/24192 + (cR*Zeta[3])/336) + 
         ep*((-552223906247381*cA^2)/2294191226880000 - 
           (429098456642299*cA*cR)/117050572800000 - (530893191821*cR^2)/
            83607552000 - (358194140407*cA^2*lmmMS)/1365590016000 - 
           (42701832841*cA*cR*lmmMS)/18063360000 - (40429667*cR^2*lmmMS)/
            13824000 - (6413*cA^2*lmmMS^2)/508032 + (46831*cA*cR*lmmMS^2)/
            3024000 + (127*cR^2*lmmMS^2)/1440 + (5203*cA^2*lmmMS^3)/2903040 + 
           (18047*cA*cR*lmmMS^3)/907200 + (3*cR^2*lmmMS^3)/56 + 
           (95*cA^2*lmmMS^4)/387072 + (5*cA*cR*lmmMS^4)/896 + 
           (cA^2*lmmMS^5)/161280 + (5326775*cA^2*lmuH)/170698752 + 
           (5139019*cA*cR*lmuH)/544320000 - (18247*cA^2*lmmMS*lmuH)/2540160 + 
           (106619*cA*cR*lmmMS*lmuH)/4536000 + (947*cA^2*lmmMS^2*lmuH)/
            483840 + (1609*cA*cR*lmmMS^2*lmuH)/75600 + (17*cA^2*lmmMS^3*lmuH)/
            16128 + (cA*cR*lmmMS^3*lmuH)/96 + (cA^2*lmmMS^4*lmuH)/16128 - 
           (17513*cA^2*lmuH^2)/5080320 + (27997*cA*cR*lmuH^2)/9072000 - 
           (cA^2*lmmMS*lmuH^2)/34560 + (467*cA*cR*lmmMS*lmuH^2)/75600 + 
           (29*cA^2*lmmMS^2*lmuH^2)/16128 + (3*cA*cR*lmmMS^2*lmuH^2)/448 + 
           (cA^2*lmmMS^3*lmuH^2)/4032 - (493*cA^2*lmuH^3)/362880 - 
           (13*cA*cR*lmuH^3)/28350 + (cA^2*lmmMS*lmuH^3)/672 + 
           (cA*cR*lmmMS*lmuH^3)/672 + (cA^2*lmmMS^2*lmuH^3)/2016 + 
           (25*cA^2*lmuH^4)/48384 + (cA^2*lmmMS*lmuH^4)/2016 + 
           (cA^2*lmuH^5)/5040 + (48646628729*cA*nh)/9103933440000 - 
           (3241436707*cR*nh)/37158912000 + (66441731*cA*lmmMS*nh)/
            43352064000 - (38607589*cR*lmmMS*nh)/928972800 + 
           (43*cA*lmmMS^2*nh)/53760 - (13*cR*lmmMS^2*nh)/4032 - 
           (cR*lmmMS^3*nh)/336 - (529*cA*lmuH*nh)/403200 + 
           (71*cR*lmuH*nh)/8640 - (43*cA*lmmMS*lmuH*nh)/67200 + 
           (cR*lmmMS*lmuH*nh)/240 - (43*cA*lmuH^2*nh)/268800 + 
           (cR*lmuH^2*nh)/960 + (22439*cA^2*Pi^2)/15240960 + 
           (93767*cA*cR*Pi^2)/54432000 + (811*cR^2*Pi^2)/1209600 + 
           (1171*cA^2*lmmMS*Pi^2)/829440 + (4759*cA*cR*lmmMS*Pi^2)/907200 + 
           (cR^2*lmmMS*Pi^2)/224 + (55*cA^2*lmmMS^2*Pi^2)/387072 + 
           (cA*cR*lmmMS^2*Pi^2)/672 + (5813*cA^2*lmuH*Pi^2)/2903040 + 
           (571*cA*cR*lmuH*Pi^2)/453600 + (55*cA^2*lmmMS*lmuH*Pi^2)/96768 + 
           (cA*cR*lmmMS*lmuH*Pi^2)/672 + (55*cA^2*lmuH^2*Pi^2)/96768 + 
           (cA*cR*lmuH^2*Pi^2)/2688 + (43*cA*nh*Pi^2)/806400 - 
           (17*cR*nh*Pi^2)/120960 - (cR*lmmMS*nh*Pi^2)/4032 - 
           (30560497*cA^2*Pi^4)/7431782400 - (13411519*cA*cR*Pi^4)/
            412876800 - (3202289*cR^2*Pi^4)/77414400 - (17*cA^2*lmmMS*Pi^4)/
            387072 - (17*cA^2*lmuH*Pi^4)/193536 + (1921*cA*nh*Pi^4)/
            47185920 - (48773*cR*nh*Pi^4)/35389440 - 
           (8029*cA^2*Pi^2*Log[2]^2)/5898240 - (577*cA*cR*Pi^2*Log[2]^2)/
            458752 + (10271*cR^2*Pi^2*Log[2]^2)/1290240 + 
           (113*cA*nh*Pi^2*Log[2]^2)/786432 - (2869*cR*nh*Pi^2*Log[2]^2)/
            589824 + (8029*cA^2*Log[2]^4)/5898240 + (577*cA*cR*Log[2]^4)/
            458752 - (10271*cR^2*Log[2]^4)/1290240 - (113*cA*nh*Log[2]^4)/
            786432 + (2869*cR*nh*Log[2]^4)/589824 + 
           (8029*cA^2*PolyLog[4, 1/2])/245760 + (1731*cA*cR*PolyLog[4, 1/2])/
            57344 - (10271*cR^2*PolyLog[4, 1/2])/53760 - 
           (113*cA*nh*PolyLog[4, 1/2])/32768 + (2869*cR*nh*PolyLog[4, 1/2])/
            24576 + nl^2*(lmmMS/12096 + lmmMS^2/8064 + lmmMS^3/36288 + 
             Pi^2/48384 + (lmmMS*Pi^2)/72576 - Zeta[3]/18144) + 
           (33084968809*cA^2*Zeta[3])/59454259200 + 
           (11204292037*cA*cR*Zeta[3])/1981808640 + (1537532983*cR^2*Zeta[3])/
            176947200 + (50728757*cA^2*lmmMS*Zeta[3])/247726080 + 
           (26347003*cA*cR*lmmMS*Zeta[3])/13762560 + 
           (2179367*cR^2*lmmMS*Zeta[3])/860160 - (3*cA^2*lmmMS^2*Zeta[3])/
            1792 - (281*cA^2*lmuH*Zeta[3])/12096 - (cA*cR*lmuH*Zeta[3])/336 - 
           (3*cA^2*lmmMS*lmuH*Zeta[3])/448 - (3*cA^2*lmuH^2*Zeta[3])/448 - 
           (449939*cA*nh*Zeta[3])/47185920 + (23506933*cR*nh*Zeta[3])/
            141557760 - (791*cA*lmmMS*nh*Zeta[3])/524288 + 
           (20083*cR*lmmMS*nh*Zeta[3])/393216 + (cA^2*Pi^2*Zeta[3])/4608 + 
           nl*((-12540221*cA)/4572288000 - (4175679923*cR)/213373440000 + 
             (84863*cA*lmmMS)/38102400 + (31677473*cR*lmmMS)/1524096000 - 
             (109*cA*lmmMS^2)/725760 - (4679*cR*lmmMS^2)/3628800 - 
             (47*cA*lmmMS^3)/96768 - (cR*lmmMS^3)/2016 - (cA*lmmMS^4)/27648 - 
             (209*cA*lmuH)/136080 - (3799*cR*lmuH)/967680 + 
             (127*cA*lmmMS*lmuH)/362880 + (cR*lmmMS*lmuH)/80640 - 
             (17*cA*lmmMS^2*lmuH)/48384 - (cA*lmmMS^3*lmuH)/8064 + 
             (31*cA*lmuH^2)/51840 + (cR*lmuH^2)/80640 + (cA*lmmMS*lmuH^2)/
              24192 - (cA*lmmMS^2*lmuH^2)/8064 + (5*cA*lmuH^3)/18144 + 
             (cA*lmuH^4)/24192 - (1963*cA*Pi^2)/4354560 - (1103*cR*Pi^2)/
              10886400 - (61*cA*lmmMS*Pi^2)/193536 - (cR*lmmMS*Pi^2)/2016 - 
             (5*cA*lmmMS^2*Pi^2)/193536 - (95*cA*lmuH*Pi^2)/290304 - 
             (5*cA*lmmMS*lmuH*Pi^2)/48384 - (5*cA*lmuH^2*Pi^2)/48384 - 
             (31*cA*Pi^4)/1290240 + (cR*Pi^4)/18144 - (1229*cA*Zeta[3])/
              145152 + (29*cR*Zeta[3])/1008 - (11*cA*lmmMS*Zeta[3])/24192 + 
             (cR*lmmMS*Zeta[3])/336 - (43*cA*lmuH*Zeta[3])/12096 + 
             (cR*lmuH*Zeta[3])/168) + (23*cA^2*Zeta[5])/4480) + 
         ep^2*((1787910880016285497*cA^2)/963560315289600000 - 
           (12213050174690791*cA*cR)/16387080192000000 - 
           (10604635655821*cR^2)/836075520000 - (2117642814018943*cA^2*lmmMS)/
            2294191226880000 - (3015344599819997*cA*cR*lmmMS)/
            273118003200000 - (2637135218881*cR^2*lmmMS)/139345920000 - 
           (1086683635621*cA^2*lmmMS^2)/2731180032000 - 
           (1181256016243*cA*cR*lmmMS^2)/325140480000 - 
           (164690131*cR^2*lmmMS^2)/38707200 - (47339*cA^2*lmmMS^3)/3810240 - 
           (9703*cA*cR*lmmMS^3)/567000 + (97759*cR^2*lmmMS^3)/604800 + 
           (5011*cA^2*lmmMS^4)/11612160 + (4547*cA*cR*lmmMS^4)/1814400 + 
           (25*cR^2*lmmMS^4)/448 + (19*cA^2*lmmMS^5)/387072 + 
           (31*cA*cR*lmmMS^5)/13440 + (cA^2*lmmMS^6)/967680 + 
           (66009030757*cA^2*lmuH)/358467379200 - (95983081*cA*cR*lmuH)/
            32659200000 + (25316827*cA^2*lmmMS*lmuH)/853493760 + 
           (8176519*cA*cR*lmmMS*lmuH)/272160000 - (35521*cA^2*lmmMS^2*lmuH)/
            5080320 + (263863*cA*cR*lmmMS^2*lmuH)/9072000 + 
           (899*cA^2*lmmMS^3*lmuH)/1451520 + (3893*cA*cR*lmmMS^3*lmuH)/
            226800 + (17*cA^2*lmmMS^4*lmuH)/64512 + (5*cA*cR*lmmMS^4*lmuH)/
            896 + (cA^2*lmmMS^5*lmuH)/80640 + (24963919*cA^2*lmuH^2)/
            853493760 + (5139019*cA*cR*lmuH^2)/1088640000 - 
           (2615*cA^2*lmmMS*lmuH^2)/508032 + (106619*cA*cR*lmmMS*lmuH^2)/
            9072000 - (19*cA^2*lmmMS^2*lmuH^2)/483840 + 
           (1609*cA*cR*lmmMS^2*lmuH^2)/151200 + (29*cA^2*lmmMS^3*lmuH^2)/
            48384 + (cA*cR*lmmMS^3*lmuH^2)/192 + (cA^2*lmmMS^4*lmuH^2)/
            16128 - (33319*cA^2*lmuH^3)/15240960 + (27997*cA*cR*lmuH^3)/
            27216000 - (31*cA^2*lmmMS*lmuH^3)/22680 + 
           (467*cA*cR*lmmMS*lmuH^3)/226800 + (cA^2*lmmMS^2*lmuH^3)/1344 + 
           (cA*cR*lmmMS^2*lmuH^3)/448 + (cA^2*lmmMS^3*lmuH^3)/6048 - 
           (739*cA^2*lmuH^4)/725760 - (13*cA*cR*lmuH^4)/113400 + 
           (25*cA^2*lmmMS*lmuH^4)/48384 + (cA*cR*lmmMS*lmuH^4)/2688 + 
           (cA^2*lmmMS^2*lmuH^4)/4032 + (13*cA^2*lmuH^5)/80640 + 
           (cA^2*lmmMS*lmuH^5)/5040 + (cA^2*lmuH^6)/15120 + 
           (27327246425027*cA*nh)/764730408960000 - (716422334557*cR*nh)/
            2229534720000 + (56280907129*cA*lmmMS*nh)/3034644480000 - 
           (10229858921*cR*lmmMS*nh)/37158912000 + (34786817*cA*lmmMS^2*nh)/
            9633792000 - (4812541*cR*lmmMS^2*nh)/68812800 + 
           (817*cA*lmmMS^3*nh)/806400 - (31*cR*lmmMS^3*nh)/4320 - 
           (25*cR*lmmMS^4*nh)/8064 - (3043*cA*lmuH*nh)/1209600 + 
           (433*cR*lmuH*nh)/25920 - (529*cA*lmmMS*lmuH*nh)/201600 + 
           (71*cR*lmmMS*lmuH*nh)/4320 - (43*cA*lmmMS^2*lmuH*nh)/67200 + 
           (cR*lmmMS^2*lmuH*nh)/240 - (529*cA*lmuH^2*nh)/806400 + 
           (71*cR*lmuH^2*nh)/17280 - (43*cA*lmmMS*lmuH^2*nh)/134400 + 
           (cR*lmmMS*lmuH^2*nh)/480 - (43*cA*lmuH^3*nh)/806400 + 
           (cR*lmuH^3*nh)/2880 - (329426708407*cA^2*Pi^2)/16387080192000 - 
           (1157554047731*cA*cR*Pi^2)/5852528640000 - (40429667*cR^2*Pi^2)/
            165888000 + (5707*cA^2*lmmMS*Pi^2)/30481920 + 
           (16937*cA*cR*lmmMS*Pi^2)/27216000 + (127*cR^2*lmmMS*Pi^2)/8640 + 
           (8149*cA^2*lmmMS^2*Pi^2)/11612160 + (11611*cA*cR*lmmMS^2*Pi^2)/
            3628800 + (3*cR^2*lmmMS^2*Pi^2)/224 + (55*cA^2*lmmMS^3*Pi^2)/
            1161216 + (cA*cR*lmmMS^3*Pi^2)/1008 + (51223*cA^2*lmuH*Pi^2)/
            15240960 + (39311*cA*cR*lmuH*Pi^2)/27216000 + 
           (5801*cA^2*lmmMS*lmuH*Pi^2)/2903040 + (571*cA*cR*lmmMS*lmuH*Pi^2)/
            226800 + (55*cA^2*lmmMS^2*lmuH*Pi^2)/193536 + 
           (cA*cR*lmmMS^2*lmuH*Pi^2)/672 + (5819*cA^2*lmuH^2*Pi^2)/2903040 + 
           (571*cA*cR*lmuH^2*Pi^2)/907200 + (55*cA^2*lmmMS*lmuH^2*Pi^2)/
            96768 + (cA*cR*lmmMS*lmuH^2*Pi^2)/1344 + (55*cA^2*lmuH^3*Pi^2)/
            145152 + (cA*cR*lmuH^3*Pi^2)/8064 + (123319811*cA*nh*Pi^2)/
            520224768000 - (46241509*cR*nh*Pi^2)/11147673600 + 
           (43*cA*lmmMS*nh*Pi^2)/230400 - (107*cR*lmmMS*nh*Pi^2)/120960 - 
           (cR*lmmMS^2*nh*Pi^2)/1344 - (43*cA*lmuH*nh*Pi^2)/1612800 + 
           (cR*lmuH*nh*Pi^2)/5760 - (18470648149*cA^2*Pi^4)/594542592000 - 
           (28186962437*cA*cR*Pi^4)/99090432000 - (1764394543*cR^2*Pi^4)/
            4128768000 - (88160851*cA^2*lmmMS*Pi^4)/7431782400 - 
           (13460159*cA*cR*lmmMS*Pi^4)/137625600 - (3202289*cR^2*lmmMS*Pi^4)/
            25804800 - (17*cA^2*lmmMS^2*Pi^4)/774144 - (3389*cA^2*lmuH*Pi^4)/
            11612160 + (cA*cR*lmuH*Pi^4)/17920 - (17*cA^2*lmmMS*lmuH*Pi^4)/
            193536 - (17*cA^2*lmuH^2*Pi^4)/193536 + (1092709*cA*nh*Pi^4)/
            1415577600 - (399925061*cR*nh*Pi^4)/29727129600 + 
           (1921*cA*lmmMS*nh*Pi^4)/15728640 - (48773*cR*lmmMS*nh*Pi^4)/
            11796480 + (4331*cA^2*Pi^6)/81285120 + (136493*cA^2*Pi^4*Log[2])/
            58982400 + (9809*cA*cR*Pi^4*Log[2])/4587520 - 
           (174607*cR^2*Pi^4*Log[2])/12902400 - (1921*cA*nh*Pi^4*Log[2])/
            7864320 + (48773*cR*nh*Pi^4*Log[2])/5898240 - 
           (9804179*cA^2*Pi^2*Log[2]^2)/1415577600 - 
           (89914399*cA*cR*Pi^2*Log[2]^2)/4954521600 + 
           (13211971*cR^2*Pi^2*Log[2]^2)/206438400 - 
           (8029*cA^2*lmmMS*Pi^2*Log[2]^2)/1966080 - 
           (1731*cA*cR*lmmMS*Pi^2*Log[2]^2)/458752 + 
           (10271*cR^2*lmmMS*Pi^2*Log[2]^2)/430080 + 
           (64277*cA*nh*Pi^2*Log[2]^2)/23592960 - 
           (23506933*cR*nh*Pi^2*Log[2]^2)/495452160 + 
           (113*cA*lmmMS*nh*Pi^2*Log[2]^2)/262144 - 
           (2869*cR*lmmMS*nh*Pi^2*Log[2]^2)/196608 + 
           (8029*cA^2*Pi^2*Log[2]^3)/2949120 + (577*cA*cR*Pi^2*Log[2]^3)/
            229376 - (10271*cR^2*Pi^2*Log[2]^3)/645120 - 
           (113*cA*nh*Pi^2*Log[2]^3)/393216 + (2869*cR*nh*Pi^2*Log[2]^3)/
            294912 + (9804179*cA^2*Log[2]^4)/1415577600 + 
           (89914399*cA*cR*Log[2]^4)/4954521600 - (13211971*cR^2*Log[2]^4)/
            206438400 + (8029*cA^2*lmmMS*Log[2]^4)/1966080 + 
           (1731*cA*cR*lmmMS*Log[2]^4)/458752 - (10271*cR^2*lmmMS*Log[2]^4)/
            430080 - (64277*cA*nh*Log[2]^4)/23592960 + 
           (23506933*cR*nh*Log[2]^4)/495452160 - (113*cA*lmmMS*nh*Log[2]^4)/
            262144 + (2869*cR*lmmMS*nh*Log[2]^4)/196608 - 
           (8029*cA^2*Log[2]^5)/4915200 - (1731*cA*cR*Log[2]^5)/1146880 + 
           (10271*cR^2*Log[2]^5)/1075200 + (113*cA*nh*Log[2]^5)/655360 - 
           (2869*cR*nh*Log[2]^5)/491520 + (9804179*cA^2*PolyLog[4, 1/2])/
            58982400 + (89914399*cA*cR*PolyLog[4, 1/2])/206438400 - 
           (13211971*cR^2*PolyLog[4, 1/2])/8601600 + 
           (8029*cA^2*lmmMS*PolyLog[4, 1/2])/81920 + 
           (5193*cA*cR*lmmMS*PolyLog[4, 1/2])/57344 - 
           (10271*cR^2*lmmMS*PolyLog[4, 1/2])/17920 - 
           (64277*cA*nh*PolyLog[4, 1/2])/983040 + 
           (23506933*cR*nh*PolyLog[4, 1/2])/20643840 - 
           (339*cA*lmmMS*nh*PolyLog[4, 1/2])/32768 + 
           (2869*cR*lmmMS*nh*PolyLog[4, 1/2])/8192 + 
           (8029*cA^2*PolyLog[5, 1/2])/40960 + (5193*cA*cR*PolyLog[5, 1/2])/
            28672 - (10271*cR^2*PolyLog[5, 1/2])/8960 - 
           (339*cA*nh*PolyLog[5, 1/2])/16384 + (2869*cR*nh*PolyLog[5, 1/2])/
            4096 - (1046922196571*cA^2*Zeta[3])/8323596288000 + 
           (24016195345423*cA*cR*Zeta[3])/1783627776000 + 
           (403744843499*cR^2*Zeta[3])/12386304000 + 
           (103928196667*cA^2*lmmMS*Zeta[3])/59454259200 + 
           (55874594009*cA*cR*lmmMS*Zeta[3])/3303014400 + 
           (10755358081*cR^2*lmmMS*Zeta[3])/412876800 + 
           (161545631*cA^2*lmmMS^2*Zeta[3])/495452160 + 
           (79122929*cA*cR*lmmMS^2*Zeta[3])/27525120 + 
           (2179367*cR^2*lmmMS^2*Zeta[3])/573440 - (cA^2*lmmMS^3*Zeta[3])/
            1792 - (1847*cA^2*lmuH*Zeta[3])/34560 + (29*cA*cR*lmuH*Zeta[3])/
            12600 - (281*cA^2*lmmMS*lmuH*Zeta[3])/12096 - 
           (5*cA*cR*lmmMS*lmuH*Zeta[3])/168 - (3*cA^2*lmmMS^2*lmuH*Zeta[3])/
            896 - (193*cA^2*lmuH^2*Zeta[3])/12096 - (cA*cR*lmuH^2*Zeta[3])/
            672 - (3*cA^2*lmmMS*lmuH^2*Zeta[3])/448 - (cA^2*lmuH^3*Zeta[3])/
            224 - (115719101*cA*nh*Zeta[3])/1651507200 + 
           (9199435673*cR*nh*Zeta[3])/11890851840 - 
           (449939*cA*lmmMS*nh*Zeta[3])/15728640 + 
           (18319579*cR*lmmMS*nh*Zeta[3])/36700160 - 
           (2373*cA*lmmMS^2*nh*Zeta[3])/1048576 + 
           (20083*cR*lmmMS^2*nh*Zeta[3])/262144 + (93171*cA^2*Pi^2*Zeta[3])/
            5242880 + (3769709*cA*cR*Pi^2*Zeta[3])/23592960 + 
           (2179367*cR^2*Pi^2*Zeta[3])/10321920 + (cA^2*lmmMS*Pi^2*Zeta[3])/
            4608 + (cA^2*lmuH*Pi^2*Zeta[3])/2304 - (791*cA*nh*Pi^2*Zeta[3])/
            6291456 + (20083*cR*nh*Pi^2*Zeta[3])/4718592 + 
           (103*cA^2*Zeta[3]^2)/2688 + nl^2*(lmmMS^2/24192 + lmmMS^3/24192 + 
             lmmMS^4/145152 + Pi^2/145152 + (lmmMS*Pi^2)/48384 + 
             (lmmMS^2*Pi^2)/145152 + Pi^4/967680 - Zeta[3]/12096 - 
             (lmmMS*Zeta[3])/18144) + (178260101*cA^2*Zeta[5])/165150720 + 
           (104941483*cA*cR*Zeta[5])/9175040 + (4086739*cR^2*Zeta[5])/
            245760 + (23*cA^2*lmmMS*Zeta[5])/4480 + (23*cA^2*lmuH*Zeta[5])/
            2240 + (17515*cA*nh*Zeta[5])/1048576 - (444695*cR*nh*Zeta[5])/
            786432 + nl*((-52954146529*cA)/6721263360000 - (543511921411*cR)/
              67212633600000 + (29805017*cA*lmmMS)/16003008000 - 
             (1579940317*cR*lmmMS)/80015040000 + (88297*cA*lmmMS^2)/
              38102400 + (250175*cR*lmmMS^2)/6096384 + (151*cA*lmmMS^3)/
              272160 + (59557*cR*lmmMS^3)/21772800 - (47*cA*lmmMS^4)/387072 + 
             (5*cR*lmmMS^4)/4032 - (cA*lmmMS^5)/138240 - (38015*cA*lmuH)/
              5225472 - (356327*cR*lmuH)/11612160 - (209*cA*lmmMS*lmuH)/
              136080 - (3799*cR*lmmMS*lmuH)/967680 + (127*cA*lmmMS^2*lmuH)/
              725760 + (cR*lmmMS^2*lmuH)/161280 - (17*cA*lmmMS^3*lmuH)/
              145152 - (cA*lmmMS^4*lmuH)/32256 - (283*cA*lmuH^2)/272160 - 
             (3799*cR*lmuH^2)/967680 + (31*cA*lmmMS*lmuH^2)/51840 + 
             (cR*lmmMS*lmuH^2)/80640 + (cA*lmmMS^2*lmuH^2)/48384 - 
             (cA*lmmMS^3*lmuH^2)/24192 + (131*cA*lmuH^3)/272160 + 
             (cR*lmuH^3)/120960 + (5*cA*lmmMS*lmuH^3)/18144 + 
             (29*cA*lmuH^4)/145152 + (cA*lmmMS*lmuH^4)/24192 + 
             (cA*lmuH^5)/40320 - (242317*cA*Pi^2)/457228800 + 
             (20216449*cR*Pi^2)/9144576000 - (379*cA*lmmMS*Pi^2)/1088640 - 
             (829*cR*lmmMS*Pi^2)/6220800 - (61*cA*lmmMS^2*Pi^2)/387072 - 
             (cR*lmmMS^2*Pi^2)/8064 - (5*cA*lmmMS^3*Pi^2)/580608 - 
             (2867*cA*lmuH*Pi^2)/4354560 + (53*cR*lmuH*Pi^2)/322560 - 
             (95*cA*lmmMS*lmuH*Pi^2)/290304 - (5*cA*lmmMS^2*lmuH*Pi^2)/
              96768 - (95*cA*lmuH^2*Pi^2)/290304 - (5*cA*lmmMS*lmuH^2*Pi^2)/
              48384 - (5*cA*lmuH^3*Pi^2)/72576 - (14093*cA*Pi^4)/69672960 - 
             (719*cR*Pi^4)/2177280 - (31*cA*lmmMS*Pi^4)/1290240 + 
             (cR*lmmMS*Pi^4)/18144 - (157*cA*lmuH*Pi^4)/1935360 + 
             (cR*lmuH*Pi^4)/9072 - (1729*cA*Zeta[3])/51840 + 
             (191827*cR*Zeta[3])/2177280 - (1229*cA*lmmMS*Zeta[3])/145152 + 
             (3*cR*lmmMS*Zeta[3])/56 - (11*cA*lmmMS^2*Zeta[3])/48384 + 
             (cR*lmmMS^2*Zeta[3])/672 - (535*cA*lmuH*Zeta[3])/24192 + 
             (2*cR*lmuH*Zeta[3])/63 - (43*cA*lmmMS*lmuH*Zeta[3])/12096 + 
             (cR*lmmMS*lmuH*Zeta[3])/168 - (59*cA*lmuH^2*Zeta[3])/12096 + 
             (cR*lmuH^2*Zeta[3])/168 + (11*cA*Pi^2*Zeta[3])/13824 - 
             (cR*Pi^2*Zeta[3])/1728 - (41*cA*Zeta[5])/5760 + 
             (cR*Zeta[5])/84))) + rhoMS*((-55059073*cA^2)/124416000 - 
         (36943*cA*cR)/13824 - (112711*cR^2)/46080 + (7*cA^2)/(960*ep^4) - 
         (67699*cA^2*lmmMS)/518400 + (473*cA*cR*lmmMS)/3456 + 
         (79*cR^2*lmmMS)/1920 + (145*cA^2*lmmMS^2)/6912 + 
         (457*cA*cR*lmmMS^2)/2880 + (21*cR^2*lmmMS^2)/320 + 
         (623*cA^2*lmmMS^3)/69120 + (49*cA*cR*lmmMS^3)/960 + 
         (7*cA^2*lmmMS^4)/23040 - (14311*cA^2*lmuH)/259200 + 
         (31*cA*cR*lmuH)/480 - (31*cA^2*lmmMS*lmuH)/4320 + 
         (5*cA*cR*lmmMS*lmuH)/144 + (7*cA^2*lmmMS^2*lmuH)/256 + 
         (21*cA*cR*lmmMS^2*lmuH)/320 + (7*cA^2*lmmMS^3*lmuH)/2880 - 
         (65*cA^2*lmuH^2)/3456 - (19*cA*cR*lmuH^2)/1440 + 
         (161*cA^2*lmmMS*lmuH^2)/5760 + (7*cA*cR*lmmMS*lmuH^2)/320 + 
         (7*cA^2*lmmMS^2*lmuH^2)/960 + (7*cA^2*lmuH^3)/720 + 
         (7*cA^2*lmmMS*lmuH^3)/720 + (7*cA^2*lmuH^4)/1440 - 
         (76697*cA*nh)/8294400 - (1763*cR*nh)/20736 + (cA*lmmMS*nh)/480 + 
         (7*cR*lmmMS*nh)/576 - (7*cR*lmmMS^2*nh)/960 - (cA*lmuH*nh)/480 + 
         ((623*cA^2)/11520 + (7*cA^2*lmmMS)/960 + (7*cA^2*lmuH)/480 - 
           (49*cA*nl)/5760)/ep^3 + ((1247*cA^2)/17280 - (19*cA*cR)/720 + 
           (623*cA^2*lmmMS)/11520 + (7*cA*cR*lmmMS)/160 + (7*cA^2*lmmMS^2)/
            1920 + (7*cA^2*lmuH)/128 + (7*cA^2*lmmMS*lmuH)/480 + 
           (7*cA^2*lmuH^2)/480 + ((-7*cA)/288 - (49*cA*lmmMS)/5760 - 
             (7*cA*lmuH)/960)*nl + (7*nl^2)/4320)/ep^2 + 
         (2423*cA^2*Pi^2)/207360 + (407*cA*cR*Pi^2)/34560 + 
         (77*cA^2*lmmMS*Pi^2)/27648 + (7*cA*cR*lmmMS*Pi^2)/960 + 
         (77*cA^2*lmuH*Pi^2)/13824 + (7*cA*cR*lmuH*Pi^2)/1920 - 
         (119*cA^2*Pi^4)/276480 + nl^2*((7*lmmMS)/4320 + (7*lmmMS^2)/8640 + 
           (7*Pi^2)/51840) + (340943*cA^2*Zeta[3])/1105920 + 
         (34903*cA*cR*Zeta[3])/15360 + (63917*cR^2*Zeta[3])/30720 - 
         (21*cA^2*lmmMS*Zeta[3])/640 - (21*cA^2*lmuH*Zeta[3])/320 + 
         (77*cA*nh*Zeta[3])/24576 + (77*cR*nh*Zeta[3])/768 + 
         ((-28687*cA^2)/518400 + (7*cA*cR)/432 + (1073*cA^2*lmmMS)/17280 + 
           (331*cA*cR*lmmMS)/2880 + (623*cA^2*lmmMS^2)/23040 + 
           (21*cA*cR*lmmMS^2)/320 + (7*cA^2*lmmMS^3)/5760 + 
           (5*cA^2*lmuH)/1728 - (19*cA*cR*lmuH)/720 + (7*cA^2*lmmMS*lmuH)/
            128 + (7*cA*cR*lmmMS*lmuH)/160 + (7*cA^2*lmmMS^2*lmuH)/960 + 
           (161*cA^2*lmuH^2)/5760 + (7*cA^2*lmmMS*lmuH^2)/480 + 
           (7*cA^2*lmuH^3)/720 + (7/4320 + (7*lmmMS)/4320)*nl^2 + 
           (77*cA^2*Pi^2)/27648 + (7*cA*cR*Pi^2)/1920 + 
           nl*((-197*cA)/51840 + (43*cR)/3456 - (7*cA*lmmMS)/288 - 
             (7*cR*lmmMS)/480 - (49*cA*lmmMS^2)/11520 - (7*cA*lmuH)/2160 - 
             (7*cA*lmmMS*lmuH)/960 - (7*cA*lmuH^2)/2880 - (7*cA*Pi^2)/
              13824) - (21*cA^2*Zeta[3])/640)/ep + 
         nl*((5891*cA)/1555200 + (1939*cR)/518400 + (7*cA*lmmMS)/5184 - 
           (41*cR*lmmMS)/17280 - (7*cA*lmmMS^2)/576 - (7*cR*lmmMS^2)/480 - 
           (49*cA*lmmMS^3)/34560 + (209*cA*lmuH)/51840 - (19*cR*lmuH)/8640 - 
           (7*cA*lmmMS*lmuH)/2160 - (7*cA*lmmMS^2*lmuH)/1920 + 
           (7*cA*lmuH^2)/4320 - (7*cA*lmmMS*lmuH^2)/2880 - 
           (49*cA*Pi^2)/17280 - (7*cR*Pi^2)/5760 - (7*cA*lmmMS*Pi^2)/13824 - 
           (7*cA*lmuH*Pi^2)/6912 - (77*cA*Zeta[3])/17280 + 
           (7*cR*Zeta[3])/240) + ep*((39068947067*cA^2)/7464960000 + 
           (147545893*cA*cR)/24883200 - (27349*cR^2)/36864 - 
           (185841331*cA^2*lmmMS)/124416000 - (8845807*cA*cR*lmmMS)/1036800 - 
           (36157*cR^2*lmmMS)/5120 - (144763*cA^2*lmmMS^2)/1036800 + 
           (1177*cA*cR*lmmMS^2)/17280 + (293*cR^2*lmmMS^2)/960 + 
           (29*cA^2*lmmMS^3)/103680 + (1387*cA*cR*lmmMS^3)/17280 + 
           (21*cR^2*lmmMS^3)/160 + (623*cA^2*lmmMS^4)/276480 + 
           (7*cA*cR*lmmMS^4)/256 + (7*cA^2*lmmMS^5)/115200 + 
           (2342767*cA^2*lmuH)/7776000 - (193*cA*cR*lmuH)/12960 - 
           (24727*cA^2*lmmMS*lmuH)/259200 + (83*cA*cR*lmmMS*lmuH)/480 - 
           (59*cA^2*lmmMS^2*lmuH)/4320 + (113*cA*cR*lmmMS^2*lmuH)/1440 + 
           (7*cA^2*lmmMS^3*lmuH)/768 + (49*cA*cR*lmmMS^3*lmuH)/960 + 
           (7*cA^2*lmmMS^4*lmuH)/11520 - (9103*cA^2*lmuH^2)/259200 + 
           (31*cA*cR*lmuH^2)/960 - (103*cA^2*lmmMS*lmuH^2)/4320 + 
           (5*cA*cR*lmmMS*lmuH^2)/288 + (161*cA^2*lmmMS^2*lmuH^2)/11520 + 
           (21*cA*cR*lmmMS^2*lmuH^2)/640 + (7*cA^2*lmmMS^3*lmuH^2)/2880 - 
           (205*cA^2*lmuH^3)/10368 - (19*cA*cR*lmuH^3)/4320 + 
           (7*cA^2*lmmMS*lmuH^3)/720 + (7*cA*cR*lmmMS*lmuH^3)/960 + 
           (7*cA^2*lmmMS^2*lmuH^3)/1440 + (91*cA^2*lmuH^4)/34560 + 
           (7*cA^2*lmmMS*lmuH^4)/1440 + (7*cA^2*lmuH^5)/3600 + 
           (6967757*cA*nh)/124416000 - (140651*cR*nh)/414720 - 
           (76697*cA*lmmMS*nh)/2764800 - (1595*cR*lmmMS*nh)/6912 + 
           (cA*lmmMS^2*nh)/192 + (7*cR*lmmMS^2*nh)/720 - (7*cR*lmmMS^3*nh)/
            480 - (cA*lmmMS*lmuH*nh)/240 - (cA*lmuH^2*nh)/960 + 
           (43103*cA^2*Pi^2)/6220800 + (1249*cA*cR*Pi^2)/207360 + 
           (79*cR^2*Pi^2)/23040 + (2249*cA^2*lmmMS*Pi^2)/207360 + 
           (407*cA*cR*lmmMS*Pi^2)/17280 + (7*cR^2*lmmMS*Pi^2)/640 + 
           (77*cA^2*lmmMS^2*Pi^2)/55296 + (7*cA*cR*lmmMS^2*Pi^2)/960 + 
           (1663*cA^2*lmuH*Pi^2)/103680 + (11*cA*cR*lmuH*Pi^2)/2160 + 
           (77*cA^2*lmmMS*lmuH*Pi^2)/13824 + (7*cA*cR*lmmMS*lmuH*Pi^2)/960 + 
           (77*cA^2*lmuH^2*Pi^2)/13824 + (7*cA*cR*lmuH^2*Pi^2)/3840 + 
           (cA*nh*Pi^2)/2880 + (7*cR*nh*Pi^2)/6912 - (7*cR*lmmMS*nh*Pi^2)/
            5760 - (907099*cA^2*Pi^4)/33177600 - (17281*cA*cR*Pi^4)/153600 - 
           (93659*cR^2*Pi^4)/921600 - (119*cA^2*lmmMS*Pi^4)/276480 - 
           (119*cA^2*lmuH*Pi^4)/138240 - (187*cA*nh*Pi^4)/737280 - 
           (187*cR*nh*Pi^4)/23040 - (157*cA^2*Pi^2*Log[2]^2)/12288 + 
           (37*cA*cR*Pi^2*Log[2]^2)/2560 + (341*cR^2*Pi^2*Log[2]^2)/15360 - 
           (11*cA*nh*Pi^2*Log[2]^2)/12288 - (11*cR*nh*Pi^2*Log[2]^2)/384 + 
           (157*cA^2*Log[2]^4)/12288 - (37*cA*cR*Log[2]^4)/2560 - 
           (341*cR^2*Log[2]^4)/15360 + (11*cA*nh*Log[2]^4)/12288 + 
           (11*cR*nh*Log[2]^4)/384 + (157*cA^2*PolyLog[4, 1/2])/512 - 
           (111*cA*cR*PolyLog[4, 1/2])/320 - (341*cR^2*PolyLog[4, 1/2])/640 + 
           (11*cA*nh*PolyLog[4, 1/2])/512 + (11*cR*nh*PolyLog[4, 1/2])/16 + 
           nl^2*((7*lmmMS^2)/8640 + (7*lmmMS^3)/25920 + (7*Pi^2)/51840 + 
             (7*lmmMS*Pi^2)/51840 - (7*Zeta[3])/12960) - 
           (5066057*cA^2*Zeta[3])/2654208 + (1511309*cA*cR*Zeta[3])/368640 + 
           (220453*cR^2*Zeta[3])/24576 + (1396013*cA^2*lmmMS*Zeta[3])/
            1105920 + (103141*cA*cR*lmmMS*Zeta[3])/15360 + 
           (63917*cR^2*lmmMS*Zeta[3])/10240 - (21*cA^2*lmmMS^2*Zeta[3])/
            1280 - (3367*cA^2*lmuH*Zeta[3])/17280 - (7*cA*cR*lmuH*Zeta[3])/
            480 - (21*cA^2*lmmMS*lmuH*Zeta[3])/320 - (21*cA^2*lmuH^2*Zeta[3])/
            320 - (2849*cA*nh*Zeta[3])/73728 + (66409*cR*nh*Zeta[3])/92160 + 
           (77*cA*lmmMS*nh*Zeta[3])/8192 + (77*cR*lmmMS*nh*Zeta[3])/256 + 
           (49*cA^2*Pi^2*Zeta[3])/23040 + nl*((-3662951*cA)/46656000 - 
             (408509*cR)/1728000 + (14039*cA*lmmMS)/1555200 + 
             (57457*cR*lmmMS)/518400 + (523*cA*lmmMS^2)/103680 - 
             (7*cR*lmmMS^2)/2304 - (7*cA*lmmMS^3)/1728 - (7*cR*lmmMS^3)/
              2880 - (49*cA*lmmMS^4)/138240 - (4181*cA*lmuH)/155520 - 
             (1403*cR*lmuH)/25920 + (209*cA*lmmMS*lmuH)/51840 - 
             (19*cR*lmmMS*lmuH)/8640 - (7*cA*lmmMS^2*lmuH)/4320 - 
             (7*cA*lmmMS^3*lmuH)/5760 + (209*cA*lmuH^2)/51840 - 
             (19*cR*lmuH^2)/8640 + (7*cA*lmmMS*lmuH^2)/4320 - 
             (7*cA*lmmMS^2*lmuH^2)/5760 + (7*cA*lmuH^3)/2592 + 
             (7*cA*lmuH^4)/17280 - (319*cA*Pi^2)/124416 + (11*cR*Pi^2)/
              13824 - (49*cA*lmmMS*Pi^2)/17280 - (7*cR*lmmMS*Pi^2)/2880 - 
             (7*cA*lmmMS^2*Pi^2)/27648 - (7*cA*lmuH*Pi^2)/2592 - 
             (7*cA*lmmMS*lmuH*Pi^2)/6912 - (7*cA*lmuH^2*Pi^2)/6912 - 
             (217*cA*Pi^4)/921600 + (7*cR*Pi^4)/12960 - (2093*cA*Zeta[3])/
              25920 + (49*cR*Zeta[3])/240 - (77*cA*lmmMS*Zeta[3])/17280 + 
             (7*cR*lmmMS*Zeta[3])/240 - (301*cA*lmuH*Zeta[3])/8640 + 
             (7*cR*lmuH*Zeta[3])/120) + (161*cA^2*Zeta[5])/3200) + 
         ep^2*((-2041664377057*cA^2)/111974400000 - (14760096163*cA*cR)/
            373248000 - (59418797*cR^2)/1658880 + (104640991889*cA^2*lmmMS)/
            7464960000 + (2212257131*cA*cR*lmmMS)/124416000 - 
           (974609*cR^2*lmmMS)/552960 - (561618217*cA^2*lmmMS^2)/248832000 - 
           (5540089*cA*cR*lmmMS^2)/414720 - (310549*cR^2*lmmMS^2)/30720 - 
           (296011*cA^2*lmmMS^3)/3110400 - (10211*cA*cR*lmmMS^3)/103680 + 
           (6163*cR^2*lmmMS^3)/11520 - (1363*cA^2*lmmMS^4)/414720 + 
           (127*cA*cR*lmmMS^4)/34560 + (35*cR^2*lmmMS^4)/256 + 
           (623*cA^2*lmmMS^5)/1382400 + (217*cA*cR*lmmMS^5)/19200 + 
           (7*cA^2*lmmMS^6)/691200 + (330671171*cA^2*lmuH)/233280000 - 
           (2773*cA*cR*lmuH)/77760 + (2452909*cA^2*lmmMS*lmuH)/7776000 + 
           (181*cA*cR*lmmMS*lmuH)/12960 - (45559*cA^2*lmmMS^2*lmuH)/518400 + 
           (187*cA*cR*lmmMS^2*lmuH)/960 - (73*cA^2*lmmMS^3*lmuH)/6480 + 
           (289*cA*cR*lmmMS^3*lmuH)/4320 + (7*cA^2*lmmMS^4*lmuH)/3072 + 
           (7*cA*cR*lmmMS^4*lmuH)/256 + (7*cA^2*lmmMS^5*lmuH)/57600 + 
           (519949*cA^2*lmuH^2)/1944000 - (193*cA*cR*lmuH^2)/25920 - 
           (14311*cA^2*lmmMS*lmuH^2)/259200 + (83*cA*cR*lmmMS*lmuH^2)/960 - 
           (293*cA^2*lmmMS^2*lmuH^2)/17280 + (113*cA*cR*lmmMS^2*lmuH^2)/
            2880 + (161*cA^2*lmmMS^3*lmuH^2)/34560 + 
           (49*cA*cR*lmmMS^3*lmuH^2)/1920 + (7*cA^2*lmmMS^4*lmuH^2)/11520 - 
           (6499*cA^2*lmuH^3)/388800 + (31*cA*cR*lmuH^3)/2880 - 
           (139*cA^2*lmmMS*lmuH^3)/6480 + (5*cA*cR*lmmMS*lmuH^3)/864 + 
           (7*cA^2*lmmMS^2*lmuH^3)/1440 + (7*cA*cR*lmmMS^2*lmuH^3)/640 + 
           (7*cA^2*lmmMS^3*lmuH^3)/4320 - (485*cA^2*lmuH^4)/41472 - 
           (19*cA*cR*lmuH^4)/17280 + (91*cA^2*lmmMS*lmuH^4)/34560 + 
           (7*cA*cR*lmmMS*lmuH^4)/3840 + (7*cA^2*lmmMS^2*lmuH^4)/2880 + 
           (7*cA^2*lmuH^5)/11520 + (7*cA^2*lmmMS*lmuH^5)/3600 + 
           (7*cA^2*lmuH^6)/10800 + (461405941*cA*nh)/3732480000 - 
           (4315699*cR*nh)/3732480 + (6881357*cA*lmmMS*nh)/41472000 - 
           (138971*cR*lmmMS*nh)/138240 - (76697*cA*lmmMS^2*nh)/1843200 - 
           (2621*cR*lmmMS^2*nh)/7680 + (19*cA*lmmMS^3*nh)/2880 - 
           (49*cR*lmmMS^3*nh)/17280 - (35*cR*lmmMS^4*nh)/2304 + 
           (cA*lmuH*nh)/480 - (cA*lmmMS^2*lmuH*nh)/240 - (cA*lmmMS*lmuH^2*nh)/
            480 - (cA*lmuH^3*nh)/2880 - (169453603*cA^2*Pi^2)/1492992000 - 
           (8830367*cA*cR*Pi^2)/12441600 - (36157*cR^2*Pi^2)/61440 - 
           (13129*cA^2*lmmMS*Pi^2)/6220800 - (317*cA*cR*lmmMS*Pi^2)/103680 + 
           (293*cR^2*lmmMS*Pi^2)/5760 + (1901*cA^2*lmmMS^2*Pi^2)/414720 + 
           (187*cA*cR*lmmMS^2*Pi^2)/13824 + (21*cR^2*lmmMS^2*Pi^2)/640 + 
           (77*cA^2*lmmMS^3*Pi^2)/165888 + (7*cA*cR*lmmMS^3*Pi^2)/1440 + 
           (75659*cA^2*lmuH*Pi^2)/3110400 + (13*cA*cR*lmuH*Pi^2)/1440 + 
           (197*cA^2*lmmMS*lmuH*Pi^2)/12960 + (11*cA*cR*lmmMS*lmuH*Pi^2)/
            1080 + (77*cA^2*lmmMS^2*lmuH*Pi^2)/27648 + 
           (7*cA*cR*lmmMS^2*lmuH*Pi^2)/960 + (3413*cA^2*lmuH^2*Pi^2)/207360 + 
           (11*cA*cR*lmuH^2*Pi^2)/4320 + (77*cA^2*lmmMS*lmuH^2*Pi^2)/13824 + 
           (7*cA*cR*lmmMS*lmuH^2*Pi^2)/1920 + (77*cA^2*lmuH^3*Pi^2)/20736 + 
           (7*cA*cR*lmuH^3*Pi^2)/11520 - (76697*cA*nh*Pi^2)/33177600 - 
           (1595*cR*nh*Pi^2)/82944 + (7*cA*lmmMS*nh*Pi^2)/5760 + 
           (7*cR*lmmMS*nh*Pi^2)/4320 - (7*cR*lmmMS^2*nh*Pi^2)/1920 - 
           (cA*lmuH*nh*Pi^2)/5760 + (9935129*cA^2*Pi^4)/132710400 - 
           (771737*cA*cR*Pi^4)/3686400 - (930041*cR^2*Pi^4)/2211840 - 
           (2581549*cA^2*lmmMS*Pi^4)/33177600 - (52109*cA*cR*lmmMS*Pi^4)/
            153600 - (93659*cR^2*lmmMS*Pi^4)/307200 - (119*cA^2*lmmMS^2*Pi^4)/
            552960 - (20153*cA^2*lmuH*Pi^4)/8294400 + (7*cA*cR*lmuH*Pi^4)/
            25600 - (119*cA^2*lmmMS*lmuH*Pi^4)/138240 - 
           (119*cA^2*lmuH^2*Pi^4)/138240 + (6919*cA*nh*Pi^4)/2211840 - 
           (161419*cR*nh*Pi^4)/2764800 - (187*cA*lmmMS*nh*Pi^4)/245760 - 
           (187*cR*lmmMS*nh*Pi^4)/7680 + (4331*cA^2*Pi^6)/8294400 + 
           (2669*cA^2*Pi^4*Log[2])/122880 - (629*cA*cR*Pi^4*Log[2])/25600 - 
           (5797*cR^2*Pi^4*Log[2])/153600 + (187*cA*nh*Pi^4*Log[2])/122880 + 
           (187*cR*nh*Pi^4*Log[2])/3840 - (1411*cA^2*Pi^2*Log[2]^2)/49152 - 
           (2575*cA*cR*Pi^2*Log[2]^2)/36864 + (9383*cR^2*Pi^2*Log[2]^2)/
            36864 - (157*cA^2*lmmMS*Pi^2*Log[2]^2)/4096 + 
           (111*cA*cR*lmmMS*Pi^2*Log[2]^2)/2560 + 
           (341*cR^2*lmmMS*Pi^2*Log[2]^2)/5120 + (407*cA*nh*Pi^2*Log[2]^2)/
            36864 - (9487*cR*nh*Pi^2*Log[2]^2)/46080 - 
           (11*cA*lmmMS*nh*Pi^2*Log[2]^2)/4096 - (11*cR*lmmMS*nh*Pi^2*
             Log[2]^2)/128 + (157*cA^2*Pi^2*Log[2]^3)/6144 - 
           (37*cA*cR*Pi^2*Log[2]^3)/1280 - (341*cR^2*Pi^2*Log[2]^3)/7680 + 
           (11*cA*nh*Pi^2*Log[2]^3)/6144 + (11*cR*nh*Pi^2*Log[2]^3)/192 + 
           (1411*cA^2*Log[2]^4)/49152 + (2575*cA*cR*Log[2]^4)/36864 - 
           (9383*cR^2*Log[2]^4)/36864 + (157*cA^2*lmmMS*Log[2]^4)/4096 - 
           (111*cA*cR*lmmMS*Log[2]^4)/2560 - (341*cR^2*lmmMS*Log[2]^4)/5120 - 
           (407*cA*nh*Log[2]^4)/36864 + (9487*cR*nh*Log[2]^4)/46080 + 
           (11*cA*lmmMS*nh*Log[2]^4)/4096 + (11*cR*lmmMS*nh*Log[2]^4)/128 - 
           (157*cA^2*Log[2]^5)/10240 + (111*cA*cR*Log[2]^5)/6400 + 
           (341*cR^2*Log[2]^5)/12800 - (11*cA*nh*Log[2]^5)/10240 - 
           (11*cR*nh*Log[2]^5)/320 + (1411*cA^2*PolyLog[4, 1/2])/2048 + 
           (2575*cA*cR*PolyLog[4, 1/2])/1536 - (9383*cR^2*PolyLog[4, 1/2])/
            1536 + (471*cA^2*lmmMS*PolyLog[4, 1/2])/512 - 
           (333*cA*cR*lmmMS*PolyLog[4, 1/2])/320 - 
           (1023*cR^2*lmmMS*PolyLog[4, 1/2])/640 - 
           (407*cA*nh*PolyLog[4, 1/2])/1536 + (9487*cR*nh*PolyLog[4, 1/2])/
            1920 + (33*cA*lmmMS*nh*PolyLog[4, 1/2])/512 + 
           (33*cR*lmmMS*nh*PolyLog[4, 1/2])/16 + (471*cA^2*PolyLog[5, 1/2])/
            256 - (333*cA*cR*PolyLog[5, 1/2])/160 - 
           (1023*cR^2*PolyLog[5, 1/2])/320 + (33*cA*nh*PolyLog[5, 1/2])/256 + 
           (33*cR*nh*PolyLog[5, 1/2])/8 + (268010191*cA^2*Zeta[3])/
            132710400 + (18956639*cA*cR*Zeta[3])/1327104 + 
           (1648001*cR^2*Zeta[3])/49152 - (68388679*cA^2*lmmMS*Zeta[3])/
            13271040 + (887867*cA*cR*lmmMS*Zeta[3])/73728 + 
           (1100473*cR^2*lmmMS*Zeta[3])/40960 + (4561223*cA^2*lmmMS^2*
             Zeta[3])/2211840 + (309871*cA*cR*lmmMS^2*Zeta[3])/30720 + 
           (191751*cR^2*lmmMS^2*Zeta[3])/20480 - (7*cA^2*lmmMS^3*Zeta[3])/
            1280 - (229*cA^2*lmuH*Zeta[3])/576 + (cA*cR*lmuH*Zeta[3])/20 - 
           (3367*cA^2*lmmMS*lmuH*Zeta[3])/17280 - 
           (7*cA*cR*lmmMS*lmuH*Zeta[3])/48 - (21*cA^2*lmmMS^2*lmuH*Zeta[3])/
            640 - (427*cA^2*lmuH^2*Zeta[3])/3456 - (7*cA*cR*lmuH^2*Zeta[3])/
            960 - (21*cA^2*lmmMS*lmuH^2*Zeta[3])/320 - 
           (7*cA^2*lmuH^3*Zeta[3])/160 - (2975341*cA*nh*Zeta[3])/8847360 + 
           (1489271*cR*nh*Zeta[3])/552960 - (2849*cA*lmmMS*nh*Zeta[3])/
            24576 + (39935*cR*lmmMS*nh*Zeta[3])/18432 + 
           (231*cA*lmmMS^2*nh*Zeta[3])/16384 + (231*cR*lmmMS^2*nh*Zeta[3])/
            512 + (53911*cA^2*Pi^2*Zeta[3])/491520 + 
           (2297*cA*cR*Pi^2*Zeta[3])/4096 + (63917*cR^2*Pi^2*Zeta[3])/
            122880 + (49*cA^2*lmmMS*Pi^2*Zeta[3])/23040 + 
           (49*cA^2*lmuH*Pi^2*Zeta[3])/11520 + (77*cA*nh*Pi^2*Zeta[3])/
            98304 + (77*cR*nh*Pi^2*Zeta[3])/3072 + (721*cA^2*Zeta[3]^2)/
            1920 + nl^2*((7*lmmMS^3)/25920 + (7*lmmMS^4)/103680 + 
             (7*lmmMS*Pi^2)/51840 + (7*lmmMS^2*Pi^2)/103680 + 
             (7*Pi^4)/691200 - (7*Zeta[3])/12960 - (7*lmmMS*Zeta[3])/12960) + 
           (22443793*cA^2*Zeta[5])/3686400 + (2239817*cA*cR*Zeta[5])/51200 + 
           (848503*cR^2*Zeta[5])/20480 + (161*cA^2*lmmMS*Zeta[5])/3200 + 
           (161*cA^2*lmuH*Zeta[5])/1600 - (1705*cA*nh*Zeta[5])/16384 - 
           (1705*cR*nh*Zeta[5])/512 + nl*((-284297917*cA)/1399680000 - 
             (139349431*cR)/466560000 - (668827*cA*lmmMS)/9331200 - 
             (624227*cR*lmmMS)/1728000 - (3181*cA*lmmMS^2)/3110400 + 
             (261451*cR*lmmMS^2)/1036800 + (593*cA*lmmMS^3)/155520 + 
             (1111*cR*lmmMS^3)/103680 - (7*cA*lmmMS^4)/6912 + 
             (7*cR*lmmMS^4)/1152 - (49*cA*lmmMS^5)/691200 - 
             (21559*cA*lmuH)/186624 - (53771*cR*lmuH)/155520 - 
             (4181*cA*lmmMS*lmuH)/155520 - (1403*cR*lmmMS*lmuH)/25920 + 
             (209*cA*lmmMS^2*lmuH)/103680 - (19*cR*lmmMS^2*lmuH)/17280 - 
             (7*cA*lmmMS^3*lmuH)/12960 - (7*cA*lmmMS^4*lmuH)/23040 - 
             (685*cA*lmuH^2)/31104 - (1403*cR*lmuH^2)/25920 + 
             (209*cA*lmmMS*lmuH^2)/51840 - (19*cR*lmmMS*lmuH^2)/8640 + 
             (7*cA*lmmMS^2*lmuH^2)/8640 - (7*cA*lmmMS^3*lmuH^2)/17280 + 
             (209*cA*lmuH^3)/77760 - (19*cR*lmuH^3)/12960 + 
             (7*cA*lmmMS*lmuH^3)/2592 + (91*cA*lmuH^4)/51840 + 
             (7*cA*lmmMS*lmuH^4)/17280 + (7*cA*lmuH^5)/28800 - 
             (76591*cA*Pi^2)/18662400 + (92237*cR*Pi^2)/6220800 - 
             (571*cA*lmmMS*Pi^2)/311040 + (101*cR*lmmMS*Pi^2)/207360 - 
             (49*cA*lmmMS^2*Pi^2)/34560 - (7*cR*lmmMS^2*Pi^2)/11520 - 
             (7*cA*lmmMS^3*Pi^2)/82944 - (3121*cA*lmuH*Pi^2)/622080 + 
             (187*cR*lmuH*Pi^2)/103680 - (7*cA*lmmMS*lmuH*Pi^2)/2592 - 
             (7*cA*lmmMS^2*lmuH*Pi^2)/13824 - (7*cA*lmuH^2*Pi^2)/2592 - 
             (7*cA*lmmMS*lmuH^2*Pi^2)/6912 - (7*cA*lmuH^3*Pi^2)/10368 - 
             (11599*cA*Pi^4)/6220800 - (1393*cR*Pi^4)/3110400 - 
             (217*cA*lmmMS*Pi^4)/921600 + (7*cR*lmmMS*Pi^4)/12960 - 
             (1099*cA*lmuH*Pi^4)/1382400 + (7*cR*lmuH*Pi^4)/6480 - 
             (1313*cA*Zeta[3])/4320 + (33409*cR*Zeta[3])/51840 - 
             (2093*cA*lmmMS*Zeta[3])/25920 + (469*cR*lmmMS*Zeta[3])/1440 - 
             (77*cA*lmmMS^2*Zeta[3])/34560 + (7*cR*lmmMS^2*Zeta[3])/480 - 
             (287*cA*lmuH*Zeta[3])/1440 + (203*cR*lmuH*Zeta[3])/720 - 
             (301*cA*lmmMS*lmuH*Zeta[3])/8640 + (7*cR*lmmMS*lmuH*Zeta[3])/
              120 - (413*cA*lmuH^2*Zeta[3])/8640 + (7*cR*lmuH^2*Zeta[3])/
              120 + (539*cA*Pi^2*Zeta[3])/69120 - (49*cR*Pi^2*Zeta[3])/8640 - 
             (2009*cA*Zeta[5])/28800 + (7*cR*Zeta[5])/60))))
 
hOS = 1 + ep*lmmOS + ep^2*(lmmOS^2/2 + Pi^2/12) + 
     ep^3*(lmmOS^3/6 + (lmmOS*Pi^2)/12 - Zeta[3]/3) + 
     ep^4*(lmmOS^4/24 + (lmmOS^2*Pi^2)/24 + Pi^4/160 - (lmmOS*Zeta[3])/3) + 
     ep^5*(lmmOS^5/120 + (lmmOS^3*Pi^2)/72 + (lmmOS*Pi^4)/160 - 
       (lmmOS^2*Zeta[3])/6 - (Pi^2*Zeta[3])/36 - Zeta[5]/5) + 
     ep^6*(lmmOS^6/720 + (lmmOS^4*Pi^2)/288 + (lmmOS^2*Pi^4)/320 + 
       (61*Pi^6)/120960 - (lmmOS^3*Zeta[3])/18 - (lmmOS*Pi^2*Zeta[3])/36 + 
       Zeta[3]^2/18 - (lmmOS*Zeta[5])/5) + 
     rhoOS*(7/120 + ep*(7/120 + (7*lmmOS)/120) + 
       ep^2*((7*lmmOS)/120 + (7*lmmOS^2)/240 + (7*Pi^2)/1440) + 
       ep^3*((7*lmmOS^2)/240 + (7*lmmOS^3)/720 + (7*Pi^2)/1440 + 
         (7*lmmOS*Pi^2)/1440 - (7*Zeta[3])/360) + 
       ep^4*((7*lmmOS^3)/720 + (7*lmmOS^4)/2880 + (7*lmmOS*Pi^2)/1440 + 
         (7*lmmOS^2*Pi^2)/2880 + (7*Pi^4)/19200 - (7*Zeta[3])/360 - 
         (7*lmmOS*Zeta[3])/360) + ep^5*((7*lmmOS^4)/2880 + 
         (7*lmmOS^5)/14400 + (7*lmmOS^2*Pi^2)/2880 + (7*lmmOS^3*Pi^2)/8640 + 
         (7*Pi^4)/19200 + (7*lmmOS*Pi^4)/19200 - (7*lmmOS*Zeta[3])/360 - 
         (7*lmmOS^2*Zeta[3])/720 - (7*Pi^2*Zeta[3])/4320 - (7*Zeta[5])/600) + 
       ep^6*((7*lmmOS^5)/14400 + (7*lmmOS^6)/86400 + (7*lmmOS^3*Pi^2)/8640 + 
         (7*lmmOS^4*Pi^2)/34560 + (7*lmmOS*Pi^4)/19200 + 
         (7*lmmOS^2*Pi^4)/38400 + (61*Pi^6)/2073600 - (7*lmmOS^2*Zeta[3])/
          720 - (7*lmmOS^3*Zeta[3])/2160 - (7*Pi^2*Zeta[3])/4320 - 
         (7*lmmOS*Pi^2*Zeta[3])/4320 + (7*Zeta[3]^2)/2160 - (7*Zeta[5])/600 - 
         (7*lmmOS*Zeta[5])/600)) + rhoOS^2*(1/168 + ep*(1/112 + lmmOS/168) + 
       ep^2*(1/336 + lmmOS/112 + lmmOS^2/336 + Pi^2/2016) + 
       ep^3*(lmmOS/336 + lmmOS^2/224 + lmmOS^3/1008 + Pi^2/1344 + 
         (lmmOS*Pi^2)/2016 - Zeta[3]/504) + ep^4*(lmmOS^2/672 + lmmOS^3/672 + 
         lmmOS^4/4032 + Pi^2/4032 + (lmmOS*Pi^2)/1344 + (lmmOS^2*Pi^2)/4032 + 
         Pi^4/26880 - Zeta[3]/336 - (lmmOS*Zeta[3])/504) + 
       ep^5*(lmmOS^3/2016 + lmmOS^4/2688 + lmmOS^5/20160 + 
         (lmmOS*Pi^2)/4032 + (lmmOS^2*Pi^2)/2688 + (lmmOS^3*Pi^2)/12096 + 
         Pi^4/17920 + (lmmOS*Pi^4)/26880 - Zeta[3]/1008 - 
         (lmmOS*Zeta[3])/336 - (lmmOS^2*Zeta[3])/1008 - (Pi^2*Zeta[3])/6048 - 
         Zeta[5]/840) + ep^6*(lmmOS^4/8064 + lmmOS^5/13440 + lmmOS^6/120960 + 
         (lmmOS^2*Pi^2)/8064 + (lmmOS^3*Pi^2)/8064 + (lmmOS^4*Pi^2)/48384 + 
         Pi^4/53760 + (lmmOS*Pi^4)/17920 + (lmmOS^2*Pi^4)/53760 + 
         (61*Pi^6)/20321280 - (lmmOS*Zeta[3])/1008 - (lmmOS^2*Zeta[3])/672 - 
         (lmmOS^3*Zeta[3])/3024 - (Pi^2*Zeta[3])/4032 - (lmmOS*Pi^2*Zeta[3])/
          6048 + Zeta[3]^2/3024 - Zeta[5]/560 - (lmmOS*Zeta[5])/840)) + 
     api5^3*((-77678557*cA^3)/6718464 - (16699*cA^2*cR)/1024 + 
       (6035*cA*cR^2)/384 - (471*cR^3)/128 - cA^3/(48*ep^6) - 
       (8166983*cA^3*lmmOS)/1119744 + (8459*cA^2*cR*lmmOS)/1152 + 
       6*cA*cR^2*lmmOS - (230845*cA^3*lmmOS^2)/62208 + 
       (875*cA^2*cR*lmmOS^2)/128 - (243*cA*cR^2*lmmOS^2)/128 + 
       (18089*cA^3*lmmOS^3)/186624 + (57*cA^2*cR*lmmOS^3)/64 + 
       (16841*cA^3*lmmOS^4)/248832 - (cA^2*cR*lmmOS^4)/16 - 
       (11*cA^3*lmmOS^5)/4608 - (cA^3*lmmOS^6)/34560 - 
       (5019773*cA^3*lmuH)/373248 + (179*cA^2*cR*lmuH)/96 + 
       (289*cA*cR^2*lmuH)/128 - (85507*cA^3*lmmOS*lmuH)/10368 + 
       (773*cA^2*cR*lmmOS*lmuH)/96 - (81*cA*cR^2*lmmOS*lmuH)/64 + 
       (9283*cA^3*lmmOS^2*lmuH)/10368 + (105*cA^2*cR*lmmOS^2*lmuH)/64 + 
       (449*cA^3*lmmOS^3*lmuH)/1296 - (cA^2*cR*lmmOS^3*lmuH)/4 - 
       (11*cA^3*lmmOS^4*lmuH)/512 - (cA^3*lmmOS^5*lmuH)/1920 - 
       (15553*cA^3*lmuH^2)/2304 + (827*cA^2*cR*lmuH^2)/384 - 
       (27*cA*cR^2*lmuH^2)/128 + (283*cA^3*lmmOS*lmuH^2)/864 + 
       (105*cA^2*cR*lmmOS*lmuH^2)/64 + (1801*cA^3*lmmOS^2*lmuH^2)/2304 - 
       (3*cA^2*cR*lmmOS^2*lmuH^2)/8 - (55*cA^3*lmmOS^3*lmuH^2)/768 - 
       (cA^3*lmmOS^4*lmuH^2)/256 - (85*cA^3*lmuH^3)/288 + 
       (29*cA^2*cR*lmuH^3)/48 + (361*cA^3*lmmOS*lmuH^3)/384 - 
       (cA^2*cR*lmmOS*lmuH^3)/4 - (77*cA^3*lmmOS^2*lmuH^3)/768 - 
       (cA^3*lmmOS^3*lmuH^3)/64 + (763*cA^3*lmuH^4)/1536 - 
       (cA^2*cR*lmuH^4)/16 - (55*cA^3*lmmOS*lmuH^4)/1536 - 
       (9*cA^3*lmmOS^2*lmuH^4)/256 + (187*cA^3*lmuH^5)/7680 - 
       (27*cA^3*lmmOS*lmuH^5)/640 - (27*cA^3*lmuH^6)/1280 - 
       (61*cA^2*nh)/6912 + (47285*cA*cR*nh)/6912 - (5*cR^2*nh)/24 + 
       (739*cA^2*lmmOS*nh)/1152 + (2921*cA*cR*lmmOS*nh)/1152 + 
       (15*cA^2*lmmOS^2*nh)/256 + (3*cA*cR*lmmOS^2*nh)/32 + 
       (1423*cA^2*lmuH*nh)/6912 + (959*cA*cR*lmuH*nh)/1152 + 
       (5*cA^2*lmmOS*lmuH*nh)/128 + (cA*cR*lmmOS*lmuH*nh)/16 + 
       (5*cA^2*lmuH^2*nh)/768 + (cA*cR*lmuH^2*nh)/96 + (cA*nh^2)/54 + 
       (113*cR*nh^2)/1728 + ((-55*cA^3)/192 - (cA^3*lmmOS)/48 - 
         (cA^3*lmuH)/16 + (5*cA^2*nl)/96)/ep^5 + (27427*cA^3*Pi^2)/139968 + 
       (4181*cA^2*cR*Pi^2)/4608 - (907*cA*cR^2*Pi^2)/384 + 
       (1019*cA^3*lmmOS*Pi^2)/41472 + (103*cA^2*cR*lmmOS*Pi^2)/384 - 
       (15*cA*cR^2*lmmOS*Pi^2)/16 - (8171*cA^3*lmmOS^2*Pi^2)/248832 - 
       (cA^2*cR*lmmOS^2*Pi^2)/64 - (209*cA^3*lmmOS^3*Pi^2)/62208 - 
       (cA^3*lmmOS^4*Pi^2)/13824 + (1445*cA^3*lmuH*Pi^2)/6912 + 
       (7*cA^2*cR*lmuH*Pi^2)/96 - (5*cA*cR^2*lmuH*Pi^2)/16 - 
       (3523*cA^3*lmmOS*lmuH*Pi^2)/20736 - (cA^2*cR*lmmOS*lmuH*Pi^2)/32 - 
       (209*cA^3*lmmOS^2*lmuH*Pi^2)/6912 - (cA^3*lmmOS^3*lmuH*Pi^2)/1152 - 
       (607*cA^3*lmuH^2*Pi^2)/3456 - (cA^2*cR*lmuH^2*Pi^2)/64 - 
       (209*cA^3*lmmOS*lmuH^2*Pi^2)/2304 - (cA^3*lmmOS^2*lmuH^2*Pi^2)/256 - 
       (209*cA^3*lmuH^3*Pi^2)/2304 - (cA^3*lmmOS*lmuH^3*Pi^2)/128 - 
       (3*cA^3*lmuH^4*Pi^2)/512 + (5*cA^2*nh*Pi^2)/2304 - 
       (163*cA*cR*nh*Pi^2)/288 - (cA*cR*lmmOS*nh*Pi^2)/4 - 
       (cA*cR*lmuH*nh*Pi^2)/12 - (324007*cA^3*Pi^4)/14929920 + 
       (6937*cA^2*cR*Pi^4)/15360 - (139*cA*cR^2*Pi^4)/3840 + 
       (17479*cA^3*lmmOS*Pi^4)/1244160 + (11*cA^3*lmmOS^2*Pi^4)/20736 + 
       (1133*cA^3*lmuH*Pi^4)/51840 + (11*cA^3*lmmOS*lmuH*Pi^4)/3456 + 
       (11*cA^3*lmuH^2*Pi^4)/2304 + (51*cA^2*nh*Pi^4)/5120 + 
       (51*cA*cR*nh*Pi^4)/2560 - (77671*cA^3*Pi^6)/13063680 + 
       ((-7459*cA^3)/10368 - (3*cA^2*cR)/32 - (55*cA^3*lmmOS)/192 - 
         (cA^3*lmmOS^2)/96 - (33*cA^3*lmuH)/64 - (cA^3*lmmOS*lmuH)/16 - 
         (3*cA^3*lmuH^2)/32 + ((445*cA^2)/1296 + (5*cA^2*lmmOS)/96 + 
           (3*cA^2*lmuH)/32)*nl - (85*cA*nl^2)/2592 - (cA^3*Pi^2)/576)/ep^4 - 
       (4*d44[pR1, pA1])/(3*NA) + (11*nh*d44[pR1, pR2])/(6*NA) - 
       (47*cA^2*cR*Pi^2*Log[2])/24 + (47*cA*cR^2*Pi^2*Log[2])/12 - 
       (3*cA^2*cR*lmmOS*Pi^2*Log[2])/4 + (3*cA*cR^2*lmmOS*Pi^2*Log[2])/2 - 
       (cA^2*cR*lmuH*Pi^2*Log[2])/4 + (cA*cR^2*lmuH*Pi^2*Log[2])/2 + 
       (cA*cR*nh*Pi^2*Log[2])/2 - (263*cA^3*Pi^2*Log[2]^2)/512 + 
       (509*cA^2*cR*Pi^2*Log[2]^2)/256 - (123*cA*cR^2*Pi^2*Log[2]^2)/64 + 
       (9*cA^2*nh*Pi^2*Log[2]^2)/256 + (9*cA*cR*nh*Pi^2*Log[2]^2)/128 + 
       (263*cA^3*Log[2]^4)/512 - (317*cA^2*cR*Log[2]^4)/256 + 
       (27*cA*cR^2*Log[2]^4)/64 - (9*cA^2*nh*Log[2]^4)/256 - 
       (9*cA*cR*nh*Log[2]^4)/128 + (789*cA^3*PolyLog[4, 1/2])/64 - 
       (951*cA^2*cR*PolyLog[4, 1/2])/32 + (81*cA*cR^2*PolyLog[4, 1/2])/8 - 
       (27*cA^2*nh*PolyLog[4, 1/2])/32 - (27*cA*cR*nh*PolyLog[4, 1/2])/16 + 
       nl^3*(lmmOS^3/1296 + (lmmOS*Pi^2)/2592 - Zeta[3]/648) + 
       (1151449*cA^3*Zeta[3])/373248 - (47741*cA^2*cR*Zeta[3])/1536 - 
       (1415*cA*cR^2*Zeta[3])/256 + (469505*cA^3*lmmOS*Zeta[3])/248832 - 
       (10417*cA^2*cR*lmmOS*Zeta[3])/512 + (567*cA*cR^2*lmmOS*Zeta[3])/128 + 
       (2431*cA^3*lmmOS^2*Zeta[3])/3456 + (35*cA^3*lmmOS^3*Zeta[3])/1728 + 
       (198353*cA^3*lmuH*Zeta[3])/82944 - (3163*cA^2*cR*lmuH*Zeta[3])/512 + 
       (189*cA*cR^2*lmuH*Zeta[3])/128 + (385*cA^3*lmmOS*lmuH*Zeta[3])/144 + 
       (35*cA^3*lmmOS^2*lmuH*Zeta[3])/192 + (473*cA^3*lmuH^2*Zeta[3])/192 + 
       (35*cA^3*lmmOS*lmuH^2*Zeta[3])/64 + (35*cA^3*lmuH^3*Zeta[3])/64 - 
       (311*cA^2*nh*Zeta[3])/384 - (563*cA*cR*nh*Zeta[3])/128 + 
       (13*cR^2*nh*Zeta[3])/64 - (189*cA^2*lmmOS*nh*Zeta[3])/512 - 
       (189*cA*cR*lmmOS*nh*Zeta[3])/256 - (63*cA^2*lmuH*nh*Zeta[3])/512 - 
       (63*cA*cR*lmuH*nh*Zeta[3])/256 - (7*cA*nh^2*Zeta[3])/256 - 
       (7*cR*nh^2*Zeta[3])/128 - (5753*cA^3*Pi^2*Zeta[3])/62208 - 
       (25*cA^3*lmmOS*Pi^2*Zeta[3])/1728 - (25*cA^3*lmuH*Pi^2*Zeta[3])/576 + 
       (13*d44[pR1, pA1]*Zeta[3])/NA - (4*nh*d44[pR1, pR2]*Zeta[3])/NA - 
       (2683*cA^3*Zeta[3]^2)/864 + ((15727*cA^3)/15552 - (19*cA^2*cR)/128 - 
         (5839*cA^3*lmmOS)/10368 - (3*cA^2*cR*lmmOS)/16 - 
         (55*cA^3*lmmOS^2)/384 - (cA^3*lmmOS^3)/288 - (47*cA^3*lmuH)/432 - 
         (3*cA^2*cR*lmuH)/16 - (33*cA^3*lmmOS*lmuH)/64 - 
         (cA^3*lmmOS^2*lmuH)/32 - (55*cA^3*lmuH^2)/128 - 
         (3*cA^3*lmmOS*lmuH^2)/32 - (3*cA^3*lmuH^3)/32 + 
         ((-499*cA)/7776 - (85*cA*lmmOS)/2592 - (11*cA*lmuH)/432)*nl^2 + 
         nl^3/216 - (209*cA^3*Pi^2)/10368 - (cA^3*lmmOS*Pi^2)/576 - 
         (cA^3*lmuH*Pi^2)/192 + nl*((-491*cA^2)/15552 + (29*cA*cR)/576 + 
           (445*cA^2*lmmOS)/1296 + (5*cA^2*lmmOS^2)/192 + 
           (197*cA^2*lmuH)/864 + (3*cA^2*lmmOS*lmuH)/32 + 
           (5*cA^2*lmuH^2)/64 + (19*cA^2*Pi^2)/5184) + (35*cA^3*Zeta[3])/288)/
        ep^3 + nl^2*((140125*cA)/839808 + (509*cR)/1728 - 
         (67913*cA*lmmOS)/279936 - (149*cR*lmmOS)/1728 + 
         (17*cA*lmmOS^2)/216 + (13*cR*lmmOS^2)/576 - (499*cA*lmmOS^3)/46656 - 
         (85*cA*lmmOS^4)/62208 + (3065*cA*lmuH)/46656 + (11*cR*lmuH)/288 - 
         (cA*lmmOS*lmuH)/54 - (cR*lmmOS*lmuH)/48 + (25*cA*lmmOS^2*lmuH)/
          2592 - (11*cA*lmmOS^3*lmuH)/2592 + (cA*lmuH^2)/432 + 
         (5*cA*lmmOS*lmuH^2)/432 - (cA*lmmOS^2*lmuH^2)/288 + 
         (43*cA*Pi^2)/5184 - (47*cR*Pi^2)/3456 - (709*cA*lmmOS*Pi^2)/93312 - 
         (79*cA*lmmOS^2*Pi^2)/62208 + (55*cA*lmuH*Pi^2)/15552 - 
         (17*cA*lmmOS*lmuH*Pi^2)/5184 - (cA*lmuH^2*Pi^2)/1728 - 
         (863*cA*Pi^4)/1244160 + (cR*Pi^4)/720 + (1927*cA*Zeta[3])/23328 - 
         (19*cR*Zeta[3])/72 - (161*cA*lmmOS*Zeta[3])/7776 + 
         (cR*lmmOS*Zeta[3])/12 - (31*cA*lmuH*Zeta[3])/1296) + 
       ((-18803*cA^3)/15552 + (2857*cA^2*cR)/768 - (27*cA*cR^2)/64 + 
         (50651*cA^3*lmmOS)/31104 + (3*cA^2*cR*lmmOS)/64 - 
         (2599*cA^3*lmmOS^2)/20736 - (3*cA^2*cR*lmmOS^2)/16 - 
         (55*cA^3*lmmOS^3)/1152 - (cA^3*lmmOS^4)/1152 + (269*cA^3*lmuH)/162 + 
         (25*cA^2*cR*lmuH)/64 + (11*cA^3*lmmOS*lmuH)/54 - 
         (3*cA^2*cR*lmmOS*lmuH)/8 - (33*cA^3*lmmOS^2*lmuH)/128 - 
         (cA^3*lmmOS^3*lmuH)/96 + (721*cA^3*lmuH^2)/1152 - 
         (3*cA^2*cR*lmuH^2)/16 - (55*cA^3*lmmOS*lmuH^2)/128 - 
         (3*cA^3*lmmOS^2*lmuH^2)/64 - (77*cA^3*lmuH^3)/384 - 
         (3*cA^3*lmmOS*lmuH^3)/32 - (9*cA^3*lmuH^4)/128 + (5*cA^2*nh)/384 + 
         (cA*cR*nh)/48 + (lmmOS*nl^3)/216 - (13031*cA^3*Pi^2)/124416 - 
         (cA^2*cR*Pi^2)/128 - (209*cA^3*lmmOS*Pi^2)/10368 - 
         (cA^3*lmmOS^2*Pi^2)/1152 - (209*cA^3*lmuH*Pi^2)/3456 - 
         (cA^3*lmmOS*lmuH*Pi^2)/192 - (cA^3*lmuH^2*Pi^2)/128 + 
         (11*cA^3*Pi^4)/10368 + nl^2*((19*cA)/216 + cR/288 - 
           (499*cA*lmmOS)/7776 - (85*cA*lmmOS^2)/5184 + (25*cA*lmuH)/1296 - 
           (11*cA*lmmOS*lmuH)/432 - (cA*lmuH^2)/144 - (79*cA*Pi^2)/31104) + 
         (2431*cA^3*Zeta[3])/1728 + (35*cA^3*lmmOS*Zeta[3])/288 + 
         (35*cA^3*lmuH*Zeta[3])/96 + nl*((-1253*cA^2)/7776 - (cA*cR)/3456 - 
           (1663*cA^2*lmmOS)/7776 + (5*cA*cR*lmmOS)/144 + (445*cA^2*lmmOS^2)/
            2592 + (5*cA^2*lmmOS^3)/576 - (1141*cA^2*lmuH)/2592 + 
           (5*cA*cR*lmuH)/48 + (197*cA^2*lmmOS*lmuH)/864 + 
           (3*cA^2*lmmOS^2*lmuH)/64 - (cA^2*lmuH^2)/576 + 
           (5*cA^2*lmmOS*lmuH^2)/64 + (7*cA^2*lmuH^3)/192 + 
           (353*cA^2*Pi^2)/10368 + (19*cA^2*lmmOS*Pi^2)/5184 + 
           (19*cA^2*lmuH*Pi^2)/1728 + (19*cA^2*Zeta[3])/864 - 
           (5*cA*cR*Zeta[3])/18))/ep^2 + (14047*cA^3*Zeta[5])/2880 - 
       (437*cA^3*lmmOS*Zeta[5])/480 - (437*cA^3*lmuH*Zeta[5])/160 + 
       ((-10422185*cA^3)/1119744 + (31829*cA^2*cR)/4608 + (95*cA*cR^2)/64 - 
         (88825*cA^3*lmmOS)/31104 + (2861*cA^2*cR*lmmOS)/384 - 
         (81*cA*cR^2*lmmOS)/64 + (64421*cA^3*lmmOS^2)/62208 + 
         (9*cA^2*cR*lmmOS^2)/16 + (3881*cA^3*lmmOS^3)/62208 - 
         (cA^2*cR*lmmOS^3)/8 - (55*cA^3*lmmOS^4)/4608 - (cA^3*lmmOS^5)/5760 - 
         (63367*cA^3*lmuH)/10368 + (555*cA^2*cR*lmuH)/128 - 
         (27*cA*cR^2*lmuH)/64 + (10201*cA^3*lmmOS*lmuH)/5184 + 
         (9*cA^2*cR*lmmOS*lmuH)/8 + (179*cA^3*lmmOS^2*lmuH)/432 - 
         (3*cA^2*cR*lmmOS^2*lmuH)/8 - (11*cA^3*lmmOS^3*lmuH)/128 - 
         (cA^3*lmmOS^4*lmuH)/384 + (209*cA^3*lmuH^2)/432 + 
         (47*cA^2*cR*lmuH^2)/64 + (1081*cA^3*lmmOS*lmuH^2)/1152 - 
         (3*cA^2*cR*lmmOS*lmuH^2)/8 - (55*cA^3*lmmOS^2*lmuH^2)/256 - 
         (cA^3*lmmOS^3*lmuH^2)/64 + (281*cA^3*lmuH^3)/384 - 
         (cA^2*cR*lmuH^3)/8 - (77*cA^3*lmmOS*lmuH^3)/384 - 
         (3*cA^3*lmmOS^2*lmuH^3)/64 - (55*cA^3*lmuH^4)/1536 - 
         (9*cA^3*lmmOS*lmuH^4)/128 - (27*cA^3*lmuH^5)/640 + 
         (397*cA^2*nh)/1728 + (1003*cA*cR*nh)/1152 + (5*cA^2*lmmOS*nh)/128 + 
         (cA*cR*lmmOS*nh)/16 + (5*cA^2*lmuH*nh)/384 + (cA*cR*lmuH*nh)/48 - 
         (853*cA^3*Pi^2)/41472 + (49*cA^2*cR*Pi^2)/768 - 
         (5*cA*cR^2*Pi^2)/16 - (11411*cA^3*lmmOS*Pi^2)/124416 - 
         (cA^2*cR*lmmOS*Pi^2)/64 - (209*cA^3*lmmOS^2*Pi^2)/20736 - 
         (cA^3*lmmOS^3*Pi^2)/3456 - (4063*cA^3*lmuH*Pi^2)/20736 - 
         (cA^2*cR*lmuH*Pi^2)/64 - (209*cA^3*lmmOS*lmuH*Pi^2)/3456 - 
         (cA^3*lmmOS^2*lmuH*Pi^2)/384 - (209*cA^3*lmuH^2*Pi^2)/2304 - 
         (cA^3*lmmOS*lmuH^2*Pi^2)/128 - (cA^3*lmuH^3*Pi^2)/128 - 
         (cA*cR*nh*Pi^2)/12 + (17479*cA^3*Pi^4)/1244160 + 
         (11*cA^3*lmmOS*Pi^4)/10368 + (11*cA^3*lmuH*Pi^4)/3456 + 
         nl^3*(lmmOS^2/432 + Pi^2/2592) - (cA^2*cR*Pi^2*Log[2])/4 + 
         (cA*cR^2*Pi^2*Log[2])/2 + (664715*cA^3*Zeta[3])/248832 - 
         (3395*cA^2*cR*Zeta[3])/512 + (189*cA*cR^2*Zeta[3])/128 + 
         (2431*cA^3*lmmOS*Zeta[3])/1728 + (35*cA^3*lmmOS^2*Zeta[3])/576 + 
         (385*cA^3*lmuH*Zeta[3])/144 + (35*cA^3*lmmOS*lmuH*Zeta[3])/96 + 
         (35*cA^3*lmuH^2*Zeta[3])/64 - (63*cA^2*nh*Zeta[3])/512 - 
         (63*cA*cR*nh*Zeta[3])/256 - (25*cA^3*Pi^2*Zeta[3])/1728 + 
         nl^2*((-55115*cA)/279936 - (83*cR)/1728 + (53*cA*lmmOS)/432 + 
           (7*cR*lmmOS)/288 - (499*cA*lmmOS^2)/15552 - (85*cA*lmmOS^3)/
            15552 - (cA*lmuH)/54 - (cR*lmuH)/48 + (25*cA*lmmOS*lmuH)/1296 - 
           (11*cA*lmmOS^2*lmuH)/864 + (5*cA*lmuH^2)/432 - (cA*lmmOS*lmuH^2)/
            144 - (709*cA*Pi^2)/93312 - (79*cA*lmmOS*Pi^2)/31104 - 
           (17*cA*lmuH*Pi^2)/5184 - (161*cA*Zeta[3])/7776 + 
           (cR*Zeta[3])/12) + nl*((8324*cA^2)/2187 + (17837*cA*cR)/20736 + 
           (17*cR^2)/192 - (2803*cA^2*lmmOS)/15552 - (365*cA*cR*lmmOS)/1728 - 
           (461*cA^2*lmmOS^2)/1944 - (53*cA*cR*lmmOS^2)/576 + 
           (445*cA^2*lmmOS^3)/7776 + (5*cA^2*lmmOS^4)/2304 + 
           (8549*cA^2*lmuH)/5184 + (239*cA*cR*lmuH)/288 - 
           (773*cA^2*lmmOS*lmuH)/1296 + (7*cA*cR*lmmOS*lmuH)/96 + 
           (197*cA^2*lmmOS^2*lmuH)/1728 + (cA^2*lmmOS^3*lmuH)/64 - 
           (95*cA^2*lmuH^2)/864 + (9*cA*cR*lmuH^2)/64 - (cA^2*lmmOS*lmuH^2)/
            576 + (5*cA^2*lmmOS^2*lmuH^2)/128 - (5*cA^2*lmuH^3)/64 + 
           (7*cA^2*lmmOS*lmuH^3)/192 + (5*cA^2*lmuH^4)/768 - (5*cA*nh)/1152 - 
           (cR*nh)/144 + (1139*cA^2*Pi^2)/46656 + (53*cA*cR*Pi^2)/1728 + 
           (353*cA^2*lmmOS*Pi^2)/10368 + (19*cA^2*lmmOS^2*Pi^2)/10368 + 
           (47*cA^2*lmuH*Pi^2)/864 + (19*cA^2*lmmOS*lmuH*Pi^2)/1728 + 
           (19*cA^2*lmuH^2*Pi^2)/1152 + (1579*cA^2*Pi^4)/622080 - 
           (11*cA*cR*Pi^4)/2160 + (3613*cA^2*Zeta[3])/7776 - 
           (325*cA*cR*Zeta[3])/216 + (19*cA^2*lmmOS*Zeta[3])/864 - 
           (5*cA*cR*lmmOS*Zeta[3])/18 + (25*cA^2*lmuH*Zeta[3])/72 - 
           (5*cA*cR*lmuH*Zeta[3])/6) - (437*cA^3*Zeta[5])/480)/ep + 
       nl*((-496475*cA^2)/3359232 + (1034603*cA*cR)/124416 + (115*cR^2)/128 + 
         (336757*cA^2*lmmOS)/69984 + (6367*cA*cR*lmmOS)/10368 + 
         (cR^2*lmmOS)/96 + (491*cA^2*lmmOS^2)/31104 + (209*cA*cR*lmmOS^2)/
          1728 - (1327*cA^2*lmmOS^3)/11664 - (341*cA*cR*lmmOS^3)/1728 + 
         (445*cA^2*lmmOS^4)/31104 + (cA^2*lmmOS^5)/2304 + 
         (347497*cA^2*lmuH)/93312 + (8843*cA*cR*lmuH)/1728 + (cR^2*lmuH)/8 + 
         (10133*cA^2*lmmOS*lmuH)/5184 + (451*cA*cR*lmmOS*lmuH)/576 - 
         (1043*cA^2*lmmOS^2*lmuH)/2592 - (17*cA*cR*lmmOS^2*lmuH)/192 + 
         (197*cA^2*lmmOS^3*lmuH)/5184 + (cA^2*lmmOS^4*lmuH)/256 + 
         (6601*cA^2*lmuH^2)/3456 + (595*cA*cR*lmuH^2)/384 - 
         (35*cA^2*lmmOS*lmuH^2)/216 + (7*cA*cR*lmmOS*lmuH^2)/64 - 
         (cA^2*lmmOS^2*lmuH^2)/1152 + (5*cA^2*lmmOS^3*lmuH^2)/384 + 
         (13*cA^2*lmuH^3)/96 + (9*cA*cR*lmuH^3)/64 - (5*cA^2*lmmOS*lmuH^3)/
          64 + (7*cA^2*lmmOS^2*lmuH^3)/384 - (15*cA^2*lmuH^4)/256 + 
         (5*cA^2*lmmOS*lmuH^4)/768 - (17*cA^2*lmuH^5)/3840 - 
         (1255*cA*nh)/20736 - (1133*cR*nh)/3456 - (5*cA*lmmOS*nh)/1152 - 
         (cR*lmmOS*nh)/144 - (19919*cA^2*Pi^2)/279936 + 
         (1939*cA*cR*Pi^2)/20736 + (5*cR^2*Pi^2)/48 + (329*cA^2*lmmOS*Pi^2)/
          46656 + (179*cA*cR*lmmOS*Pi^2)/1728 + (353*cA^2*lmmOS^2*Pi^2)/
          20736 + (19*cA^2*lmmOS^3*Pi^2)/31104 - (149*cA^2*lmuH*Pi^2)/1944 + 
         (cA*cR*lmuH*Pi^2)/288 + (47*cA^2*lmmOS*lmuH*Pi^2)/864 + 
         (19*cA^2*lmmOS^2*lmuH*Pi^2)/3456 + (13*cA^2*lmuH^2*Pi^2)/384 + 
         (19*cA^2*lmmOS*lmuH^2*Pi^2)/1152 + (19*cA^2*lmuH^3*Pi^2)/1152 + 
         (cR*nh*Pi^2)/36 + (52387*cA^2*Pi^4)/3732480 - (29*cA*cR*Pi^4)/1080 + 
         (1579*cA^2*lmmOS*Pi^4)/622080 - (11*cA*cR*lmmOS*Pi^4)/2160 + 
         (293*cA^2*lmuH*Pi^4)/25920 - (11*cA*cR*lmuH*Pi^4)/720 + 
         (11*d44[pR1, pR2])/(3*NA) + (cA*cR*Pi^2*Log[2])/12 - 
         (cR^2*Pi^2*Log[2])/6 + (1863647*cA^2*Zeta[3])/746496 - 
         (80861*cA*cR*Zeta[3])/41472 + (171*cR^2*Zeta[3])/128 + 
         (3613*cA^2*lmmOS*Zeta[3])/7776 - (325*cA*cR*lmmOS*Zeta[3])/216 + 
         (19*cA^2*lmmOS^2*Zeta[3])/1728 - (5*cA*cR*lmmOS^2*Zeta[3])/36 + 
         (761*cA^2*lmuH*Zeta[3])/324 - (113*cA*cR*lmuH*Zeta[3])/36 + 
         (25*cA^2*lmmOS*lmuH*Zeta[3])/72 - (5*cA*cR*lmmOS*lmuH*Zeta[3])/6 + 
         (77*cA^2*lmuH^2*Zeta[3])/96 - (5*cA*cR*lmuH^2*Zeta[3])/4 + 
         (7*cA*nh*Zeta[3])/512 + (7*cR*nh*Zeta[3])/256 - 
         (2645*cA^2*Pi^2*Zeta[3])/31104 + (11*cA*cR*Pi^2*Zeta[3])/108 - 
         (8*d44[pR1, pR2]*Zeta[3])/NA + (2243*cA^2*Zeta[5])/1440 + 
         (cA*cR*Zeta[5])/18 - (5*cR^2*Zeta[5])/2) + 
       rhoOS*((1057509884915591*cA^3)/310393036800000 - (76898256821*cA^2*cR)/
          57480192000 + (1245540511*cA*cR^2)/121651200 + 
         (9016993*cR^3)/2419200 - (7*cA^3)/(5760*ep^6) - 
         (900884439323*cA^3*lmmOS)/134369280000 - (424160411*cA^2*cR*lmmOS)/
          49766400 + (838721*cA*cR^2*lmmOS)/368640 + 
         (1884413603*cA^3*lmmOS^2)/1492992000 + (40177*cA^2*cR*lmmOS^2)/
          6912 + (108141*cA*cR^2*lmmOS^2)/20480 + (1032571*cA^3*lmmOS^3)/
          27993600 - (439*cA^2*cR*lmmOS^3)/51840 - (34231*cA^3*lmmOS^4)/
          29859840 + (61*cA^2*cR*lmmOS^4)/4320 - (413*cA^3*lmmOS^5)/2764800 - 
         (7*cA^3*lmmOS^6)/4147200 - (147249771281*cA^3*lmuH)/44789760000 - 
         (16531553*cA^2*cR*lmuH)/5529600 + (15229*cA*cR^2*lmuH)/368640 + 
         (168765011*cA^3*lmmOS*lmuH)/248832000 + (111163*cA^2*cR*lmmOS*lmuH)/
          25920 + (36047*cA*cR^2*lmmOS*lmuH)/10240 + 
         (635969*cA^3*lmmOS^2*lmuH)/6220800 + (3587*cA^2*cR*lmmOS^2*lmuH)/
          17280 - (2981*cA^3*lmmOS^3*lmuH)/1244160 + 
         (61*cA^2*cR*lmmOS^3*lmuH)/1080 - (259*cA^3*lmmOS^4*lmuH)/184320 - 
         (7*cA^3*lmmOS^5*lmuH)/230400 - (21523733*cA^3*lmuH^2)/165888000 + 
         (1111*cA^2*cR*lmuH^2)/1280 + (36047*cA*cR^2*lmuH^2)/61440 + 
         (226133*cA^3*lmmOS*lmuH^2)/2073600 + (3587*cA^2*cR*lmmOS*lmuH^2)/
          17280 + (923*cA^3*lmmOS^2*lmuH^2)/138240 + 
         (61*cA^2*cR*lmmOS^2*lmuH^2)/720 - (469*cA^3*lmmOS^3*lmuH^2)/92160 - 
         (7*cA^3*lmmOS^4*lmuH^2)/30720 + (96311*cA^3*lmuH^3)/2073600 + 
         (9*cA^2*cR*lmuH^3)/160 + (883*cA^3*lmmOS*lmuH^3)/34560 + 
         (61*cA^2*cR*lmmOS*lmuH^3)/1080 - (791*cA^3*lmmOS^2*lmuH^3)/92160 - 
         (7*cA^3*lmmOS^3*lmuH^3)/7680 + (3109*cA^3*lmuH^4)/138240 + 
         (61*cA^2*cR*lmuH^4)/4320 - (1141*cA^3*lmmOS*lmuH^4)/184320 - 
         (21*cA^3*lmmOS^2*lmuH^4)/10240 - (959*cA^3*lmuH^5)/921600 - 
         (63*cA^3*lmmOS*lmuH^5)/25600 - (63*cA^3*lmuH^6)/51200 + 
         (294520898393*cA^2*nh)/6584094720000 + (1408617666229*cA*cR*nh)/
          724250419200 - (3533371*cR^2*nh)/1935360 - (33393487*cA^2*lmmOS*nh)/
          497664000 + (3604849*cA*cR*lmmOS*nh)/2488320 + 
         (71897*cA^2*lmmOS^2*nh)/3686400 + (557*cA*cR*lmmOS^2*nh)/1440 - 
         (19*cA^2*lmmOS^3*nh)/5760 - (9065117*cA^2*lmuH*nh)/248832000 + 
         (351017*cA*cR*lmuH*nh)/829440 + (80537*cA^2*lmmOS*lmuH*nh)/5529600 + 
         (557*cA*cR*lmmOS*lmuH*nh)/2160 - (cA^2*lmmOS^2*lmuH*nh)/1920 + 
         (96857*cA^2*lmuH^2*nh)/33177600 + (557*cA*cR*lmuH^2*nh)/12960 + 
         (cA^2*lmmOS*lmuH^2*nh)/384 + (7*cA^2*lmuH^3*nh)/5760 - 
         (6779603*cA*nh^2)/627056640 + (727787*cR*nh^2)/4898880 + 
         ((-413*cA^3)/23040 - (7*cA^3*lmmOS)/5760 - (7*cA^3*lmuH)/1920 + 
           (7*cA^2*nl)/2304)/ep^5 + (760415093*cA^3*Pi^2)/13436928000 + 
         (106099*cA^2*cR*Pi^2)/207360 - (28349*cA*cR^2*Pi^2)/36864 + 
         (589*cR^3*Pi^2)/1280 - (269279*cA^3*lmmOS*Pi^2)/37324800 + 
         (13201*cA^2*cR*lmmOS*Pi^2)/103680 - (511*cA*cR^2*lmmOS*Pi^2)/1152 - 
         (21517*cA^3*lmmOS^2*Pi^2)/5971968 + (439*cA^2*cR*lmmOS^2*Pi^2)/
          17280 - (21*cA*cR^2*lmmOS^2*Pi^2)/256 - (1589*cA^3*lmmOS^3*Pi^2)/
          7464960 - (7*cA^3*lmmOS^4*Pi^2)/1658880 - (14147*cA^3*lmuH*Pi^2)/
          3110400 + (8*cA^2*cR*lmuH*Pi^2)/135 - (35*cA*cR^2*lmuH*Pi^2)/256 - 
         (38911*cA^3*lmmOS*lmuH*Pi^2)/2488320 + (187*cA^2*cR*lmmOS*lmuH*Pi^2)/
          8640 - (7*cA*cR^2*lmmOS*lmuH*Pi^2)/128 - 
         (1589*cA^3*lmmOS^2*lmuH*Pi^2)/829440 - (7*cA^3*lmmOS^3*lmuH*Pi^2)/
          138240 - (13799*cA^3*lmuH^2*Pi^2)/829440 + 
         (103*cA^2*cR*lmuH^2*Pi^2)/17280 - (7*cA*cR^2*lmuH^2*Pi^2)/768 - 
         (1589*cA^3*lmmOS*lmuH^2*Pi^2)/276480 - (7*cA^3*lmmOS^2*lmuH^2*Pi^2)/
          30720 - (1589*cA^3*lmuH^3*Pi^2)/276480 - (7*cA^3*lmmOS*lmuH^3*Pi^2)/
          15360 - (7*cA^3*lmuH^4*Pi^2)/20480 + (114137*cA^2*nh*Pi^2)/
          99532800 - (589*cA*cR*nh*Pi^2)/155520 + (449*cR^2*nh*Pi^2)/6480 - 
         (cA^2*lmmOS*nh*Pi^2)/1920 - (959*cA*cR*lmmOS*nh*Pi^2)/8640 - 
         (7*cA*cR*lmmOS^2*nh*Pi^2)/320 - (cA^2*lmuH*nh*Pi^2)/5760 - 
         (49*cA*cR*lmuH*nh*Pi^2)/1440 - (7*cA*cR*lmmOS*lmuH*nh*Pi^2)/480 - 
         (7*cA*cR*lmuH^2*nh*Pi^2)/2880 - (7*cR*nh^2*Pi^2)/8100 + 
         (31497396737*cA^3*Pi^4)/110361968640 + (249450589*cA^2*cR*Pi^4)/
          1277337600 - (4350691507*cA*cR^2*Pi^4)/5109350400 + 
         (6391789*cR^3*Pi^4)/58060800 + (23131447*cA^3*lmmOS*Pi^4)/
          597196800 + (3151*cA^2*cR*lmmOS*Pi^4)/20480 + 
         (4499*cA*cR^2*lmmOS*Pi^4)/24576 + (77*cA^3*lmmOS^2*Pi^4)/2488320 + 
         (2802427*cA^3*lmuH*Pi^4)/199065600 + (3151*cA^2*cR*lmuH*Pi^4)/
          61440 + (4499*cA*cR^2*lmuH*Pi^4)/73728 + (77*cA^3*lmmOS*lmuH*Pi^4)/
          414720 + (77*cA^3*lmuH^2*Pi^4)/276480 - (46476481*cA^2*nh*Pi^4)/
          2786918400 + (47074037*cA*cR*nh*Pi^4)/696729600 + 
         (3713*cR^2*nh*Pi^4)/20736 + (187*cA^2*lmmOS*nh*Pi^4)/491520 + 
         (187*cA*cR*lmmOS*nh*Pi^4)/15360 + (187*cA^2*lmuH*nh*Pi^4)/1474560 + 
         (187*cA*cR*lmuH*nh*Pi^4)/46080 - (77671*cA^3*Pi^6)/223948800 + 
         ((-81211*cA^3)/1244160 + (61*cA^2*cR)/2880 - (413*cA^3*lmmOS)/
            23040 - (7*cA^3*lmmOS^2)/11520 - (259*cA^3*lmuH)/7680 - 
           (7*cA^3*lmmOS*lmuH)/1920 - (7*cA^3*lmuH^2)/1280 + 
           ((1435*cA^2)/62208 + (7*cA^2*lmmOS)/2304 + (7*cA^2*lmuH)/1280)*
            nl - (119*cA*nl^2)/62208 - (7*cA^3*Pi^2)/69120)/ep^4 - 
         (35085319*d44[pR1, pA1])/(13305600*NA) + 
         (76339381*Pi^4*d44[pR1, pA1])/(63866880*NA) + 
         (24226021*nh*d44[pR1, pR2])/(15966720*NA) + 
         (1489*nh*Pi^4*d44[pR1, pR2])/(17280*NA) - (4561*cA^2*cR*Pi^2*Log[2])/
          8640 + (6691*cA*cR^2*Pi^2*Log[2])/4320 - (71*cR^3*Pi^2*Log[2])/72 - 
         (217*cA^2*cR*lmmOS*Pi^2*Log[2])/576 + (217*cA*cR^2*lmmOS*Pi^2*
           Log[2])/288 - (21*cA^2*cR*lmmOS^2*Pi^2*Log[2])/320 + 
         (21*cA*cR^2*lmmOS^2*Pi^2*Log[2])/160 - (7*cA^2*cR*lmuH*Pi^2*Log[2])/
          60 + (7*cA*cR^2*lmuH*Pi^2*Log[2])/30 - 
         (7*cA^2*cR*lmmOS*lmuH*Pi^2*Log[2])/160 + 
         (7*cA*cR^2*lmmOS*lmuH*Pi^2*Log[2])/80 - 
         (7*cA^2*cR*lmuH^2*Pi^2*Log[2])/960 + (7*cA*cR^2*lmuH^2*Pi^2*Log[2])/
          480 + (217*cA*cR*nh*Pi^2*Log[2])/4320 - (7*cR^2*nh*Pi^2*Log[2])/
          135 + (7*cA*cR*lmmOS*nh*Pi^2*Log[2])/80 + 
         (7*cA*cR*lmuH*nh*Pi^2*Log[2])/240 - (27392147*cA^3*Pi^4*Log[2])/
          510935040 + (1721609*cA^2*cR*Pi^4*Log[2])/3942400 + 
         (32262761*cA*cR^2*Pi^4*Log[2])/212889600 - (7249*cR^3*Pi^4*Log[2])/
          5040 - (187*cA^2*nh*Pi^4*Log[2])/245760 - 
         (187*cA*cR*nh*Pi^4*Log[2])/7680 - (911441*Pi^4*d44[pR1, pA1]*Log[2])/
          (831600*NA) + (1198094819*cA^3*Pi^2*Log[2]^2)/1021870080 + 
         (5477497*cA^2*cR*Pi^2*Log[2]^2)/28385280 - 
         (483552119*cA*cR^2*Pi^2*Log[2]^2)/85155840 + 
         (169693*cR^3*Pi^2*Log[2]^2)/483840 + (157*cA^3*lmmOS*Pi^2*Log[2]^2)/
          8192 + (337*cA^2*cR*lmmOS*Pi^2*Log[2]^2)/5120 - 
         (2133*cA*cR^2*lmmOS*Pi^2*Log[2]^2)/10240 + 
         (157*cA^3*lmuH*Pi^2*Log[2]^2)/24576 + (337*cA^2*cR*lmuH*Pi^2*
           Log[2]^2)/15360 - (711*cA*cR^2*lmuH*Pi^2*Log[2]^2)/10240 - 
         (2640857*cA^2*nh*Pi^2*Log[2]^2)/46448640 + 
         (484741*cA*cR*nh*Pi^2*Log[2]^2)/2903040 + 
         (1103*cR^2*nh*Pi^2*Log[2]^2)/1728 + (11*cA^2*lmmOS*nh*Pi^2*Log[2]^2)/
          8192 + (11*cA*cR*lmmOS*nh*Pi^2*Log[2]^2)/256 + 
         (11*cA^2*lmuH*nh*Pi^2*Log[2]^2)/24576 + 
         (11*cA*cR*lmuH*nh*Pi^2*Log[2]^2)/768 + (2729191*Pi^2*d44[pR1, pA1]*
           Log[2]^2)/(532224*NA) + (151*nh*Pi^2*d44[pR1, pR2]*Log[2]^2)/
          (360*NA) - (2278723*cA^3*Pi^2*Log[2]^3)/25546752 + 
         (716921*cA^2*cR*Pi^2*Log[2]^3)/1774080 + 
         (6208537*cA*cR^2*Pi^2*Log[2]^3)/10644480 - (113*cR^3*Pi^2*Log[2]^3)/
          63 - (11*cA^2*nh*Pi^2*Log[2]^3)/12288 - (11*cA*cR*nh*Pi^2*Log[2]^3)/
          384 - (17197*Pi^2*d44[pR1, pA1]*Log[2]^3)/(10395*NA) - 
         (1198094819*cA^3*Log[2]^4)/1021870080 + (5216263*cA^2*cR*Log[2]^4)/
          28385280 + (419389559*cA*cR^2*Log[2]^4)/85155840 - 
         (169693*cR^3*Log[2]^4)/483840 - (157*cA^3*lmmOS*Log[2]^4)/8192 + 
         (67*cA^2*cR*lmmOS*Log[2]^4)/1024 - (111*cA*cR^2*lmmOS*Log[2]^4)/
          2048 - (157*cA^3*lmuH*Log[2]^4)/24576 + (67*cA^2*cR*lmuH*Log[2]^4)/
          3072 - (37*cA*cR^2*lmuH*Log[2]^4)/2048 + (2640857*cA^2*nh*Log[2]^4)/
          46448640 - (738757*cA*cR*nh*Log[2]^4)/2903040 - 
         (1103*cR^2*nh*Log[2]^4)/1728 - (11*cA^2*lmmOS*nh*Log[2]^4)/8192 - 
         (11*cA*cR*lmmOS*nh*Log[2]^4)/256 - (11*cA^2*lmuH*nh*Log[2]^4)/
          24576 - (11*cA*cR*lmuH*nh*Log[2]^4)/768 - 
         (2729191*d44[pR1, pA1]*Log[2]^4)/(532224*NA) - 
         (151*nh*d44[pR1, pR2]*Log[2]^4)/(360*NA) + (2278723*cA^3*Log[2]^5)/
          42577920 - (872153*cA^2*cR*Log[2]^5)/2956800 - 
         (4345753*cA*cR^2*Log[2]^5)/17740800 + (113*cR^3*Log[2]^5)/105 + 
         (11*cA^2*nh*Log[2]^5)/20480 + (11*cA*cR*nh*Log[2]^5)/640 + 
         (17197*d44[pR1, pA1]*Log[2]^5)/(17325*NA) - 
         (1198094819*cA^3*PolyLog[4, 1/2])/42577920 + 
         (5216263*cA^2*cR*PolyLog[4, 1/2])/1182720 + 
         (419389559*cA*cR^2*PolyLog[4, 1/2])/3548160 - 
         (169693*cR^3*PolyLog[4, 1/2])/20160 - 
         (471*cA^3*lmmOS*PolyLog[4, 1/2])/1024 + 
         (201*cA^2*cR*lmmOS*PolyLog[4, 1/2])/128 - 
         (333*cA*cR^2*lmmOS*PolyLog[4, 1/2])/256 - 
         (157*cA^3*lmuH*PolyLog[4, 1/2])/1024 + 
         (67*cA^2*cR*lmuH*PolyLog[4, 1/2])/128 - 
         (111*cA*cR^2*lmuH*PolyLog[4, 1/2])/256 + 
         (2640857*cA^2*nh*PolyLog[4, 1/2])/1935360 - 
         (738757*cA*cR*nh*PolyLog[4, 1/2])/120960 - 
         (1103*cR^2*nh*PolyLog[4, 1/2])/72 - 
         (33*cA^2*lmmOS*nh*PolyLog[4, 1/2])/1024 - 
         (33*cA*cR*lmmOS*nh*PolyLog[4, 1/2])/32 - 
         (11*cA^2*lmuH*nh*PolyLog[4, 1/2])/1024 - 
         (11*cA*cR*lmuH*nh*PolyLog[4, 1/2])/32 - 
         (2729191*d44[pR1, pA1]*PolyLog[4, 1/2])/(22176*NA) - 
         (151*nh*d44[pR1, pR2]*PolyLog[4, 1/2])/(15*NA) - 
         (2278723*cA^3*PolyLog[5, 1/2])/354816 + 
         (872153*cA^2*cR*PolyLog[5, 1/2])/24640 + 
         (4345753*cA*cR^2*PolyLog[5, 1/2])/147840 - 
         (904*cR^3*PolyLog[5, 1/2])/7 - (33*cA^2*nh*PolyLog[5, 1/2])/512 - 
         (33*cA*cR*nh*PolyLog[5, 1/2])/16 - (137576*d44[pR1, pA1]*
           PolyLog[5, 1/2])/(1155*NA) + nl^3*((7*lmmOS^2)/51840 + 
           (7*lmmOS^3)/155520 + (7*Pi^2)/311040 + (7*lmmOS*Pi^2)/311040 - 
           (7*Zeta[3])/77760) - (1915218245209*cA^3*Zeta[3])/137952460800 - 
         (1130280587*cA^2*cR*Zeta[3])/464486400 + (612398797*cA*cR^2*Zeta[3])/
          11059200 - (5171977*cR^3*Zeta[3])/537600 + 
         (543990757*cA^3*lmmOS*Zeta[3])/238878720 - 
         (16977233*cA^2*cR*lmmOS*Zeta[3])/2211840 - 
         (12643679*cA*cR^2*lmmOS*Zeta[3])/737280 - 
         (13651861*cA^3*lmmOS^2*Zeta[3])/13271040 - 
         (20673*cA^2*cR*lmmOS^2*Zeta[3])/4096 - 
         (39963*cA*cR^2*lmmOS^2*Zeta[3])/8192 + (49*cA^3*lmmOS^3*Zeta[3])/
          41472 + (93861319*cA^3*lmuH*Zeta[3])/79626240 - 
         (4444967*cA^2*cR*lmuH*Zeta[3])/2211840 - 
         (1242041*cA*cR^2*lmuH*Zeta[3])/245760 - 
         (238121*cA^3*lmmOS*lmuH*Zeta[3])/442368 - 
         (6891*cA^2*cR*lmmOS*lmuH*Zeta[3])/2048 - 
         (13321*cA*cR^2*lmmOS*lmuH*Zeta[3])/4096 + 
         (49*cA^3*lmmOS^2*lmuH*Zeta[3])/4608 + (83099*cA^3*lmuH^2*Zeta[3])/
          1474560 - (2297*cA^2*cR*lmuH^2*Zeta[3])/4096 - 
         (13321*cA*cR^2*lmuH^2*Zeta[3])/24576 + 
         (49*cA^3*lmmOS*lmuH^2*Zeta[3])/1536 + (49*cA^3*lmuH^3*Zeta[3])/
          1536 + (12222962477*cA^2*nh*Zeta[3])/13005619200 - 
         (26897253169*cA*cR*nh*Zeta[3])/5960908800 - 
         (34700459*cR^2*nh*Zeta[3])/3870720 + (16247*cA^2*lmmOS*nh*Zeta[3])/
          294912 - (54523*cA*cR*lmmOS*nh*Zeta[3])/36864 - 
         (231*cA^2*lmmOS^2*nh*Zeta[3])/32768 - (231*cA*cR*lmmOS^2*nh*Zeta[3])/
          1024 + (2849*cA^2*lmuH*nh*Zeta[3])/147456 - 
         (17045*cA*cR*lmuH*nh*Zeta[3])/36864 - (77*cA^2*lmmOS*lmuH*nh*
           Zeta[3])/16384 - (77*cA*cR*lmmOS*lmuH*nh*Zeta[3])/512 - 
         (77*cA^2*lmuH^2*nh*Zeta[3])/98304 - (77*cA*cR*lmuH^2*nh*Zeta[3])/
          3072 + (40091*cA*nh^2*Zeta[3])/5160960 - (10279*cR*nh^2*Zeta[3])/
          96768 - (5492951*cA^3*Pi^2*Zeta[3])/119439360 - 
         (3977*cA^2*cR*Pi^2*Zeta[3])/12288 + (16723*cA*cR^2*Pi^2*Zeta[3])/
          368640 + (7*cR^3*Pi^2*Zeta[3])/960 - (35*cA^3*lmmOS*Pi^2*Zeta[3])/
          41472 - (35*cA^3*lmuH*Pi^2*Zeta[3])/13824 - 
         (77*cA^2*nh*Pi^2*Zeta[3])/294912 - (721*cA*cR*nh*Pi^2*Zeta[3])/
          46080 - (1062005899*d44[pR1, pA1]*Zeta[3])/(17740800*NA) - 
         (59351603*nh*d44[pR1, pR2]*Zeta[3])/(10644480*NA) - 
         (18781*cA^3*Zeta[3]^2)/103680 + ((-273497*cA^3)/18662400 + 
           (1231*cA^2*cR)/6912 - (78079*cA^3*lmmOS)/1244160 + 
           (61*cA^2*cR*lmmOS)/1440 - (413*cA^3*lmmOS^2)/46080 - 
           (7*cA^3*lmmOS^3)/34560 - (10289*cA^3*lmuH)/207360 + 
           (61*cA^2*cR*lmuH)/1440 - (259*cA^3*lmmOS*lmuH)/7680 - 
           (7*cA^3*lmmOS^2*lmuH)/3840 - (469*cA^3*lmuH^2)/15360 - 
           (7*cA^3*lmmOS*lmuH^2)/1280 - (7*cA^3*lmuH^3)/1280 + 
           ((-2639*cA)/466560 - (119*cA*lmmOS)/62208 - (77*cA*lmuH)/51840)*
            nl^2 + (7*nl^3)/25920 - (1589*cA^3*Pi^2)/1244160 - 
           (7*cA^3*lmmOS*Pi^2)/69120 - (7*cA^3*lmuH*Pi^2)/23040 + 
           nl*((48307*cA^2)/1866240 - (973*cA*cR)/34560 + (1435*cA^2*lmmOS)/
              62208 + (7*cA^2*lmmOS^2)/4608 + (973*cA^2*lmuH)/51840 + 
             (7*cA^2*lmmOS*lmuH)/1280 + (7*cA^2*lmuH^2)/1536 + 
             (133*cA^2*Pi^2)/622080) + (49*cA^3*Zeta[3])/6912)/ep^3 + 
         nl^2*((-2175179*cA)/1007769600 - (12109*cR)/1555200 + 
           (431153*cA*lmmOS)/167961600 + (25579*cR*lmmOS)/3110400 + 
           (1529*cA*lmmOS^2)/1866240 + (79*cR*lmmOS^2)/23040 - 
           (2639*cA*lmmOS^3)/2799360 - (119*cA*lmmOS^4)/1492992 + 
           (9989*cA*lmuH)/5598720 - (cR*lmuH)/720 + (377*cA*lmmOS*lmuH)/
            311040 - (19*cR*lmmOS*lmuH)/51840 - (7*cA*lmmOS^2*lmuH)/38880 - 
           (77*cA*lmmOS^3*lmuH)/311040 + (7*cA*lmuH^2)/8640 + 
           (7*cA*lmmOS*lmuH^2)/25920 - (7*cA*lmmOS^2*lmuH^2)/34560 - 
           (913*cA*Pi^2)/11197440 - (541*cR*Pi^2)/1244160 - 
           (3311*cA*lmmOS*Pi^2)/5598720 - (7*cR*lmmOS*Pi^2)/8640 - 
           (553*cA*lmmOS^2*Pi^2)/7464960 + (7*cA*lmuH*Pi^2)/466560 - 
           (119*cA*lmmOS*lmuH*Pi^2)/622080 - (7*cA*lmuH^2*Pi^2)/207360 - 
           (6041*cA*Pi^4)/149299200 + (7*cR*Pi^4)/86400 + (2381*cA*Zeta[3])/
            1399680 - (29*cR*Zeta[3])/4320 - (1127*cA*lmmOS*Zeta[3])/933120 + 
           (7*cR*lmmOS*Zeta[3])/1440 - (217*cA*lmuH*Zeta[3])/155520) + 
         ((250433507*cA^3)/746496000 + (354103*cA^2*cR)/207360 + 
           (36047*cA*cR^2)/30720 + (185213*cA^3*lmmOS)/9331200 + 
           (4813*cA^2*cR*lmmOS)/17280 - (14363*cA^3*lmmOS^2)/497664 + 
           (61*cA^2*cR*lmmOS^2)/1440 - (413*cA^3*lmmOS^3)/138240 - 
           (7*cA^3*lmmOS^4)/138240 + (61169*cA^3*lmuH)/777600 + 
           (1157*cA^2*cR*lmuH)/5760 - (1849*cA^3*lmmOS*lmuH)/41472 + 
           (61*cA^2*cR*lmmOS*lmuH)/720 - (259*cA^3*lmmOS^2*lmuH)/15360 - 
           (7*cA^3*lmmOS^3*lmuH)/11520 - (121*cA^3*lmuH^2)/69120 + 
           (61*cA^2*cR*lmuH^2)/1440 - (469*cA^3*lmmOS*lmuH^2)/15360 - 
           (7*cA^3*lmmOS^2*lmuH^2)/2560 - (791*cA^3*lmuH^3)/46080 - 
           (7*cA^3*lmmOS*lmuH^3)/1280 - (21*cA^3*lmuH^4)/5120 + 
           (76697*cA^2*nh)/16588800 + (557*cA*cR*nh)/6480 - 
           (cA^2*lmmOS*nh)/960 + (cA^2*lmuH*nh)/960 + 
           (7/25920 + (7*lmmOS)/25920)*nl^3 - (116981*cA^3*Pi^2)/14929920 + 
           (229*cA^2*cR*Pi^2)/34560 - (7*cA*cR^2*Pi^2)/384 - 
           (1589*cA^3*lmmOS*Pi^2)/1244160 - (7*cA^3*lmmOS^2*Pi^2)/138240 - 
           (1589*cA^3*lmuH*Pi^2)/414720 - (7*cA^3*lmmOS*lmuH*Pi^2)/23040 - 
           (7*cA^3*lmuH^2*Pi^2)/15360 - (7*cA*cR*nh*Pi^2)/1440 + 
           (77*cA^3*Pi^4)/1244160 + nl^2*((-73*cA)/933120 + (127*cR)/20736 - 
             (2639*cA*lmmOS)/466560 - (119*cA*lmmOS^2)/124416 - 
             (7*cA*lmuH)/19440 - (77*cA*lmmOS*lmuH)/51840 - 
             (7*cA*lmuH^2)/17280 - (553*cA*Pi^2)/3732480) - 
           (7*cA^2*cR*Pi^2*Log[2])/480 + (7*cA*cR^2*Pi^2*Log[2])/240 - 
           (991021*cA^3*Zeta[3])/6635520 - (2297*cA^2*cR*Zeta[3])/2048 - 
           (13321*cA*cR^2*Zeta[3])/12288 + (49*cA^3*lmmOS*Zeta[3])/6912 + 
           (49*cA^3*lmuH*Zeta[3])/2304 - (77*cA^2*nh*Zeta[3])/49152 - 
           (77*cA*cR*nh*Zeta[3])/1536 + nl*((-2909*cA^2)/103680 - 
             (3037*cA*cR)/32400 + (643*cA^2*lmmOS)/29160 - (51*cA*cR*lmmOS)/
              1280 + (1435*cA^2*lmmOS^2)/124416 + (7*cA^2*lmmOS^3)/13824 - 
             (2887*cA^2*lmuH)/311040 - (799*cA*cR*lmuH)/34560 + 
             (973*cA^2*lmmOS*lmuH)/51840 + (7*cA^2*lmmOS^2*lmuH)/2560 + 
             (77*cA^2*lmuH^2)/17280 + (7*cA^2*lmmOS*lmuH^2)/1536 + 
             (49*cA^2*lmuH^3)/23040 + (2737*cA^2*Pi^2)/1244160 + 
             (7*cA*cR*Pi^2)/2880 + (133*cA^2*lmmOS*Pi^2)/622080 + 
             (133*cA^2*lmuH*Pi^2)/207360 + (133*cA^2*Zeta[3])/103680 - 
             (7*cA*cR*Zeta[3])/432))/ep^2 + (115455281*cA^3*Zeta[5])/
          68124672 - (528680589*cA^2*cR*Zeta[5])/7884800 - 
         (558170017*cA*cR^2*Zeta[5])/9461760 + (221063*cR^3*Zeta[5])/1344 - 
         (3059*cA^3*lmmOS*Zeta[5])/57600 - (3059*cA^3*lmuH*Zeta[5])/19200 + 
         (1705*cA^2*nh*Zeta[5])/32768 + (5995*cA*cR*nh*Zeta[5])/3072 + 
         (4961977*d44[pR1, pA1]*Zeta[5])/(36960*NA) + 
         ((-294810691589*cA^3)/134369280000 - (35116937*cA^2*cR)/49766400 + 
           (89807*cA*cR^2)/40960 + (686547569*cA^3*lmmOS)/746496000 + 
           (447619*cA^2*cR*lmmOS)/103680 + (36047*cA*cR^2*lmmOS)/10240 + 
           (51281*cA^3*lmmOS^2)/1166400 + (35*cA^2*cR*lmmOS^2)/216 - 
           (59287*cA^3*lmmOS^3)/7464960 + (61*cA^2*cR*lmmOS^3)/2160 - 
           (413*cA^3*lmmOS^4)/552960 - (7*cA^3*lmmOS^5)/691200 + 
           (38064113*cA^3*lmuH)/248832000 + (168187*cA^2*cR*lmuH)/103680 + 
           (36047*cA*cR^2*lmuH)/30720 + (376067*cA^3*lmmOS*lmuH)/3110400 + 
           (35*cA^2*cR*lmmOS*lmuH)/108 - (7157*cA^3*lmmOS^2*lmuH)/414720 + 
           (61*cA^2*cR*lmmOS^2*lmuH)/720 - (259*cA^3*lmmOS^3*lmuH)/46080 - 
           (7*cA^3*lmmOS^4*lmuH)/46080 + (166289*cA^3*lmuH^2)/2073600 + 
           (2129*cA^2*cR*lmuH^2)/17280 + (227*cA^3*lmmOS*lmuH^2)/69120 + 
           (61*cA^2*cR*lmmOS*lmuH^2)/720 - (469*cA^3*lmmOS^2*lmuH^2)/30720 - 
           (7*cA^3*lmmOS^3*lmuH^2)/7680 + (767*cA^3*lmuH^3)/34560 + 
           (61*cA^2*cR*lmuH^3)/2160 - (791*cA^3*lmmOS*lmuH^3)/46080 - 
           (7*cA^3*lmmOS^2*lmuH^3)/2560 - (1141*cA^3*lmuH^4)/184320 - 
           (21*cA^3*lmmOS*lmuH^4)/5120 - (63*cA^3*lmuH^5)/25600 - 
           (9717179*cA^2*nh)/497664000 + (1458571*cA*cR*nh)/2488320 + 
           (66137*cA^2*lmmOS*nh)/5529600 + (557*cA*cR*lmmOS*nh)/2160 - 
           (cA^2*lmmOS^2*nh)/384 + (108377*cA^2*lmuH*nh)/16588800 + 
           (557*cA*cR*lmuH*nh)/6480 + (cA^2*lmmOS*lmuH*nh)/960 + 
           (cA^2*lmuH^2*nh)/640 - (409607*cA^3*Pi^2)/37324800 + 
           (2413*cA^2*cR*Pi^2)/41472 - (49*cA*cR^2*Pi^2)/288 - 
           (113849*cA^3*lmmOS*Pi^2)/14929920 + (313*cA^2*cR*lmmOS*Pi^2)/
            17280 - (7*cA*cR^2*lmmOS*Pi^2)/128 - (1589*cA^3*lmmOS^2*Pi^2)/
            2488320 - (7*cA^3*lmmOS^3*Pi^2)/414720 - (7991*cA^3*lmuH*Pi^2)/
            497664 + (29*cA^2*cR*lmuH*Pi^2)/3456 - (7*cA*cR^2*lmuH*Pi^2)/
            384 - (1589*cA^3*lmmOS*lmuH*Pi^2)/414720 - 
           (7*cA^3*lmmOS^2*lmuH*Pi^2)/46080 - (1589*cA^3*lmuH^2*Pi^2)/
            276480 - (7*cA^3*lmmOS*lmuH^2*Pi^2)/15360 - (7*cA^3*lmuH^3*Pi^2)/
            15360 - (cA^2*nh*Pi^2)/5760 - (371*cA*cR*nh*Pi^2)/8640 - 
           (7*cA*cR*lmmOS*nh*Pi^2)/480 - (7*cA*cR*lmuH*nh*Pi^2)/1440 + 
           (8061397*cA^3*Pi^4)/597196800 + (3151*cA^2*cR*Pi^4)/61440 + 
           (4499*cA*cR^2*Pi^4)/73728 + (77*cA^3*lmmOS*Pi^4)/1244160 + 
           (77*cA^3*lmuH*Pi^4)/414720 + (187*cA^2*nh*Pi^4)/1474560 + 
           (187*cA*cR*nh*Pi^4)/46080 + nl^3*((7*lmmOS)/25920 + 
             (7*lmmOS^2)/51840 + (7*Pi^2)/311040) - (413*cA^2*cR*Pi^2*Log[2])/
            2880 + (413*cA*cR^2*Pi^2*Log[2])/1440 - 
           (7*cA^2*cR*lmmOS*Pi^2*Log[2])/160 + (7*cA*cR^2*lmmOS*Pi^2*Log[2])/
            80 - (7*cA^2*cR*lmuH*Pi^2*Log[2])/480 + 
           (7*cA*cR^2*lmuH*Pi^2*Log[2])/240 + (7*cA*cR*nh*Pi^2*Log[2])/240 + 
           (157*cA^3*Pi^2*Log[2]^2)/24576 + (337*cA^2*cR*Pi^2*Log[2]^2)/
            15360 - (711*cA*cR^2*Pi^2*Log[2]^2)/10240 + 
           (11*cA^2*nh*Pi^2*Log[2]^2)/24576 + (11*cA*cR*nh*Pi^2*Log[2]^2)/
            768 - (157*cA^3*Log[2]^4)/24576 + (67*cA^2*cR*Log[2]^4)/3072 - 
           (37*cA*cR^2*Log[2]^4)/2048 - (11*cA^2*nh*Log[2]^4)/24576 - 
           (11*cA*cR*nh*Log[2]^4)/768 - (157*cA^3*PolyLog[4, 1/2])/1024 + 
           (67*cA^2*cR*PolyLog[4, 1/2])/128 - (111*cA*cR^2*PolyLog[4, 1/2])/
            256 - (11*cA^2*nh*PolyLog[4, 1/2])/1024 - 
           (11*cA*cR*nh*PolyLog[4, 1/2])/32 + (155763643*cA^3*Zeta[3])/
            238878720 - (1753319*cA^2*cR*Zeta[3])/442368 - 
           (5191433*cA*cR^2*Zeta[3])/737280 - (4156231*cA^3*lmmOS*Zeta[3])/
            6635520 - (6891*cA^2*cR*lmmOS*Zeta[3])/2048 - 
           (13321*cA*cR^2*lmmOS*Zeta[3])/4096 + (49*cA^3*lmmOS^2*Zeta[3])/
            13824 - (27107*cA^3*lmuH*Zeta[3])/442368 - 
           (2297*cA^2*cR*lmuH*Zeta[3])/2048 - (13321*cA*cR^2*lmuH*Zeta[3])/
            12288 + (49*cA^3*lmmOS*lmuH*Zeta[3])/2304 + 
           (49*cA^3*lmuH^2*Zeta[3])/1536 + (539*cA^2*nh*Zeta[3])/32768 - 
           (6811*cA*cR*nh*Zeta[3])/12288 - (77*cA^2*lmmOS*nh*Zeta[3])/16384 - 
           (77*cA*cR*lmmOS*nh*Zeta[3])/512 - (77*cA^2*lmuH*nh*Zeta[3])/
            49152 - (77*cA*cR*lmuH*nh*Zeta[3])/1536 - (35*cA^3*Pi^2*Zeta[3])/
            41472 + nl^2*((376343*cA)/167961600 + (21259*cR)/3110400 + 
             (91*cA*lmmOS)/116640 + (673*cR*lmmOS)/103680 - (2639*cA*lmmOS^2)/
              933120 - (119*cA*lmmOS^3)/373248 + (377*cA*lmuH)/311040 - 
             (19*cR*lmuH)/51840 - (7*cA*lmmOS*lmuH)/19440 - 
             (77*cA*lmmOS^2*lmuH)/103680 + (7*cA*lmuH^2)/25920 - 
             (7*cA*lmmOS*lmuH^2)/17280 - (3311*cA*Pi^2)/5598720 - 
             (7*cR*Pi^2)/8640 - (553*cA*lmmOS*Pi^2)/3732480 - 
             (119*cA*lmuH*Pi^2)/622080 - (1127*cA*Zeta[3])/933120 + 
             (7*cR*Zeta[3])/1440) + nl*((-300626857*cA^2)/6718464000 - 
             (1776169*cA*cR)/5184000 - (35099*cR^2)/92160 - (3937*cA^2*lmmOS)/
              86400 - (5033*cA*cR*lmmOS)/43200 + (1415*cA^2*lmmOS^2)/186624 - 
             (1247*cA*cR*lmmOS^2)/69120 + (1435*cA^2*lmmOS^3)/373248 + 
             (7*cA^2*lmmOS^4)/55296 - (107*cA^2*lmuH)/86400 + 
             (12391*cA*cR*lmuH)/1036800 - (3949*cA^2*lmmOS*lmuH)/311040 - 
             (1081*cA*cR*lmmOS*lmuH)/34560 + (973*cA^2*lmmOS^2*lmuH)/103680 + 
             (7*cA^2*lmmOS^3*lmuH)/7680 - (2347*cA^2*lmuH^2)/207360 - 
             (133*cA*cR*lmuH^2)/23040 + (77*cA^2*lmmOS*lmuH^2)/17280 + 
             (7*cA^2*lmmOS^2*lmuH^2)/3072 - (7*cA^2*lmuH^3)/2880 + 
             (49*cA^2*lmmOS*lmuH^3)/23040 + (7*cA^2*lmuH^4)/18432 - 
             (76697*cA*nh)/49766400 - (557*cR*nh)/19440 + (cA*lmmOS*nh)/
              2880 - (cA*lmuH*nh)/2880 + (52927*cA^2*Pi^2)/11197440 + 
             (2701*cA*cR*Pi^2)/207360 + (7*cR^2*Pi^2)/1152 + 
             (2737*cA^2*lmmOS*Pi^2)/1244160 + (7*cA*cR*lmmOS*Pi^2)/960 + 
             (133*cA^2*lmmOS^2*Pi^2)/1244160 + (791*cA^2*lmuH*Pi^2)/207360 + 
             (7*cA*cR*lmuH*Pi^2)/2880 + (133*cA^2*lmmOS*lmuH*Pi^2)/207360 + 
             (133*cA^2*lmuH^2*Pi^2)/138240 + (7*cR*nh*Pi^2)/4320 + 
             (11053*cA^2*Pi^4)/74649600 - (77*cA*cR*Pi^4)/259200 + 
             (7*cA*cR*Pi^2*Log[2])/1440 - (7*cR^2*Pi^2*Log[2])/720 + 
             (6443047*cA^2*Zeta[3])/59719680 + (44771*cA*cR*Zeta[3])/165888 + 
             (13321*cR^2*Zeta[3])/36864 + (133*cA^2*lmmOS*Zeta[3])/103680 - 
             (7*cA*cR*lmmOS*Zeta[3])/432 + (35*cA^2*lmuH*Zeta[3])/1728 - 
             (7*cA*cR*lmuH*Zeta[3])/144 + (77*cA*nh*Zeta[3])/147456 + 
             (77*cR*nh*Zeta[3])/4608) - (3059*cA^3*Zeta[5])/57600)/ep + 
         nl*((273043555669*cA^2)/403107840000 + (5873926319*cA*cR)/
            3732480000 + (380873111*cR^2)/746496000 - (6497713*cA^2*lmmOS)/
            6718464000 - (47999*cA*cR*lmmOS)/3888000 - (4622789*cR^2*lmmOS)/
            12441600 - (851*cA^2*lmmOS^2)/25920 - (61513*cA*cR*lmmOS^2)/
            1036800 - (11*cR^2*lmmOS^2)/6480 + (697*cA^2*lmmOS^3)/1119744 + 
           (203*cA*cR*lmmOS^3)/23040 + (1435*cA^2*lmmOS^4)/1492992 + 
           (7*cA^2*lmmOS^5)/276480 + (16081489*cA^2*lmuH)/279936000 + 
           (9281371*cA*cR*lmuH)/31104000 - (30917*cR^2*lmuH)/1555200 + 
           (211*cA^2*lmmOS*lmuH)/345600 + (13943*cA*cR*lmmOS*lmuH)/1036800 + 
           (11*cR^2*lmmOS*lmuH)/3240 - (583*cA^2*lmmOS^2*lmuH)/62208 - 
           (707*cA*cR*lmmOS^2*lmuH)/69120 + (973*cA^2*lmmOS^3*lmuH)/311040 + 
           (7*cA^2*lmmOS^4*lmuH)/30720 + (11737*cA^2*lmuH^2)/518400 + 
           (124391*cA*cR*lmuH^2)/2073600 - (11*cR^2*lmuH^2)/6480 - 
           (1307*cA^2*lmmOS*lmuH^2)/103680 - (437*cA*cR*lmmOS*lmuH^2)/69120 + 
           (77*cA^2*lmmOS^2*lmuH^2)/34560 + (7*cA^2*lmmOS^3*lmuH^2)/9216 - 
           (11*cA^2*lmuH^3)/2592 + (557*cA*cR*lmuH^3)/207360 - 
           (7*cA^2*lmmOS*lmuH^3)/2880 + (49*cA^2*lmmOS^2*lmuH^3)/46080 - 
           (7*cA^2*lmuH^4)/2304 + (7*cA^2*lmmOS*lmuH^4)/18432 - 
           (119*cA^2*lmuH^5)/460800 - (9357947*cA*nh)/746496000 - 
           (2916163*cR*nh)/37324800 - (82457*cA*lmmOS*nh)/49766400 - 
           (521*cR*lmmOS*nh)/19440 + (cA*lmmOS^2*nh)/1920 + 
           (cA*lmuH*nh)/8640 - (cR*lmuH*nh)/540 - (cA*lmmOS*lmuH*nh)/1440 + 
           (cA*lmuH^2*nh)/5760 + (24731*cA^2*Pi^2)/167961600 + 
           (251377*cA*cR*Pi^2)/12441600 - (2389*cR^2*Pi^2)/311040 + 
           (48121*cA^2*lmmOS*Pi^2)/11197440 + (8207*cA*cR*lmmOS*Pi^2)/
            207360 + (7*cR^2*lmmOS*Pi^2)/1152 + (2737*cA^2*lmmOS^2*Pi^2)/
            2488320 + (7*cA*cR*lmmOS^2*Pi^2)/640 + (133*cA^2*lmmOS^3*Pi^2)/
            3732480 + (113*cA^2*lmuH*Pi^2)/116640 + (313*cA*cR*lmuH*Pi^2)/
            41472 + (791*cA^2*lmmOS*lmuH*Pi^2)/207360 + 
           (7*cA*cR*lmmOS*lmuH*Pi^2)/960 + (133*cA^2*lmmOS^2*lmuH*Pi^2)/
            414720 + (203*cA^2*lmuH^2*Pi^2)/69120 + (7*cA*cR*lmuH^2*Pi^2)/
            5760 + (133*cA^2*lmmOS*lmuH^2*Pi^2)/138240 + 
           (133*cA^2*lmuH^3*Pi^2)/138240 + (cA*nh*Pi^2)/17280 + 
           (203*cR*nh*Pi^2)/25920 + (7*cR*lmmOS*nh*Pi^2)/4320 + 
           (548507*cA^2*Pi^4)/895795200 + (43727*cA*cR*Pi^4)/4147200 + 
           (1033*cR^2*Pi^4)/184320 + (11053*cA^2*lmmOS*Pi^4)/74649600 - 
           (77*cA*cR*lmmOS*Pi^4)/259200 + (2051*cA^2*lmuH*Pi^4)/3110400 - 
           (77*cA*cR*lmuH*Pi^4)/86400 - (11*cA*nh*Pi^4)/6635520 - 
           (11*cR*nh*Pi^4)/207360 + (709*d44[pR1, pR2])/(288*NA) - 
           (17*Pi^4*d44[pR1, pR2])/(270*NA) + (7*cA*cR*Pi^2*Log[2])/2160 - 
           (7*cR^2*Pi^2*Log[2])/1080 + (7*cA*cR*lmmOS*Pi^2*Log[2])/1440 - 
           (7*cR^2*lmmOS*Pi^2*Log[2])/720 - (7*cR*nh*Pi^2*Log[2])/720 - 
           (157*cA^2*Pi^2*Log[2]^2)/221184 - (337*cA*cR*Pi^2*Log[2]^2)/
            138240 + (79*cR^2*Pi^2*Log[2]^2)/10240 - (11*cA*nh*Pi^2*Log[2]^2)/
            221184 - (11*cR*nh*Pi^2*Log[2]^2)/6912 + (157*cA^2*Log[2]^4)/
            221184 - (67*cA*cR*Log[2]^4)/27648 + (37*cR^2*Log[2]^4)/18432 + 
           (11*cA*nh*Log[2]^4)/221184 + (11*cR*nh*Log[2]^4)/6912 + 
           (157*cA^2*PolyLog[4, 1/2])/9216 - (67*cA*cR*PolyLog[4, 1/2])/
            1152 + (37*cR^2*PolyLog[4, 1/2])/768 + (11*cA*nh*PolyLog[4, 1/2])/
            9216 + (11*cR*nh*PolyLog[4, 1/2])/288 - (265864211*cA^2*Zeta[3])/
            716636160 - (37265609*cA*cR*Zeta[3])/19906560 - 
           (1504603*cR^2*Zeta[3])/2211840 + (6443047*cA^2*lmmOS*Zeta[3])/
            59719680 + (44771*cA*cR*lmmOS*Zeta[3])/165888 + 
           (13321*cR^2*lmmOS*Zeta[3])/36864 + (133*cA^2*lmmOS^2*Zeta[3])/
            207360 - (7*cA*cR*lmmOS^2*Zeta[3])/864 + 
           (12229*cA^2*lmuH*Zeta[3])/77760 - (1001*cA*cR*lmuH*Zeta[3])/4320 + 
           (35*cA^2*lmmOS*lmuH*Zeta[3])/1728 - (7*cA*cR*lmmOS*lmuH*Zeta[3])/
            144 + (539*cA^2*lmuH^2*Zeta[3])/11520 - (7*cA*cR*lmuH^2*Zeta[3])/
            96 + (1043*cA*nh*Zeta[3])/442368 + (4249*cR*nh*Zeta[3])/110592 + 
           (77*cA*lmmOS*nh*Zeta[3])/147456 + (77*cR*lmmOS*nh*Zeta[3])/4608 - 
           (3703*cA^2*Pi^2*Zeta[3])/746496 + (77*cA*cR*Pi^2*Zeta[3])/12960 + 
           (49*d44[pR1, pR2]*Zeta[3])/(18*NA) + (15701*cA^2*Zeta[5])/172800 + 
           (7*cA*cR*Zeta[5])/2160 - (7*cR^2*Zeta[5])/48)) + 
       rhoOS^2*((-1693230705064916383469*cA^3)/2480204251555430400000 - 
         (102934931448387137083*cA^2*cR)/14060114804736000000 - 
         (62593165539469277*cA*cR^2)/10042939146240000 + 
         (4069572672461*cR^3)/3099672576000 - cA^3/(8064*ep^6) + 
         (22200604413284767*cA^3*lmmOS)/41295442083840000 + 
         (1374657264009769*cA^2*cR*lmmOS)/234101145600000 + 
         (557825003773*cA*cR^2*lmmOS)/55738368000 + 
         (3429583668463*cA^3*lmmOS^2)/16387080192000 + 
         (157821169717*cA^2*cR*lmmOS^2)/92897280000 + 
         (55364417*cA*cR^2*lmmOS^2)/25804800 + (9285023*cA^3*lmmOS^3)/
          2194698240 + (35653*cA^2*cR*lmmOS^3)/13608000 - 
         (33241*cA^3*lmmOS^4)/104509440 + (277*cA^2*cR*lmmOS^4)/113400 - 
         (61*cA^3*lmmOS^5)/3870720 - (cA^3*lmmOS^6)/5806080 + 
         (510352200969343*cA^3*lmuH)/13765147361280000 + 
         (431407298516219*cA^2*cR*lmuH)/234101145600000 + 
         (509104316813*cA*cR^2*lmuH)/167215104000 + 
         (343801815607*cA^3*lmmOS*lmuH)/2731180032000 + 
         (170554787381*cA^2*cR*lmmOS*lmuH)/139345920000 + 
         (55364417*cA*cR^2*lmmOS*lmuH)/38707200 + (201323*cA^3*lmmOS^2*lmuH)/
          24385536 + (218473*cA^2*cR*lmmOS^2*lmuH)/4536000 - 
         (20609*cA^3*lmmOS^3*lmuH)/17418240 + (277*cA^2*cR*lmmOS^3*lmuH)/
          28350 - (13*cA^3*lmmOS^4*lmuH)/86016 - (cA^3*lmmOS^5*lmuH)/322560 - 
         (8443254977*cA^3*lmuH^2)/1820786688000 + 
         (21811698637*cA^2*cR*lmuH^2)/92897280000 + (55364417*cA*cR^2*lmuH^2)/
          232243200 + (94153*cA^3*lmmOS*lmuH^2)/10160640 + 
         (218473*cA^2*cR*lmmOS*lmuH^2)/4536000 - (4163*cA^3*lmmOS^2*lmuH^2)/
          3870720 + (277*cA^2*cR*lmmOS^2*lmuH^2)/18900 - 
         (73*cA^3*lmmOS^3*lmuH^2)/129024 - (cA^3*lmmOS^4*lmuH^2)/43008 + 
         (100333*cA^3*lmuH^3)/20321280 + (188003*cA^2*cR*lmuH^3)/13608000 + 
         (2089*cA^3*lmmOS*lmuH^3)/1935360 + (277*cA^2*cR*lmmOS*lmuH^3)/
          28350 - (131*cA^3*lmmOS^2*lmuH^3)/129024 - (cA^3*lmmOS^3*lmuH^3)/
          10752 + (14059*cA^3*lmuH^4)/7741440 + (277*cA^2*cR*lmuH^4)/113400 - 
         (31*cA^3*lmmOS*lmuH^4)/36864 - (3*cA^3*lmmOS^2*lmuH^4)/14336 - 
         (299*cA^3*lmuH^5)/1290240 - (9*cA^3*lmmOS*lmuH^5)/35840 - 
         (9*cA^3*lmuH^6)/71680 + (14678335674706727809*cA^2*nh)/
          129915460795760640000 + (2825783408381250127*cA*cR*nh)/
          3977003901911040000 - (15875872515599*cR^2*nh)/11588006707200 - 
         (99949443569*cA^2*lmmOS*nh)/13655900160000 + 
         (29966555227*cA*cR*lmmOS*nh)/95551488000 - (167*cR^2*lmmOS*nh)/
          25920 - (131150851*cA^2*lmmOS^2*nh)/57802752000 + 
         (33757943*cA*cR*lmmOS^2*nh)/412876800 - (817*cA^2*lmmOS^3*nh)/
          1612800 + (19*cA*cR*lmmOS^3*nh)/5760 - (62547925369*cA^2*lmuH*nh)/
          18207866880000 + (2483181409*cA*cR*lmuH*nh)/24772608000 + 
         (167*cR^2*lmuH*nh)/25920 + (102257149*cA^2*lmmOS*lmuH*nh)/
          86704128000 + (70272229*cA*cR*lmmOS*lmuH*nh)/1857945600 - 
         (43*cA^2*lmmOS^2*lmuH*nh)/537600 + (cA*cR*lmmOS^2*lmuH*nh)/1920 + 
         (413796349*cA^2*lmuH^2*nh)/520224768000 + (26941669*cA*cR*lmuH^2*nh)/
          11147673600 + (43*cA^2*lmmOS*lmuH^2*nh)/107520 - 
         (cA*cR*lmmOS*lmuH^2*nh)/384 + (43*cA^2*lmuH^3*nh)/230400 - 
         (7*cA*cR*lmuH^3*nh)/5760 - (67355344787*cA*nh^2)/15941173248000 + 
         (5991898111*cR*nh^2)/110361968640 - (cA*lmmOS*nh^2)/345600 + 
         (cA*lmuH*nh^2)/345600 + ((-61*cA^3)/32256 - (cA^3*lmmOS)/8064 - 
           (cA^3*lmuH)/2688 + (5*cA^2*nl)/16128)/ep^5 + 
         (1172859885221*cA^3*Pi^2)/147483721728000 + 
         (103951023367*cA^2*cR*Pi^2)/836075520000 - (17386547*cA*cR^2*Pi^2)/
          139345920 + (13177*cR^3*Pi^2)/120960 - (202193*cA^3*lmmOS*Pi^2)/
          162570240 + (938921*cA^2*cR*lmmOS*Pi^2)/36288000 - 
         (365*cA*cR^2*lmmOS*Pi^2)/4032 - (92173*cA^3*lmmOS^2*Pi^2)/
          209018880 + (1151*cA^2*cR*lmmOS^2*Pi^2)/226800 - 
         (15*cA*cR^2*lmmOS^2*Pi^2)/896 - (59*cA^3*lmmOS^3*Pi^2)/2612736 - 
         (cA^3*lmmOS^4*Pi^2)/2322432 - (40007*cA^3*lmuH*Pi^2)/27095040 + 
         (1282643*cA^2*cR*lmuH*Pi^2)/108864000 - (25*cA*cR^2*lmuH*Pi^2)/896 - 
         (16309*cA^3*lmmOS*lmuH*Pi^2)/8709120 + (17*cA^2*cR*lmmOS*lmuH*Pi^2)/
          4050 - (5*cA*cR^2*lmmOS*lmuH*Pi^2)/448 - 
         (59*cA^3*lmmOS^2*lmuH*Pi^2)/290304 - (cA^3*lmmOS^3*lmuH*Pi^2)/
          193536 - (23591*cA^3*lmuH^2*Pi^2)/11612160 + 
         (251*cA^2*cR*lmuH^2*Pi^2)/226800 - (5*cA*cR^2*lmuH^2*Pi^2)/2688 - 
         (59*cA^3*lmmOS*lmuH^2*Pi^2)/96768 - (cA^3*lmmOS^2*lmuH^2*Pi^2)/
          43008 - (59*cA^3*lmuH^3*Pi^2)/96768 - (cA^3*lmmOS*lmuH^3*Pi^2)/
          21504 - (cA^3*lmuH^4*Pi^2)/28672 - (272288771*cA^2*nh*Pi^2)/
          1560674304000 - (35174171*cA*cR*nh*Pi^2)/33443020800 + 
         (49*cR^2*nh*Pi^2)/2700 - (43*cA^2*lmmOS*nh*Pi^2)/537600 - 
         (2677*cA*cR*lmmOS*nh*Pi^2)/120960 - (cA*cR*lmmOS^2*nh*Pi^2)/224 - 
         (43*cA^2*lmuH*nh*Pi^2)/1612800 - (13*cA*cR*lmuH*nh*Pi^2)/1920 - 
         (cA*cR*lmmOS*lmuH*nh*Pi^2)/336 - (cA*cR*lmuH^2*nh*Pi^2)/2016 - 
         (cR*nh^2*Pi^2)/5670 - (445166279297893*cA^3*Pi^4)/4591057895424000 + 
         (5082495653377*cA^2*cR*Pi^4)/255058771968000 + 
         (27809390114503*cA*cR^2*Pi^4)/31882346496000 + 
         (1279910543047*cR^3*Pi^4)/7970586624000 + 
         (790058539*cA^3*lmmOS*Pi^4)/133772083200 + 
         (12574399*cA^2*cR*lmmOS*Pi^4)/275251200 + 
         (3524849*cA*cR^2*lmmOS*Pi^4)/51609600 + (11*cA^3*lmmOS^2*Pi^4)/
          3483648 + (93468691*cA^3*lmuH*Pi^4)/44590694400 + 
         (12574399*cA^2*cR*lmuH*Pi^4)/825753600 + (3524849*cA*cR^2*lmuH*Pi^4)/
          154828800 + (11*cA^3*lmmOS*lmuH*Pi^4)/580608 + 
         (11*cA^3*lmuH^2*Pi^4)/387072 - (440018935541*cA^2*nh*Pi^4)/
          58859716608000 + (2451328719893*cA*cR*nh*Pi^4)/29429858304000 + 
         (810625379*cR^2*nh*Pi^4)/2786918400 - (1921*cA^2*lmmOS*nh*Pi^4)/
          31457280 + (48773*cA*cR*lmmOS*nh*Pi^4)/23592960 - 
         (1921*cA^2*lmuH*nh*Pi^4)/94371840 + (48773*cA*cR*lmuH*nh*Pi^4)/
          70778880 - (77671*cA^3*Pi^6)/2194698240 + 
         ((-34051*cA^3)/4354560 + (277*cA^2*cR)/75600 - (61*cA^3*lmmOS)/
            32256 - (cA^3*lmmOS^2)/16128 - (13*cA^3*lmuH)/3584 - 
           (cA^3*lmmOS*lmuH)/2688 - (cA^3*lmuH^2)/1792 + 
           ((2185*cA^2)/870912 + (5*cA^2*lmmOS)/16128 + (cA^2*lmuH)/1792)*
            nl - (85*cA*nl^2)/435456 - (cA^3*Pi^2)/96768)/ep^4 + 
         (271161840307*d44[pR1, pA1])/(105670656000*NA) - 
         (19*lmmOS*d44[pR1, pA1])/(13824*NA) + (19*lmuH*d44[pR1, pA1])/
          (13824*NA) - (622593692081*Pi^4*d44[pR1, pA1])/(3985293312000*NA) + 
         (1234082295799*nh*d44[pR1, pR2])/(2789705318400*NA) - 
         (16542457*nh*Pi^4*d44[pR1, pR2])/(1857945600*NA) - 
         (6679*cA^2*cR*Pi^2*Log[2])/60480 + (5603*cA*cR^2*Pi^2*Log[2])/
          16800 - (2129*cR^3*Pi^2*Log[2])/9450 - 
         (155*cA^2*cR*lmmOS*Pi^2*Log[2])/2016 + 
         (155*cA*cR^2*lmmOS*Pi^2*Log[2])/1008 - 
         (3*cA^2*cR*lmmOS^2*Pi^2*Log[2])/224 + (3*cA*cR^2*lmmOS^2*Pi^2*
           Log[2])/112 - (cA^2*cR*lmuH*Pi^2*Log[2])/42 + 
         (cA*cR^2*lmuH*Pi^2*Log[2])/21 - (cA^2*cR*lmmOS*lmuH*Pi^2*Log[2])/
          112 + (cA*cR^2*lmmOS*lmuH*Pi^2*Log[2])/56 - 
         (cA^2*cR*lmuH^2*Pi^2*Log[2])/672 + (cA*cR^2*lmuH^2*Pi^2*Log[2])/
          336 + (31*cA*cR*nh*Pi^2*Log[2])/3024 - (2*cR^2*nh*Pi^2*Log[2])/
          189 + (cA*cR*lmmOS*nh*Pi^2*Log[2])/56 + (cA*cR*lmuH*nh*Pi^2*Log[2])/
          168 - (11639217467*cA^3*Pi^4*Log[2])/151820697600 + 
         (766362284201*cA^2*cR*Pi^4*Log[2])/2656862208000 - 
         (33694676531*cA*cR^2*Pi^4*Log[2])/166053888000 - 
         (952373*cR^3*Pi^4*Log[2])/15444000 + (1921*cA^2*nh*Pi^4*Log[2])/
          15728640 - (48773*cA*cR*nh*Pi^4*Log[2])/11796480 - 
         (2629807*Pi^4*d44[pR1, pA1]*Log[2])/(6006000*NA) - 
         (8843322877177*cA^3*Pi^2*Log[2]^2)/25505877196800 - 
         (32381598811*cA^2*cR*Pi^2*Log[2]^2)/56679727104 + 
         (1143549792347*cA*cR^2*Pi^2*Log[2]^2)/531372441600 + 
         (53133456427*cR^3*Pi^2*Log[2]^2)/66421555200 + 
         (8029*cA^3*lmmOS*Pi^2*Log[2]^2)/3932160 + 
         (18115*cA^2*cR*lmmOS*Pi^2*Log[2]^2)/917504 - 
         (40991*cA*cR^2*lmmOS*Pi^2*Log[2]^2)/860160 + 
         (8029*cA^3*lmuH*Pi^2*Log[2]^2)/11796480 + 
         (18115*cA^2*cR*lmuH*Pi^2*Log[2]^2)/2752512 - 
         (40991*cA*cR^2*lmuH*Pi^2*Log[2]^2)/2580480 - 
         (2600673247*cA^2*nh*Pi^2*Log[2]^2)/98099527680 + 
         (19386227101*cA*cR*nh*Pi^2*Log[2]^2)/70071091200 + 
         (9545687*cR^2*nh*Pi^2*Log[2]^2)/9289728 - 
         (113*cA^2*lmmOS*nh*Pi^2*Log[2]^2)/524288 + 
         (2869*cA*cR*lmmOS*nh*Pi^2*Log[2]^2)/393216 - 
         (113*cA^2*lmuH*nh*Pi^2*Log[2]^2)/1572864 + 
         (2869*cA*cR*lmuH*nh*Pi^2*Log[2]^2)/1179648 - 
         (4494400219*Pi^2*d44[pR1, pA1]*Log[2]^2)/(16605388800*NA) - 
         (1010393*nh*Pi^2*d44[pR1, pR2]*Log[2]^2)/(77414400*NA) - 
         (1228186409*cA^3*Pi^2*Log[2]^3)/10627448832 + 
         (50731062553*cA^2*cR*Pi^2*Log[2]^3)/132843110400 - 
         (1308214723*cA*cR^2*Pi^2*Log[2]^3)/8302694400 - 
         (137239*cR^3*Pi^2*Log[2]^3)/772200 + (113*cA^2*nh*Pi^2*Log[2]^3)/
          786432 - (2869*cA*cR*nh*Pi^2*Log[2]^3)/589824 - 
         (49619*Pi^2*d44[pR1, pA1]*Log[2]^3)/(75075*NA) + 
         (8843322877177*cA^3*Log[2]^4)/25505877196800 + 
         (36739415131*cA^2*cR*Log[2]^4)/56679727104 - 
         (1225258848347*cA*cR^2*Log[2]^4)/531372441600 - 
         (53133456427*cR^3*Log[2]^4)/66421555200 - (8029*cA^3*lmmOS*Log[2]^4)/
          3932160 + (923*cA^2*cR*lmmOS*Log[2]^4)/131072 - 
         (727*cA*cR^2*lmmOS*Log[2]^4)/122880 - (8029*cA^3*lmuH*Log[2]^4)/
          11796480 + (923*cA^2*cR*lmuH*Log[2]^4)/393216 - 
         (727*cA*cR^2*lmuH*Log[2]^4)/368640 + (2600673247*cA^2*nh*Log[2]^4)/
          98099527680 - (144462476107*cA*cR*nh*Log[2]^4)/490497638400 - 
         (9545687*cR^2*nh*Log[2]^4)/9289728 + (113*cA^2*lmmOS*nh*Log[2]^4)/
          524288 - (2869*cA*cR*lmmOS*nh*Log[2]^4)/393216 + 
         (113*cA^2*lmuH*nh*Log[2]^4)/1572864 - (2869*cA*cR*lmuH*nh*Log[2]^4)/
          1179648 + (4494400219*d44[pR1, pA1]*Log[2]^4)/(16605388800*NA) + 
         (1010393*nh*d44[pR1, pR2]*Log[2]^4)/(77414400*NA) + 
         (1228186409*cA^3*Log[2]^5)/17712414720 - 
         (53103260953*cA^2*cR*Log[2]^5)/221405184000 + 
         (1604739523*cA*cR^2*Log[2]^5)/13837824000 + (137239*cR^3*Log[2]^5)/
          1287000 - (113*cA^2*nh*Log[2]^5)/1310720 + (2869*cA*cR*nh*Log[2]^5)/
          983040 + (49619*d44[pR1, pA1]*Log[2]^5)/(125125*NA) + 
         (8843322877177*cA^3*PolyLog[4, 1/2])/1062744883200 + 
         (36739415131*cA^2*cR*PolyLog[4, 1/2])/2361655296 - 
         (1225258848347*cA*cR^2*PolyLog[4, 1/2])/22140518400 - 
         (53133456427*cR^3*PolyLog[4, 1/2])/2767564800 - 
         (8029*cA^3*lmmOS*PolyLog[4, 1/2])/163840 + 
         (2769*cA^2*cR*lmmOS*PolyLog[4, 1/2])/16384 - 
         (727*cA*cR^2*lmmOS*PolyLog[4, 1/2])/5120 - 
         (8029*cA^3*lmuH*PolyLog[4, 1/2])/491520 + 
         (923*cA^2*cR*lmuH*PolyLog[4, 1/2])/16384 - 
         (727*cA*cR^2*lmuH*PolyLog[4, 1/2])/15360 + 
         (2600673247*cA^2*nh*PolyLog[4, 1/2])/4087480320 - 
         (144462476107*cA*cR*nh*PolyLog[4, 1/2])/20437401600 - 
         (9545687*cR^2*nh*PolyLog[4, 1/2])/387072 + 
         (339*cA^2*lmmOS*nh*PolyLog[4, 1/2])/65536 - 
         (2869*cA*cR*lmmOS*nh*PolyLog[4, 1/2])/16384 + 
         (113*cA^2*lmuH*nh*PolyLog[4, 1/2])/65536 - 
         (2869*cA*cR*lmuH*nh*PolyLog[4, 1/2])/49152 + 
         (4494400219*d44[pR1, pA1]*PolyLog[4, 1/2])/(691891200*NA) + 
         (1010393*nh*d44[pR1, pR2]*PolyLog[4, 1/2])/(3225600*NA) - 
         (1228186409*cA^3*PolyLog[5, 1/2])/147603456 + 
         (53103260953*cA^2*cR*PolyLog[5, 1/2])/1845043200 - 
         (1604739523*cA*cR^2*PolyLog[5, 1/2])/115315200 - 
         (137239*cR^3*PolyLog[5, 1/2])/10725 + (339*cA^2*nh*PolyLog[5, 1/2])/
          32768 - (2869*cA*cR*nh*PolyLog[5, 1/2])/8192 - 
         (1190856*d44[pR1, pA1]*PolyLog[5, 1/2])/(25025*NA) + 
         nl^3*(lmmOS/72576 + lmmOS^2/48384 + lmmOS^3/217728 + Pi^2/290304 + 
           (lmmOS*Pi^2)/435456 - Zeta[3]/108864) + 
         (93832295889751801*cA^3*Zeta[3])/12854962107187200 + 
         (589196886021599*cA^2*cR*Zeta[3])/108206751744000 - 
         (6719889959330507*cA*cR^2*Zeta[3])/148784283648000 - 
         (4500439609207*cR^3*Zeta[3])/476872704000 - 
         (993781262683*cA^3*lmmOS*Zeta[3])/1070176665600 - 
         (3045251063*cA^2*cR*lmmOS*Zeta[3])/339738624 - 
         (35109203603*cA*cR^2*lmmOS*Zeta[3])/2477260800 - 
         (484616413*cA^3*lmmOS^2*Zeta[3])/2972712960 - 
         (3769709*cA^2*cR*lmmOS^2*Zeta[3])/2621440 - 
         (317921*cA*cR^2*lmmOS^2*Zeta[3])/163840 + (5*cA^3*lmmOS^3*Zeta[3])/
          41472 - (89075568187*cA^3*lmuH*Zeta[3])/356725555200 - 
         (167432810123*cA^2*cR*lmuH*Zeta[3])/59454259200 - 
         (11050270081*cA*cR^2*lmuH*Zeta[3])/2477260800 - 
         (6558691*cA^3*lmmOS*lmuH*Zeta[3])/70778880 - 
         (3769709*cA^2*cR*lmmOS*lmuH*Zeta[3])/3932160 - 
         (317921*cA*cR^2*lmmOS*lmuH*Zeta[3])/245760 + 
         (5*cA^3*lmmOS^2*lmuH*Zeta[3])/4608 + (299827*cA^3*lmuH^2*Zeta[3])/
          330301440 - (3769709*cA^2*cR*lmuH^2*Zeta[3])/23592960 - 
         (317921*cA*cR^2*lmuH^2*Zeta[3])/1474560 + 
         (5*cA^3*lmmOS*lmuH^2*Zeta[3])/1536 + (5*cA^3*lmuH^3*Zeta[3])/1536 + 
         (13106227531090721*cA^2*nh*Zeta[3])/39279050883072000 - 
         (33873368094192251*cA*cR*nh*Zeta[3])/6546508480512000 - 
         (4499469092203*cR^2*nh*Zeta[3])/286123622400 + 
         (696661*cA^2*lmmOS*nh*Zeta[3])/47185920 - 
         (92633779*cA*cR*lmmOS*nh*Zeta[3])/283115520 + 
         (2373*cA^2*lmmOS^2*nh*Zeta[3])/2097152 - 
         (20083*cA*cR*lmmOS^2*nh*Zeta[3])/524288 + 
         (449939*cA^2*lmuH*nh*Zeta[3])/94371840 - 
         (29405173*cA*cR*lmuH*nh*Zeta[3])/283115520 + 
         (791*cA^2*lmmOS*lmuH*nh*Zeta[3])/1048576 - 
         (20083*cA*cR*lmmOS*lmuH*nh*Zeta[3])/786432 + 
         (791*cA^2*lmuH^2*nh*Zeta[3])/6291456 - 
         (20083*cA*cR*lmuH^2*nh*Zeta[3])/4718592 + 
         (484038617*cA*nh^2*Zeta[3])/141699317760 - 
         (347538727*cR*nh^2*Zeta[3])/8174960640 - 
         (184408991*cA^3*Pi^2*Zeta[3])/26754416640 - 
         (40211963*cA^2*cR*Pi^2*Zeta[3])/495452160 - 
         (796967*cA*cR^2*Pi^2*Zeta[3])/30965760 + (cR^3*Pi^2*Zeta[3])/672 - 
         (25*cA^3*lmmOS*Pi^2*Zeta[3])/290304 - (25*cA^3*lmuH*Pi^2*Zeta[3])/
          96768 + (791*cA^2*nh*Pi^2*Zeta[3])/18874368 - 
         (288037*cA*cR*nh*Pi^2*Zeta[3])/99090432 + 
         (25424010059923*d44[pR1, pA1]*Zeta[3])/(2324754432000*NA) + 
         (5991575341*nh*d44[pR1, pR2]*Zeta[3])/(22960537600*NA) - 
         (2683*cA^3*Zeta[3]^2)/145152 + ((-2449987*cA^3)/365783040 + 
           (68287*cA^2*cR)/2016000 - (33997*cA^3*lmmOS)/4354560 + 
           (277*cA^2*cR*lmmOS)/37800 - (61*cA^3*lmmOS^2)/64512 - 
           (cA^3*lmmOS^3)/48384 - (21113*cA^3*lmuH)/2903040 + 
           (277*cA^2*cR*lmuH)/37800 - (13*cA^3*lmmOS*lmuH)/3584 - 
           (cA^3*lmmOS^2*lmuH)/5376 - (73*cA^3*lmuH^2)/21504 - 
           (cA^3*lmmOS*lmuH^2)/1792 - (cA^3*lmuH^3)/1792 + 
           ((-1763*cA)/2612736 - (85*cA*lmmOS)/435456 - (11*cA*lmuH)/72576)*
            nl^2 + nl^3/36288 - (59*cA^3*Pi^2)/435456 - (cA^3*lmmOS*Pi^2)/
            96768 - (cA^3*lmuH*Pi^2)/32256 + nl*((3829*cA^2)/933120 - 
             (16787*cA*cR)/3628800 + (2185*cA^2*lmmOS)/870912 + 
             (5*cA^2*lmmOS^2)/32256 + (91*cA^2*lmuH)/41472 + 
             (cA^2*lmmOS*lmuH)/1792 + (5*cA^2*lmuH^2)/10752 + 
             (19*cA^2*Pi^2)/870912) + (5*cA^3*Zeta[3])/6912)/ep^3 + 
         nl^2*((26032591*cA)/98761420800 - (12159533*cR)/21946982400 + 
           (1448273*cA*lmmOS)/4115059200 + (437977*cR*lmmOS)/203212800 - 
           (229*cA*lmmOS^2)/2177280 + (5197*cR*lmmOS^2)/10886400 - 
           (1763*cA*lmmOS^3)/15676416 - (85*cA*lmmOS^4)/10450944 + 
           (21407*cA*lmuH)/78382080 - (1103*cR*lmuH)/5806080 + 
           (89*cA*lmmOS*lmuH)/725760 + (cR*lmmOS*lmuH)/483840 - 
           (7*cA*lmmOS^2*lmuH)/124416 - (11*cA*lmmOS^3*lmuH)/435456 + 
           (cA*lmuH^2)/10368 + (cA*lmmOS*lmuH^2)/145152 - (cA*lmmOS^2*lmuH^2)/
            48384 - (281*cA*Pi^2)/6531840 - (14761*cR*Pi^2)/130636800 - 
           (2129*cA*lmmOS*Pi^2)/31352832 - (cR*lmmOS*Pi^2)/6048 - 
           (79*cA*lmmOS^2*Pi^2)/10450944 - (43*cA*lmuH*Pi^2)/5225472 - 
           (17*cA*lmmOS*lmuH*Pi^2)/870912 - (cA*lmuH^2*Pi^2)/290304 - 
           (863*cA*Pi^4)/209018880 + (cR*Pi^4)/120960 + (10553*cA*Zeta[3])/
            195955200 - (97*cR*Zeta[3])/302400 - (23*cA*lmmOS*Zeta[3])/
            186624 + (cR*lmmOS*Zeta[3])/2016 - (31*cA*lmuH*Zeta[3])/217728) + 
         ((386256346807*cA^3)/8193540096000 + (65166734119*cA^2*cR)/
            139345920000 + (55364417*cA*cR^2)/116121600 - 
           (1382677*cA^3*lmmOS)/365783040 + (492703*cA^2*cR*lmmOS)/9072000 - 
           (33889*cA^3*lmmOS^2)/8709120 + (277*cA^2*cR*lmmOS^2)/37800 - 
           (61*cA^3*lmmOS^3)/193536 - (cA^3*lmmOS^4)/193536 + 
           (201133*cA^3*lmuH)/60963840 + (370823*cA^2*cR*lmuH)/9072000 - 
           (21041*cA^3*lmmOS*lmuH)/2903040 + (277*cA^2*cR*lmmOS*lmuH)/18900 - 
           (13*cA^3*lmmOS^2*lmuH)/7168 - (cA^3*lmmOS^3*lmuH)/16128 - 
           (4307*cA^3*lmuH^2)/1935360 + (277*cA^2*cR*lmuH^2)/37800 - 
           (73*cA^3*lmmOS*lmuH^2)/21504 - (cA^3*lmmOS^2*lmuH^2)/3584 - 
           (131*cA^3*lmuH^3)/64512 - (cA^3*lmmOS*lmuH^3)/1792 - 
           (3*cA^3*lmuH^4)/7168 - (9563651*cA^2*nh)/260112384000 + 
           (85002469*cA*cR*nh)/5573836800 - (43*cA^2*lmmOS*nh)/268800 + 
           (cA*cR*lmmOS*nh)/960 + (43*cA^2*lmuH*nh)/268800 - 
           (cA*cR*lmuH*nh)/960 + (1/24192 + lmmOS/36288)*nl^3 - 
           (92497*cA^3*Pi^2)/104509440 + (1177*cA^2*cR*Pi^2)/907200 - 
           (5*cA*cR^2*Pi^2)/1344 - (59*cA^3*lmmOS*Pi^2)/435456 - 
           (cA^3*lmmOS^2*Pi^2)/193536 - (59*cA^3*lmuH*Pi^2)/145152 - 
           (cA^3*lmmOS*lmuH*Pi^2)/32256 - (cA^3*lmuH^2*Pi^2)/21504 - 
           (cA*cR*nh*Pi^2)/1008 + (11*cA^3*Pi^4)/1741824 + 
           nl^2*((-191*cA)/544320 + (10439*cR)/10886400 - (1763*cA*lmmOS)/
              2612736 - (85*cA*lmmOS^2)/870912 - (7*cA*lmuH)/62208 - 
             (11*cA*lmmOS*lmuH)/72576 - (cA*lmuH^2)/24192 - 
             (79*cA*Pi^2)/5225472) - (cA^2*cR*Pi^2*Log[2])/336 + 
           (cA*cR^2*Pi^2*Log[2])/168 - (41348917*cA^3*Zeta[3])/1486356480 - 
           (3769709*cA^2*cR*Zeta[3])/11796480 - (317921*cA*cR^2*Zeta[3])/
            737280 + (5*cA^3*lmmOS*Zeta[3])/6912 + (5*cA^3*lmuH*Zeta[3])/
            2304 + (791*cA^2*nh*Zeta[3])/3145728 - (20083*cA*cR*nh*Zeta[3])/
            2359296 + nl*((-20513*cA^2)/18662400 - (4981601*cA*cR)/
              254016000 + (7253*cA^2*lmmOS)/1866240 - (1873*cA*cR*lmmOS)/
              290304 + (2185*cA^2*lmmOS^2)/1741824 + (5*cA^2*lmmOS^3)/96768 + 
             (221*cA^2*lmuH)/1088640 - (9629*cA*cR*lmuH)/2419200 + 
             (91*cA^2*lmmOS*lmuH)/41472 + (cA^2*lmmOS^2*lmuH)/3584 + 
             (19*cA^2*lmuH^2)/27648 + (5*cA^2*lmmOS*lmuH^2)/10752 + 
             (cA^2*lmuH^3)/4608 + (205*cA^2*Pi^2)/870912 + (cA*cR*Pi^2)/
              2016 + (19*cA^2*lmmOS*Pi^2)/870912 + (19*cA^2*lmuH*Pi^2)/
              290304 + (19*cA^2*Zeta[3])/145152 - (5*cA*cR*Zeta[3])/3024))/
          ep^2 + (1139225702687*cA^3*Zeta[5])/141699317760 - 
         (4834660921697*cA^2*cR*Zeta[5])/118082764800 + 
         (103397519387*cA*cR^2*Zeta[5])/7380172800 + (16570237*cR^3*Zeta[5])/
          1372800 - (437*cA^3*lmmOS*Zeta[5])/80640 - (437*cA^3*lmuH*Zeta[5])/
          26880 - (17515*cA^2*nh*Zeta[5])/2097152 + 
         (1239877*cA*cR*nh*Zeta[5])/4718592 + (185105929*d44[pR1, pA1]*
           Zeta[5])/(3603600*NA) + ((8287965781548709*cA^3)/
            41295442083840000 + (21956200083401*cA^2*cR)/8670412800000 + 
           (655266377693*cA*cR^2)/167215104000 + (1180231426021*cA^3*lmmOS)/
            8193540096000 + (171519926453*cA^2*cR*lmmOS)/139345920000 + 
           (55364417*cA*cR^2*lmmOS)/38707200 + (1462583*cA^3*lmmOS^2)/
            731566080 + (44269*cA^2*cR*lmmOS^2)/1296000 - 
           (33673*cA^3*lmmOS^3)/26127360 + (277*cA^2*cR*lmmOS^3)/56700 - 
           (61*cA^3*lmmOS^4)/774144 - (cA^3*lmmOS^5)/967680 + 
           (91039996669*cA^3*lmuH)/2731180032000 + (62968094183*cA^2*cR*lmuH)/
            139345920000 + (55364417*cA*cR^2*lmuH)/116121600 + 
           (430147*cA^3*lmmOS*lmuH)/60963840 + (44269*cA^2*cR*lmmOS*lmuH)/
            648000 - (20897*cA^3*lmmOS^2*lmuH)/5806080 + 
           (277*cA^2*cR*lmmOS^2*lmuH)/18900 - (13*cA^3*lmmOS^3*lmuH)/21504 - 
           (cA^3*lmmOS^4*lmuH)/64512 + (66547*cA^3*lmuH^2)/10160640 + 
           (82981*cA^2*cR*lmuH^2)/3024000 - (4259*cA^3*lmmOS*lmuH^2)/
            1935360 + (277*cA^2*cR*lmmOS*lmuH^2)/18900 - 
           (73*cA^3*lmmOS^2*lmuH^2)/43008 - (cA^3*lmmOS^3*lmuH^2)/10752 + 
           (2057*cA^3*lmuH^3)/1935360 + (277*cA^2*cR*lmuH^3)/56700 - 
           (131*cA^3*lmmOS*lmuH^3)/64512 - (cA^3*lmmOS^2*lmuH^3)/3584 - 
           (31*cA^3*lmuH^4)/36864 - (3*cA^3*lmmOS*lmuH^4)/7168 - 
           (9*cA^3*lmuH^5)/35840 - (74810945911*cA^2*nh)/27311800320000 + 
           (83228353543*cA*cR*nh)/668860416000 - (91870211*cA^2*lmmOS*nh)/
            86704128000 + (96184549*cA*cR*lmmOS*nh)/1857945600 - 
           (43*cA^2*lmmOS^2*nh)/107520 + (cA*cR*lmmOS^2*nh)/384 + 
           (237356029*cA^2*lmuH*nh)/260112384000 + (51456229*cA*cR*lmuH*nh)/
            5573836800 + (43*cA^2*lmmOS*lmuH*nh)/268800 - 
           (cA*cR*lmmOS*lmuH*nh)/960 + (43*cA^2*lmuH^2*nh)/179200 - 
           (cA*cR*lmuH^2*nh)/640 - (268813*cA^3*Pi^2)/162570240 + 
           (2529523*cA^2*cR*Pi^2)/217728000 - (5*cA*cR^2*Pi^2)/144 - 
           (92389*cA^3*lmmOS*Pi^2)/104509440 + (1627*cA^2*cR*lmmOS*Pi^2)/
            453600 - (5*cA*cR^2*lmmOS*Pi^2)/448 - (59*cA^3*lmmOS^2*Pi^2)/
            870912 - (cA^3*lmmOS^3*Pi^2)/580608 - (16327*cA^3*lmuH*Pi^2)/
            8709120 + (727*cA^2*cR*lmuH*Pi^2)/453600 - (5*cA*cR^2*lmuH*Pi^2)/
            1344 - (59*cA^3*lmmOS*lmuH*Pi^2)/145152 - 
           (cA^3*lmmOS^2*lmuH*Pi^2)/64512 - (59*cA^3*lmuH^2*Pi^2)/96768 - 
           (cA^3*lmmOS*lmuH^2*Pi^2)/21504 - (cA^3*lmuH^3*Pi^2)/21504 - 
           (43*cA^2*nh*Pi^2)/1612800 - (1039*cA*cR*nh*Pi^2)/120960 - 
           (cA*cR*lmmOS*nh*Pi^2)/336 - (cA*cR*lmuH*nh*Pi^2)/1008 + 
           (271655353*cA^3*Pi^4)/133772083200 + (12574399*cA^2*cR*Pi^4)/
            825753600 + (3524849*cA*cR^2*Pi^4)/154828800 + 
           (11*cA^3*lmmOS*Pi^4)/1741824 + (11*cA^3*lmuH*Pi^4)/580608 - 
           (1921*cA^2*nh*Pi^4)/94371840 + (48773*cA*cR*nh*Pi^4)/70778880 + 
           nl^3*(1/72576 + lmmOS/24192 + lmmOS^2/72576 + Pi^2/435456) - 
           (59*cA^2*cR*Pi^2*Log[2])/2016 + (59*cA*cR^2*Pi^2*Log[2])/1008 - 
           (cA^2*cR*lmmOS*Pi^2*Log[2])/112 + (cA*cR^2*lmmOS*Pi^2*Log[2])/56 - 
           (cA^2*cR*lmuH*Pi^2*Log[2])/336 + (cA*cR^2*lmuH*Pi^2*Log[2])/168 + 
           (cA*cR*nh*Pi^2*Log[2])/168 + (8029*cA^3*Pi^2*Log[2]^2)/11796480 + 
           (18115*cA^2*cR*Pi^2*Log[2]^2)/2752512 - 
           (40991*cA*cR^2*Pi^2*Log[2]^2)/2580480 - 
           (113*cA^2*nh*Pi^2*Log[2]^2)/1572864 + (2869*cA*cR*nh*Pi^2*
             Log[2]^2)/1179648 - (8029*cA^3*Log[2]^4)/11796480 + 
           (923*cA^2*cR*Log[2]^4)/393216 - (727*cA*cR^2*Log[2]^4)/368640 + 
           (113*cA^2*nh*Log[2]^4)/1572864 - (2869*cA*cR*nh*Log[2]^4)/
            1179648 - (8029*cA^3*PolyLog[4, 1/2])/491520 + 
           (923*cA^2*cR*PolyLog[4, 1/2])/16384 - 
           (727*cA*cR^2*PolyLog[4, 1/2])/15360 + 
           (113*cA^2*nh*PolyLog[4, 1/2])/65536 - 
           (2869*cA*cR*nh*PolyLog[4, 1/2])/49152 - 
           (356207694841*cA^3*Zeta[3])/1070176665600 - 
           (201212019907*cA^2*cR*Zeta[3])/59454259200 - 
           (1445407049*cA*cR^2*Zeta[3])/275251200 - 
           (152165791*cA^3*lmmOS*Zeta[3])/1486356480 - 
           (3769709*cA^2*cR*lmmOS*Zeta[3])/3932160 - 
           (317921*cA*cR^2*lmmOS*Zeta[3])/245760 + (5*cA^3*lmmOS^2*Zeta[3])/
            13824 - (1281697*cA^3*lmuH*Zeta[3])/70778880 - 
           (3769709*cA^2*cR*lmuH*Zeta[3])/11796480 - 
           (317921*cA*cR^2*lmuH*Zeta[3])/737280 + (5*cA^3*lmmOS*lmuH*Zeta[3])/
            2304 + (5*cA^3*lmuH^2*Zeta[3])/1536 + (123361*cA^2*nh*Zeta[3])/
            23592960 - (33823433*cA*cR*nh*Zeta[3])/283115520 + 
           (791*cA^2*lmmOS*nh*Zeta[3])/1048576 - (20083*cA*cR*lmmOS*nh*
             Zeta[3])/786432 + (791*cA^2*lmuH*nh*Zeta[3])/3145728 - 
           (20083*cA*cR*lmuH*nh*Zeta[3])/2359296 - (25*cA^3*Pi^2*Zeta[3])/
            290304 + nl^2*((2502481*cA)/8230118400 + (33281*cR)/16934400 - 
             (611*cA*lmmOS)/2177280 + (20833*cR*lmmOS)/21772800 - 
             (1763*cA*lmmOS^2)/5225472 - (85*cA*lmmOS^3)/2612736 + 
             (89*cA*lmuH)/725760 + (cR*lmuH)/483840 - (7*cA*lmmOS*lmuH)/
              62208 - (11*cA*lmmOS^2*lmuH)/145152 + (cA*lmuH^2)/145152 - 
             (cA*lmmOS*lmuH^2)/24192 - (2129*cA*Pi^2)/31352832 - 
             (cR*Pi^2)/6048 - (79*cA*lmmOS*Pi^2)/5225472 - (17*cA*lmuH*Pi^2)/
              870912 - (23*cA*Zeta[3])/186624 + (cR*Zeta[3])/2016) + 
           nl*((-1077491291557*cA^2)/73741860864000 - (175601138953*cA*cR)/
              1365590016000 - (54737009*cR^2)/348364800 - 
             (1538203*cA^2*lmmOS)/457228800 - (68972647*cA*cR*lmmOS)/
              3048192000 + (42563*cA^2*lmmOS^2)/26127360 - 
             (18913*cA*cR*lmmOS^2)/7257600 + (2185*cA^2*lmmOS^3)/5225472 + 
             (5*cA^2*lmmOS^4)/387072 - (105731*cA^2*lmuH)/76204800 - 
             (14393333*cA*cR*lmuH)/3048192000 - (13*cA^2*lmmOS*lmuH)/
              1088640 - (18853*cA*cR*lmmOS*lmuH)/3628800 + 
             (91*cA^2*lmmOS^2*lmuH)/82944 + (cA^2*lmmOS^3*lmuH)/10752 - 
             (197*cA^2*lmuH^2)/207360 - (9629*cA*cR*lmuH^2)/7257600 + 
             (19*cA^2*lmmOS*lmuH^2)/27648 + (5*cA^2*lmmOS^2*lmuH^2)/21504 - 
             (cA^2*lmuH^3)/7168 + (cA^2*lmmOS*lmuH^3)/4608 + 
             (5*cA^2*lmuH^4)/129024 + (9563651*cA*nh)/780337152000 - 
             (85002469*cR*nh)/16721510400 + (43*cA*lmmOS*nh)/806400 - 
             (cR*lmmOS*nh)/2880 - (43*cA*lmuH*nh)/806400 + (cR*lmuH*nh)/
              2880 + (98821*cA^2*Pi^2)/156764160 + (123467*cA*cR*Pi^2)/
              43545600 + (5*cR^2*Pi^2)/4032 + (205*cA^2*lmmOS*Pi^2)/870912 + 
             (cA*cR*lmmOS*Pi^2)/672 + (19*cA^2*lmmOS^2*Pi^2)/1741824 + 
             (35*cA^2*lmuH*Pi^2)/82944 + (cA*cR*lmuH*Pi^2)/2016 + 
             (19*cA^2*lmmOS*lmuH*Pi^2)/290304 + (19*cA^2*lmuH^2*Pi^2)/
              193536 + (cR*nh*Pi^2)/3024 + (1579*cA^2*Pi^4)/104509440 - 
             (11*cA*cR*Pi^4)/362880 + (cA*cR*Pi^2*Log[2])/1008 - 
             (cR^2*Pi^2*Log[2])/504 + (205848991*cA^2*Zeta[3])/13377208320 + 
             (70664689*cA*cR*Zeta[3])/743178240 + (317921*cR^2*Zeta[3])/
              2211840 + (19*cA^2*lmmOS*Zeta[3])/145152 - 
             (5*cA*cR*lmmOS*Zeta[3])/3024 + (25*cA^2*lmuH*Zeta[3])/12096 - 
             (5*cA*cR*lmuH*Zeta[3])/1008 - (791*cA*nh*Zeta[3])/9437184 + 
             (20083*cR*nh*Zeta[3])/7077888) - (437*cA^3*Zeta[5])/80640)/ep + 
         nl*((6515032025335669*cA^2)/123886326251520000 + 
           (6018411381249619*cA*cR)/34412868403200000 + (2231603511343*cR^2)/
            8193540096000 - (999975940069*cA^2*lmmOS)/73741860864000 - 
           (1584736842247*cA*cR*lmmOS)/20483850240000 - (19192919*cR^2*lmmOS)/
            121927680 - (1610327*cA^2*lmmOS^2)/457228800 - 
           (92029481*cA*cR*lmmOS^2)/12192768000 - (193*cR^2*lmmOS^2)/774144 + 
           (18533*cA^2*lmmOS^3)/78382080 + (3467*cA*cR*lmmOS^3)/1741824 + 
           (2185*cA^2*lmmOS^4)/20901888 + (cA^2*lmmOS^5)/387072 + 
           (199177907*cA^2*lmuH)/384072192000 + (37968877393*cA*cR*lmuH)/
            1280240640000 - (3768139*cR^2*lmuH)/2438553600 - 
           (142853*cA^2*lmmOS*lmuH)/76204800 - (7373281*cA*cR*lmmOS*lmuH)/
            2032128000 + (193*cR^2*lmmOS*lmuH)/387072 - 
           (277*cA^2*lmmOS^2*lmuH)/870912 - (19843*cA*cR*lmmOS^2*lmuH)/
            14515200 + (91*cA^2*lmmOS^3*lmuH)/248832 + (cA^2*lmmOS^4*lmuH)/
            43008 + (52781*cA^2*lmuH^2)/101606400 + (8064619*cA*cR*lmuH^2)/
            2438553600 - (193*cR^2*lmuH^2)/774144 - (383*cA^2*lmmOS*lmuH^2)/
            362880 - (19213*cA*cR*lmmOS*lmuH^2)/14515200 + 
           (19*cA^2*lmmOS^2*lmuH^2)/55296 + (5*cA^2*lmmOS^3*lmuH^2)/64512 - 
           (3*cA^2*lmuH^3)/4480 + (17*cA*cR*lmuH^3)/967680 - 
           (cA^2*lmmOS*lmuH^3)/7168 + (cA^2*lmmOS^2*lmuH^3)/9216 - 
           (25*cA^2*lmuH^4)/86016 + (5*cA^2*lmmOS*lmuH^4)/129024 - 
           (17*cA^2*lmuH^5)/645120 - (75910418473*cA*nh)/40967700480000 - 
           (71155065113*cR*nh)/4682022912000 + (53499011*cA*lmmOS*nh)/
            780337152000 - (63531493*cR*lmmOS*nh)/16721510400 + 
           (43*cA*lmmOS^2*nh)/537600 - (cR*lmmOS^2*nh)/1920 - 
           (467*cA*lmuH*nh)/8294400 - (9319*cR*lmuH*nh)/7257600 - 
           (43*cA*lmmOS*lmuH*nh)/403200 + (cR*lmmOS*lmuH*nh)/1440 + 
           (43*cA*lmuH^2*nh)/1612800 - (cR*lmuH^2*nh)/5760 + 
           (1431041*cA^2*Pi^2)/4115059200 + (7609849*cA*cR*Pi^2)/1463132160 - 
           (369*cR^2*Pi^2)/102400 + (93313*cA^2*lmmOS*Pi^2)/156764160 + 
           (45139*cA*cR*lmmOS*Pi^2)/5443200 + (5*cR^2*lmmOS*Pi^2)/4032 + 
           (205*cA^2*lmmOS^2*Pi^2)/1741824 + (cA*cR*lmmOS^2*Pi^2)/448 + 
           (19*cA^2*lmmOS^3*Pi^2)/5225472 + (1837*cA^2*lmuH*Pi^2)/5225472 + 
           (997*cA*cR*lmuH*Pi^2)/518400 + (35*cA^2*lmmOS*lmuH*Pi^2)/82944 + 
           (cA*cR*lmmOS*lmuH*Pi^2)/672 + (19*cA^2*lmmOS^2*lmuH*Pi^2)/580608 + 
           (5*cA^2*lmuH^2*Pi^2)/14336 + (cA*cR*lmuH^2*Pi^2)/4032 + 
           (19*cA^2*lmmOS*lmuH^2*Pi^2)/193536 + (19*cA^2*lmuH^3*Pi^2)/
            193536 + (43*cA*nh*Pi^2)/4838400 + (559*cR*nh*Pi^2)/362880 + 
           (cR*lmmOS*nh*Pi^2)/3024 - (163199471*cA^2*Pi^4)/1003290624000 + 
           (10336817*cA*cR*Pi^4)/3715891200 + (233897*cR^2*Pi^4)/99532800 + 
           (1579*cA^2*lmmOS*Pi^4)/104509440 - (11*cA*cR*lmmOS*Pi^4)/362880 + 
           (293*cA^2*lmuH*Pi^4)/4354560 - (11*cA*cR*lmuH*Pi^4)/120960 + 
           (113*cA*nh*Pi^4)/424673280 - (2869*cR*nh*Pi^4)/318504960 + 
           (9222149*d44[pR1, pR2])/(13996800*NA) - (3137*Pi^4*d44[pR1, pR2])/
            (162000*NA) + (cA*cR*Pi^2*Log[2])/1512 - (cR^2*Pi^2*Log[2])/756 + 
           (cA*cR*lmmOS*Pi^2*Log[2])/1008 - (cR^2*lmmOS*Pi^2*Log[2])/504 - 
           (cR*nh*Pi^2*Log[2])/504 - (8029*cA^2*Pi^2*Log[2]^2)/106168320 - 
           (18115*cA*cR*Pi^2*Log[2]^2)/24772608 + (40991*cR^2*Pi^2*Log[2]^2)/
            23224320 + (113*cA*nh*Pi^2*Log[2]^2)/14155776 - 
           (2869*cR*nh*Pi^2*Log[2]^2)/10616832 + (8029*cA^2*Log[2]^4)/
            106168320 - (923*cA*cR*Log[2]^4)/3538944 + (727*cR^2*Log[2]^4)/
            3317760 - (113*cA*nh*Log[2]^4)/14155776 + (2869*cR*nh*Log[2]^4)/
            10616832 + (8029*cA^2*PolyLog[4, 1/2])/4423680 - 
           (923*cA*cR*PolyLog[4, 1/2])/147456 + (727*cR^2*PolyLog[4, 1/2])/
            138240 - (113*cA*nh*PolyLog[4, 1/2])/589824 + 
           (2869*cR*nh*PolyLog[4, 1/2])/442368 - (4779435509*cA^2*Zeta[3])/
            642105999360 - (16940334161*cA*cR*Zeta[3])/59454259200 - 
           (2761040113*cR^2*Zeta[3])/7431782400 + (205848991*cA^2*lmmOS*
             Zeta[3])/13377208320 + (70664689*cA*cR*lmmOS*Zeta[3])/
            743178240 + (317921*cR^2*lmmOS*Zeta[3])/2211840 + 
           (19*cA^2*lmmOS^2*Zeta[3])/290304 - (5*cA*cR*lmmOS^2*Zeta[3])/
            6048 + (3719*cA^2*lmuH*Zeta[3])/217728 - (79*cA*cR*lmuH*Zeta[3])/
            3024 + (25*cA^2*lmmOS*lmuH*Zeta[3])/12096 - 
           (5*cA*cR*lmmOS*lmuH*Zeta[3])/1008 + (11*cA^2*lmuH^2*Zeta[3])/
            2304 - (5*cA*cR*lmuH^2*Zeta[3])/672 + (21875*cA*nh*Zeta[3])/
            28311552 + (2258417*cR*nh*Zeta[3])/283115520 - 
           (791*cA*lmmOS*nh*Zeta[3])/9437184 + (20083*cR*lmmOS*nh*Zeta[3])/
            7077888 - (2645*cA^2*Pi^2*Zeta[3])/5225472 + 
           (11*cA*cR*Pi^2*Zeta[3])/18144 + (2129*d44[pR1, pR2]*Zeta[3])/
            (2160*NA) + (2243*cA^2*Zeta[5])/241920 + (cA*cR*Zeta[5])/3024 - 
           (5*cR^2*Zeta[5])/336))) + api5*((5*cA)/4 - (3*cR)/4 - 
       cA/(2*ep^2) - (11*cA*lmmOS)/12 - (cA*lmmOS^2)/4 - (cA*lmmOS*lmuH)/2 - 
       (cA*lmuH^2)/4 + ((-11*cA)/12 - (cA*lmmOS)/2 - (cA*lmuH)/2 + nl/6)/ep + 
       (lmmOS*nl)/6 + ep*((-11*cA)/6 + (29*cR)/8 + (5*cA*lmmOS)/2 - 
         (3*cR*lmmOS)/2 - (11*cA*lmmOS^2)/24 - (cA*lmmOS^3)/12 - 
         (cA*lmmOS^2*lmuH)/4 - (cA*lmmOS*lmuH^2)/4 - (cA*lmuH^3)/12 - 
         (11*cA*Pi^2)/144 + nl*(lmmOS^2/12 + Pi^2/72) + (4*cA*Zeta[3])/3) + 
       ep^2*((8*cA)/9 + (29*cR)/16 - (19*cA*lmmOS)/6 + (29*cR*lmmOS)/4 + 
         (5*cA*lmmOS^2)/2 - (3*cR*lmmOS^2)/2 - (11*cA*lmmOS^3)/72 - 
         (cA*lmmOS^4)/48 - (cA*lmuH)/2 - (cA*lmmOS^3*lmuH)/12 - 
         (cA*lmmOS^2*lmuH^2)/8 - (cA*lmmOS*lmuH^3)/12 - (cA*lmuH^4)/48 + 
         (5*cA*Pi^2)/24 - (cR*Pi^2)/8 - (11*cA*lmmOS*Pi^2)/144 + 
         (cA*Pi^4)/60 + nl*(lmmOS^3/36 + (lmmOS*Pi^2)/72 - Zeta[3]/18) + 
         (11*cA*Zeta[3])/36 + (4*cA*lmmOS*Zeta[3])/3 + (4*cA*lmuH*Zeta[3])/
          3) + ep^3*((-901*cA)/108 + (413*cR)/32 + (59*cA*lmmOS)/18 + 
         (29*cR*lmmOS)/8 - (35*cA*lmmOS^2)/12 + (29*cR*lmmOS^2)/4 + 
         (5*cA*lmmOS^3)/3 - cR*lmmOS^3 - (11*cA*lmmOS^4)/288 - 
         (cA*lmmOS^5)/240 - (3*cA*lmuH)/2 - (cA*lmmOS*lmuH)/2 - 
         (cA*lmmOS^4*lmuH)/48 - (cA*lmuH^2)/4 - (cA*lmmOS^3*lmuH^2)/24 - 
         (cA*lmmOS^2*lmuH^3)/24 - (cA*lmmOS*lmuH^4)/48 - (cA*lmuH^5)/240 - 
         (2*cA*Pi^2)/9 + (29*cR*Pi^2)/48 + (5*cA*lmmOS*Pi^2)/12 - 
         (cR*lmmOS*Pi^2)/4 - (11*cA*lmmOS^2*Pi^2)/288 - (11*cA*Pi^4)/1920 + 
         (cA*lmmOS*Pi^4)/60 + (cA*lmuH*Pi^4)/60 - (5*cA*Zeta[3])/6 + 
         (cR*Zeta[3])/2 + (11*cA*lmmOS*Zeta[3])/36 + (2*cA*lmmOS^2*Zeta[3])/
          3 + (4*cA*lmmOS*lmuH*Zeta[3])/3 + (2*cA*lmuH^2*Zeta[3])/3 + 
         nl*(lmmOS^4/144 + (lmmOS^2*Pi^2)/144 + Pi^4/960 - 
           (lmmOS*Zeta[3])/18) + (16*cA*Zeta[5])/5) + 
       ep^4*((1363*cA)/648 + (413*cR)/64 - (356*cA*lmmOS)/27 + 
         (413*cR*lmmOS)/16 + (145*cA*lmmOS^2)/36 + (29*cR*lmmOS^2)/8 - 
         (67*cA*lmmOS^3)/36 + (29*cR*lmmOS^3)/6 + (5*cA*lmmOS^4)/6 - 
         (cR*lmmOS^4)/2 - (11*cA*lmmOS^5)/1440 - (cA*lmmOS^6)/1440 - 
         (7*cA*lmuH)/2 - (3*cA*lmmOS*lmuH)/2 - (cA*lmmOS^2*lmuH)/4 - 
         (cA*lmmOS^5*lmuH)/240 - (3*cA*lmuH^2)/4 - (cA*lmmOS*lmuH^2)/4 - 
         (cA*lmmOS^4*lmuH^2)/96 - (cA*lmuH^3)/12 - (cA*lmmOS^3*lmuH^3)/72 - 
         (cA*lmmOS^2*lmuH^4)/96 - (cA*lmmOS*lmuH^5)/240 - (cA*lmuH^6)/1440 + 
         (43*cA*Pi^2)/108 + (29*cR*Pi^2)/96 - (4*cA*lmmOS*Pi^2)/9 + 
         (29*cR*lmmOS*Pi^2)/24 + (5*cA*lmmOS^2*Pi^2)/12 - 
         (cR*lmmOS^2*Pi^2)/4 - (11*cA*lmmOS^3*Pi^2)/864 + (7*cA*Pi^4)/288 - 
         (7*cR*Pi^4)/480 - (11*cA*lmmOS*Pi^4)/1920 + (cA*lmmOS^2*Pi^4)/120 + 
         (cA*lmmOS*lmuH*Pi^4)/60 + (cA*lmuH^2*Pi^4)/120 + (cA*Pi^6)/189 + 
         (20*cA*Zeta[3])/9 - (29*cR*Zeta[3])/12 - (5*cA*lmmOS*Zeta[3])/3 + 
         cR*lmmOS*Zeta[3] + (11*cA*lmmOS^2*Zeta[3])/72 + 
         (2*cA*lmmOS^3*Zeta[3])/9 + (2*cA*lmmOS^2*lmuH*Zeta[3])/3 + 
         (2*cA*lmmOS*lmuH^2*Zeta[3])/3 + (2*cA*lmuH^3*Zeta[3])/9 + 
         (11*cA*Pi^2*Zeta[3])/432 - (16*cA*Zeta[3]^2)/9 + 
         nl*(lmmOS^5/720 + (lmmOS^3*Pi^2)/432 + (lmmOS*Pi^4)/960 - 
           (lmmOS^2*Zeta[3])/36 - (Pi^2*Zeta[3])/216 - Zeta[5]/30) + 
         (11*cA*Zeta[5])/60 + (16*cA*lmmOS*Zeta[5])/5 + (16*cA*lmuH*Zeta[5])/
          5) + rhoOS^2*((-193*cA)/20160 + (277*cR)/9450 - cA/(336*ep^2) - 
         (5*cA*lmmOS)/504 - (cA*lmmOS^2)/672 - (cA*lmuH)/224 - 
         (cA*lmmOS*lmuH)/336 - (cA*lmuH^2)/672 + 
         ((-5*cA)/504 - (cA*lmmOS)/336 - (cA*lmuH)/336 + nl/1008)/ep + 
         (1/672 + lmmOS/1008)*nl + ep*((29*cA)/26460 + (188003*cR)/2268000 - 
           (191*cA*lmmOS)/20160 + (277*cR*lmmOS)/4725 - (5*cA*lmmOS^2)/1008 - 
           (cA*lmmOS^3)/2016 - (cA*lmuH)/672 - (cA*lmmOS*lmuH)/224 - 
           (cA*lmmOS^2*lmuH)/672 - (cA*lmuH^2)/448 - (cA*lmmOS*lmuH^2)/672 - 
           (cA*lmuH^3)/2016 - (11*cA*Pi^2)/24192 + 
           nl*(1/2016 + lmmOS/672 + lmmOS^2/2016 + Pi^2/12096) + 
           (cA*Zeta[3])/126) + ep^2*((-183263*cA)/17781120 + 
           (54800981*cR)/272160000 + (3343*cA*lmmOS)/423360 + 
           (188003*cR*lmmOS)/1134000 - (187*cA*lmmOS^2)/40320 + 
           (277*cR*lmmOS^2)/4725 - (5*cA*lmmOS^3)/3024 - (cA*lmmOS^4)/8064 - 
           (cA*lmuH)/336 - (cA*lmmOS*lmuH)/672 - (cA*lmmOS^2*lmuH)/448 - 
           (cA*lmmOS^3*lmuH)/2016 - (cA*lmuH^2)/1344 - (cA*lmmOS*lmuH^2)/
            448 - (cA*lmmOS^2*lmuH^2)/1344 - (cA*lmuH^3)/1344 - 
           (cA*lmmOS*lmuH^3)/2016 - (cA*lmuH^4)/8064 - (23*cA*Pi^2)/34560 + 
           (277*cR*Pi^2)/56700 - (11*cA*lmmOS*Pi^2)/24192 + (cA*Pi^4)/10080 + 
           nl*(lmmOS/2016 + lmmOS^2/1344 + lmmOS^3/6048 + Pi^2/8064 + 
             (lmmOS*Pi^2)/12096 - Zeta[3]/3024) + (83*cA*Zeta[3])/6048 + 
           (cA*lmmOS*Zeta[3])/126 + (cA*lmuH*Zeta[3])/126) + 
         ep^3*((-146341799*cA)/3734035200 + (7296127081*cR)/16329600000 - 
           (64193*cA*lmmOS)/8890560 + (54800981*cR*lmmOS)/136080000 + 
           (9101*cA*lmmOS^2)/846720 + (188003*cR*lmmOS^2)/1134000 - 
           (179*cA*lmmOS^3)/120960 + (554*cR*lmmOS^3)/14175 - 
           (5*cA*lmmOS^4)/12096 - (cA*lmmOS^5)/40320 - (3*cA*lmuH)/224 - 
           (cA*lmmOS*lmuH)/336 - (cA*lmmOS^2*lmuH)/1344 - (cA*lmmOS^3*lmuH)/
            1344 - (cA*lmmOS^4*lmuH)/8064 - (cA*lmuH^2)/672 - 
           (cA*lmmOS*lmuH^2)/1344 - (cA*lmmOS^2*lmuH^2)/896 - 
           (cA*lmmOS^3*lmuH^2)/4032 - (cA*lmuH^3)/4032 - (cA*lmmOS*lmuH^3)/
            1344 - (cA*lmmOS^2*lmuH^3)/4032 - (cA*lmuH^4)/5376 - 
           (cA*lmmOS*lmuH^4)/8064 - (cA*lmuH^5)/40320 + (4603*cA*Pi^2)/
            5080320 + (188003*cR*Pi^2)/13608000 - (157*cA*lmmOS*Pi^2)/
            241920 + (277*cR*lmmOS*Pi^2)/28350 - (11*cA*lmmOS^2*Pi^2)/48384 + 
           (37*cA*Pi^4)/322560 + (cA*lmmOS*Pi^4)/10080 + (cA*lmuH*Pi^4)/
            10080 + (401*cA*Zeta[3])/60480 - (277*cR*Zeta[3])/14175 + 
           (83*cA*lmmOS*Zeta[3])/6048 + (cA*lmmOS^2*Zeta[3])/252 + 
           (cA*lmuH*Zeta[3])/84 + (cA*lmmOS*lmuH*Zeta[3])/126 + 
           (cA*lmuH^2*Zeta[3])/252 + nl*(lmmOS^2/4032 + lmmOS^3/4032 + 
             lmmOS^4/24192 + Pi^2/24192 + (lmmOS*Pi^2)/8064 + 
             (lmmOS^2*Pi^2)/24192 + Pi^4/161280 - Zeta[3]/2016 - 
             (lmmOS*Zeta[3])/3024) + (2*cA*Zeta[5])/105) + 
         ep^4*((-64903349909*cA)/784147392000 + (875855521931*cR)/
            979776000000 - (79662599*cA*lmmOS)/1867017600 + 
           (7296127081*cR*lmmOS)/8164800000 - (2329*cA*lmmOS^2)/4445280 + 
           (54800981*cR*lmmOS^2)/136080000 + (20617*cA*lmmOS^3)/2540160 + 
           (188003*cR*lmmOS^3)/1701000 - (163*cA*lmmOS^4)/483840 + 
           (277*cR*lmmOS^4)/14175 - (cA*lmmOS^5)/12096 - 
           (cA*lmmOS^6)/241920 - (cA*lmuH)/28 - (3*cA*lmmOS*lmuH)/224 - 
           (cA*lmmOS^2*lmuH)/672 - (cA*lmmOS^3*lmuH)/4032 - 
           (cA*lmmOS^4*lmuH)/5376 - (cA*lmmOS^5*lmuH)/40320 - 
           (3*cA*lmuH^2)/448 - (cA*lmmOS*lmuH^2)/672 - (cA*lmmOS^2*lmuH^2)/
            2688 - (cA*lmmOS^3*lmuH^2)/2688 - (cA*lmmOS^4*lmuH^2)/16128 - 
           (cA*lmuH^3)/2016 - (cA*lmmOS*lmuH^3)/4032 - (cA*lmmOS^2*lmuH^3)/
            2688 - (cA*lmmOS^3*lmuH^3)/12096 - (cA*lmuH^4)/16128 - 
           (cA*lmmOS*lmuH^4)/5376 - (cA*lmmOS^2*lmuH^4)/16128 - 
           (cA*lmuH^5)/26880 - (cA*lmmOS*lmuH^5)/40320 - (cA*lmuH^6)/241920 + 
           (54877*cA*Pi^2)/106686720 + (54800981*cR*Pi^2)/1632960000 + 
           (10361*cA*lmmOS*Pi^2)/5080320 + (188003*cR*lmmOS*Pi^2)/6804000 - 
           (149*cA*lmmOS^2*Pi^2)/483840 + (277*cR*lmmOS^2*Pi^2)/28350 - 
           (11*cA*lmmOS^3*Pi^2)/145152 + (11*cA*Pi^4)/29030400 + 
           (277*cR*Pi^4)/486000 + (37*cA*lmmOS*Pi^4)/322560 + 
           (cA*lmmOS^2*Pi^4)/20160 + (cA*lmuH*Pi^4)/6720 + 
           (cA*lmmOS*lmuH*Pi^4)/10080 + (cA*lmuH^2*Pi^4)/20160 + 
           (cA*Pi^6)/31752 + (5477*cA*Zeta[3])/1270080 - (188003*cR*Zeta[3])/
            3402000 + (397*cA*lmmOS*Zeta[3])/60480 - (554*cR*lmmOS*Zeta[3])/
            14175 + (83*cA*lmmOS^2*Zeta[3])/12096 + (cA*lmmOS^3*Zeta[3])/
            756 + (cA*lmuH*Zeta[3])/252 + (cA*lmmOS*lmuH*Zeta[3])/84 + 
           (cA*lmmOS^2*lmuH*Zeta[3])/252 + (cA*lmuH^2*Zeta[3])/168 + 
           (cA*lmmOS*lmuH^2*Zeta[3])/252 + (cA*lmuH^3*Zeta[3])/756 + 
           (11*cA*Pi^2*Zeta[3])/72576 - (2*cA*Zeta[3]^2)/189 + 
           nl*(lmmOS^3/12096 + lmmOS^4/16128 + lmmOS^5/120960 + 
             (lmmOS*Pi^2)/24192 + (lmmOS^2*Pi^2)/16128 + (lmmOS^3*Pi^2)/
              72576 + Pi^4/107520 + (lmmOS*Pi^4)/161280 - Zeta[3]/6048 - 
             (lmmOS*Zeta[3])/2016 - (lmmOS^2*Zeta[3])/6048 - 
             (Pi^2*Zeta[3])/36288 - Zeta[5]/5040) + (299*cA*Zeta[5])/10080 + 
           (cR*Zeta[5])/140 + (2*cA*lmmOS*Zeta[5])/105 + (2*cA*lmuH*Zeta[5])/
            105)) + rhoOS*(-cA/30 + (61*cR)/360 - (7*cA)/(240*ep^2) - 
         (119*cA*lmmOS)/1440 - (7*cA*lmmOS^2)/480 - (7*cA*lmuH)/240 - 
         (7*cA*lmmOS*lmuH)/240 - (7*cA*lmuH^2)/480 + 
         ((-119*cA)/1440 - (7*cA*lmmOS)/240 - (7*cA*lmuH)/240 + (7*nl)/720)/
          ep + (7/720 + (7*lmmOS)/720)*nl + ep*((553*cA)/10800 + (27*cR)/80 - 
           (19*cA*lmmOS)/1440 + (61*cR*lmmOS)/180 - (119*cA*lmmOS^2)/2880 - 
           (7*cA*lmmOS^3)/1440 - (7*cA*lmmOS*lmuH)/240 - (7*cA*lmmOS^2*lmuH)/
            480 - (7*cA*lmuH^2)/480 - (7*cA*lmmOS*lmuH^2)/480 - 
           (7*cA*lmuH^3)/1440 - (77*cA*Pi^2)/17280 + 
           nl*((7*lmmOS)/720 + (7*lmmOS^2)/1440 + (7*Pi^2)/8640) + 
           (7*cA*Zeta[3])/90) + ep^2*((-31319*cA)/216000 + (6997*cR)/6480 + 
           (1421*cA*lmmOS)/10800 + (27*cR*lmmOS)/40 + (13*cA*lmmOS^2)/960 + 
           (61*cR*lmmOS^2)/180 - (119*cA*lmmOS^3)/8640 - (7*cA*lmmOS^4)/
            5760 - (7*cA*lmuH)/240 - (7*cA*lmmOS^2*lmuH)/480 - 
           (7*cA*lmmOS^3*lmuH)/1440 - (7*cA*lmmOS*lmuH^2)/480 - 
           (7*cA*lmmOS^2*lmuH^2)/960 - (7*cA*lmuH^3)/1440 - 
           (7*cA*lmmOS*lmuH^3)/1440 - (7*cA*lmuH^4)/5760 - 
           (19*cA*Pi^2)/17280 + (61*cR*Pi^2)/2160 - (77*cA*lmmOS*Pi^2)/
            17280 + (7*cA*Pi^4)/7200 + nl*((7*lmmOS^2)/1440 + 
             (7*lmmOS^3)/4320 + (7*Pi^2)/8640 + (7*lmmOS*Pi^2)/8640 - 
             (7*Zeta[3])/2160) + (413*cA*Zeta[3])/4320 + (7*cA*lmmOS*Zeta[3])/
            90 + (7*cA*lmuH*Zeta[3])/90) + ep^3*((-5622341*cA)/19440000 + 
           (82369*cR)/38880 - (18719*cA*lmmOS)/108000 + (6997*cR*lmmOS)/
            3240 + (3157*cA*lmmOS^2)/21600 + (27*cR*lmmOS^2)/40 + 
           (31*cA*lmmOS^3)/1728 + (61*cR*lmmOS^3)/270 - (119*cA*lmmOS^4)/
            34560 - (7*cA*lmmOS^5)/28800 - (7*cA*lmuH)/60 - 
           (7*cA*lmmOS*lmuH)/240 - (7*cA*lmmOS^3*lmuH)/1440 - 
           (7*cA*lmmOS^4*lmuH)/5760 - (7*cA*lmuH^2)/480 - 
           (7*cA*lmmOS^2*lmuH^2)/960 - (7*cA*lmmOS^3*lmuH^2)/2880 - 
           (7*cA*lmmOS*lmuH^3)/1440 - (7*cA*lmmOS^2*lmuH^3)/2880 - 
           (7*cA*lmuH^4)/5760 - (7*cA*lmmOS*lmuH^4)/5760 - 
           (7*cA*lmuH^5)/28800 + (217*cA*Pi^2)/16200 + (9*cR*Pi^2)/160 + 
           (13*cA*lmmOS*Pi^2)/5760 + (61*cR*lmmOS*Pi^2)/1080 - 
           (77*cA*lmmOS^2*Pi^2)/34560 + (49*cA*Pi^4)/76800 + 
           (7*cA*lmmOS*Pi^4)/7200 + (7*cA*lmuH*Pi^4)/7200 + 
           (19*cA*Zeta[3])/4320 - (61*cR*Zeta[3])/540 + 
           (413*cA*lmmOS*Zeta[3])/4320 + (7*cA*lmmOS^2*Zeta[3])/180 + 
           (7*cA*lmuH*Zeta[3])/90 + (7*cA*lmmOS*lmuH*Zeta[3])/90 + 
           (7*cA*lmuH^2*Zeta[3])/180 + nl*((7*lmmOS^3)/4320 + 
             (7*lmmOS^4)/17280 + (7*lmmOS*Pi^2)/8640 + (7*lmmOS^2*Pi^2)/
              17280 + (7*Pi^4)/115200 - (7*Zeta[3])/2160 - (7*lmmOS*Zeta[3])/
              2160) + (14*cA*Zeta[5])/75) + ep^4*((-384163783*cA)/583200000 + 
           (327301*cR)/77760 - (2787341*cA*lmmOS)/9720000 + 
           (82369*cR*lmmOS)/19440 - (12419*cA*lmmOS^2)/108000 + 
           (6997*cR*lmmOS^2)/3240 + (6629*cA*lmmOS^3)/64800 + 
           (9*cR*lmmOS^3)/20 + (43*cA*lmmOS^4)/3840 + (61*cR*lmmOS^4)/540 - 
           (119*cA*lmmOS^5)/172800 - (7*cA*lmmOS^6)/172800 - (7*cA*lmuH)/24 - 
           (7*cA*lmmOS*lmuH)/60 - (7*cA*lmmOS^2*lmuH)/480 - 
           (7*cA*lmmOS^4*lmuH)/5760 - (7*cA*lmmOS^5*lmuH)/28800 - 
           (7*cA*lmuH^2)/120 - (7*cA*lmmOS*lmuH^2)/480 - 
           (7*cA*lmmOS^3*lmuH^2)/2880 - (7*cA*lmmOS^4*lmuH^2)/11520 - 
           (7*cA*lmuH^3)/1440 - (7*cA*lmmOS^2*lmuH^3)/2880 - 
           (7*cA*lmmOS^3*lmuH^3)/8640 - (7*cA*lmmOS*lmuH^4)/5760 - 
           (7*cA*lmmOS^2*lmuH^4)/11520 - (7*cA*lmuH^5)/28800 - 
           (7*cA*lmmOS*lmuH^5)/28800 - (7*cA*lmuH^6)/172800 - 
           (6119*cA*Pi^2)/1296000 + (6997*cR*Pi^2)/38880 + 
           (217*cA*lmmOS*Pi^2)/8100 + (9*cR*lmmOS*Pi^2)/80 + 
           (31*cA*lmmOS^2*Pi^2)/6912 + (61*cR*lmmOS^2*Pi^2)/1080 - 
           (77*cA*lmmOS^3*Pi^2)/103680 + (119*cA*Pi^4)/2073600 + 
           (427*cR*Pi^4)/129600 + (49*cA*lmmOS*Pi^4)/76800 + 
           (7*cA*lmmOS^2*Pi^4)/14400 + (7*cA*lmuH*Pi^4)/7200 + 
           (7*cA*lmmOS*lmuH*Pi^4)/7200 + (7*cA*lmuH^2*Pi^4)/14400 + 
           (cA*Pi^6)/3240 + (49*cA*Zeta[3])/2025 - (9*cR*Zeta[3])/40 - 
           (13*cA*lmmOS*Zeta[3])/1440 - (61*cR*lmmOS*Zeta[3])/270 + 
           (413*cA*lmmOS^2*Zeta[3])/8640 + (7*cA*lmmOS^3*Zeta[3])/540 + 
           (7*cA*lmmOS*lmuH*Zeta[3])/90 + (7*cA*lmmOS^2*lmuH*Zeta[3])/180 + 
           (7*cA*lmuH^2*Zeta[3])/180 + (7*cA*lmmOS*lmuH^2*Zeta[3])/180 + 
           (7*cA*lmuH^3*Zeta[3])/540 + (77*cA*Pi^2*Zeta[3])/51840 - 
           (14*cA*Zeta[3]^2)/135 + nl*((7*lmmOS^4)/17280 + 
             (7*lmmOS^5)/86400 + (7*lmmOS^2*Pi^2)/17280 + (7*lmmOS^3*Pi^2)/
              51840 + (7*Pi^4)/115200 + (7*lmmOS*Pi^4)/115200 - 
             (7*lmmOS*Zeta[3])/2160 - (7*lmmOS^2*Zeta[3])/4320 - 
             (7*Pi^2*Zeta[3])/25920 - (7*Zeta[5])/3600) + (1421*cA*Zeta[5])/
            7200 + (7*cR*Zeta[5])/200 + (14*cA*lmmOS*Zeta[5])/75 + 
           (14*cA*lmuH*Zeta[5])/75))) + api5^2*((26185*cA^2)/5184 - 
       (101*cA*cR)/16 + (27*cR^2)/32 + cA^2/(8*ep^4) - (463*cA^2*lmmOS)/432 - 
       (47*cA*cR*lmmOS)/16 - (545*cA^2*lmmOS^2)/576 + (3*cA*cR*lmmOS^2)/4 + 
       (77*cA^2*lmmOS^3)/576 + (cA^2*lmmOS^4)/192 + (53*cA^2*lmuH)/54 - 
       (29*cA*cR*lmuH)/16 - (247*cA^2*lmmOS*lmuH)/144 + 
       (3*cA*cR*lmmOS*lmuH)/4 + (11*cA^2*lmmOS^2*lmuH)/32 + 
       (cA^2*lmmOS^3*lmuH)/24 - (7*cA^2*lmuH^2)/9 + (3*cA*cR*lmuH^2)/16 + 
       (11*cA^2*lmmOS*lmuH^2)/48 + (cA^2*lmmOS^2*lmuH^2)/8 + 
       (cA^2*lmmOS*lmuH^3)/6 + (cA^2*lmuH^4)/12 - (5*cA*nh)/192 - 
       (cR*nh)/24 + ((77*cA^2)/96 + (cA^2*lmmOS)/8 + (cA^2*lmuH)/4 - 
         (7*cA*nl)/48)/ep^3 + ((-5*cA^2)/288 + (3*cA*cR)/8 + 
         (77*cA^2*lmmOS)/96 + (cA^2*lmmOS^2)/16 + (11*cA^2*lmuH)/16 + 
         (cA^2*lmmOS*lmuH)/4 + (cA^2*lmuH^2)/4 + 
         ((-13*cA)/48 - (7*cA*lmmOS)/48 - (cA*lmuH)/8)*nl + nl^2/36)/ep^2 + 
       (397*cA^2*Pi^2)/3456 + (cA*cR*Pi^2)/32 + (55*cA^2*lmmOS*Pi^2)/1152 + 
       (55*cA^2*lmuH*Pi^2)/576 - (17*cA^2*Pi^4)/2304 + 
       nl^2*(lmmOS^2/72 + Pi^2/432) - (671*cA^2*Zeta[3])/288 - 
       (9*cA^2*lmmOS*Zeta[3])/16 - (9*cA^2*lmuH*Zeta[3])/8 + 
       ((-445*cA^2)/432 - (9*cA*cR)/8 - (185*cA^2*lmmOS)/288 + 
         (3*cA*cR*lmmOS)/4 + (77*cA^2*lmmOS^2)/192 + (cA^2*lmmOS^3)/48 - 
         (157*cA^2*lmuH)/144 + (3*cA*cR*lmuH)/8 + (11*cA^2*lmmOS*lmuH)/16 + 
         (cA^2*lmmOS^2*lmuH)/8 + (11*cA^2*lmuH^2)/48 + (cA^2*lmmOS*lmuH^2)/
          4 + (cA^2*lmuH^3)/6 + (lmmOS*nl^2)/36 + (55*cA^2*Pi^2)/1152 + 
         nl*((77*cA)/216 - cR/16 - (13*cA*lmmOS)/48 - (7*cA*lmmOS^2)/96 + 
           (5*cA*lmuH)/72 - (cA*lmmOS*lmuH)/8 - (cA*lmuH^2)/24 - 
           (5*cA*Pi^2)/576) - (9*cA^2*Zeta[3])/16)/ep + 
       nl*((-3047*cA)/2592 - cR/4 + (61*cA*lmmOS)/108 + (cR*lmmOS)/16 - 
         (13*cA*lmmOS^2)/96 - (7*cA*lmmOS^3)/288 - (13*cA*lmuH)/108 - 
         (cR*lmuH)/8 + (5*cA*lmmOS*lmuH)/72 - (cA*lmmOS^2*lmuH)/16 + 
         (5*cA*lmuH^2)/72 - (cA*lmmOS*lmuH^2)/24 - (23*cA*Pi^2)/576 - 
         (5*cA*lmmOS*Pi^2)/576 - (5*cA*lmuH*Pi^2)/288 - (11*cA*Zeta[3])/144 + 
         (cR*Zeta[3])/2) + ep*((541139*cA^2)/62208 - (7337*cA*cR)/1152 - 
         (289*cR^2)/64 + (39127*cA^2*lmmOS)/5184 - (1093*cA*cR*lmmOS)/96 + 
         (81*cR^2*lmmOS)/32 + (185*cA^2*lmmOS^2)/864 - (127*cA*cR*lmmOS^2)/
          32 - (1265*cA^2*lmmOS^3)/1728 + (cA*cR*lmmOS^3)/2 + 
         (77*cA^2*lmmOS^4)/2304 + (cA^2*lmmOS^5)/960 + (5501*cA^2*lmuH)/
          1296 - (29*cA*cR*lmuH)/32 + (89*cA^2*lmmOS*lmuH)/54 - 
         (29*cA*cR*lmmOS*lmuH)/8 - (427*cA^2*lmmOS^2*lmuH)/288 + 
         (3*cA*cR*lmmOS^2*lmuH)/4 + (11*cA^2*lmmOS^3*lmuH)/96 + 
         (cA^2*lmmOS^4*lmuH)/96 + (35*cA^2*lmuH^2)/54 - 
         (29*cA*cR*lmuH^2)/32 - (157*cA^2*lmmOS*lmuH^2)/144 + 
         (3*cA*cR*lmmOS*lmuH^2)/8 + (11*cA^2*lmmOS^2*lmuH^2)/96 + 
         (cA^2*lmmOS^3*lmuH^2)/24 - (179*cA^2*lmuH^3)/432 + 
         (cA*cR*lmuH^3)/16 + (cA^2*lmmOS^2*lmuH^3)/12 - 
         (11*cA^2*lmuH^4)/288 + (cA^2*lmmOS*lmuH^4)/12 + (cA^2*lmuH^5)/30 - 
         (1423*cA*nh)/3456 - (959*cR*nh)/576 - (5*cA*lmmOS*nh)/64 - 
         (cR*lmmOS*nh)/8 - (115*cA^2*Pi^2)/5184 - (25*cA*cR*Pi^2)/96 + 
         (5*cR^2*Pi^2)/8 + (217*cA^2*lmmOS*Pi^2)/3456 + (cA*cR*lmmOS*Pi^2)/
          16 + (55*cA^2*lmmOS^2*Pi^2)/2304 + (245*cA^2*lmuH*Pi^2)/1728 + 
         (cA*cR*lmuH*Pi^2)/32 + (55*cA^2*lmmOS*lmuH*Pi^2)/576 + 
         (55*cA^2*lmuH^2*Pi^2)/576 + (cR*nh*Pi^2)/6 - (3971*cA^2*Pi^4)/
          138240 - (17*cA^2*lmmOS*Pi^4)/2304 - (17*cA^2*lmuH*Pi^4)/1152 + 
         (cA*cR*Pi^2*Log[2])/2 - cR^2*Pi^2*Log[2] + 
         nl^2*(lmmOS^3/216 + (lmmOS*Pi^2)/432 - Zeta[3]/108) - 
         (12923*cA^2*Zeta[3])/13824 + (3339*cA*cR*Zeta[3])/256 - 
         (189*cR^2*Zeta[3])/64 - (671*cA^2*lmmOS*Zeta[3])/288 - 
         (9*cA^2*lmmOS^2*Zeta[3])/32 - (319*cA^2*lmuH*Zeta[3])/144 - 
         (9*cA^2*lmmOS*lmuH*Zeta[3])/8 - (9*cA^2*lmuH^2*Zeta[3])/8 + 
         (63*cA*nh*Zeta[3])/256 + (63*cR*nh*Zeta[3])/128 + 
         (7*cA^2*Pi^2*Zeta[3])/192 + nl*((-50915*cA)/15552 - (253*cR)/96 - 
           (3893*cA*lmmOS)/2592 - (9*cR*lmmOS)/16 + (167*cA*lmmOS^2)/432 + 
           (11*cR*lmmOS^2)/32 - (13*cA*lmmOS^3)/288 - (7*cA*lmmOS^4)/1152 - 
           (229*cA*lmuH)/162 - (67*cR*lmuH)/48 - (13*cA*lmmOS*lmuH)/108 - 
           (cR*lmmOS*lmuH)/8 + (5*cA*lmmOS^2*lmuH)/144 - (cA*lmmOS^3*lmuH)/
            48 - (13*cA*lmuH^2)/108 - (cR*lmuH^2)/8 + (5*cA*lmmOS*lmuH^2)/
            72 - (cA*lmmOS^2*lmuH^2)/48 + (5*cA*lmuH^3)/108 + 
           (cA*lmuH^4)/144 + (37*cA*Pi^2)/1296 - (31*cR*Pi^2)/576 - 
           (23*cA*lmmOS*Pi^2)/576 - (5*cA*lmmOS^2*Pi^2)/1152 - 
           (25*cA*lmuH*Pi^2)/864 - (5*cA*lmmOS*lmuH*Pi^2)/288 - 
           (5*cA*lmuH^2*Pi^2)/288 - (31*cA*Pi^4)/7680 + (cR*Pi^4)/108 - 
           (565*cA*Zeta[3])/432 + (23*cR*Zeta[3])/12 - (11*cA*lmmOS*Zeta[3])/
            144 + (cR*lmmOS*Zeta[3])/2 - (43*cA*lmuH*Zeta[3])/72 + 
           cR*lmuH*Zeta[3]) + (69*cA^2*Zeta[5])/80) + 
       ep^2*((10564525*cA^2)/186624 + (4367*cA*cR)/3456 - (2965*cR^2)/384 + 
         (176369*cA^2*lmmOS)/62208 - (3727*cA*cR*lmmOS)/384 - 
         (867*cR^2*lmmOS)/64 + (71473*cA^2*lmmOS^2)/10368 - 
         (1829*cA*cR*lmmOS^2)/192 + (243*cR^2*lmmOS^2)/64 + 
         (3533*cA^2*lmmOS^3)/2592 - (353*cA*cR*lmmOS^3)/96 - 
         (2705*cA^2*lmmOS^4)/6912 + (cA*cR*lmmOS^4)/4 + 
         (77*cA^2*lmmOS^5)/11520 + (cA^2*lmmOS^6)/5760 + 
         (193553*cA^2*lmuH)/7776 - (389*cA*cR*lmuH)/64 + 
         (3953*cA^2*lmmOS*lmuH)/1296 - (29*cA*cR*lmmOS*lmuH)/16 + 
         (161*cA^2*lmmOS^2*lmuH)/108 - (29*cA*cR*lmmOS^2*lmuH)/8 - 
         (787*cA^2*lmmOS^3*lmuH)/864 + (cA*cR*lmmOS^3*lmuH)/2 + 
         (11*cA^2*lmmOS^4*lmuH)/384 + (cA^2*lmmOS^5*lmuH)/480 + 
         (5681*cA^2*lmuH^2)/1296 - (29*cA*cR*lmuH^2)/64 + 
         (53*cA^2*lmmOS*lmuH^2)/54 - (29*cA*cR*lmmOS*lmuH^2)/16 - 
         (247*cA^2*lmmOS^2*lmuH^2)/288 + (3*cA*cR*lmmOS^2*lmuH^2)/8 + 
         (11*cA^2*lmmOS^3*lmuH^2)/288 + (cA^2*lmmOS^4*lmuH^2)/96 + 
         (26*cA^2*lmuH^3)/81 - (29*cA*cR*lmuH^3)/96 - (14*cA^2*lmmOS*lmuH^3)/
          27 + (cA*cR*lmmOS*lmuH^3)/8 + (cA^2*lmmOS^3*lmuH^3)/36 - 
         (313*cA^2*lmuH^4)/1728 + (cA*cR*lmuH^4)/64 - (11*cA^2*lmmOS*lmuH^4)/
          288 + (cA^2*lmmOS^2*lmuH^4)/24 - (11*cA^2*lmuH^5)/480 + 
         (cA^2*lmmOS*lmuH^5)/30 + (cA^2*lmuH^6)/90 + (9533*cA*nh)/20736 - 
         (13831*cR*nh)/1728 - (1423*cA*lmmOS*nh)/1152 - 
         (959*cR*lmmOS*nh)/192 - (15*cA*lmmOS^2*nh)/128 - 
         (3*cR*lmmOS^2*nh)/16 + (46339*cA^2*Pi^2)/62208 - 
         (959*cA*cR*Pi^2)/576 + (467*cR^2*Pi^2)/128 + (245*cA^2*lmmOS*Pi^2)/
          5184 - (55*cA*cR*lmmOS*Pi^2)/64 + (15*cR^2*lmmOS*Pi^2)/8 - 
         (143*cA^2*lmmOS^2*Pi^2)/6912 + (cA*cR*lmmOS^2*Pi^2)/16 + 
         (55*cA^2*lmmOS^3*Pi^2)/6912 + (53*cA^2*lmuH*Pi^2)/162 - 
         (29*cA*cR*lmuH*Pi^2)/192 + (155*cA^2*lmmOS*lmuH*Pi^2)/1728 + 
         (cA*cR*lmmOS*lmuH*Pi^2)/16 + (55*cA^2*lmmOS^2*lmuH*Pi^2)/1152 + 
         (145*cA^2*lmuH^2*Pi^2)/864 + (cA*cR*lmuH^2*Pi^2)/64 + 
         (55*cA^2*lmmOS*lmuH^2*Pi^2)/576 + (55*cA^2*lmuH^3*Pi^2)/864 - 
         (5*cA*nh*Pi^2)/768 + (79*cR*nh*Pi^2)/96 + (cR*lmmOS*nh*Pi^2)/2 + 
         (121*cA^2*Pi^4)/1440 - (2313*cA*cR*Pi^4)/2560 + 
         (139*cR^2*Pi^4)/1920 - (3971*cA^2*lmmOS*Pi^4)/138240 - 
         (17*cA^2*lmmOS^2*Pi^4)/4608 - (1859*cA^2*lmuH*Pi^4)/69120 - 
         (17*cA^2*lmmOS*lmuH*Pi^4)/1152 - (17*cA^2*lmuH^2*Pi^4)/1152 - 
         (51*cA*nh*Pi^4)/2560 - (51*cR*nh*Pi^4)/1280 + (4331*cA^2*Pi^6)/
          483840 + 3*cA*cR*Pi^2*Log[2] - 6*cR^2*Pi^2*Log[2] + 
         (3*cA*cR*lmmOS*Pi^2*Log[2])/2 - 3*cR^2*lmmOS*Pi^2*Log[2] - 
         cR*nh*Pi^2*Log[2] + (263*cA^2*Pi^2*Log[2]^2)/256 - 
         (509*cA*cR*Pi^2*Log[2]^2)/128 + (123*cR^2*Pi^2*Log[2]^2)/32 - 
         (9*cA*nh*Pi^2*Log[2]^2)/128 - (9*cR*nh*Pi^2*Log[2]^2)/64 - 
         (263*cA^2*Log[2]^4)/256 + (317*cA*cR*Log[2]^4)/128 - 
         (27*cR^2*Log[2]^4)/32 + (9*cA*nh*Log[2]^4)/128 + 
         (9*cR*nh*Log[2]^4)/64 - (789*cA^2*PolyLog[4, 1/2])/32 + 
         (951*cA*cR*PolyLog[4, 1/2])/16 - (81*cR^2*PolyLog[4, 1/2])/4 + 
         (27*cA*nh*PolyLog[4, 1/2])/16 + (27*cR*nh*PolyLog[4, 1/2])/8 - 
         (838571*cA^2*Zeta[3])/27648 + (93119*cA*cR*Zeta[3])/1536 + 
         (647*cR^2*Zeta[3])/64 + (13807*cA^2*lmmOS*Zeta[3])/13824 + 
         (10305*cA*cR*lmmOS*Zeta[3])/256 - (567*cR^2*lmmOS*Zeta[3])/64 - 
         (671*cA^2*lmmOS^2*Zeta[3])/576 - (3*cA^2*lmmOS^3*Zeta[3])/32 - 
         (467*cA^2*lmuH*Zeta[3])/144 - (9*cA*cR*lmuH*Zeta[3])/8 - 
         (319*cA^2*lmmOS*lmuH*Zeta[3])/144 - (9*cA^2*lmmOS^2*lmuH*Zeta[3])/
          16 - (143*cA^2*lmuH^2*Zeta[3])/144 - (9*cA^2*lmmOS*lmuH^2*Zeta[3])/
          8 - (3*cA^2*lmuH^3*Zeta[3])/4 + (1799*cA*nh*Zeta[3])/1536 + 
         (1561*cR*nh*Zeta[3])/256 + (189*cA*lmmOS*nh*Zeta[3])/256 + 
         (189*cR*lmmOS*nh*Zeta[3])/128 - (77*cA^2*Pi^2*Zeta[3])/384 + 
         (7*cA^2*lmmOS*Pi^2*Zeta[3])/192 + (7*cA^2*lmuH*Pi^2*Zeta[3])/96 + 
         (103*cA^2*Zeta[3]^2)/16 + nl^2*(lmmOS^4/864 + (lmmOS^2*Pi^2)/864 + 
           Pi^4/5760 - (lmmOS*Zeta[3])/108) - (2123*cA^2*Zeta[5])/480 + 
         (69*cA^2*lmmOS*Zeta[5])/80 + (69*cA^2*lmuH*Zeta[5])/40 + 
         nl*((-1169153*cA)/93312 - (8797*cR)/432 - (57053*cA*lmmOS)/15552 - 
           (53*cR*lmmOS)/36 - (5279*cA*lmmOS^2)/5184 - (65*cR*lmmOS^2)/48 + 
           (61*cA*lmmOS^3)/648 + (49*cR*lmmOS^3)/96 - (13*cA*lmmOS^4)/1152 - 
           (7*cA*lmmOS^5)/5760 - (25075*cA*lmuH)/3888 - (2027*cR*lmuH)/288 - 
           (229*cA*lmmOS*lmuH)/162 - (67*cR*lmmOS*lmuH)/48 - 
           (13*cA*lmmOS^2*lmuH)/216 - (cR*lmmOS^2*lmuH)/16 + 
           (5*cA*lmmOS^3*lmuH)/432 - (cA*lmmOS^4*lmuH)/192 - 
           (431*cA*lmuH^2)/324 - (67*cR*lmuH^2)/48 - (13*cA*lmmOS*lmuH^2)/
            108 - (cR*lmmOS*lmuH^2)/8 + (5*cA*lmmOS^2*lmuH^2)/144 - 
           (cA*lmmOS^3*lmuH^2)/144 - (13*cA*lmuH^3)/162 - (cR*lmuH^3)/12 + 
           (5*cA*lmmOS*lmuH^3)/108 + (5*cA*lmuH^4)/216 + (cA*lmmOS*lmuH^4)/
            144 + (cA*lmuH^5)/240 - (3125*cA*Pi^2)/31104 - (47*cR*Pi^2)/216 + 
           (119*cA*lmmOS*Pi^2)/2592 - (97*cR*lmmOS*Pi^2)/576 - 
           (23*cA*lmmOS^2*Pi^2)/1152 - (5*cA*lmmOS^3*Pi^2)/3456 - 
           (61*cA*lmuH*Pi^2)/1296 + (11*cR*lmuH*Pi^2)/288 - 
           (25*cA*lmmOS*lmuH*Pi^2)/864 - (5*cA*lmmOS^2*lmuH*Pi^2)/576 - 
           (25*cA*lmuH^2*Pi^2)/864 - (5*cA*lmmOS*lmuH^2*Pi^2)/288 - 
           (5*cA*lmuH^3*Pi^2)/432 - (5791*cA*Pi^4)/207360 + 
           (23*cR*Pi^4)/648 - (31*cA*lmmOS*Pi^4)/7680 + (cR*lmmOS*Pi^4)/108 - 
           (157*cA*lmuH*Pi^4)/11520 + (cR*lmuH*Pi^4)/54 - (881*cA*Zeta[3])/
            216 + (1337*cR*Zeta[3])/144 - (565*cA*lmmOS*Zeta[3])/432 + 
           (23*cR*lmmOS*Zeta[3])/12 - (11*cA*lmmOS^2*Zeta[3])/288 + 
           (cR*lmmOS^2*Zeta[3])/4 - (203*cA*lmuH*Zeta[3])/72 + 
           (23*cR*lmuH*Zeta[3])/6 - (43*cA*lmmOS*lmuH*Zeta[3])/72 + 
           cR*lmmOS*lmuH*Zeta[3] - (59*cA*lmuH^2*Zeta[3])/72 + 
           cR*lmuH^2*Zeta[3] + (77*cA*Pi^2*Zeta[3])/576 - (7*cR*Pi^2*Zeta[3])/
            72 - (287*cA*Zeta[5])/240 + 2*cR*Zeta[5])) + 
       rhoOS^2*((-108986798269*cA^2)/1365590016000 - (62221453543*cA*cR)/
          69672960000 - (55364417*cR^2)/58060800 + cA^2/(1344*ep^4) - 
         (8161*cA^2*lmmOS)/1270080 - (82981*cA*cR*lmmOS)/756000 + 
         (757*cA^2*lmmOS^2)/138240 - (277*cA*cR*lmmOS^2)/9450 + 
         (95*cA^2*lmmOS^3)/96768 + (cA^2*lmmOS^4)/32256 - 
         (961*cA^2*lmuH)/254016 - (188003*cA*cR*lmuH)/4536000 + 
         (971*cA^2*lmmOS*lmuH)/241920 - (277*cA*cR*lmmOS*lmuH)/9450 + 
         (17*cA^2*lmmOS^2*lmuH)/5376 + (cA^2*lmmOS^3*lmuH)/4032 - 
         (cA^2*lmuH^2)/241920 - (277*cA*cR*lmuH^2)/37800 + 
         (29*cA^2*lmmOS*lmuH^2)/8064 + (cA^2*lmmOS^2*lmuH^2)/1344 + 
         (cA^2*lmuH^3)/672 + (cA^2*lmmOS*lmuH^3)/1008 + (cA^2*lmuH^4)/2016 + 
         (9563651*cA*nh)/130056192000 - (85002469*cR*nh)/2786918400 + 
         (43*cA*lmmOS*nh)/134400 - (cR*lmmOS*nh)/480 - (43*cA*lmuH*nh)/
          134400 + (cR*lmuH*nh)/480 + ((95*cA^2)/16128 + (cA^2*lmmOS)/1344 + 
           (cA^2*lmuH)/672 - (cA*nl)/1152)/ep^3 + 
         ((5371*cA^2)/483840 - (277*cA*cR)/18900 + (95*cA^2*lmmOS)/16128 + 
           (cA^2*lmmOS^2)/2688 + (17*cA^2*lmuH)/2688 + (cA^2*lmmOS*lmuH)/
            672 + (cA^2*lmuH^2)/672 + ((-47*cA)/16128 - (cA*lmmOS)/1152 - 
             (cA*lmuH)/1344)*nl + nl^2/6048)/ep^2 + (8221*cA^2*Pi^2)/
          5806080 - (727*cA*cR*Pi^2)/226800 + (5*cR^2*Pi^2)/672 + 
         (55*cA^2*lmmOS*Pi^2)/193536 + (55*cA^2*lmuH*Pi^2)/96768 + 
         (cR*nh*Pi^2)/504 - (17*cA^2*Pi^4)/387072 + 
         nl^2*(1/12096 + lmmOS/4032 + lmmOS^2/12096 + Pi^2/72576) + 
         (cA*cR*Pi^2*Log[2])/168 - (cR^2*Pi^2*Log[2])/84 + 
         (13789799*cA^2*Zeta[3])/247726080 + (3769709*cA*cR*Zeta[3])/
          5898240 + (317921*cR^2*Zeta[3])/368640 - (3*cA^2*lmmOS*Zeta[3])/
          896 - (3*cA^2*lmuH*Zeta[3])/448 - (791*cA*nh*Zeta[3])/1572864 + 
         (20083*cR*nh*Zeta[3])/1179648 + ((2647*cA^2)/2540160 - 
           (44269*cA*cR)/648000 + (5347*cA^2*lmmOS)/483840 - 
           (277*cA*cR*lmmOS)/9450 + (95*cA^2*lmmOS^2)/32256 + 
           (cA^2*lmmOS^3)/8064 + (983*cA^2*lmuH)/241920 - (277*cA*cR*lmuH)/
            18900 + (17*cA^2*lmmOS*lmuH)/2688 + (cA^2*lmmOS^2*lmuH)/1344 + 
           (29*cA^2*lmuH^2)/8064 + (cA^2*lmmOS*lmuH^2)/672 + 
           (cA^2*lmuH^3)/1008 + (1/4032 + lmmOS/6048)*nl^2 + 
           (55*cA^2*Pi^2)/193536 + nl*((-709*cA)/362880 + (9539*cR)/1814400 - 
             (47*cA*lmmOS)/16128 - (cA*lmmOS^2)/2304 - (17*cA*lmuH)/24192 - 
             (cA*lmmOS*lmuH)/1344 - (cA*lmuH^2)/4032 - (5*cA*Pi^2)/96768) - 
           (3*cA^2*Zeta[3])/896)/ep + nl*((3187*cA)/4762800 + 
           (23867*cR)/2116800 - (139*cA*lmmOS)/90720 + (2719*cR*lmmOS)/
            518400 - (47*cA*lmmOS^2)/32256 - (cA*lmmOS^3)/6912 + 
           (127*cA*lmuH)/362880 + (cR*lmuH)/80640 - (17*cA*lmmOS*lmuH)/
            24192 - (cA*lmmOS^2*lmuH)/2688 + (cA*lmuH^2)/24192 - 
           (cA*lmmOS*lmuH^2)/4032 - (61*cA*Pi^2)/193536 - (cR*Pi^2)/1008 - 
           (5*cA*lmmOS*Pi^2)/96768 - (5*cA*lmuH*Pi^2)/48384 - 
           (11*cA*Zeta[3])/24192 + (cR*Zeta[3])/336) + 
         ep*((-552223906247381*cA^2)/2294191226880000 - 
           (429661611842299*cA*cR)/117050572800000 - (509104316813*cR^2)/
            83607552000 - (358194140407*cA^2*lmmOS)/1365590016000 - 
           (6261537263*cA*cR*lmmOS)/2580480000 - (55364417*cR^2*lmmOS)/
            19353600 - (6413*cA^2*lmmOS^2)/508032 - (52511*cA*cR*lmmOS^2)/
            756000 + (5203*cA^2*lmmOS^3)/2903040 - (277*cA*cR*lmmOS^3)/
            14175 + (95*cA^2*lmmOS^4)/387072 + (cA^2*lmmOS^5)/161280 + 
           (5326775*cA^2*lmuH)/170698752 - (54800981*cA*cR*lmuH)/544320000 - 
           (18247*cA^2*lmmOS*lmuH)/2540160 - (188003*cA*cR*lmmOS*lmuH)/
            2268000 + (947*cA^2*lmmOS^2*lmuH)/483840 - 
           (277*cA*cR*lmmOS^2*lmuH)/9450 + (17*cA^2*lmmOS^3*lmuH)/16128 + 
           (cA^2*lmmOS^4*lmuH)/16128 - (17513*cA^2*lmuH^2)/5080320 - 
           (188003*cA*cR*lmuH^2)/9072000 - (cA^2*lmmOS*lmuH^2)/34560 - 
           (277*cA*cR*lmmOS*lmuH^2)/18900 + (29*cA^2*lmmOS^2*lmuH^2)/16128 + 
           (cA^2*lmmOS^3*lmuH^2)/4032 - (493*cA^2*lmuH^3)/362880 - 
           (277*cA*cR*lmuH^3)/113400 + (cA^2*lmmOS*lmuH^3)/672 + 
           (cA^2*lmmOS^2*lmuH^3)/2016 + (25*cA^2*lmuH^4)/48384 + 
           (cA^2*lmmOS*lmuH^4)/2016 + (cA^2*lmuH^5)/5040 + 
           (48646628729*cA*nh)/9103933440000 - (7169756707*cR*nh)/
            37158912000 + (66441731*cA*lmmOS*nh)/43352064000 - 
           (92636389*cR*lmmOS*nh)/928972800 + (43*cA*lmmOS^2*nh)/53760 - 
           (cR*lmmOS^2*nh)/192 - (529*cA*lmuH*nh)/403200 + 
           (71*cR*lmuH*nh)/8640 - (43*cA*lmmOS*lmuH*nh)/67200 + 
           (cR*lmmOS*lmuH*nh)/240 - (43*cA*lmuH^2*nh)/268800 + 
           (cR*lmuH^2*nh)/960 + (22439*cA^2*Pi^2)/15240960 - 
           (1038883*cA*cR*Pi^2)/54432000 + (25*cR^2*Pi^2)/448 + 
           (1171*cA^2*lmmOS*Pi^2)/829440 - (17*cA*cR*lmmOS*Pi^2)/2025 + 
           (5*cR^2*lmmOS*Pi^2)/224 + (55*cA^2*lmmOS^2*Pi^2)/387072 + 
           (5813*cA^2*lmuH*Pi^2)/2903040 - (277*cA*cR*lmuH*Pi^2)/226800 + 
           (55*cA^2*lmmOS*lmuH*Pi^2)/96768 + (55*cA^2*lmuH^2*Pi^2)/96768 + 
           (43*cA*nh*Pi^2)/806400 + (13*cR*nh*Pi^2)/960 + (cR*lmmOS*nh*Pi^2)/
            168 - (30560497*cA^2*Pi^4)/7431782400 - (12574399*cA*cR*Pi^4)/
            412876800 - (3524849*cR^2*Pi^4)/77414400 - (17*cA^2*lmmOS*Pi^4)/
            387072 - (17*cA^2*lmuH*Pi^4)/193536 + (1921*cA*nh*Pi^4)/
            47185920 - (48773*cR*nh*Pi^4)/35389440 + (cA*cR*Pi^2*Log[2])/21 - 
           (2*cR^2*Pi^2*Log[2])/21 + (cA*cR*lmmOS*Pi^2*Log[2])/56 - 
           (cR^2*lmmOS*Pi^2*Log[2])/28 - (cR*nh*Pi^2*Log[2])/84 - 
           (8029*cA^2*Pi^2*Log[2]^2)/5898240 - (18115*cA*cR*Pi^2*Log[2]^2)/
            1376256 + (40991*cR^2*Pi^2*Log[2]^2)/1290240 + 
           (113*cA*nh*Pi^2*Log[2]^2)/786432 - (2869*cR*nh*Pi^2*Log[2]^2)/
            589824 + (8029*cA^2*Log[2]^4)/5898240 - (923*cA*cR*Log[2]^4)/
            196608 + (727*cR^2*Log[2]^4)/184320 - (113*cA*nh*Log[2]^4)/
            786432 + (2869*cR*nh*Log[2]^4)/589824 + 
           (8029*cA^2*PolyLog[4, 1/2])/245760 - (923*cA*cR*PolyLog[4, 1/2])/
            8192 + (727*cR^2*PolyLog[4, 1/2])/7680 - 
           (113*cA*nh*PolyLog[4, 1/2])/32768 + (2869*cR*nh*PolyLog[4, 1/2])/
            24576 + nl^2*(lmmOS/12096 + lmmOS^2/8064 + lmmOS^3/36288 + 
             Pi^2/48384 + (lmmOS*Pi^2)/72576 - Zeta[3]/18144) + 
           (33084968809*cA^2*Zeta[3])/59454259200 + 
           (11108937157*cA*cR*Zeta[3])/1981808640 + 
           (11050270081*cR^2*Zeta[3])/1238630400 + 
           (50728757*cA^2*lmmOS*Zeta[3])/247726080 + 
           (3769709*cA*cR*lmmOS*Zeta[3])/1966080 + 
           (317921*cR^2*lmmOS*Zeta[3])/122880 - (3*cA^2*lmmOS^2*Zeta[3])/
            1792 - (281*cA^2*lmuH*Zeta[3])/12096 - 
           (3*cA^2*lmmOS*lmuH*Zeta[3])/448 - (3*cA^2*lmuH^2*Zeta[3])/448 - 
           (449939*cA*nh*Zeta[3])/47185920 + (29405173*cR*nh*Zeta[3])/
            141557760 - (791*cA*lmmOS*nh*Zeta[3])/524288 + 
           (20083*cR*lmmOS*nh*Zeta[3])/393216 + (cA^2*Pi^2*Zeta[3])/4608 + 
           nl*((-12540221*cA)/4572288000 - (7787469923*cR)/213373440000 + 
             (84863*cA*lmmOS)/38102400 + (13722473*cR*lmmOS)/1524096000 - 
             (109*cA*lmmOS^2)/725760 - (8279*cR*lmmOS^2)/3628800 - 
             (47*cA*lmmOS^3)/96768 - (cA*lmmOS^4)/27648 - (209*cA*lmuH)/
              136080 - (3799*cR*lmuH)/967680 + (127*cA*lmmOS*lmuH)/362880 + 
             (cR*lmmOS*lmuH)/80640 - (17*cA*lmmOS^2*lmuH)/48384 - 
             (cA*lmmOS^3*lmuH)/8064 + (31*cA*lmuH^2)/51840 + 
             (cR*lmuH^2)/80640 + (cA*lmmOS*lmuH^2)/24192 - 
             (cA*lmmOS^2*lmuH^2)/8064 + (5*cA*lmuH^3)/18144 + 
             (cA*lmuH^4)/24192 - (1963*cA*Pi^2)/4354560 - (7679*cR*Pi^2)/
              1555200 - (61*cA*lmmOS*Pi^2)/193536 - (cR*lmmOS*Pi^2)/336 - 
             (5*cA*lmmOS^2*Pi^2)/193536 - (95*cA*lmuH*Pi^2)/290304 - 
             (5*cA*lmmOS*lmuH*Pi^2)/48384 - (5*cA*lmuH^2*Pi^2)/48384 - 
             (31*cA*Pi^4)/1290240 + (cR*Pi^4)/18144 - (1229*cA*Zeta[3])/
              145152 + (cR*Zeta[3])/63 - (11*cA*lmmOS*Zeta[3])/24192 + 
             (cR*lmmOS*Zeta[3])/336 - (43*cA*lmuH*Zeta[3])/12096 + 
             (cR*lmuH*Zeta[3])/168) + (23*cA^2*Zeta[5])/4480) + 
         ep^2*((1787910880016285497*cA^2)/963560315289600000 - 
           (1020988862690791*cA*cR)/16387080192000000 - (9693588877453*cR^2)/
            836075520000 - (2117642814018943*cA^2*lmmOS)/2294191226880000 - 
           (405970178488571*cA*cR*lmmOS)/39016857600000 - 
           (509104316813*cR^2*lmmOS)/27869184000 - 
           (1086683635621*cA^2*lmmOS^2)/2731180032000 - 
           (157326269749*cA*cR*lmmOS^2)/46448640000 - (55364417*cR^2*lmmOS^2)/
            12902400 - (47339*cA^2*lmmOS^3)/3810240 - (3403*cA*cR*lmmOS^3)/
            567000 + (5011*cA^2*lmmOS^4)/11612160 - (277*cA*cR*lmmOS^4)/
            28350 + (19*cA^2*lmmOS^5)/387072 + (cA^2*lmmOS^6)/967680 + 
           (66009030757*cA^2*lmuH)/358467379200 - (7774783081*cA*cR*lmuH)/
            32659200000 + (25316827*cA^2*lmmOS*lmuH)/853493760 - 
           (54800981*cA*cR*lmmOS*lmuH)/272160000 - (35521*cA^2*lmmOS^2*lmuH)/
            5080320 - (188003*cA*cR*lmmOS^2*lmuH)/2268000 + 
           (899*cA^2*lmmOS^3*lmuH)/1451520 - (277*cA*cR*lmmOS^3*lmuH)/14175 + 
           (17*cA^2*lmmOS^4*lmuH)/64512 + (cA^2*lmmOS^5*lmuH)/80640 + 
           (24963919*cA^2*lmuH^2)/853493760 - (54800981*cA*cR*lmuH^2)/
            1088640000 - (2615*cA^2*lmmOS*lmuH^2)/508032 - 
           (188003*cA*cR*lmmOS*lmuH^2)/4536000 - (19*cA^2*lmmOS^2*lmuH^2)/
            483840 - (277*cA*cR*lmmOS^2*lmuH^2)/18900 + 
           (29*cA^2*lmmOS^3*lmuH^2)/48384 + (cA^2*lmmOS^4*lmuH^2)/16128 - 
           (33319*cA^2*lmuH^3)/15240960 - (188003*cA*cR*lmuH^3)/27216000 - 
           (31*cA^2*lmmOS*lmuH^3)/22680 - (277*cA*cR*lmmOS*lmuH^3)/56700 + 
           (cA^2*lmmOS^2*lmuH^3)/1344 + (cA^2*lmmOS^3*lmuH^3)/6048 - 
           (739*cA^2*lmuH^4)/725760 - (277*cA*cR*lmuH^4)/453600 + 
           (25*cA^2*lmmOS*lmuH^4)/48384 + (cA^2*lmmOS^2*lmuH^4)/4032 + 
           (13*cA^2*lmuH^5)/80640 + (cA^2*lmmOS*lmuH^5)/5040 + 
           (cA^2*lmuH^6)/15120 + (27327246425027*cA*nh)/764730408960000 - 
           (1641386174557*cR*nh)/2229534720000 + (56280907129*cA*lmmOS*nh)/
            3034644480000 - (22130018921*cR*lmmOS*nh)/37158912000 + 
           (34786817*cA*lmmOS^2*nh)/9633792000 - (32575223*cR*lmmOS^2*nh)/
            206438400 + (817*cA*lmmOS^3*nh)/806400 - (19*cR*lmmOS^3*nh)/
            2880 - (3043*cA*lmuH*nh)/1209600 + (433*cR*lmuH*nh)/25920 - 
           (529*cA*lmmOS*lmuH*nh)/201600 + (71*cR*lmmOS*lmuH*nh)/4320 - 
           (43*cA*lmmOS^2*lmuH*nh)/67200 + (cR*lmmOS^2*lmuH*nh)/240 - 
           (529*cA*lmuH^2*nh)/806400 + (71*cR*lmuH^2*nh)/17280 - 
           (43*cA*lmmOS*lmuH^2*nh)/134400 + (cR*lmmOS*lmuH^2*nh)/480 - 
           (43*cA*lmuH^3*nh)/806400 + (cR*lmuH^3*nh)/2880 - 
           (329426708407*cA^2*Pi^2)/16387080192000 - 
           (205799940533*cA*cR*Pi^2)/836075520000 + (1947583*cR^2*Pi^2)/
            232243200 + (5707*cA^2*lmmOS*Pi^2)/30481920 - 
           (1220563*cA*cR*lmmOS*Pi^2)/27216000 + (75*cR^2*lmmOS*Pi^2)/448 + 
           (8149*cA^2*lmmOS^2*Pi^2)/11612160 - (2579*cA*cR*lmmOS^2*Pi^2)/
            226800 + (15*cR^2*lmmOS^2*Pi^2)/448 + (55*cA^2*lmmOS^3*Pi^2)/
            1161216 + (51223*cA^2*lmuH*Pi^2)/15240960 - 
           (188003*cA*cR*lmuH*Pi^2)/54432000 + (5801*cA^2*lmmOS*lmuH*Pi^2)/
            2903040 - (277*cA*cR*lmmOS*lmuH*Pi^2)/113400 + 
           (55*cA^2*lmmOS^2*lmuH*Pi^2)/193536 + (5819*cA^2*lmuH^2*Pi^2)/
            2903040 - (277*cA*cR*lmuH^2*Pi^2)/453600 + 
           (55*cA^2*lmmOS*lmuH^2*Pi^2)/96768 + (55*cA^2*lmuH^3*Pi^2)/145152 + 
           (123319811*cA*nh*Pi^2)/520224768000 + (546692891*cR*nh*Pi^2)/
            11147673600 + (43*cA*lmmOS*nh*Pi^2)/230400 + 
           (233*cR*lmmOS*nh*Pi^2)/5760 + (cR*lmmOS^2*nh*Pi^2)/112 - 
           (43*cA*lmuH*nh*Pi^2)/1612800 + (cR*lmuH*nh*Pi^2)/5760 - 
           (18470648149*cA^2*Pi^4)/594542592000 - (26789202437*cA*cR*Pi^4)/
            99090432000 - (1862340143*cR^2*Pi^4)/4128768000 - 
           (88160851*cA^2*lmmOS*Pi^4)/7431782400 - 
           (12574399*cA*cR*lmmOS*Pi^4)/137625600 - (3524849*cR^2*lmmOS*Pi^4)/
            25804800 - (17*cA^2*lmmOS^2*Pi^4)/774144 - (3389*cA^2*lmuH*Pi^4)/
            11612160 - (17*cA^2*lmmOS*lmuH*Pi^4)/193536 - 
           (17*cA^2*lmuH^2*Pi^4)/193536 + (1092709*cA*nh*Pi^4)/1415577600 - 
           (445820741*cR*nh*Pi^4)/29727129600 + (1921*cA*lmmOS*nh*Pi^4)/
            15728640 - (48773*cR*lmmOS*nh*Pi^4)/11796480 + 
           (4331*cA^2*Pi^6)/81285120 + (47*cA*cR*Pi^2*Log[2])/224 - 
           (47*cR^2*Pi^2*Log[2])/112 + (cA*cR*lmmOS*Pi^2*Log[2])/7 - 
           (2*cR^2*lmmOS*Pi^2*Log[2])/7 + (3*cA*cR*lmmOS^2*Pi^2*Log[2])/112 - 
           (3*cR^2*lmmOS^2*Pi^2*Log[2])/56 - (cR*nh*Pi^2*Log[2])/12 - 
           (cR*lmmOS*nh*Pi^2*Log[2])/28 + (136493*cA^2*Pi^4*Log[2])/
            58982400 - (104231*cA*cR*Pi^4*Log[2])/41287680 - 
           (54287*cR^2*Pi^4*Log[2])/12902400 - (1921*cA*nh*Pi^4*Log[2])/
            7864320 + (48773*cR*nh*Pi^4*Log[2])/5898240 - 
           (9804179*cA^2*Pi^2*Log[2]^2)/1415577600 - 
           (561773599*cA*cR*Pi^2*Log[2]^2)/4954521600 + 
           (52533571*cR^2*Pi^2*Log[2]^2)/206438400 - 
           (8029*cA^2*lmmOS*Pi^2*Log[2]^2)/1966080 - 
           (18115*cA*cR*lmmOS*Pi^2*Log[2]^2)/458752 + 
           (40991*cR^2*lmmOS*Pi^2*Log[2]^2)/430080 + 
           (64277*cA*nh*Pi^2*Log[2]^2)/23592960 - 
           (11710453*cR*nh*Pi^2*Log[2]^2)/495452160 + 
           (113*cA*lmmOS*nh*Pi^2*Log[2]^2)/262144 - 
           (2869*cR*lmmOS*nh*Pi^2*Log[2]^2)/196608 + 
           (8029*cA^2*Pi^2*Log[2]^3)/2949120 + (18115*cA*cR*Pi^2*Log[2]^3)/
            688128 - (40991*cR^2*Pi^2*Log[2]^3)/645120 - 
           (113*cA*nh*Pi^2*Log[2]^3)/393216 + (2869*cR*nh*Pi^2*Log[2]^3)/
            294912 + (9804179*cA^2*Log[2]^4)/1415577600 - 
           (146015201*cA*cR*Log[2]^4)/4954521600 + (6448829*cR^2*Log[2]^4)/
            206438400 + (8029*cA^2*lmmOS*Log[2]^4)/1966080 - 
           (923*cA*cR*lmmOS*Log[2]^4)/65536 + (727*cR^2*lmmOS*Log[2]^4)/
            61440 - (64277*cA*nh*Log[2]^4)/23592960 + 
           (4200739*cR*nh*Log[2]^4)/70778880 - (113*cA*lmmOS*nh*Log[2]^4)/
            262144 + (2869*cR*lmmOS*nh*Log[2]^4)/196608 - 
           (8029*cA^2*Log[2]^5)/4915200 + (923*cA*cR*Log[2]^5)/163840 - 
           (727*cR^2*Log[2]^5)/153600 + (113*cA*nh*Log[2]^5)/655360 - 
           (2869*cR*nh*Log[2]^5)/491520 + (9804179*cA^2*PolyLog[4, 1/2])/
            58982400 - (146015201*cA*cR*PolyLog[4, 1/2])/206438400 + 
           (6448829*cR^2*PolyLog[4, 1/2])/8601600 + 
           (8029*cA^2*lmmOS*PolyLog[4, 1/2])/81920 - 
           (2769*cA*cR*lmmOS*PolyLog[4, 1/2])/8192 + 
           (727*cR^2*lmmOS*PolyLog[4, 1/2])/2560 - 
           (64277*cA*nh*PolyLog[4, 1/2])/983040 + 
           (4200739*cR*nh*PolyLog[4, 1/2])/2949120 - 
           (339*cA*lmmOS*nh*PolyLog[4, 1/2])/32768 + 
           (2869*cR*lmmOS*nh*PolyLog[4, 1/2])/8192 + 
           (8029*cA^2*PolyLog[5, 1/2])/40960 - (2769*cA*cR*PolyLog[5, 1/2])/
            4096 + (727*cR^2*PolyLog[5, 1/2])/1280 - 
           (339*cA*nh*PolyLog[5, 1/2])/16384 + (2869*cR*nh*PolyLog[5, 1/2])/
            4096 - (1046922196571*cA^2*Zeta[3])/8323596288000 + 
           (23447575518223*cA*cR*Zeta[3])/1783627776000 + 
           (139956399353*cR^2*Zeta[3])/4128768000 + 
           (103928196667*cA^2*lmmOS*Zeta[3])/59454259200 + 
           (2638069429*cA*cR*lmmOS*Zeta[3])/157286400 + 
           (11050270081*cR^2*lmmOS*Zeta[3])/412876800 + 
           (161545631*cA^2*lmmOS^2*Zeta[3])/495452160 + 
           (3769709*cA*cR*lmmOS^2*Zeta[3])/1310720 + 
           (317921*cR^2*lmmOS^2*Zeta[3])/81920 - (cA^2*lmmOS^3*Zeta[3])/
            1792 - (1847*cA^2*lmuH*Zeta[3])/34560 + (277*cA*cR*lmuH*Zeta[3])/
            6300 - (281*cA^2*lmmOS*lmuH*Zeta[3])/12096 - 
           (3*cA^2*lmmOS^2*lmuH*Zeta[3])/896 - (193*cA^2*lmuH^2*Zeta[3])/
            12096 - (3*cA^2*lmmOS*lmuH^2*Zeta[3])/448 - (cA^2*lmuH^3*Zeta[3])/
            224 - (115719101*cA*nh*Zeta[3])/1651507200 + 
           (1811061599*cR*nh*Zeta[3])/1698693120 - 
           (449939*cA*lmmOS*nh*Zeta[3])/15728640 + 
           (29405173*cR*lmmOS*nh*Zeta[3])/47185920 - 
           (2373*cA*lmmOS^2*nh*Zeta[3])/1048576 + 
           (20083*cR*lmmOS^2*nh*Zeta[3])/262144 + (93171*cA^2*Pi^2*Zeta[3])/
            5242880 + (29337083*cA*cR*Pi^2*Zeta[3])/165150720 + 
           (1856807*cR^2*Pi^2*Zeta[3])/10321920 + (cA^2*lmmOS*Pi^2*Zeta[3])/
            4608 + (cA^2*lmuH*Pi^2*Zeta[3])/2304 - (791*cA*nh*Pi^2*Zeta[3])/
            6291456 + (20083*cR*nh*Pi^2*Zeta[3])/4718592 + 
           (103*cA^2*Zeta[3]^2)/2688 + nl^2*(lmmOS^2/24192 + lmmOS^3/24192 + 
             lmmOS^4/145152 + Pi^2/145152 + (lmmOS*Pi^2)/48384 + 
             (lmmOS^2*Pi^2)/145152 + Pi^4/967680 - Zeta[3]/12096 - 
             (lmmOS*Zeta[3])/18144) + (178260101*cA^2*Zeta[5])/165150720 + 
           (113239979*cA*cR*Zeta[5])/9175040 + (3641299*cR^2*Zeta[5])/
            245760 + (23*cA^2*lmmOS*Zeta[5])/4480 + (23*cA^2*lmuH*Zeta[5])/
            2240 + (17515*cA*nh*Zeta[5])/1048576 - (444695*cR*nh*Zeta[5])/
            786432 + nl*((-52954146529*cA)/6721263360000 - (9624385471411*cR)/
              67212633600000 + (29805017*cA*lmmOS)/16003008000 - 
             (11705851567*cR*lmmOS)/80015040000 + (88297*cA*lmmOS^2)/
              38102400 - (77551*cR*lmmOS^2)/6096384 + (151*cA*lmmOS^3)/
              272160 - (27749*cR*lmmOS^3)/3110400 - (47*cA*lmmOS^4)/387072 - 
             (cA*lmmOS^5)/138240 - (38015*cA*lmuH)/5225472 - 
             (356327*cR*lmuH)/11612160 - (209*cA*lmmOS*lmuH)/136080 - 
             (3799*cR*lmmOS*lmuH)/967680 + (127*cA*lmmOS^2*lmuH)/725760 + 
             (cR*lmmOS^2*lmuH)/161280 - (17*cA*lmmOS^3*lmuH)/145152 - 
             (cA*lmmOS^4*lmuH)/32256 - (283*cA*lmuH^2)/272160 - 
             (3799*cR*lmuH^2)/967680 + (31*cA*lmmOS*lmuH^2)/51840 + 
             (cR*lmmOS*lmuH^2)/80640 + (cA*lmmOS^2*lmuH^2)/48384 - 
             (cA*lmmOS^3*lmuH^2)/24192 + (131*cA*lmuH^3)/272160 + 
             (cR*lmuH^3)/120960 + (5*cA*lmmOS*lmuH^3)/18144 + 
             (29*cA*lmuH^4)/145152 + (cA*lmmOS*lmuH^4)/24192 + 
             (cA*lmuH^5)/40320 - (242317*cA*Pi^2)/457228800 - 
             (165665051*cR*Pi^2)/9144576000 - (379*cA*lmmOS*Pi^2)/1088640 - 
             (725803*cR*lmmOS*Pi^2)/43545600 - (61*cA*lmmOS^2*Pi^2)/387072 - 
             (cR*lmmOS^2*Pi^2)/224 - (5*cA*lmmOS^3*Pi^2)/580608 - 
             (2867*cA*lmuH*Pi^2)/4354560 + (53*cR*lmuH*Pi^2)/322560 - 
             (95*cA*lmmOS*lmuH*Pi^2)/290304 - (5*cA*lmmOS^2*lmuH*Pi^2)/
              96768 - (95*cA*lmuH^2*Pi^2)/290304 - (5*cA*lmmOS*lmuH^2*Pi^2)/
              48384 - (5*cA*lmuH^3*Pi^2)/72576 - (14093*cA*Pi^4)/69672960 - 
             (25*cR*Pi^4)/15552 - (31*cA*lmmOS*Pi^4)/1290240 + 
             (cR*lmmOS*Pi^4)/18144 - (157*cA*lmuH*Pi^4)/1935360 + 
             (cR*lmuH*Pi^4)/9072 - (1729*cA*Zeta[3])/51840 + 
             (43867*cR*Zeta[3])/2177280 - (1229*cA*lmmOS*Zeta[3])/145152 + 
             (cR*lmmOS*Zeta[3])/63 - (11*cA*lmmOS^2*Zeta[3])/48384 + 
             (cR*lmmOS^2*Zeta[3])/672 - (535*cA*lmuH*Zeta[3])/24192 + 
             (2*cR*lmuH*Zeta[3])/63 - (43*cA*lmmOS*lmuH*Zeta[3])/12096 + 
             (cR*lmmOS*lmuH*Zeta[3])/168 - (59*cA*lmuH^2*Zeta[3])/12096 + 
             (cR*lmuH^2*Zeta[3])/168 + (11*cA*Pi^2*Zeta[3])/13824 - 
             (cR*Pi^2*Zeta[3])/1728 - (41*cA*Zeta[5])/5760 + 
             (cR*Zeta[5])/84))) + rhoOS*((-55059073*cA^2)/124416000 - 
         (28057*cA*cR)/8640 - (36047*cR^2)/15360 + (7*cA^2)/(960*ep^4) - 
         (67699*cA^2*lmmOS)/518400 - (2129*cA*cR*lmmOS)/4320 + 
         (145*cA^2*lmmOS^2)/6912 - (61*cA*cR*lmmOS^2)/360 + 
         (623*cA^2*lmmOS^3)/69120 + (7*cA^2*lmmOS^4)/23040 - 
         (14311*cA^2*lmuH)/259200 - (27*cA*cR*lmuH)/160 - 
         (31*cA^2*lmmOS*lmuH)/4320 - (61*cA*cR*lmmOS*lmuH)/360 + 
         (7*cA^2*lmmOS^2*lmuH)/256 + (7*cA^2*lmmOS^3*lmuH)/2880 - 
         (65*cA^2*lmuH^2)/3456 - (61*cA*cR*lmuH^2)/1440 + 
         (161*cA^2*lmmOS*lmuH^2)/5760 + (7*cA^2*lmmOS^2*lmuH^2)/960 + 
         (7*cA^2*lmuH^3)/720 + (7*cA^2*lmmOS*lmuH^3)/720 + 
         (7*cA^2*lmuH^4)/1440 - (76697*cA*nh)/8294400 - (557*cR*nh)/3240 + 
         (cA*lmmOS*nh)/480 - (cA*lmuH*nh)/480 + 
         ((623*cA^2)/11520 + (7*cA^2*lmmOS)/960 + (7*cA^2*lmuH)/480 - 
           (49*cA*nl)/5760)/ep^3 + ((1247*cA^2)/17280 - (61*cA*cR)/720 + 
           (623*cA^2*lmmOS)/11520 + (7*cA^2*lmmOS^2)/1920 + 
           (7*cA^2*lmuH)/128 + (7*cA^2*lmmOS*lmuH)/480 + (7*cA^2*lmuH^2)/
            480 + ((-7*cA)/288 - (49*cA*lmmOS)/5760 - (7*cA*lmuH)/960)*nl + 
           (7*nl^2)/4320)/ep^2 + (2423*cA^2*Pi^2)/207360 - 
         (29*cA*cR*Pi^2)/1728 + (7*cR^2*Pi^2)/192 + (77*cA^2*lmmOS*Pi^2)/
          27648 + (77*cA^2*lmuH*Pi^2)/13824 + (7*cR*nh*Pi^2)/720 - 
         (119*cA^2*Pi^4)/276480 + nl^2*((7*lmmOS)/4320 + (7*lmmOS^2)/8640 + 
           (7*Pi^2)/51840) + (7*cA*cR*Pi^2*Log[2])/240 - 
         (7*cR^2*Pi^2*Log[2])/120 + (340943*cA^2*Zeta[3])/1105920 + 
         (2297*cA*cR*Zeta[3])/1024 + (13321*cR^2*Zeta[3])/6144 - 
         (21*cA^2*lmmOS*Zeta[3])/640 - (21*cA^2*lmuH*Zeta[3])/320 + 
         (77*cA*nh*Zeta[3])/24576 + (77*cR*nh*Zeta[3])/768 + 
         ((-28687*cA^2)/518400 - (35*cA*cR)/108 + (1073*cA^2*lmmOS)/17280 - 
           (61*cA*cR*lmmOS)/360 + (623*cA^2*lmmOS^2)/23040 + 
           (7*cA^2*lmmOS^3)/5760 + (5*cA^2*lmuH)/1728 - (61*cA*cR*lmuH)/720 + 
           (7*cA^2*lmmOS*lmuH)/128 + (7*cA^2*lmmOS^2*lmuH)/960 + 
           (161*cA^2*lmuH^2)/5760 + (7*cA^2*lmmOS*lmuH^2)/480 + 
           (7*cA^2*lmuH^3)/720 + (7/4320 + (7*lmmOS)/4320)*nl^2 + 
           (77*cA^2*Pi^2)/27648 + nl*((-197*cA)/51840 + (551*cR)/17280 - 
             (7*cA*lmmOS)/288 - (49*cA*lmmOS^2)/11520 - (7*cA*lmuH)/2160 - 
             (7*cA*lmmOS*lmuH)/960 - (7*cA*lmuH^2)/2880 - (7*cA*Pi^2)/
              13824) - (21*cA^2*Zeta[3])/640)/ep + 
         nl*((5891*cA)/1555200 + (9947*cR)/259200 + (7*cA*lmmOS)/5184 + 
           (589*cR*lmmOS)/17280 - (7*cA*lmmOS^2)/576 - (49*cA*lmmOS^3)/
            34560 + (209*cA*lmuH)/51840 - (19*cR*lmuH)/8640 - 
           (7*cA*lmmOS*lmuH)/2160 - (7*cA*lmmOS^2*lmuH)/1920 + 
           (7*cA*lmuH^2)/4320 - (7*cA*lmmOS*lmuH^2)/2880 - 
           (49*cA*Pi^2)/17280 - (7*cR*Pi^2)/1440 - (7*cA*lmmOS*Pi^2)/13824 - 
           (7*cA*lmuH*Pi^2)/6912 - (77*cA*Zeta[3])/17280 + 
           (7*cR*Zeta[3])/240) + ep*((39068947067*cA^2)/7464960000 + 
           (153260137*cA*cR)/24883200 - (15229*cR^2)/184320 - 
           (185841331*cA^2*lmmOS)/124416000 - (222481*cA*cR*lmmOS)/25920 - 
           (36047*cR^2*lmmOS)/5120 - (144763*cA^2*lmmOS^2)/1036800 - 
           (449*cA*cR*lmmOS^2)/1728 + (29*cA^2*lmmOS^3)/103680 - 
           (61*cA*cR*lmmOS^3)/540 + (623*cA^2*lmmOS^4)/276480 + 
           (7*cA^2*lmmOS^5)/115200 + (2342767*cA^2*lmuH)/7776000 - 
           (6997*cA*cR*lmuH)/12960 - (24727*cA^2*lmmOS*lmuH)/259200 - 
           (27*cA*cR*lmmOS*lmuH)/80 - (59*cA^2*lmmOS^2*lmuH)/4320 - 
           (61*cA*cR*lmmOS^2*lmuH)/360 + (7*cA^2*lmmOS^3*lmuH)/768 + 
           (7*cA^2*lmmOS^4*lmuH)/11520 - (9103*cA^2*lmuH^2)/259200 - 
           (27*cA*cR*lmuH^2)/320 - (103*cA^2*lmmOS*lmuH^2)/4320 - 
           (61*cA*cR*lmmOS*lmuH^2)/720 + (161*cA^2*lmmOS^2*lmuH^2)/11520 + 
           (7*cA^2*lmmOS^3*lmuH^2)/2880 - (205*cA^2*lmuH^3)/10368 - 
           (61*cA*cR*lmuH^3)/4320 + (7*cA^2*lmmOS*lmuH^3)/720 + 
           (7*cA^2*lmmOS^2*lmuH^3)/1440 + (91*cA^2*lmuH^4)/34560 + 
           (7*cA^2*lmmOS*lmuH^4)/1440 + (7*cA^2*lmuH^5)/3600 + 
           (6967757*cA*nh)/124416000 - (355481*cR*nh)/414720 - 
           (76697*cA*lmmOS*nh)/2764800 - (557*cR*lmmOS*nh)/1080 + 
           (cA*lmmOS^2*nh)/192 - (cA*lmmOS*lmuH*nh)/240 - 
           (cA*lmuH^2*nh)/960 + (43103*cA^2*Pi^2)/6220800 - 
           (2401*cA*cR*Pi^2)/25920 + (35*cR^2*Pi^2)/128 + 
           (2249*cA^2*lmmOS*Pi^2)/207360 - (187*cA*cR*lmmOS*Pi^2)/4320 + 
           (7*cR^2*lmmOS*Pi^2)/64 + (77*cA^2*lmmOS^2*Pi^2)/55296 + 
           (1663*cA^2*lmuH*Pi^2)/103680 - (61*cA*cR*lmuH*Pi^2)/8640 + 
           (77*cA^2*lmmOS*lmuH*Pi^2)/13824 + (77*cA^2*lmuH^2*Pi^2)/13824 + 
           (cA*nh*Pi^2)/2880 + (49*cR*nh*Pi^2)/720 + (7*cR*lmmOS*nh*Pi^2)/
            240 - (907099*cA^2*Pi^4)/33177600 - (3151*cA*cR*Pi^4)/30720 - 
           (4499*cR^2*Pi^4)/36864 - (119*cA^2*lmmOS*Pi^4)/276480 - 
           (119*cA^2*lmuH*Pi^4)/138240 - (187*cA*nh*Pi^4)/737280 - 
           (187*cR*nh*Pi^4)/23040 + (7*cA*cR*Pi^2*Log[2])/30 - 
           (7*cR^2*Pi^2*Log[2])/15 + (7*cA*cR*lmmOS*Pi^2*Log[2])/80 - 
           (7*cR^2*lmmOS*Pi^2*Log[2])/40 - (7*cR*nh*Pi^2*Log[2])/120 - 
           (157*cA^2*Pi^2*Log[2]^2)/12288 - (337*cA*cR*Pi^2*Log[2]^2)/7680 + 
           (711*cR^2*Pi^2*Log[2]^2)/5120 - (11*cA*nh*Pi^2*Log[2]^2)/12288 - 
           (11*cR*nh*Pi^2*Log[2]^2)/384 + (157*cA^2*Log[2]^4)/12288 - 
           (67*cA*cR*Log[2]^4)/1536 + (37*cR^2*Log[2]^4)/1024 + 
           (11*cA*nh*Log[2]^4)/12288 + (11*cR*nh*Log[2]^4)/384 + 
           (157*cA^2*PolyLog[4, 1/2])/512 - (67*cA*cR*PolyLog[4, 1/2])/64 + 
           (111*cR^2*PolyLog[4, 1/2])/128 + (11*cA*nh*PolyLog[4, 1/2])/512 + 
           (11*cR*nh*PolyLog[4, 1/2])/16 + nl^2*((7*lmmOS^2)/8640 + 
             (7*lmmOS^3)/25920 + (7*Pi^2)/51840 + (7*lmmOS*Pi^2)/51840 - 
             (7*Zeta[3])/12960) - (5066057*cA^2*Zeta[3])/2654208 + 
           (474799*cA*cR*Zeta[3])/122880 + (1242041*cR^2*Zeta[3])/122880 + 
           (1396013*cA^2*lmmOS*Zeta[3])/1105920 + (6891*cA*cR*lmmOS*Zeta[3])/
            1024 + (13321*cR^2*lmmOS*Zeta[3])/2048 - 
           (21*cA^2*lmmOS^2*Zeta[3])/1280 - (3367*cA^2*lmuH*Zeta[3])/17280 - 
           (21*cA^2*lmmOS*lmuH*Zeta[3])/320 - (21*cA^2*lmuH^2*Zeta[3])/320 - 
           (2849*cA*nh*Zeta[3])/73728 + (17045*cR*nh*Zeta[3])/18432 + 
           (77*cA*lmmOS*nh*Zeta[3])/8192 + (77*cR*lmmOS*nh*Zeta[3])/256 + 
           (49*cA^2*Pi^2*Zeta[3])/23040 + nl*((-3662951*cA)/46656000 - 
             (280117*cR)/864000 + (14039*cA*lmmOS)/1555200 + 
             (12821*cR*lmmOS)/259200 + (523*cA*lmmOS^2)/103680 - 
             (91*cR*lmmOS^2)/11520 - (7*cA*lmmOS^3)/1728 - (49*cA*lmmOS^4)/
              138240 - (4181*cA*lmuH)/155520 - (1403*cR*lmuH)/25920 + 
             (209*cA*lmmOS*lmuH)/51840 - (19*cR*lmmOS*lmuH)/8640 - 
             (7*cA*lmmOS^2*lmuH)/4320 - (7*cA*lmmOS^3*lmuH)/5760 + 
             (209*cA*lmuH^2)/51840 - (19*cR*lmuH^2)/8640 + 
             (7*cA*lmmOS*lmuH^2)/4320 - (7*cA*lmmOS^2*lmuH^2)/5760 + 
             (7*cA*lmuH^3)/2592 + (7*cA*lmuH^4)/17280 - (319*cA*Pi^2)/
              124416 - (1583*cR*Pi^2)/69120 - (49*cA*lmmOS*Pi^2)/17280 - 
             (7*cR*lmmOS*Pi^2)/480 - (7*cA*lmmOS^2*Pi^2)/27648 - 
             (7*cA*lmuH*Pi^2)/2592 - (7*cA*lmmOS*lmuH*Pi^2)/6912 - 
             (7*cA*lmuH^2*Pi^2)/6912 - (217*cA*Pi^4)/921600 + 
             (7*cR*Pi^4)/12960 - (2093*cA*Zeta[3])/25920 + (203*cR*Zeta[3])/
              1440 - (77*cA*lmmOS*Zeta[3])/17280 + (7*cR*lmmOS*Zeta[3])/240 - 
             (301*cA*lmuH*Zeta[3])/8640 + (7*cR*lmuH*Zeta[3])/120) + 
           (161*cA^2*Zeta[5])/3200) + ep^2*((-2041664377057*cA^2)/
            111974400000 - (13316955937*cA*cR)/373248000 - 
           (6015707*cR^2)/184320 + (104640991889*cA^2*lmmOS)/7464960000 + 
           (537505531*cA*cR*lmmOS)/24883200 - (15229*cR^2*lmmOS)/61440 - 
           (561618217*cA^2*lmmOS^2)/248832000 - (607379*cA*cR*lmmOS^2)/
            51840 - (108141*cR^2*lmmOS^2)/10240 - (296011*cA^2*lmmOS^3)/
            3110400 + (1549*cA*cR*lmmOS^3)/25920 - (1363*cA^2*lmmOS^4)/
            414720 - (61*cA*cR*lmmOS^4)/1080 + (623*cA^2*lmmOS^5)/1382400 + 
           (7*cA^2*lmmOS^6)/691200 + (330671171*cA^2*lmuH)/233280000 - 
           (88957*cA*cR*lmuH)/77760 + (2452909*cA^2*lmmOS*lmuH)/7776000 - 
           (6997*cA*cR*lmmOS*lmuH)/6480 - (45559*cA^2*lmmOS^2*lmuH)/518400 - 
           (27*cA*cR*lmmOS^2*lmuH)/80 - (73*cA^2*lmmOS^3*lmuH)/6480 - 
           (61*cA*cR*lmmOS^3*lmuH)/540 + (7*cA^2*lmmOS^4*lmuH)/3072 + 
           (7*cA^2*lmmOS^5*lmuH)/57600 + (519949*cA^2*lmuH^2)/1944000 - 
           (6997*cA*cR*lmuH^2)/25920 - (14311*cA^2*lmmOS*lmuH^2)/259200 - 
           (27*cA*cR*lmmOS*lmuH^2)/160 - (293*cA^2*lmmOS^2*lmuH^2)/17280 - 
           (61*cA*cR*lmmOS^2*lmuH^2)/720 + (161*cA^2*lmmOS^3*lmuH^2)/34560 + 
           (7*cA^2*lmmOS^4*lmuH^2)/11520 - (6499*cA^2*lmuH^3)/388800 - 
           (9*cA*cR*lmuH^3)/320 - (139*cA^2*lmmOS*lmuH^3)/6480 - 
           (61*cA*cR*lmmOS*lmuH^3)/2160 + (7*cA^2*lmmOS^2*lmuH^3)/1440 + 
           (7*cA^2*lmmOS^3*lmuH^3)/4320 - (485*cA^2*lmuH^4)/41472 - 
           (61*cA*cR*lmuH^4)/17280 + (91*cA^2*lmmOS*lmuH^4)/34560 + 
           (7*cA^2*lmmOS^2*lmuH^4)/2880 + (7*cA^2*lmuH^5)/11520 + 
           (7*cA^2*lmmOS*lmuH^5)/3600 + (7*cA^2*lmuH^6)/10800 + 
           (461405941*cA*nh)/3732480000 - (2955553*cR*nh)/933120 + 
           (6881357*cA*lmmOS*nh)/41472000 - (355481*cR*lmmOS*nh)/138240 - 
           (76697*cA*lmmOS^2*nh)/1843200 - (557*cR*lmmOS^2*nh)/720 + 
           (19*cA*lmmOS^3*nh)/2880 + (cA*lmuH*nh)/480 - (cA*lmmOS^2*lmuH*nh)/
            240 - (cA*lmmOS*lmuH^2*nh)/480 - (cA*lmuH^3*nh)/2880 - 
           (169453603*cA^2*Pi^2)/1492992000 - (287489*cA*cR*Pi^2)/311040 + 
           (113059*cR^2*Pi^2)/184320 - (13129*cA^2*lmmOS*Pi^2)/6220800 - 
           (10993*cA*cR*lmmOS*Pi^2)/51840 + (105*cR^2*lmmOS*Pi^2)/128 + 
           (1901*cA^2*lmmOS^2*Pi^2)/414720 - (25*cA*cR*lmmOS^2*Pi^2)/432 + 
           (21*cR^2*lmmOS^2*Pi^2)/128 + (77*cA^2*lmmOS^3*Pi^2)/165888 + 
           (75659*cA^2*lmuH*Pi^2)/3110400 - (9*cA*cR*lmuH*Pi^2)/640 + 
           (197*cA^2*lmmOS*lmuH*Pi^2)/12960 - (61*cA*cR*lmmOS*lmuH*Pi^2)/
            4320 + (77*cA^2*lmmOS^2*lmuH*Pi^2)/27648 + 
           (3413*cA^2*lmuH^2*Pi^2)/207360 - (61*cA*cR*lmuH^2*Pi^2)/17280 + 
           (77*cA^2*lmmOS*lmuH^2*Pi^2)/13824 + (77*cA^2*lmuH^3*Pi^2)/20736 - 
           (76697*cA*nh*Pi^2)/33177600 + (3097*cR*nh*Pi^2)/12960 + 
           (7*cA*lmmOS*nh*Pi^2)/5760 + (49*cR*lmmOS*nh*Pi^2)/240 + 
           (7*cR*lmmOS^2*nh*Pi^2)/160 - (cA*lmuH*nh*Pi^2)/5760 + 
           (9935129*cA^2*Pi^4)/132710400 - (516937*cA*cR*Pi^4)/3686400 - 
           (5930701*cR^2*Pi^4)/11059200 - (2581549*cA^2*lmmOS*Pi^4)/
            33177600 - (3151*cA*cR*lmmOS*Pi^4)/10240 - (4499*cR^2*lmmOS*Pi^4)/
            12288 - (119*cA^2*lmmOS^2*Pi^4)/552960 - (20153*cA^2*lmuH*Pi^4)/
            8294400 - (119*cA^2*lmmOS*lmuH*Pi^4)/138240 - 
           (119*cA^2*lmuH^2*Pi^4)/138240 + (6919*cA*nh*Pi^4)/2211840 - 
           (36467*cR*nh*Pi^4)/552960 - (187*cA*lmmOS*nh*Pi^4)/245760 - 
           (187*cR*lmmOS*nh*Pi^4)/7680 + (4331*cA^2*Pi^6)/8294400 + 
           (49*cA*cR*Pi^2*Log[2])/48 - (49*cR^2*Pi^2*Log[2])/24 + 
           (7*cA*cR*lmmOS*Pi^2*Log[2])/10 - (7*cR^2*lmmOS*Pi^2*Log[2])/5 + 
           (21*cA*cR*lmmOS^2*Pi^2*Log[2])/160 - (21*cR^2*lmmOS^2*Pi^2*Log[2])/
            80 - (49*cR*nh*Pi^2*Log[2])/120 - (7*cR*lmmOS*nh*Pi^2*Log[2])/
            40 + (2669*cA^2*Pi^4*Log[2])/122880 - (437*cA*cR*Pi^4*Log[2])/
            9216 + (733*cR^2*Pi^4*Log[2])/92160 + (187*cA*nh*Pi^4*Log[2])/
            122880 + (187*cR*nh*Pi^4*Log[2])/3840 - (1411*cA^2*Pi^2*Log[2]^2)/
            49152 - (98891*cA*cR*Pi^2*Log[2]^2)/184320 + 
           (218947*cR^2*Pi^2*Log[2]^2)/184320 - (157*cA^2*lmmOS*Pi^2*
             Log[2]^2)/4096 - (337*cA*cR*lmmOS*Pi^2*Log[2]^2)/2560 + 
           (2133*cR^2*lmmOS*Pi^2*Log[2]^2)/5120 + (407*cA*nh*Pi^2*Log[2]^2)/
            36864 - (4111*cR*nh*Pi^2*Log[2]^2)/46080 - 
           (11*cA*lmmOS*nh*Pi^2*Log[2]^2)/4096 - (11*cR*lmmOS*nh*Pi^2*
             Log[2]^2)/128 + (157*cA^2*Pi^2*Log[2]^3)/6144 + 
           (337*cA*cR*Pi^2*Log[2]^3)/3840 - (711*cR^2*Pi^2*Log[2]^3)/2560 + 
           (11*cA*nh*Pi^2*Log[2]^3)/6144 + (11*cR*nh*Pi^2*Log[2]^3)/192 + 
           (1411*cA^2*Log[2]^4)/49152 - (30133*cA*cR*Log[2]^4)/184320 + 
           (39101*cR^2*Log[2]^4)/184320 + (157*cA^2*lmmOS*Log[2]^4)/4096 - 
           (67*cA*cR*lmmOS*Log[2]^4)/512 + (111*cR^2*lmmOS*Log[2]^4)/1024 - 
           (407*cA*nh*Log[2]^4)/36864 + (2435*cR*nh*Log[2]^4)/9216 + 
           (11*cA*lmmOS*nh*Log[2]^4)/4096 + (11*cR*lmmOS*nh*Log[2]^4)/128 - 
           (157*cA^2*Log[2]^5)/10240 + (67*cA*cR*Log[2]^5)/1280 - 
           (111*cR^2*Log[2]^5)/2560 - (11*cA*nh*Log[2]^5)/10240 - 
           (11*cR*nh*Log[2]^5)/320 + (1411*cA^2*PolyLog[4, 1/2])/2048 - 
           (30133*cA*cR*PolyLog[4, 1/2])/7680 + (39101*cR^2*PolyLog[4, 1/2])/
            7680 + (471*cA^2*lmmOS*PolyLog[4, 1/2])/512 - 
           (201*cA*cR*lmmOS*PolyLog[4, 1/2])/64 + 
           (333*cR^2*lmmOS*PolyLog[4, 1/2])/128 - (407*cA*nh*PolyLog[4, 1/2])/
            1536 + (2435*cR*nh*PolyLog[4, 1/2])/384 + 
           (33*cA*lmmOS*nh*PolyLog[4, 1/2])/512 + 
           (33*cR*lmmOS*nh*PolyLog[4, 1/2])/16 + (471*cA^2*PolyLog[5, 1/2])/
            256 - (201*cA*cR*PolyLog[5, 1/2])/32 + (333*cR^2*PolyLog[5, 1/2])/
            64 + (33*cA*nh*PolyLog[5, 1/2])/256 + (33*cR*nh*PolyLog[5, 1/2])/
            8 + (268010191*cA^2*Zeta[3])/132710400 + (84402523*cA*cR*Zeta[3])/
            6635520 + (29407247*cR^2*Zeta[3])/737280 - 
           (68388679*cA^2*lmmOS*Zeta[3])/13271040 + 
           (278633*cA*cR*lmmOS*Zeta[3])/24576 + (1242041*cR^2*lmmOS*Zeta[3])/
            40960 + (4561223*cA^2*lmmOS^2*Zeta[3])/2211840 + 
           (20673*cA*cR*lmmOS^2*Zeta[3])/2048 + (39963*cR^2*lmmOS^2*Zeta[3])/
            4096 - (7*cA^2*lmmOS^3*Zeta[3])/1280 - (229*cA^2*lmuH*Zeta[3])/
            576 + (61*cA*cR*lmuH*Zeta[3])/240 - (3367*cA^2*lmmOS*lmuH*
             Zeta[3])/17280 - (21*cA^2*lmmOS^2*lmuH*Zeta[3])/640 - 
           (427*cA^2*lmuH^2*Zeta[3])/3456 - (21*cA^2*lmmOS*lmuH^2*Zeta[3])/
            320 - (7*cA^2*lmuH^3*Zeta[3])/160 - (2975341*cA*nh*Zeta[3])/
            8847360 + (2281783*cR*nh*Zeta[3])/552960 - 
           (2849*cA*lmmOS*nh*Zeta[3])/24576 + (17045*cR*lmmOS*nh*Zeta[3])/
            6144 + (231*cA*lmmOS^2*nh*Zeta[3])/16384 + 
           (231*cR*lmmOS^2*nh*Zeta[3])/512 + (53911*cA^2*Pi^2*Zeta[3])/
            491520 + (13277*cA*cR*Pi^2*Zeta[3])/20480 + 
           (45101*cR^2*Pi^2*Zeta[3])/122880 + (49*cA^2*lmmOS*Pi^2*Zeta[3])/
            23040 + (49*cA^2*lmuH*Pi^2*Zeta[3])/11520 + 
           (77*cA*nh*Pi^2*Zeta[3])/98304 + (77*cR*nh*Pi^2*Zeta[3])/3072 + 
           (721*cA^2*Zeta[3]^2)/1920 + nl^2*((7*lmmOS^3)/25920 + 
             (7*lmmOS^4)/103680 + (7*lmmOS*Pi^2)/51840 + (7*lmmOS^2*Pi^2)/
              103680 + (7*Pi^4)/691200 - (7*Zeta[3])/12960 - 
             (7*lmmOS*Zeta[3])/12960) + (22443793*cA^2*Zeta[5])/3686400 + 
           (2466729*cA*cR*Zeta[5])/51200 + (133323*cR^2*Zeta[5])/4096 + 
           (161*cA^2*lmmOS*Zeta[5])/3200 + (161*cA^2*lmuH*Zeta[5])/1600 - 
           (1705*cA*nh*Zeta[5])/16384 - (1705*cR*nh*Zeta[5])/512 + 
           nl*((-284297917*cA)/1399680000 - (112498639*cR)/116640000 - 
             (668827*cA*lmmOS)/9331200 - (852601*cR*lmmOS)/864000 - 
             (3181*cA*lmmOS^2)/3110400 - (7717*cR*lmmOS^2)/518400 + 
             (593*cA*lmmOS^3)/155520 - (4811*cR*lmmOS^3)/103680 - 
             (7*cA*lmmOS^4)/6912 - (49*cA*lmmOS^5)/691200 - 
             (21559*cA*lmuH)/186624 - (53771*cR*lmuH)/155520 - 
             (4181*cA*lmmOS*lmuH)/155520 - (1403*cR*lmmOS*lmuH)/25920 + 
             (209*cA*lmmOS^2*lmuH)/103680 - (19*cR*lmmOS^2*lmuH)/17280 - 
             (7*cA*lmmOS^3*lmuH)/12960 - (7*cA*lmmOS^4*lmuH)/23040 - 
             (685*cA*lmuH^2)/31104 - (1403*cR*lmuH^2)/25920 + 
             (209*cA*lmmOS*lmuH^2)/51840 - (19*cR*lmmOS*lmuH^2)/8640 + 
             (7*cA*lmmOS^2*lmuH^2)/8640 - (7*cA*lmmOS^3*lmuH^2)/17280 + 
             (209*cA*lmuH^3)/77760 - (19*cR*lmuH^3)/12960 + 
             (7*cA*lmmOS*lmuH^3)/2592 + (91*cA*lmuH^4)/51840 + 
             (7*cA*lmmOS*lmuH^4)/17280 + (7*cA*lmuH^5)/28800 - 
             (76591*cA*Pi^2)/18662400 - (260849*cR*Pi^2)/3110400 - 
             (571*cA*lmmOS*Pi^2)/311040 - (16699*cR*lmmOS*Pi^2)/207360 - 
             (49*cA*lmmOS^2*Pi^2)/34560 - (7*cR*lmmOS^2*Pi^2)/320 - 
             (7*cA*lmmOS^3*Pi^2)/82944 - (3121*cA*lmuH*Pi^2)/622080 + 
             (187*cR*lmuH*Pi^2)/103680 - (7*cA*lmmOS*lmuH*Pi^2)/2592 - 
             (7*cA*lmmOS^2*lmuH*Pi^2)/13824 - (7*cA*lmuH^2*Pi^2)/2592 - 
             (7*cA*lmmOS*lmuH^2*Pi^2)/6912 - (7*cA*lmuH^3*Pi^2)/10368 - 
             (11599*cA*Pi^4)/6220800 - (1043*cR*Pi^4)/155520 - 
             (217*cA*lmmOS*Pi^4)/921600 + (7*cR*lmmOS*Pi^4)/12960 - 
             (1099*cA*lmuH*Pi^4)/1382400 + (7*cR*lmuH*Pi^4)/6480 - 
             (1313*cA*Zeta[3])/4320 + (16147*cR*Zeta[3])/51840 - 
             (2093*cA*lmmOS*Zeta[3])/25920 + (203*cR*lmmOS*Zeta[3])/1440 - 
             (77*cA*lmmOS^2*Zeta[3])/34560 + (7*cR*lmmOS^2*Zeta[3])/480 - 
             (287*cA*lmuH*Zeta[3])/1440 + (203*cR*lmuH*Zeta[3])/720 - 
             (301*cA*lmmOS*lmuH*Zeta[3])/8640 + (7*cR*lmmOS*lmuH*Zeta[3])/
              120 - (413*cA*lmuH^2*Zeta[3])/8640 + (7*cR*lmuH^2*Zeta[3])/
              120 + (539*cA*Pi^2*Zeta[3])/69120 - (49*cR*Pi^2*Zeta[3])/8640 - 
             (2009*cA*Zeta[5])/28800 + (7*cR*Zeta[5])/60))))
 
LogFMS = api5^3*((62629597*cA^3)/3359232 - (10787*cA^2*cR)/864 + 
       (689*cA*cR^2)/96 - (51*cR^3)/16 + (1363*cA^3*lmmMS)/1152 - 
       (947*cA^2*cR*lmmMS)/288 + (33*cA*cR^2*lmmMS)/16 + 
       (77*cA^3*lmmMS^2)/192 - (121*cA^2*cR*lmmMS^2)/192 + 
       (373975*cA^3*lmuH)/93312 - (8375*cA^3*lmuH^2)/10368 - 
       (445*cA^3*lmuH^3)/1296 - (121*cA^3*lmuH^4)/3456 - (107*cA^2*nh)/864 + 
       (9299*cA*cR*nh)/6912 - (23*cR^2*nh)/96 - (55*cA^2*lmmMS*nh)/1152 - 
       (11*cA*cR*lmmMS*nh)/144 + (cA*nh^2)/54 + (113*cR*nh^2)/1728 + 
       ((-1331*cA^3)/5184 + (121*cA^2*nl)/1296 - (11*cA*nl^2)/1296)/ep^4 + 
       (165289*cA^3*Pi^2)/559872 + (3415*cA^3*lmuH*Pi^2)/7776 + 
       (85*cA^3*lmuH^2*Pi^2)/576 + (11*cA^3*lmuH^3*Pi^2)/864 - 
       (2477*cA^3*Pi^4)/311040 - (319*cA^3*lmuH*Pi^4)/17280 - 
       (11*cA^3*lmuH^2*Pi^4)/2880 - (193*cA^3*Pi^6)/204120 + 
       ((535*cA^3)/3888 - (121*cA^3*lmuH)/864 + 
         ((-37*cA)/1944 - (cA*lmuH)/216)*nl^2 + nl^3/648 - 
         (55*cA^3*Pi^2)/5184 + nl*((119*cA^2)/7776 - (cA*cR)/36 + 
           (11*cA^2*lmuH)/216 + (5*cA^2*Pi^2)/2592))/ep^3 - 
       (4*d44[pR1, pA1])/(3*NA) + (11*nh*d44[pR1, pR2])/(6*NA) - 
       (2571193*cA^3*Zeta[3])/248832 + (5105*cA^2*cR*Zeta[3])/512 - 
       (407*cA*cR^2*Zeta[3])/128 - (32*cA^3*lmuH*Zeta[3])/27 + 
       (cA^2*nh*Zeta[3])/768 - (115*cA*cR*nh*Zeta[3])/128 + 
       (13*cR^2*nh*Zeta[3])/64 - (7*cA*nh^2*Zeta[3])/256 - 
       (7*cR*nh^2*Zeta[3])/128 - (77*cA^3*Pi^2*Zeta[3])/576 - 
       (5*cA^3*lmuH*Pi^2*Zeta[3])/144 + (13*d44[pR1, pA1]*Zeta[3])/NA - 
       (4*nh*d44[pR1, pR2]*Zeta[3])/NA - (13*cA^3*Zeta[3]^2)/72 + 
       nl^2*((74795*cA)/104976 + (317*cR)/432 + (5*cA*lmmMS)/576 + 
         (cR*lmmMS)/72 - (cR*lmmMS^2)/24 + (14057*cA*lmuH)/46656 + 
         (13*cR*lmuH)/48 + (29*cA*lmuH^2)/1296 + (cR*lmuH^2)/48 - 
         (5*cA*lmuH^3)/648 - (cA*lmuH^4)/864 + (cA*Pi^2)/864 - 
         (5*cR*Pi^2)/864 + (5*cA*lmuH*Pi^2)/648 + (cA*lmuH^2*Pi^2)/432 + 
         (cA*Pi^4)/15552 - (cR*Pi^4)/6480 + (143*cA*Zeta[3])/486 - 
         (7*cR*Zeta[3])/12 + (2*cA*lmuH*Zeta[3])/27 - (cR*lmuH*Zeta[3])/6) + 
       ((8773*cA^3)/15552 + (1043*cA^3*lmuH)/2592 + (173*cA^3*Pi^2)/31104 - 
         (11*cA^3*lmuH*Pi^2)/864 - (11*cA^3*Pi^4)/12960 + 
         nl^2*((37*cA)/1296 + cR/72 + (5*cA*lmuH)/648 - (cA*Pi^2)/2592) - 
         (55*cA^3*Zeta[3])/864 + nl*((-497*cA^2)/1944 - (77*cA*cR)/1728 - 
           (167*cA^2*lmuH)/1296 - (cA*cR*lmuH)/48 + (13*cA^2*Pi^2)/7776 + 
           (cA^2*lmuH*Pi^2)/432 + (17*cA^2*Zeta[3])/432 - 
           (cA*cR*Zeta[3])/36))/ep^2 + (1111*cA^3*Zeta[5])/288 - 
       (cA^3*lmuH*Zeta[5])/4 + ((-48593*cA^3)/69984 - (245*cA^3*lmuH)/576 + 
         (6109*cA^3*Pi^2)/93312 + (67*cA^3*lmuH*Pi^2)/1296 - 
         (319*cA^3*Pi^4)/51840 - (11*cA^3*lmuH*Pi^4)/4320 + 
         (61*cA^3*Zeta[3])/288 - (11*cA^3*lmuH*Zeta[3])/144 - 
         (5*cA^3*Pi^2*Zeta[3])/432 + nl^2*((-269*cA)/279936 - (11*cR)/1728 + 
           (cA*lmuH)/648 + (5*cA*Pi^2)/7776 - (7*cA*Zeta[3])/648) + 
         nl*((30715*cA^2)/279936 + (1217*cA*cR)/5184 - cR^2/192 + 
           (209*cA^2*lmuH)/2592 + (55*cA*cR*lmuH)/576 - (599*cA^2*Pi^2)/
            46656 - (cA*cR*Pi^2)/576 - (5*cA^2*lmuH*Pi^2)/648 + 
           (41*cA^2*Pi^4)/25920 - (cA*cR*Pi^4)/2160 + (89*cA^2*Zeta[3])/
            1296 - (19*cA*cR*Zeta[3])/216 + (7*cA^2*lmuH*Zeta[3])/72 - 
           (cA*cR*lmuH*Zeta[3])/12) - (cA^3*Zeta[5])/12)/ep + 
       nl*((-15723499*cA^2)/1679616 - (221423*cA*cR)/62208 + (109*cR^2)/384 - 
         (55*cA^2*lmmMS)/576 + (65*cA*cR*lmmMS)/144 - (cR^2*lmmMS)/2 - 
         (7*cA^2*lmmMS^2)/96 + (11*cA*cR*lmmMS^2)/32 - (33259*cA^2*lmuH)/
          11664 - (3833*cA*cR*lmuH)/3456 + (cR^2*lmuH)/32 + 
         (215*cA^2*lmuH^2)/5184 + (11*cA*cR*lmuH^2)/384 + 
         (289*cA^2*lmuH^3)/2592 + (cA*cR*lmuH^3)/96 + (11*cA^2*lmuH^4)/864 + 
         (7*cA*nh)/864 - (29*cR*nh)/576 + (5*cA*lmmMS*nh)/576 + 
         (cR*lmmMS*nh)/72 - (5945*cA^2*Pi^2)/279936 + (65*cA*cR*Pi^2)/6912 - 
         (229*cA^2*lmuH*Pi^2)/1944 - (cA*cR*lmuH*Pi^2)/96 - 
         (cA^2*lmuH^2*Pi^2)/27 - (cA^2*lmuH^3*Pi^2)/432 + 
         (37*cA^2*Pi^4)/25920 - (cA*cR*Pi^4)/1620 + (41*cA^2*lmuH*Pi^4)/
          8640 - (cA*cR*lmuH*Pi^4)/720 + (11*d44[pR1, pR2])/(3*NA) - 
         (15911*cA^2*Zeta[3])/41472 + (27341*cA*cR*Zeta[3])/20736 + 
         (141*cR^2*Zeta[3])/64 - (7*cA^2*lmuH*Zeta[3])/144 + 
         (47*cA*cR*lmuH*Zeta[3])/72 + (cA^2*lmuH^2*Zeta[3])/8 - 
         (cA*cR*lmuH^2*Zeta[3])/8 - (7*cA*nh*Zeta[3])/256 - 
         (7*cR*nh*Zeta[3])/128 - (cA^2*Pi^2*Zeta[3])/96 + 
         (5*cA*cR*Pi^2*Zeta[3])/144 - (8*d44[pR1, pR2]*Zeta[3])/NA + 
         (107*cA^2*Zeta[5])/144 + (19*cA*cR*Zeta[5])/18 - 
         (5*cR^2*Zeta[5])/2) + rhoMS^2*((931525286210119*cA^3)/
          13390585528320000 - (45063508177203349*cA^2*cR)/5021469573120000 - 
         (27883219291671377*cA*cR^2)/2008587829248000 + (40107612288631*cR^3)/
          9299017728000 - (862523231*cA^3*lmmMS)/7962624000 - 
         (11816578601*cA^2*cR*lmmMS)/12192768000 + (617411851*cA*cR^2*lmmMS)/
          1990656000 + (19769287*cR^3*lmmMS)/7741440 - (24557*cA^3*lmmMS^2)/
          6220800 + (140039*cA^2*cR*lmmMS^2)/87091200 + 
         (84547*cA*cR^2*lmmMS^2)/2150400 - (17791*cR^3*lmmMS^2)/537600 - 
         (103697*cA^2*cR*lmmMS^3)/29030400 + (9427*cA*cR^2*lmmMS^3)/537600 - 
         (857*cR^3*lmmMS^3)/44800 + (557951*cA^3*lmuH)/2709504000 - 
         (163*cA^2*cR*lmuH)/226800 + (271*cA^3*lmmMS*lmuH)/806400 - 
         (29*cA^2*cR*lmmMS*lmuH)/44800 + (cA^3*lmuH^2)/33600 + 
         (279660447817170163*cA^2*nh)/2227122185070182400 + 
         (11990483865206543*cA*cR*nh)/44188932243456000 - 
         (26531808073039*cR^2*nh)/23176013414400 + (9131021771*cA^2*lmmMS*nh)/
          2341011456000 - (38073735379*cA*cR*lmmMS*nh)/1170505728000 + 
         (8495303*cR^2*lmmMS*nh)/309657600 + (13*cA^2*lmmMS^2*nh)/193536 - 
         (4309*cA*cR*lmmMS^2*nh)/1075200 + (8641*cR^2*lmmMS^2*nh)/2419200 - 
         (9427*cA*cR*lmmMS^3*nh)/14515200 + (857*cR^2*lmmMS^3*nh)/268800 - 
         (1079069*cA^2*lmuH*nh)/406425600 + (26779*cA*cR*lmuH*nh)/1451520 - 
         (17*cR^2*lmuH*nh)/51840 + (37*cA^2*lmmMS*lmuH*nh)/161280 + 
         (cA*cR*lmmMS*lmuH*nh)/1680 - (cR^2*lmmMS*lmuH*nh)/160 - 
         (41*cA^2*lmuH^2*nh)/138240 + (11*cA*cR*lmuH^2*nh)/5760 - 
         (1567460838089*cA*nh^2)/430411677696000 + (13335219901*cR*nh^2)/
          331085905920 - (cA*lmmMS*nh^2)/345600 + (857*cR*lmmMS*nh^2)/
          2488320 + (857*cR*lmmMS^2*nh^2)/2903040 - (857*cR*lmmMS^3*nh^2)/
          7257600 + (cA*lmuH*nh^2)/345600 + (101*cA^3*Pi^2)/38707200 - 
         (7*cA^2*nh*Pi^2)/138240 - (3097193206561*cA^3*Pi^4)/23187161088000 - 
         (18594877561501*cA^2*cR*Pi^4)/127529385984000 + 
         (5413273815283*cA*cR^2*Pi^4)/7970586624000 + (81726768113*cR^3*Pi^4)/
          531372441600 - (120805964623*cA^2*nh*Pi^4)/19619905536000 + 
         (355859762309*cA*cR*nh*Pi^4)/4904976384000 + 
         (3912568463*cR^2*nh*Pi^4)/13934592000 + 
         (3165526496521*d44[pR1, pA1])/(1162377216000*NA) - 
         (19*lmmMS*d44[pR1, pA1])/(13824*NA) + (19*lmuH*d44[pR1, pA1])/
          (13824*NA) - (300156346307*Pi^4*d44[pR1, pA1])/(1328431104000*NA) + 
         (324710282317*nh*d44[pR1, pR2])/(929901772800*NA) - 
         (1725431*nh*Pi^4*d44[pR1, pR2])/(123863040*NA) - 
         (23618467*cA^3*Pi^4*Log[2])/323481600 + 
         (5457286201*cA^2*cR*Pi^4*Log[2])/20756736000 - 
         (369704849*cA*cR^2*Pi^4*Log[2])/1729728000 + 
         (1373543*cR^3*Pi^4*Log[2])/61776000 - (485097181*Pi^4*d44[pR1, pA1]*
           Log[2])/(1297296000*NA) - (80826668141*cA^3*Pi^2*Log[2]^2)/
          193226342400 - (667545197749*cA^2*cR*Pi^2*Log[2]^2)/1062744883200 + 
         (1072275163*cA*cR^2*Pi^2*Log[2]^2)/415134720 + 
         (17446423297*cR^3*Pi^2*Log[2]^2)/22140518400 - 
         (3592767901*cA^2*nh*Pi^2*Log[2]^2)/163499212800 + 
         (1490495093*cA*cR*nh*Pi^2*Log[2]^2)/5839257600 + 
         (229775263*cR^2*nh*Pi^2*Log[2]^2)/232243200 - 
         (350426957*Pi^2*d44[pR1, pA1]*Log[2]^2)/(615014400*NA) - 
         (968179*nh*Pi^2*d44[pR1, pR2]*Log[2]^2)/(25804800*NA) - 
         (6212767*cA^3*Pi^2*Log[2]^3)/56609280 + 
         (191437759*cA^2*cR*Pi^2*Log[2]^3)/518918400 - 
         (1163557*cA*cR^2*Pi^2*Log[2]^3)/5405400 - (14111*cR^3*Pi^2*Log[2]^3)/
          193050 - (9152777*Pi^2*d44[pR1, pA1]*Log[2]^3)/(16216200*NA) + 
         (80826668141*cA^3*Log[2]^4)/193226342400 + 
         (667545197749*cA^2*cR*Log[2]^4)/1062744883200 - 
         (1072275163*cA*cR^2*Log[2]^4)/415134720 - 
         (17446423297*cR^3*Log[2]^4)/22140518400 + 
         (3592767901*cA^2*nh*Log[2]^4)/163499212800 - 
         (1490495093*cA*cR*nh*Log[2]^4)/5839257600 - 
         (229775263*cR^2*nh*Log[2]^4)/232243200 + 
         (350426957*d44[pR1, pA1]*Log[2]^4)/(615014400*NA) + 
         (968179*nh*d44[pR1, pR2]*Log[2]^4)/(25804800*NA) + 
         (6212767*cA^3*Log[2]^5)/94348800 - (191437759*cA^2*cR*Log[2]^5)/
          864864000 + (1163557*cA*cR^2*Log[2]^5)/9009000 + 
         (14111*cR^3*Log[2]^5)/321750 + (9152777*d44[pR1, pA1]*Log[2]^5)/
          (27027000*NA) + (80826668141*cA^3*PolyLog[4, 1/2])/8051097600 + 
         (667545197749*cA^2*cR*PolyLog[4, 1/2])/44281036800 - 
         (1072275163*cA*cR^2*PolyLog[4, 1/2])/17297280 - 
         (17446423297*cR^3*PolyLog[4, 1/2])/922521600 + 
         (3592767901*cA^2*nh*PolyLog[4, 1/2])/6812467200 - 
         (1490495093*cA*cR*nh*PolyLog[4, 1/2])/243302400 - 
         (229775263*cR^2*nh*PolyLog[4, 1/2])/9676800 + 
         (350426957*d44[pR1, pA1]*PolyLog[4, 1/2])/(25625600*NA) + 
         (968179*nh*d44[pR1, pR2]*PolyLog[4, 1/2])/(1075200*NA) - 
         (6212767*cA^3*PolyLog[5, 1/2])/786240 + 
         (191437759*cA^2*cR*PolyLog[5, 1/2])/7207200 - 
         (1163557*cA*cR^2*PolyLog[5, 1/2])/75075 - 
         (56444*cR^3*PolyLog[5, 1/2])/10725 - (9152777*d44[pR1, pA1]*
           PolyLog[5, 1/2])/(225225*NA) + (15347420321246009*cA^3*Zeta[3])/
          1785411403776000 + (6013862666317*cA^2*cR*Zeta[3])/375717888000 - 
         (1389685544244317*cA*cR^2*Zeta[3])/49594761216000 - 
         (1879349798173*cR^3*Zeta[3])/158957568000 + 
         (1212761*cA^3*lmmMS*Zeta[3])/14155776 + 
         (62189537*cA^2*cR*lmmMS*Zeta[3])/77414400 - 
         (9004973*cA*cR^2*lmmMS*Zeta[3])/41287680 - 
         (6220579*cR^3*lmmMS*Zeta[3])/2867200 + 
         (3246617496176063*cA^2*nh*Zeta[3])/13093016961024000 - 
         (2859924692169107*cA*cR*nh*Zeta[3])/654650848051200 - 
         (8743738864723*cR^2*nh*Zeta[3])/572247244800 - 
         (177947*cA^2*lmmMS*nh*Zeta[3])/141557760 + 
         (23883203*cA*cR*lmmMS*nh*Zeta[3])/825753600 - 
         (2745949*cR^2*lmmMS*nh*Zeta[3])/68812800 + 
         (2148537701*cA*nh^2*Zeta[3])/708496588800 - 
         (274506823*cR*nh^2*Zeta[3])/8174960640 + 
         (33464929535239*d44[pR1, pA1]*Zeta[3])/(2324754432000*NA) + 
         (1109196184493*nh*d44[pR1, pR2]*Zeta[3])/(1859803545600*NA) + 
         nl^2*((-1989409217*cA)/1097349120000 - (106407031*cR)/320060160000 - 
           (1571*cA*lmmMS)/7776000 - (1362157*cR*lmmMS)/1143072000 - 
           (623*cA*lmmMS^2)/12441600 - (1069*cR*lmmMS^2)/10886400 - 
           (857*cR*lmmMS^3)/7257600 - (577*cA*lmuH)/907200 - 
           (1253*cR*lmuH)/1866240 - (5951*cA*lmuH^2)/87091200 - 
           (1667*cR*lmuH^2)/21772800 + (5951*cA*Pi^2)/522547200 + 
           (1667*cR*Pi^2)/130636800 - (137*cA*Zeta[3])/967680 - 
           (9943*cR*Zeta[3])/7257600) + nl*((54807884540179*cA^2)/
            421382062080000 + (351419454288613*cA*cR)/491612405760000 + 
           (78734580216493*cR^2)/61451550720000 + (261500519*cA^2*lmmMS)/
            11943936000 + (61962899893*cA*cR*lmmMS)/292626432000 + 
           (990908671*cR^2*lmmMS)/3657830400 + (43079*cA^2*lmmMS^2)/
            49766400 + (587617*cA*cR*lmmMS^2)/348364800 - 
           (113303*cR^2*lmmMS^2)/24883200 + (9427*cA*cR*lmmMS^3)/7257600 - 
           (857*cR^2*lmmMS^3)/268800 + (49595513*cA^2*lmuH)/18289152000 + 
           (1605983*cA*cR*lmuH)/5225472000 - (22512781*cR^2*lmuH)/
            36578304000 + (33781*cA^2*lmmMS*lmuH)/174182400 - 
           (13877*cA*cR*lmmMS*lmuH)/34836480 - (93847*cR^2*lmmMS*lmuH)/
            87091200 + (84613*cA^2*lmuH^2)/348364800 + (41*cA*cR*lmuH^2)/
            7741440 - (26177*cR^2*lmuH^2)/174182400 - (731731430573*cA*nh)/
            491612405760000 + (48062680489*cR*nh)/7023034368000 - 
           (447198721*cA*lmmMS*nh)/1170505728000 + (1940237*cR*lmmMS*nh)/
            334430208 - (cA*lmmMS^2*nh)/30240 + (cR*lmmMS^2*nh)/2880 + 
           (857*cR*lmmMS^3*nh)/7257600 + (1807*cA*lmuH*nh)/11612160 - 
           (739*cR*lmuH*nh)/290304 + (cA*lmuH^2*nh)/30240 - 
           (cR*lmuH^2*nh)/2880 - (84937*cA^2*Pi^2)/1045094400 + 
           (5473*cA*cR*Pi^2)/116121600 + (26177*cR^2*Pi^2)/522547200 + 
           (33966659*cA^2*Pi^4)/222953472000 + (71436409*cA*cR*Pi^4)/
            12386304000 + (36958261*cR^2*Pi^4)/4644864000 - 
           (113239*cA*nh*Pi^4)/12740198400 + (153811*cR*nh*Pi^4)/1061683200 + 
           (4956899*d44[pR1, pR2])/(9797760*NA) - (1271*Pi^4*d44[pR1, pR2])/
            (81000*NA) + (1211*cA^2*Pi^2*Log[2]^2)/17694720 + 
           (72283*cA*cR*Pi^2*Log[2]^2)/309657600 - (28667*cR^2*Pi^2*Log[2]^2)/
            38707200 - (2311*cA*nh*Pi^2*Log[2]^2)/106168320 + 
           (3139*cR*nh*Pi^2*Log[2]^2)/8847360 - (1211*cA^2*Log[2]^4)/
            17694720 - (72283*cA*cR*Log[2]^4)/309657600 + 
           (28667*cR^2*Log[2]^4)/38707200 + (2311*cA*nh*Log[2]^4)/106168320 - 
           (3139*cR*nh*Log[2]^4)/8847360 - (1211*cA^2*PolyLog[4, 1/2])/
            737280 - (72283*cA*cR*PolyLog[4, 1/2])/12902400 + 
           (28667*cR^2*PolyLog[4, 1/2])/1612800 + 
           (2311*cA*nh*PolyLog[4, 1/2])/4423680 - 
           (3139*cR*nh*PolyLog[4, 1/2])/368640 - (259770031*cA^2*Zeta[3])/
            2378170368 - (31366231093*cA*cR*Zeta[3])/29727129600 - 
           (6377613101*cR^2*Zeta[3])/3715891200 - (110251*cA^2*lmmMS*Zeta[3])/
            7077888 - (102294391*cA*cR*lmmMS*Zeta[3])/619315200 - 
           (6385123*cR^2*lmmMS*Zeta[3])/25804800 + (8146879*cA*nh*Zeta[3])/
            4246732800 - (279589459*cR*nh*Zeta[3])/14863564800 + 
           (16177*cA*lmmMS*nh*Zeta[3])/70778880 - (21973*cR*lmmMS*nh*Zeta[3])/
            5898240 + (16013*d44[pR1, pR2]*Zeta[3])/(18900*NA)) + 
         (39770717*cA^3*Zeta[5])/4792320 - (3310798133*cA^2*cR*Zeta[5])/
          102502400 + (789352007*cA*cR^2*Zeta[5])/32947200 + 
         (286705103*cR^3*Zeta[5])/115315200 - (1693*cA*cR*nh*Zeta[5])/40320 + 
         (836718319*d44[pR1, pA1]*Zeta[5])/(19219200*NA)) + 
       rhoMS*((-63634073593*cA^3)/45984153600 - (35009957249*cA^2*cR)/
          3832012800 - (28073563*cA*cR^2)/91238400 + (125086079*cR^3)/
          19353600 - (1189273*cA^3*lmmMS)/1105920 - (211206481*cA^2*cR*lmmMS)/
          49766400 - (67493*cA*cR^2*lmmMS)/276480 + (36369*cR^3*lmmMS)/
          10240 - (1759*cA^3*lmmMS^2)/51840 + (4307*cA^2*cR*lmmMS^2)/103680 + 
         (341*cA*cR^2*lmmMS^2)/3840 - (23*cR^3*lmmMS^2)/320 - 
         (847*cA^2*cR*lmmMS^3)/34560 + (77*cA*cR^2*lmmMS^3)/1280 - 
         (21*cR^3*lmmMS^3)/640 - (14923*cA^3*lmuH)/691200 - 
         (7*cA^2*cR*lmuH)/1920 - (3*cA^3*lmmMS*lmuH)/320 + 
         (3*cA^2*cR*lmmMS*lmuH)/320 - (cA^3*lmuH^2)/960 + 
         (46164184187*cA^2*nh)/263363788800 + (286362225773*cA*cR*nh)/
          1448500838400 - (8496599*cR^2*nh)/5806080 - (93407*cA^2*lmmMS*nh)/
          9953280 - (6105127*cA*cR*lmmMS*nh)/49766400 + (1189*cR^2*lmmMS*nh)/
          8640 + (cA^2*lmmMS^2*nh)/288 - (163*cA*cR*lmmMS^2*nh)/11520 - 
         (11*cR^2*lmmMS^2*nh)/2304 - (77*cA*cR*lmmMS^3*nh)/17280 + 
         (7*cR^2*lmmMS^3*nh)/640 - (551*cA^2*lmuH*nh)/115200 - 
         (cA*cR*lmuH*nh)/360 - (cA^2*lmmMS*lmuH*nh)/320 + 
         (cA*cR*lmmMS*lmuH*nh)/320 - (cA^2*lmuH^2*nh)/2880 - 
         (7456979*cA*nh^2)/627056640 + (427909*cR*nh^2)/3919104 + 
         (49*cR*lmmMS*nh^2)/20736 + (7*cR*lmmMS^2*nh^2)/3456 - 
         (7*cR*lmmMS^3*nh^2)/8640 - (cA^3*Pi^2)/11520 + (cA^2*nh*Pi^2)/1440 + 
         (9152173421*cA^3*Pi^4)/30656102400 + (130209091*cA^2*cR*Pi^4)/
          5109350400 - (517529449*cA*cR^2*Pi^4)/425779200 + 
         (6250669*cR^3*Pi^4)/58060800 - (21382733*cA^2*nh*Pi^4)/1393459200 + 
         (17015771*cA*cR*nh*Pi^4)/696729600 + (94099*cR^2*nh*Pi^4)/518400 - 
         (34050439*d44[pR1, pA1])/(13305600*NA) + 
         (76339381*Pi^4*d44[pR1, pA1])/(63866880*NA) + 
         (22518469*nh*d44[pR1, pR2])/(15966720*NA) + 
         (1489*nh*Pi^4*d44[pR1, pR2])/(17280*NA) - (682603*cA^3*Pi^4*Log[2])/
          15966720 + (1826267*cA^2*cR*Pi^4*Log[2])/4435200 + 
         (525419*cA*cR^2*Pi^4*Log[2])/3326400 - (7249*cR^3*Pi^4*Log[2])/
          5040 - (911441*Pi^4*d44[pR1, pA1]*Log[2])/(831600*NA) + 
         (292864841*cA^3*Pi^2*Log[2]^2)/255467520 - 
         (680095*cA^2*cR*Pi^2*Log[2]^2)/8515584 - 
         (1495453*cA*cR^2*Pi^2*Log[2]^2)/295680 + (197917*cR^3*Pi^2*Log[2]^2)/
          483840 - (1211281*cA^2*nh*Pi^2*Log[2]^2)/23224320 + 
         (115369*cA*cR*nh*Pi^2*Log[2]^2)/1161216 + 
         (5459*cR^2*nh*Pi^2*Log[2]^2)/8640 + (2729191*Pi^2*d44[pR1, pA1]*
           Log[2]^2)/(532224*NA) + (151*nh*Pi^2*d44[pR1, pR2]*Log[2]^2)/
          (360*NA) - (30505*cA^3*Pi^2*Log[2]^3)/399168 + 
         (49673*cA^2*cR*Pi^2*Log[2]^3)/110880 + (9239*cA*cR^2*Pi^2*Log[2]^3)/
          20790 - (113*cR^3*Pi^2*Log[2]^3)/63 - 
         (17197*Pi^2*d44[pR1, pA1]*Log[2]^3)/(10395*NA) - 
         (292864841*cA^3*Log[2]^4)/255467520 + (680095*cA^2*cR*Log[2]^4)/
          8515584 + (1495453*cA*cR^2*Log[2]^4)/295680 - 
         (197917*cR^3*Log[2]^4)/483840 + (1211281*cA^2*nh*Log[2]^4)/
          23224320 - (115369*cA*cR*nh*Log[2]^4)/1161216 - 
         (5459*cR^2*nh*Log[2]^4)/8640 - (2729191*d44[pR1, pA1]*Log[2]^4)/
          (532224*NA) - (151*nh*d44[pR1, pR2]*Log[2]^4)/(360*NA) + 
         (6101*cA^3*Log[2]^5)/133056 - (49673*cA^2*cR*Log[2]^5)/184800 - 
         (9239*cA*cR^2*Log[2]^5)/34650 + (113*cR^3*Log[2]^5)/105 + 
         (17197*d44[pR1, pA1]*Log[2]^5)/(17325*NA) - 
         (292864841*cA^3*PolyLog[4, 1/2])/10644480 + 
         (680095*cA^2*cR*PolyLog[4, 1/2])/354816 + 
         (1495453*cA*cR^2*PolyLog[4, 1/2])/12320 - 
         (197917*cR^3*PolyLog[4, 1/2])/20160 + 
         (1211281*cA^2*nh*PolyLog[4, 1/2])/967680 - 
         (115369*cA*cR*nh*PolyLog[4, 1/2])/48384 - 
         (5459*cR^2*nh*PolyLog[4, 1/2])/360 - (2729191*d44[pR1, pA1]*
           PolyLog[4, 1/2])/(22176*NA) - (151*nh*d44[pR1, pR2]*
           PolyLog[4, 1/2])/(15*NA) - (30505*cA^3*PolyLog[5, 1/2])/5544 + 
         (49673*cA^2*cR*PolyLog[5, 1/2])/1540 + 
         (36956*cA*cR^2*PolyLog[5, 1/2])/1155 - (904*cR^3*PolyLog[5, 1/2])/
          7 - (137576*d44[pR1, pA1]*PolyLog[5, 1/2])/(1155*NA) - 
         (9898132063*cA^3*Zeta[3])/681246720 + (317178703*cA^2*cR*Zeta[3])/
          77414400 + (433768091*cA*cR^2*Zeta[3])/5529600 - 
         (56006411*cR^3*Zeta[3])/4300800 + (128953*cA^3*lmmMS*Zeta[3])/
          147456 + (284849*cA^2*cR*lmmMS*Zeta[3])/81920 + 
         (70801*cA*cR^2*lmmMS*Zeta[3])/184320 - (63917*cR^3*lmmMS*Zeta[3])/
          20480 + (4761740101*cA^2*nh*Zeta[3])/6502809600 - 
         (2281478237*cA*cR*nh*Zeta[3])/1324646400 - 
         (35730047*cR^2*nh*Zeta[3])/3870720 + (847*cA^2*lmmMS*nh*Zeta[3])/
          147456 + (164311*cA*cR*lmmMS*nh*Zeta[3])/737280 - 
         (497*cR^2*lmmMS*nh*Zeta[3])/2560 + (48323*cA*nh^2*Zeta[3])/5160960 - 
         (5497*cR*nh^2*Zeta[3])/64512 - (1075459339*d44[pR1, pA1]*Zeta[3])/
          (17740800*NA) - (56867891*nh*d44[pR1, pR2]*Zeta[3])/(10644480*NA) + 
         nl^2*((-5706901*cA)/186624000 - (233767*cR)/46656000 - 
           (91*cA*lmmMS)/86400 - (287*cR*lmmMS)/21600 - (31*cA*lmmMS^2)/
            103680 + (13*cR*lmmMS^2)/8640 - (7*cR*lmmMS^3)/8640 - 
           (197*cA*lmuH)/17280 - (127*cR*lmuH)/15552 - (121*cA*lmuH^2)/
            103680 - (11*cR*lmuH^2)/12960 + (121*cA*Pi^2)/622080 + 
           (11*cR*Pi^2)/77760 - (11*cA*Zeta[3])/5760 - (13*cR*Zeta[3])/
            1728) + nl*((217258903*cA^2)/1492992000 + (1096549*cA*cR)/
            8294400 + (285396343*cR^2)/373248000 + (5607103*cA^2*lmmMS)/
            24883200 + (3118003*cA*cR*lmmMS)/3110400 + (4681781*cR^2*lmmMS)/
            6220800 + (2263*cA^2*lmmMS^2)/414720 - (71*cA*cR*lmmMS^2)/8640 - 
           (167*cR^2*lmmMS^2)/103680 + (77*cA*cR*lmmMS^3)/8640 - 
           (7*cR^2*lmmMS^3)/640 + (145579*cA^2*lmuH)/3110400 + 
           (7079*cA*cR*lmuH)/3110400 - (1339*cR^2*lmuH)/194400 + 
           (1331*cA^2*lmmMS*lmuH)/207360 - (121*cA*cR*lmmMS*lmuH)/103680 - 
           (11*cR^2*lmmMS*lmuH)/2592 + (1763*cA^2*lmuH^2)/414720 - 
           (11*cR^2*lmuH^2)/6480 - (2084813*cA*nh)/93312000 + 
           (54307*cR*nh)/2332800 + (61217*cA*lmmMS*nh)/24883200 + 
           (10609*cR*lmmMS*nh)/311040 - (cA*lmmMS^2*nh)/2880 + 
           (7*cR*lmmMS^3*nh)/8640 + (cA*lmuH*nh)/8640 - (cR*lmuH*nh)/540 + 
           (cA*lmuH^2*nh)/2880 - (1547*cA^2*Pi^2)/1244160 + 
           (11*cA*cR*Pi^2)/17280 + (11*cR^2*Pi^2)/19440 + (255553*cA^2*Pi^4)/
            66355200 + (70667*cA*cR*Pi^4)/2764800 + (377083*cR^2*Pi^4)/
            16588800 + (539*cA*nh*Pi^4)/13271040 + (539*cR*nh*Pi^4)/414720 + 
           (1079*d44[pR1, pR2])/(480*NA) - (17*Pi^4*d44[pR1, pR2])/(270*NA) + 
           (157*cA^2*Pi^2*Log[2]^2)/110592 - (37*cA*cR*Pi^2*Log[2]^2)/23040 - 
           (341*cR^2*Pi^2*Log[2]^2)/138240 + (11*cA*nh*Pi^2*Log[2]^2)/
            110592 + (11*cR*nh*Pi^2*Log[2]^2)/3456 - (157*cA^2*Log[2]^4)/
            110592 + (37*cA*cR*Log[2]^4)/23040 + (341*cR^2*Log[2]^4)/138240 - 
           (11*cA*nh*Log[2]^4)/110592 - (11*cR*nh*Log[2]^4)/3456 - 
           (157*cA^2*PolyLog[4, 1/2])/4608 + (37*cA*cR*PolyLog[4, 1/2])/960 + 
           (341*cR^2*PolyLog[4, 1/2])/5760 - (11*cA*nh*PolyLog[4, 1/2])/
            4608 - (11*cR*nh*PolyLog[4, 1/2])/144 - (397837*cA^2*Zeta[3])/
            1474560 - (2460851*cA*cR*Zeta[3])/1105920 - 
           (2703347*cR^2*Zeta[3])/1105920 - (11723*cA^2*lmmMS*Zeta[3])/
            73728 - (3679*cA*cR*lmmMS*Zeta[3])/5120 - 
           (67949*cR^2*lmmMS*Zeta[3])/92160 + (5747*cA*nh*Zeta[3])/552960 - 
           (2443*cR*nh*Zeta[3])/23040 - (77*cA*lmmMS*nh*Zeta[3])/73728 - 
           (77*cR*lmmMS*nh*Zeta[3])/2304 + (287*d44[pR1, pR2]*Zeta[3])/
            (90*NA)) + (3272351*cA^3*Zeta[5])/709632 - 
         (25543237*cA^2*cR*Zeta[5])/591360 - (6266833*cA*cR^2*Zeta[5])/
          147840 + (221161*cR^3*Zeta[5])/1344 + (cA*cR*nh*Zeta[5])/4 + 
         (4961977*d44[pR1, pA1]*Zeta[5])/(36960*NA))) + 
     api5*((5*cA)/4 - (3*cR)/4 - cA/(2*ep^2) - (cA*lmuH^2)/4 + 
       ((-11*cA)/12 - (cA*lmuH)/2 + nl/6)/ep + (cA*Pi^2)/24 + 
       ep*((-11*cA)/6 + (13*cR)/8 + (5*cA*lmmMS)/4 - (9*cR*lmmMS)/4 - 
         (cA*lmuH^3)/12 + (cA*lmuH*Pi^2)/24 + (7*cA*Zeta[3])/6) + 
       ep^2*((8*cA)/9 - (35*cR)/16 - (4*cA*lmmMS)/3 + (13*cR*lmmMS)/8 + 
         (5*cA*lmmMS^2)/8 - (9*cR*lmmMS^2)/8 - (cA*lmuH)/2 - (cA*lmuH^4)/48 + 
         (5*cA*Pi^2)/48 - (3*cR*Pi^2)/16 + (cA*lmuH^2*Pi^2)/48 + 
         (47*cA*Pi^4)/2880 + (7*cA*lmuH*Zeta[3])/6) + 
       ep^3*((-901*cA)/108 + (157*cR)/32 + (43*cA*lmmMS)/18 - 
         (35*cR*lmmMS)/16 - (2*cA*lmmMS^2)/3 + (13*cR*lmmMS^2)/16 + 
         (5*cA*lmmMS^3)/24 - (3*cR*lmmMS^3)/8 - (3*cA*lmuH)/2 - 
         (cA*lmuH^2)/4 - (cA*lmuH^5)/240 - (5*cA*Pi^2)/72 + (13*cR*Pi^2)/96 + 
         (5*cA*lmmMS*Pi^2)/48 - (3*cR*lmmMS*Pi^2)/16 + (cA*lmuH^3*Pi^2)/144 + 
         (47*cA*lmuH*Pi^4)/2880 - (5*cA*Zeta[3])/12 + (3*cR*Zeta[3])/4 + 
         (7*cA*lmuH^2*Zeta[3])/12 - (7*cA*Pi^2*Zeta[3])/72 + 
         (31*cA*Zeta[5])/10) + ep^4*((1363*cA)/648 - (611*cR)/64 - 
         (523*cA*lmmMS)/108 + (157*cR*lmmMS)/32 + (43*cA*lmmMS^2)/36 - 
         (35*cR*lmmMS^2)/32 - (2*cA*lmmMS^3)/9 + (13*cR*lmmMS^3)/48 + 
         (5*cA*lmmMS^4)/96 - (3*cR*lmmMS^4)/32 - (7*cA*lmuH)/2 - 
         (3*cA*lmuH^2)/4 - (cA*lmuH^3)/12 - (cA*lmuH^6)/1440 + 
         (35*cA*Pi^2)/108 - (35*cR*Pi^2)/192 - (cA*lmmMS*Pi^2)/9 + 
         (13*cR*lmmMS*Pi^2)/96 + (5*cA*lmmMS^2*Pi^2)/96 - 
         (3*cR*lmmMS^2*Pi^2)/32 + (cA*lmuH*Pi^2)/24 + (cA*lmuH^4*Pi^2)/576 + 
         (cA*Pi^4)/128 - (9*cR*Pi^4)/640 + (47*cA*lmuH^2*Pi^4)/5760 + 
         (949*cA*Pi^6)/241920 + (29*cA*Zeta[3])/18 - (13*cR*Zeta[3])/24 - 
         (5*cA*lmmMS*Zeta[3])/12 + (3*cR*lmmMS*Zeta[3])/4 + 
         (7*cA*lmuH^3*Zeta[3])/36 - (7*cA*lmuH*Pi^2*Zeta[3])/72 - 
         (49*cA*Zeta[3]^2)/36 + (31*cA*lmuH*Zeta[5])/10) + 
       rhoMS^2*((-1289*cA)/302400 + (1049*cR)/241920 - (857*cR*lmmMS)/67200 + 
         ep*((213757*cA)/127008000 - (378817*cR)/36288000 - 
           (1289*cA*lmmMS)/302400 - (14807*cR*lmmMS)/1209600 - 
           (857*cR*lmmMS^2)/134400 - (857*cR*Pi^2)/806400) + 
         ep^2*((-7931297*cA)/2963520000 - (21653*cR)/1920000 + 
           (213757*cA*lmmMS)/127008000 - (517597*cR*lmmMS)/36288000 - 
           (1289*cA*lmmMS^2)/604800 - (14807*cR*lmmMS^2)/2419200 - 
           (857*cR*lmmMS^3)/403200 - (1289*cA*Pi^2)/3628800 - 
           (14807*cR*Pi^2)/14515200 - (857*cR*lmmMS*Pi^2)/806400 + 
           (857*cR*Zeta[3])/201600) + ep^3*((26541781157*cA)/5601052800000 - 
           (314038463*cR)/32659200000 - (7931297*cA*lmmMS)/2963520000 - 
           (21653*cR*lmmMS)/1920000 + (213757*cA*lmmMS^2)/254016000 - 
           (517597*cR*lmmMS^2)/72576000 - (1289*cA*lmmMS^3)/1814400 - 
           (14807*cR*lmmMS^3)/7257600 - (857*cR*lmmMS^4)/1612800 + 
           (213757*cA*Pi^2)/1524096000 - (517597*cR*Pi^2)/435456000 - 
           (1289*cA*lmmMS*Pi^2)/3628800 - (14807*cR*lmmMS*Pi^2)/14515200 - 
           (857*cR*lmmMS^2*Pi^2)/1612800 - (857*cR*Pi^4)/10752000 + 
           (1289*cA*Zeta[3])/907200 + (14807*cR*Zeta[3])/3628800 + 
           (857*cR*lmmMS*Zeta[3])/201600) + 
         ep^4*((-17343922860563*cA)/1176221088000000 + (3050833139*cR)/
            244944000000 + (26541781157*cA*lmmMS)/5601052800000 - 
           (314038463*cR*lmmMS)/32659200000 - (7931297*cA*lmmMS^2)/
            5927040000 - (21653*cR*lmmMS^2)/3840000 + (213757*cA*lmmMS^3)/
            762048000 - (517597*cR*lmmMS^3)/217728000 - (1289*cA*lmmMS^4)/
            7257600 - (14807*cR*lmmMS^4)/29030400 - (857*cR*lmmMS^5)/
            8064000 - (7931297*cA*Pi^2)/35562240000 - (21653*cR*Pi^2)/
            23040000 + (213757*cA*lmmMS*Pi^2)/1524096000 - 
           (517597*cR*lmmMS*Pi^2)/435456000 - (1289*cA*lmmMS^2*Pi^2)/
            7257600 - (14807*cR*lmmMS^2*Pi^2)/29030400 - 
           (857*cR*lmmMS^3*Pi^2)/4838400 - (1289*cA*Pi^4)/48384000 - 
           (14807*cR*Pi^4)/193536000 - (857*cR*lmmMS*Pi^4)/10752000 - 
           (213757*cA*Zeta[3])/381024000 + (517597*cR*Zeta[3])/108864000 + 
           (1289*cA*lmmMS*Zeta[3])/907200 + (14807*cR*lmmMS*Zeta[3])/
            3628800 + (857*cR*lmmMS^2*Zeta[3])/403200 + (857*cR*Pi^2*Zeta[3])/
            2419200 + (857*cR*Zeta[5])/336000)) + 
       rhoMS*((-19*cA)/360 + (139*cR)/1440 - (7*cR*lmmMS)/80 + 
         ep*((1841*cA)/21600 - (173*cR)/960 - (19*cA*lmmMS)/360 + 
           (13*cR*lmmMS)/1440 - (7*cR*lmmMS^2)/160 - (7*cR*Pi^2)/960) + 
         ep^2*((-6473*cA)/72000 + (649*cR)/10368 + (1841*cA*lmmMS)/21600 - 
           (173*cR*lmmMS)/960 - (19*cA*lmmMS^2)/720 + (13*cR*lmmMS^2)/2880 - 
           (7*cR*lmmMS^3)/480 - (19*cA*Pi^2)/4320 + (13*cR*Pi^2)/17280 - 
           (7*cR*lmmMS*Pi^2)/960 + (7*cR*Zeta[3])/240) + 
         ep^3*((2830159*cA)/19440000 - (43561*cR)/311040 - 
           (6473*cA*lmmMS)/72000 + (649*cR*lmmMS)/10368 + (1841*cA*lmmMS^2)/
            43200 - (173*cR*lmmMS^2)/1920 - (19*cA*lmmMS^3)/2160 + 
           (13*cR*lmmMS^3)/8640 - (7*cR*lmmMS^4)/1920 + (1841*cA*Pi^2)/
            259200 - (173*cR*Pi^2)/11520 - (19*cA*lmmMS*Pi^2)/4320 + 
           (13*cR*lmmMS*Pi^2)/17280 - (7*cR*lmmMS^2*Pi^2)/1920 - 
           (7*cR*Pi^4)/12800 + (19*cA*Zeta[3])/1080 - (13*cR*Zeta[3])/4320 + 
           (7*cR*lmmMS*Zeta[3])/240) + ep^4*((-171906283*cA)/583200000 + 
           (174071*cR)/622080 + (2830159*cA*lmmMS)/19440000 - 
           (43561*cR*lmmMS)/311040 - (6473*cA*lmmMS^2)/144000 + 
           (649*cR*lmmMS^2)/20736 + (1841*cA*lmmMS^3)/129600 - 
           (173*cR*lmmMS^3)/5760 - (19*cA*lmmMS^4)/8640 + 
           (13*cR*lmmMS^4)/34560 - (7*cR*lmmMS^5)/9600 - (6473*cA*Pi^2)/
            864000 + (649*cR*Pi^2)/124416 + (1841*cA*lmmMS*Pi^2)/259200 - 
           (173*cR*lmmMS*Pi^2)/11520 - (19*cA*lmmMS^2*Pi^2)/8640 + 
           (13*cR*lmmMS^2*Pi^2)/34560 - (7*cR*lmmMS^3*Pi^2)/5760 - 
           (19*cA*Pi^4)/57600 + (13*cR*Pi^4)/230400 - (7*cR*lmmMS*Pi^4)/
            12800 - (1841*cA*Zeta[3])/64800 + (173*cR*Zeta[3])/2880 + 
           (19*cA*lmmMS*Zeta[3])/1080 - (13*cR*lmmMS*Zeta[3])/4320 + 
           (7*cR*lmmMS^2*Zeta[3])/480 + (7*cR*Pi^2*Zeta[3])/2880 + 
           (7*cR*Zeta[5])/400))) + api5^2*((15727*cA^2)/5184 - 
       (55*cA*cR)/48 + (9*cR^2)/16 + (7*cA^2*lmmMS)/16 - 
       (11*cA*cR*lmmMS)/16 - (5*cA^2*lmuH)/27 - (67*cA^2*lmuH^2)/144 - 
       (11*cA^2*lmuH^3)/144 - (5*cA*nh)/192 - (cR*nh)/24 + 
       ((11*cA^2)/32 - (cA*nl)/16)/ep^3 + (67*cA^2*Pi^2)/576 + 
       (11*cA^2*lmuH*Pi^2)/144 + (cA^2*lmuH^2*Pi^2)/48 + 
       ((3*cA^2)/16 + (11*cA^2*lmuH)/48 + ((-17*cA)/144 - (cA*lmuH)/24)*nl + 
         nl^2/72 + (cA^2*Pi^2)/96)/ep^2 - (143*cA^2*Zeta[3])/144 + 
       (cA^2*lmuH*Zeta[3])/8 + ((-173*cA^2)/216 - (67*cA^2*lmuH)/144 + 
         (11*cA^2*Pi^2)/576 + (cA^2*lmuH*Pi^2)/48 + 
         nl*((4*cA)/27 + cR/16 + (5*cA*lmuH)/72 - (cA*Pi^2)/288) + 
         (cA^2*Zeta[3])/16)/ep + nl*((-2255*cA)/2592 - (41*cR)/48 + 
         (cR*lmmMS)/4 - (13*cA*lmuH)/108 - (cR*lmuH)/8 + (5*cA*lmuH^2)/72 + 
         (cA*lmuH^3)/72 - (5*cA*Pi^2)/288 - (cA*lmuH*Pi^2)/72 - 
         (23*cA*Zeta[3])/72 + (cR*Zeta[3])/2) + 
       ep*((474899*cA^2)/62208 - (14339*cA*cR)/1152 + (29*cR^2)/16 + 
         (29*cA^2*lmmMS)/32 - (451*cA*cR*lmmMS)/96 + (69*cR^2*lmmMS)/16 + 
         (97*cA^2*lmmMS^2)/96 - (55*cA*cR*lmmMS^2)/32 + 
         (4511*cA^2*lmuH)/1296 - (5*cA^2*lmuH^2)/27 - (67*cA^2*lmuH^3)/216 - 
         (11*cA^2*lmuH^4)/192 - (1423*cA*nh)/3456 - (101*cR*nh)/576 - 
         (5*cA*lmmMS*nh)/96 + (cR*lmmMS*nh)/8 - (cR*lmmMS^2*nh)/8 + 
         (347*cA^2*Pi^2)/1728 - (11*cA*cR*Pi^2)/192 + (67*cA^2*lmuH*Pi^2)/
          288 + (55*cA^2*lmuH^2*Pi^2)/576 + (cA^2*lmuH^3*Pi^2)/72 - 
         (11*cA^2*Pi^4)/640 - (36043*cA^2*Zeta[3])/13824 + 
         (3819*cA*cR*Zeta[3])/256 - (285*cR^2*Zeta[3])/64 - 
         (11*cA^2*lmuH*Zeta[3])/12 + (cA^2*lmuH^2*Zeta[3])/8 + 
         (63*cA*nh*Zeta[3])/256 + (63*cR*nh*Zeta[3])/128 - 
         (5*cA^2*Pi^2*Zeta[3])/288 + nl*((-53219*cA)/15552 - (211*cR)/96 - 
           (5*cA*lmmMS)/48 - (3*cR*lmmMS)/8 - (5*cA*lmmMS^2)/48 + 
           (7*cR*lmmMS^2)/16 - (431*cA*lmuH)/324 - (67*cR*lmuH)/48 - 
           (13*cA*lmuH^2)/108 - (cR*lmuH^2)/8 + (5*cA*lmuH^3)/108 + 
           (cA*lmuH^4)/96 - (cA*Pi^2)/54 + (13*cR*Pi^2)/288 - 
           (5*cA*lmuH*Pi^2)/144 - (5*cA*lmuH^2*Pi^2)/288 - 
           (53*cA*Pi^4)/8640 + (cR*Pi^4)/108 - (151*cA*Zeta[3])/108 + 
           (23*cR*Zeta[3])/12 - (5*cA*lmuH*Zeta[3])/6 + cR*lmuH*Zeta[3]) + 
         (39*cA^2*Zeta[5])/16) + ep^2*((8812621*cA^2)/186624 - 
         (5723*cA*cR)/1728 - (4567*cR^2)/384 - (7385*cA^2*lmmMS)/3456 - 
         (7171*cA*cR*lmmMS)/288 + (19*cR^2*lmmMS)/16 + (85*cA^2*lmmMS^2)/
          288 - (313*cA*cR*lmmMS^2)/64 + 6*cR^2*lmmMS^2 + 
         (83*cA^2*lmmMS^3)/96 - (143*cA*cR*lmmMS^3)/96 + 
         (141677*cA^2*lmuH)/7776 + (2107*cA^2*lmuH^2)/648 - 
         (10*cA^2*lmuH^3)/81 - (67*cA^2*lmuH^4)/432 - (77*cA^2*lmuH^5)/2880 + 
         (9533*cA*nh)/20736 - (1817*cR*nh)/864 - (1423*cA*lmmMS*nh)/1728 - 
         (101*cR*lmmMS*nh)/288 - (5*cA*lmmMS^2*nh)/96 + (cR*lmmMS^2*nh)/8 - 
         (cR*lmmMS^3*nh)/8 + (2645*cA^2*Pi^2)/10368 - (451*cA*cR*Pi^2)/1152 + 
         (23*cR^2*Pi^2)/64 + (97*cA^2*lmmMS*Pi^2)/576 - (55*cA*cR*lmmMS*Pi^2)/
          192 + (71*cA^2*lmuH*Pi^2)/216 + (67*cA^2*lmuH^2*Pi^2)/288 + 
         (121*cA^2*lmuH^3*Pi^2)/1728 + (cA^2*lmuH^4*Pi^2)/144 - 
         (5*cA*nh*Pi^2)/1152 + (cR*nh*Pi^2)/96 - (cR*lmmMS*nh*Pi^2)/48 + 
         (7411*cA^2*Pi^4)/138240 - (547*cA*cR*Pi^4)/512 + 
         (811*cR^2*Pi^4)/1920 - (671*cA^2*lmuH*Pi^4)/34560 - 
         (51*cA*nh*Pi^4)/2560 - (51*cR*nh*Pi^4)/1280 + (2623*cA^2*Pi^6)/
          241920 + (263*cA^2*Pi^2*Log[2]^2)/256 - (381*cA*cR*Pi^2*Log[2]^2)/
          128 + (59*cR^2*Pi^2*Log[2]^2)/32 - (9*cA*nh*Pi^2*Log[2]^2)/128 - 
         (9*cR*nh*Pi^2*Log[2]^2)/64 - (263*cA^2*Log[2]^4)/256 + 
         (381*cA*cR*Log[2]^4)/128 - (59*cR^2*Log[2]^4)/32 + 
         (9*cA*nh*Log[2]^4)/128 + (9*cR*nh*Log[2]^4)/64 - 
         (789*cA^2*PolyLog[4, 1/2])/32 + (1143*cA*cR*PolyLog[4, 1/2])/16 - 
         (177*cR^2*PolyLog[4, 1/2])/4 + (27*cA*nh*PolyLog[4, 1/2])/16 + 
         (27*cR*nh*PolyLog[4, 1/2])/8 - (2331649*cA^2*Zeta[3])/82944 + 
         (95455*cA*cR*Zeta[3])/1536 - (409*cR^2*Zeta[3])/64 + 
         (15*cA^2*lmmMS*Zeta[3])/256 + (3819*cA*cR*lmmMS*Zeta[3])/128 - 
         (285*cR^2*lmmMS*Zeta[3])/32 - (1139*cA^2*lmuH*Zeta[3])/216 - 
         (55*cA^2*lmuH^2*Zeta[3])/144 + (cA^2*lmuH^3*Zeta[3])/12 + 
         (1799*cA*nh*Zeta[3])/1536 + (665*cR*nh*Zeta[3])/256 + 
         (63*cA*lmmMS*nh*Zeta[3])/128 + (63*cR*lmmMS*nh*Zeta[3])/64 - 
         (11*cA^2*Pi^2*Zeta[3])/108 - (5*cA^2*lmuH*Pi^2*Zeta[3])/144 + 
         (235*cA^2*Zeta[3]^2)/48 - (341*cA^2*Zeta[5])/240 + 
         (39*cA^2*lmuH*Zeta[5])/8 + nl*((-1039409*cA)/93312 - (8419*cR)/432 - 
           (685*cA*lmmMS)/864 + (433*cR*lmmMS)/144 + (cA*lmmMS^2)/144 - 
           (49*cR*lmmMS^2)/96 - (5*cA*lmmMS^3)/48 + (17*cR*lmmMS^3)/48 - 
           (24103*cA*lmuH)/3888 - (2027*cR*lmuH)/288 - (835*cA*lmuH^2)/648 - 
           (67*cR*lmuH^2)/48 - (13*cA*lmuH^3)/162 - (cR*lmuH^3)/12 + 
           (5*cA*lmuH^4)/216 + (7*cA*lmuH^5)/1440 + (47*cA*Pi^2)/5184 + 
           (155*cR*Pi^2)/1728 - (5*cA*lmmMS*Pi^2)/288 + (7*cR*lmmMS*Pi^2)/
            96 - (cA*lmuH*Pi^2)/27 + (7*cR*lmuH*Pi^2)/144 - 
           (5*cA*lmuH^2*Pi^2)/144 - (11*cA*lmuH^3*Pi^2)/864 - 
           (257*cA*Pi^4)/10368 + (23*cR*Pi^4)/648 - (259*cA*lmuH*Pi^4)/
            17280 + (cR*lmuH*Pi^4)/54 - (2521*cA*Zeta[3])/648 + 
           (92*cR*Zeta[3])/9 - (151*cA*lmuH*Zeta[3])/54 + 
           (23*cR*lmuH*Zeta[3])/6 - (67*cA*lmuH^2*Zeta[3])/72 + 
           cR*lmuH^2*Zeta[3] + (17*cA*Pi^2*Zeta[3])/108 - (5*cR*Pi^2*Zeta[3])/
            36 - (209*cA*Zeta[5])/120 + 2*cR*Zeta[5])) + 
       rhoMS*((-532639*cA^2)/921600 - (583637*cA*cR)/207360 - 
         (111643*cR^2)/46080 - (91*cA^2*lmmMS)/2160 + (43*cA*cR*lmmMS)/864 - 
         (47*cR^2*lmmMS)/1920 - (77*cA*cR*lmmMS^2)/1920 + 
         (21*cR^2*lmmMS^2)/320 - (cA^2*lmuH)/160 - (64097*cA*nh)/8294400 - 
         (8563*cR*nh)/103680 + (cA*lmmMS*nh)/480 + (7*cR*lmmMS*nh)/576 - 
         (7*cR*lmmMS^2*nh)/960 - (cA*lmuH*nh)/480 + 
         ((269*cA)/7200 + (37039*cR)/518400 + (31*cA*lmmMS)/17280 - 
           (13*cR*lmmMS)/1440 + (7*cR*lmmMS^2)/960 + (121*cA*lmuH)/17280 + 
           (11*cR*lmuH)/2160)*nl + (11723*cA^2*Zeta[3])/24576 + 
         (11709*cA*cR*Zeta[3])/5120 + (63917*cR^2*Zeta[3])/30720 + 
         (77*cA*nh*Zeta[3])/24576 + (77*cR*nh*Zeta[3])/768 + 
         ep*((419893529*cA^2)/99532800 + (178336297*cA*cR)/24883200 - 
           (13735*cR^2)/12288 - (853699*cA^2*lmmMS)/829440 - 
           (1545083*cA*cR*lmmMS)/259200 - (105979*cR^2*lmmMS)/23040 - 
           (191*cA^2*lmmMS^2)/2880 + (359*cA*cR*lmmMS^2)/3840 + 
           (11*cR^2*lmmMS^2)/320 - (77*cA*cR*lmmMS^3)/1920 + 
           (21*cR^2*lmmMS^3)/320 - (559*cA^2*lmuH)/11520 - 
           (cA^2*lmuH^2)/160 + (10145057*cA*nh)/124416000 - 
           (135401*cR*nh)/414720 - (64097*cA*lmmMS*nh)/4147200 - 
           (7933*cR*lmmMS*nh)/51840 + (cA*lmmMS^2*nh)/320 + 
           (7*cR*lmmMS^2*nh)/1440 - (7*cR*lmmMS^3*nh)/960 - 
           (cA*lmmMS*lmuH*nh)/480 - (cA*lmuH^2*nh)/960 - (31*cA^2*Pi^2)/
            10368 + (43*cA*cR*Pi^2)/10368 - (47*cR^2*Pi^2)/23040 - 
           (77*cA*cR*lmmMS*Pi^2)/11520 + (7*cR^2*lmmMS*Pi^2)/640 + 
           (cA*nh*Pi^2)/2880 + (7*cR*nh*Pi^2)/6912 - (7*cR*lmmMS*nh*Pi^2)/
            5760 - (3721*cA^2*Pi^4)/147456 - (17323*cA*cR*Pi^4)/153600 - 
           (93659*cR^2*Pi^4)/921600 - (187*cA*nh*Pi^4)/737280 - 
           (187*cR*nh*Pi^4)/23040 - (157*cA^2*Pi^2*Log[2]^2)/12288 + 
           (37*cA*cR*Pi^2*Log[2]^2)/2560 + (341*cR^2*Pi^2*Log[2]^2)/15360 - 
           (11*cA*nh*Pi^2*Log[2]^2)/12288 - (11*cR*nh*Pi^2*Log[2]^2)/384 + 
           (157*cA^2*Log[2]^4)/12288 - (37*cA*cR*Log[2]^4)/2560 - 
           (341*cR^2*Log[2]^4)/15360 + (11*cA*nh*Log[2]^4)/12288 + 
           (11*cR*nh*Log[2]^4)/384 + (157*cA^2*PolyLog[4, 1/2])/512 - 
           (111*cA*cR*PolyLog[4, 1/2])/320 - (341*cR^2*PolyLog[4, 1/2])/640 + 
           (11*cA*nh*PolyLog[4, 1/2])/512 + (11*cR*nh*PolyLog[4, 1/2])/16 - 
           (483385*cA^2*Zeta[3])/294912 + (393979*cA*cR*Zeta[3])/122880 + 
           (226837*cR^2*Zeta[3])/24576 + (11723*cA^2*lmmMS*Zeta[3])/12288 + 
           (11709*cA*cR*lmmMS*Zeta[3])/2560 + (63917*cR^2*lmmMS*Zeta[3])/
            15360 - (19537*cA*nh*Zeta[3])/368640 + (63763*cR*nh*Zeta[3])/
            92160 + (77*cA*lmmMS*nh*Zeta[3])/12288 + (77*cR*lmmMS*nh*Zeta[3])/
            384 + nl*((381067*cA)/1944000 - (984931*cR)/15552000 - 
             (539*cA*lmmMS)/259200 + (13003*cR*lmmMS)/86400 + 
             (107*cA*lmmMS^2)/17280 - (169*cR*lmmMS^2)/17280 + 
             (7*cR*lmmMS^3)/960 + (649*cA*lmuH)/10368 + (1793*cR*lmuH)/
              51840 + (121*cA*lmuH^2)/17280 + (11*cR*lmuH^2)/2160 - 
             (cA*Pi^2)/2304 - (61*cR*Pi^2)/51840 + (7*cR*lmmMS*Pi^2)/5760 + 
             (7*cR*Zeta[3])/120)) + ep^2*((-54099302549*cA^2)/2488320000 - 
           (4882893589*cA*cR)/124416000 - (57697949*cR^2)/1658880 + 
           (2137608781*cA^2*lmmMS)/248832000 + (298562291*cA*cR*lmmMS)/
            20736000 - (569299*cR^2*lmmMS)/276480 - (1368829*cA^2*lmmMS^2)/
            1382400 - (6291203*cA*cR*lmmMS^2)/1036800 - (103021*cR^2*lmmMS^2)/
            23040 - (271*cA^2*lmmMS^3)/5184 + (7973*cA*cR*lmmMS^3)/103680 + 
           (49*cR^2*lmmMS^3)/1152 - (539*cA*cR*lmmMS^4)/23040 + 
           (49*cR^2*lmmMS^4)/1280 - (16291*cA^2*lmuH)/69120 - 
           (559*cA^2*lmuH^2)/11520 - (cA^2*lmuH^3)/240 + (450958441*cA*nh)/
            3732480000 - (3819637*cR*nh)/3732480 + (10015457*cA*lmmMS*nh)/
            62208000 - (135401*cR*lmmMS*nh)/207360 - (64097*cA*lmmMS^2*nh)/
            4147200 - (7933*cR*lmmMS^2*nh)/51840 + (7*cA*lmmMS^3*nh)/2880 + 
           (7*cR*lmmMS^3*nh)/8640 - (49*cR*lmmMS^4*nh)/11520 + 
           (cA*lmuH*nh)/480 - (cA*lmmMS^2*lmuH*nh)/960 - (cA*lmmMS*lmuH^2*nh)/
            960 - (cA*lmuH^3*nh)/2880 - (813451*cA^2*Pi^2)/9953280 - 
           (1545083*cA*cR*Pi^2)/3110400 - (105979*cR^2*Pi^2)/276480 - 
           (191*cA^2*lmmMS*Pi^2)/17280 + (359*cA*cR*lmmMS*Pi^2)/23040 + 
           (11*cR^2*lmmMS*Pi^2)/1920 - (77*cA*cR*lmmMS^2*Pi^2)/7680 + 
           (21*cR^2*lmmMS^2*Pi^2)/1280 + (cA^2*lmuH*Pi^2)/960 - 
           (64097*cA*nh*Pi^2)/49766400 - (7933*cR*nh*Pi^2)/622080 + 
           (cA*lmmMS*nh*Pi^2)/1440 + (7*cR*lmmMS*nh*Pi^2)/8640 - 
           (7*cR*lmmMS^2*nh*Pi^2)/3840 + (1066873*cA^2*Pi^4)/14745600 - 
           (550549*cA*cR*Pi^4)/3686400 - (4922701*cR^2*Pi^4)/11059200 - 
           (3721*cA^2*lmmMS*Pi^4)/73728 - (17323*cA*cR*lmmMS*Pi^4)/76800 - 
           (93659*cR^2*lmmMS*Pi^4)/460800 + (47447*cA*nh*Pi^4)/11059200 - 
           (154993*cR*nh*Pi^4)/2764800 - (187*cA*lmmMS*nh*Pi^4)/368640 - 
           (187*cR*lmmMS*nh*Pi^4)/11520 + (2669*cA^2*Pi^4*Log[2])/122880 - 
           (629*cA*cR*Pi^4*Log[2])/25600 - (5797*cR^2*Pi^4*Log[2])/153600 + 
           (187*cA*nh*Pi^4*Log[2])/122880 + (187*cR*nh*Pi^4*Log[2])/3840 - 
           (7261*cA^2*Pi^2*Log[2]^2)/81920 + (19129*cA*cR*Pi^2*Log[2]^2)/
            184320 + (27091*cR^2*Pi^2*Log[2]^2)/184320 - 
           (157*cA^2*lmmMS*Pi^2*Log[2]^2)/6144 + (37*cA*cR*lmmMS*Pi^2*
             Log[2]^2)/1280 + (341*cR^2*lmmMS*Pi^2*Log[2]^2)/7680 + 
           (2791*cA*nh*Pi^2*Log[2]^2)/184320 - (9109*cR*nh*Pi^2*Log[2]^2)/
            46080 - (11*cA*lmmMS*nh*Pi^2*Log[2]^2)/6144 - 
           (11*cR*lmmMS*nh*Pi^2*Log[2]^2)/192 + (157*cA^2*Pi^2*Log[2]^3)/
            6144 - (37*cA*cR*Pi^2*Log[2]^3)/1280 - (341*cR^2*Pi^2*Log[2]^3)/
            7680 + (11*cA*nh*Pi^2*Log[2]^3)/6144 + (11*cR*nh*Pi^2*Log[2]^3)/
            192 + (7261*cA^2*Log[2]^4)/81920 - (19129*cA*cR*Log[2]^4)/
            184320 - (27091*cR^2*Log[2]^4)/184320 + (157*cA^2*lmmMS*Log[2]^4)/
            6144 - (37*cA*cR*lmmMS*Log[2]^4)/1280 - (341*cR^2*lmmMS*Log[2]^4)/
            7680 - (2791*cA*nh*Log[2]^4)/184320 + (9109*cR*nh*Log[2]^4)/
            46080 + (11*cA*lmmMS*nh*Log[2]^4)/6144 + 
           (11*cR*lmmMS*nh*Log[2]^4)/192 - (157*cA^2*Log[2]^5)/10240 + 
           (111*cA*cR*Log[2]^5)/6400 + (341*cR^2*Log[2]^5)/12800 - 
           (11*cA*nh*Log[2]^5)/10240 - (11*cR*nh*Log[2]^5)/320 + 
           (21783*cA^2*PolyLog[4, 1/2])/10240 - (19129*cA*cR*PolyLog[4, 1/2])/
            7680 - (27091*cR^2*PolyLog[4, 1/2])/7680 + 
           (157*cA^2*lmmMS*PolyLog[4, 1/2])/256 - 
           (111*cA*cR*lmmMS*PolyLog[4, 1/2])/160 - 
           (341*cR^2*lmmMS*PolyLog[4, 1/2])/320 - 
           (2791*cA*nh*PolyLog[4, 1/2])/7680 + (9109*cR*nh*PolyLog[4, 1/2])/
            1920 + (11*cA*lmmMS*nh*PolyLog[4, 1/2])/256 + 
           (11*cR*lmmMS*nh*PolyLog[4, 1/2])/8 + (471*cA^2*PolyLog[5, 1/2])/
            256 - (333*cA*cR*PolyLog[5, 1/2])/160 - 
           (1023*cR^2*PolyLog[5, 1/2])/320 + (33*cA*nh*PolyLog[5, 1/2])/256 + 
           (33*cR*nh*PolyLog[5, 1/2])/8 + (99472123*cA^2*Zeta[3])/26542080 + 
           (66235487*cA*cR*Zeta[3])/6635520 + (2800279*cR^2*Zeta[3])/81920 - 
           (483385*cA^2*lmmMS*Zeta[3])/147456 + (237373*cA*cR*lmmMS*Zeta[3])/
            36864 + (1131497*cR^2*lmmMS*Zeta[3])/61440 + 
           (11723*cA^2*lmmMS^2*Zeta[3])/12288 + (11709*cA*cR*lmmMS^2*Zeta[3])/
            2560 + (63917*cR^2*lmmMS^2*Zeta[3])/15360 - 
           (3706813*cA*nh*Zeta[3])/8847360 + (277921*cR*nh*Zeta[3])/110592 - 
           (19537*cA*lmmMS*nh*Zeta[3])/184320 + (21329*cR*lmmMS*nh*Zeta[3])/
            15360 + (77*cA*lmmMS^2*nh*Zeta[3])/12288 + 
           (77*cR*lmmMS^2*nh*Zeta[3])/384 + (11723*cA^2*Pi^2*Zeta[3])/
            147456 + (3903*cA*cR*Pi^2*Zeta[3])/10240 + 
           (63917*cR^2*Pi^2*Zeta[3])/184320 + (77*cA*nh*Pi^2*Zeta[3])/
            147456 + (77*cR*nh*Pi^2*Zeta[3])/4608 + 
           nl*((202511*cA)/291600 + (149808023*cR)/155520000 + 
             (6623*cA*lmmMS)/103680 - (2203181*cR*lmmMS)/7776000 - 
             (119*cA*lmmMS^2)/12960 + (28601*cR*lmmMS^2)/172800 + 
             (29*cA*lmmMS^3)/5184 - (13*cR*lmmMS^3)/1920 + (49*cR*lmmMS^4)/
              11520 + (106733*cA*lmuH)/311040 + (9097*cR*lmuH)/62208 + 
             (649*cA*lmuH^2)/10368 + (1793*cR*lmuH^2)/51840 + 
             (121*cA*lmuH^3)/25920 + (11*cR*lmuH^3)/3240 - (1397*cA*Pi^2)/
              259200 + (7511*cR*Pi^2)/777600 + (107*cA*lmmMS*Pi^2)/103680 - 
             (169*cR*lmmMS*Pi^2)/103680 + (7*cR*lmmMS^2*Pi^2)/3840 - 
             (121*cA*lmuH*Pi^2)/103680 - (11*cR*lmuH*Pi^2)/12960 - 
             (1981*cR*Pi^4)/691200 + (229*cA*Zeta[3])/51840 - 
             (859*cR*Zeta[3])/12960 + (161*cR*lmmMS*Zeta[3])/1440) + 
           (103153*cA^2*Zeta[5])/16384 + (448053*cA*cR*Zeta[5])/10240 + 
           (848503*cR^2*Zeta[5])/20480 - (1705*cA*nh*Zeta[5])/16384 - 
           (1705*cR*nh*Zeta[5])/512)) + 
       rhoMS^2*((-745550009*cA^2)/13005619200 - (2888889593*cA*cR)/
          4644864000 - (99742973*cR^2)/116121600 - (7481*cA^2*lmmMS)/
          1814400 - (217*cA*cR*lmmMS)/518400 + (1043*cR^2*lmmMS)/230400 - 
         (9427*cA*cR*lmmMS^2)/1612800 + (857*cR^2*lmmMS^2)/44800 + 
         (29*cA^2*lmuH)/134400 + (265053121*cA*nh)/390168576000 - 
         (4292737*cR*nh)/557383680 + (cA*lmmMS*nh)/5040 - 
         (151*cR*lmmMS*nh)/483840 - (857*cR*lmmMS^2*nh)/806400 - 
         (cA*lmuH*nh)/5040 + (cR*lmuH*nh)/480 + 
         ((45617*cA)/18144000 + (20186431*cR)/3048192000 + 
           (623*cA*lmmMS)/2073600 + (1069*cR*lmmMS)/1814400 + 
           (857*cR*lmmMS^2)/806400 + (5951*cA*lmuH)/14515200 + 
           (1667*cR*lmuH)/3628800)*nl + (110251*cA^2*Zeta[3])/2359296 + 
         (106243447*cA*cR*Zeta[3])/206438400 + (6220579*cR^2*Zeta[3])/
          8601600 - (16177*cA*nh*Zeta[3])/23592960 + (21973*cR*nh*Zeta[3])/
          1966080 + ep*((-183218082652883*cA^2)/327741603840000 - 
           (89665848955231*cA*cR)/23410114560000 - (515411271617*cR^2)/
            83607552000 - (11241763927*cA^2*lmmMS)/97542144000 - 
           (62157021821*cA*cR*lmmMS)/48771072000 - (484894297*cR^2*lmmMS)/
            290304000 - (14701*cA^2*lmmMS^2)/2419200 + (3529*cA*cR*lmmMS^2)/
            9676800 + (17447*cR^2*lmmMS^2)/537600 - (9427*cA*cR*lmmMS^3)/
            1612800 + (857*cR^2*lmmMS^3)/44800 + (1481*cA^2*lmuH)/691200 + 
           (29*cA^2*lmuH^2)/134400 + (304887364129*cA*nh)/81935400960000 - 
           (2302109027*cR*nh)/37158912000 + (497296321*cA*lmmMS*nh)/
            195084288000 - (5941249*cR*lmmMS*nh)/278691840 + 
           (cA*lmmMS^2*nh)/3360 - (6617*cR*lmmMS^2*nh)/2419200 - 
           (857*cR*lmmMS^3*nh)/806400 - (cA*lmuH*nh)/840 + 
           (71*cR*lmuH*nh)/8640 - (cA*lmmMS*lmuH*nh)/5040 + 
           (cR*lmmMS*lmuH*nh)/480 - (cA*lmuH^2*nh)/10080 + 
           (cR*lmuH^2*nh)/960 - (3149*cA^2*Pi^2)/8709120 - 
           (217*cA*cR*Pi^2)/6220800 + (1043*cR^2*Pi^2)/2764800 - 
           (9427*cA*cR*lmmMS*Pi^2)/9676800 + (857*cR^2*lmmMS*Pi^2)/268800 + 
           (cA*nh*Pi^2)/30240 - (1159*cR*nh*Pi^2)/5806080 - 
           (857*cR*lmmMS*nh*Pi^2)/4838400 - (283499*cA^2*Pi^4)/117964800 - 
           (53591563*cA*cR*Pi^4)/2064384000 - (9144533*cR^2*Pi^4)/258048000 + 
           (39287*cA*nh*Pi^4)/707788800 - (53363*cR*nh*Pi^4)/58982400 - 
           (1211*cA^2*Pi^2*Log[2]^2)/1966080 - (72283*cA*cR*Pi^2*Log[2]^2)/
            34406400 + (28667*cR^2*Pi^2*Log[2]^2)/4300800 + 
           (2311*cA*nh*Pi^2*Log[2]^2)/11796480 - (3139*cR*nh*Pi^2*Log[2]^2)/
            983040 + (1211*cA^2*Log[2]^4)/1966080 + (72283*cA*cR*Log[2]^4)/
            34406400 - (28667*cR^2*Log[2]^4)/4300800 - (2311*cA*nh*Log[2]^4)/
            11796480 + (3139*cR*nh*Log[2]^4)/983040 + 
           (1211*cA^2*PolyLog[4, 1/2])/81920 + (72283*cA*cR*PolyLog[4, 1/2])/
            1433600 - (28667*cR^2*PolyLog[4, 1/2])/179200 - 
           (2311*cA*nh*PolyLog[4, 1/2])/491520 + (3139*cR*nh*PolyLog[4, 1/2])/
            40960 + (13145693363*cA^2*Zeta[3])/19818086400 + 
           (51997646777*cA*cR*Zeta[3])/9909043200 + (9978329317*cR^2*Zeta[3])/
            1238630400 + (110251*cA^2*lmmMS*Zeta[3])/1179648 + 
           (106243447*cA*cR*lmmMS*Zeta[3])/103219200 + 
           (6220579*cR^2*lmmMS*Zeta[3])/4300800 - (5727101*cA*nh*Zeta[3])/
            707788800 + (82755721*cR*nh*Zeta[3])/707788800 - 
           (16177*cA*lmmMS*nh*Zeta[3])/11796480 + (21973*cR*lmmMS*nh*Zeta[3])/
            983040 + nl*((2089506271*cA)/160030080000 + (3224647*cR)/
              889056000 + (808831*cA*lmmMS)/762048000 + (79609*cR*lmmMS)/
              5644800 + (9517*cA*lmmMS^2)/14515200 + (3337*cR*lmmMS^2)/
              2073600 + (857*cR*lmmMS^3)/806400 + (10033*cA*lmuH)/2721600 + 
             (34663*cR*lmuH)/10886400 + (5951*cA*lmuH^2)/14515200 + 
             (1667*cR*lmuH^2)/3628800 - (53*cA*Pi^2)/5806080 + 
             (157*cR*Pi^2)/14515200 + (857*cR*lmmMS*Pi^2)/4838400 + 
             (857*cR*Zeta[3])/100800)) + ep^2*((337522928518761407*cA^2)/
            137651473612800000 + (12393586321257487*cA*cR)/9832248115200000 - 
           (2935612871839*cR^2)/278691840000 - (185597033147219*cA^2*lmmMS)/
            163870801920000 - (628479127320601*cA*cR*lmmMS)/81935400960000 - 
           (2565612545029*cR^2*lmmMS)/209018880000 - (413574869*cA^2*lmmMS^2)/
            3612672000 - (1387623737*cA*cR*lmmMS^2)/1083801600 - 
           (476017873*cR^2*lmmMS^2)/290304000 - (20477*cA^2*lmmMS^3)/
            4354560 + (43913*cA*cR*lmmMS^3)/87091200 + (74861*cR^2*lmmMS^3)/
            2419200 - (9427*cA*cR*lmmMS^4)/2764800 + (857*cR^2*lmmMS^4)/
            76800 + (280177*cA^2*lmuH)/23224320 + (1481*cA^2*lmuH^2)/691200 + 
           (29*cA^2*lmuH^3)/201600 + (858511212074791*cA*nh)/
            34412868403200000 - (4582721625413*cR*nh)/20065812480000 + 
           (412928836129*cA*lmmMS*nh)/40967700480000 - 
           (289179403*cR*lmmMS*nh)/2064384000 + (613417921*cA*lmmMS^2*nh)/
            195084288000 - (35875781*cR*lmmMS^2*nh)/1393459200 + 
           (cA*lmmMS^3*nh)/4320 - (341*cR*lmmMS^3*nh)/129600 - 
           (857*cR*lmmMS^4*nh)/1382400 - (319*cA*lmuH*nh)/120960 + 
           (433*cR*lmuH*nh)/25920 - (cA*lmmMS*lmuH*nh)/840 + 
           (71*cR*lmmMS*lmuH*nh)/8640 - (cA*lmmMS^2*lmuH*nh)/10080 + 
           (cR*lmmMS^2*lmuH*nh)/960 - (cA*lmuH^2*nh)/1680 + 
           (71*cR*lmuH^2*nh)/17280 - (cA*lmmMS*lmuH^2*nh)/10080 + 
           (cR*lmmMS*lmuH^2*nh)/960 - (cA*lmuH^3*nh)/30240 + 
           (cR*lmuH^3*nh)/2880 - (11450762647*cA^2*Pi^2)/1170505728000 - 
           (62157021821*cA*cR*Pi^2)/585252864000 - (484894297*cR^2*Pi^2)/
            3483648000 - (14701*cA^2*lmmMS*Pi^2)/14515200 + 
           (3529*cA*cR*lmmMS*Pi^2)/58060800 + (17447*cR^2*lmmMS*Pi^2)/
            3225600 - (9427*cA*cR*lmmMS^2*Pi^2)/6451200 + 
           (857*cR^2*lmmMS^2*Pi^2)/179200 - (29*cA^2*lmuH*Pi^2)/806400 + 
           (729539521*cA*nh*Pi^2)/2341011456000 - (1646285*cR*nh*Pi^2)/
            668860416 + (cA*lmmMS*nh*Pi^2)/15120 - (9137*cR*lmmMS*nh*Pi^2)/
            14515200 - (857*cR*lmmMS^2*nh*Pi^2)/3225600 - 
           (576499319*cA^2*Pi^4)/16986931200 - (3129780359*cA*cR*Pi^4)/
            11890851840 - (14788830563*cR^2*Pi^4)/37158912000 - 
           (283499*cA^2*lmmMS*Pi^4)/58982400 - (53591563*cA*cR*lmmMS*Pi^4)/
            1032192000 - (9144533*cR^2*lmmMS*Pi^4)/129024000 + 
           (97360717*cA*nh*Pi^4)/148635648000 - (469314739*cR*nh*Pi^4)/
            49545216000 + (39287*cA*lmmMS*nh*Pi^4)/353894400 - 
           (53363*cR*lmmMS*nh*Pi^4)/29491200 + (20587*cA^2*Pi^4*Log[2])/
            19660800 + (1228811*cA*cR*Pi^4*Log[2])/344064000 - 
           (487339*cR^2*Pi^4*Log[2])/43008000 - (39287*cA*nh*Pi^4*Log[2])/
            117964800 + (53363*cR*nh*Pi^4*Log[2])/9830400 - 
           (70605557*cA^2*Pi^2*Log[2]^2)/9909043200 - 
           (12101141*cA*cR*Pi^2*Log[2]^2)/1651507200 + 
           (5345449*cR^2*Pi^2*Log[2]^2)/123863040 - 
           (1211*cA^2*lmmMS*Pi^2*Log[2]^2)/983040 - 
           (72283*cA*cR*lmmMS*Pi^2*Log[2]^2)/17203200 + 
           (28667*cR^2*lmmMS*Pi^2*Log[2]^2)/2150400 + 
           (5727101*cA*nh*Pi^2*Log[2]^2)/2477260800 - 
           (82755721*cR*nh*Pi^2*Log[2]^2)/2477260800 + 
           (2311*cA*lmmMS*nh*Pi^2*Log[2]^2)/5898240 - 
           (3139*cR*lmmMS*nh*Pi^2*Log[2]^2)/491520 + 
           (1211*cA^2*Pi^2*Log[2]^3)/983040 + (72283*cA*cR*Pi^2*Log[2]^3)/
            17203200 - (28667*cR^2*Pi^2*Log[2]^3)/2150400 - 
           (2311*cA*nh*Pi^2*Log[2]^3)/5898240 + (3139*cR*nh*Pi^2*Log[2]^3)/
            491520 + (70605557*cA^2*Log[2]^4)/9909043200 + 
           (12101141*cA*cR*Log[2]^4)/1651507200 - (5345449*cR^2*Log[2]^4)/
            123863040 + (1211*cA^2*lmmMS*Log[2]^4)/983040 + 
           (72283*cA*cR*lmmMS*Log[2]^4)/17203200 - 
           (28667*cR^2*lmmMS*Log[2]^4)/2150400 - (5727101*cA*nh*Log[2]^4)/
            2477260800 + (82755721*cR*nh*Log[2]^4)/2477260800 - 
           (2311*cA*lmmMS*nh*Log[2]^4)/5898240 + (3139*cR*lmmMS*nh*Log[2]^4)/
            491520 - (1211*cA^2*Log[2]^5)/1638400 - (72283*cA*cR*Log[2]^5)/
            28672000 + (28667*cR^2*Log[2]^5)/3584000 + (2311*cA*nh*Log[2]^5)/
            9830400 - (3139*cR*nh*Log[2]^5)/819200 + 
           (70605557*cA^2*PolyLog[4, 1/2])/412876800 + 
           (12101141*cA*cR*PolyLog[4, 1/2])/68812800 - 
           (5345449*cR^2*PolyLog[4, 1/2])/5160960 + 
           (1211*cA^2*lmmMS*PolyLog[4, 1/2])/40960 + 
           (72283*cA*cR*lmmMS*PolyLog[4, 1/2])/716800 - 
           (28667*cR^2*lmmMS*PolyLog[4, 1/2])/89600 - 
           (5727101*cA*nh*PolyLog[4, 1/2])/103219200 + 
           (82755721*cR*nh*PolyLog[4, 1/2])/103219200 - 
           (2311*cA*lmmMS*nh*PolyLog[4, 1/2])/245760 + 
           (3139*cR*lmmMS*nh*PolyLog[4, 1/2])/20480 + 
           (3633*cA^2*PolyLog[5, 1/2])/40960 + (216849*cA*cR*PolyLog[5, 1/2])/
            716800 - (86001*cR^2*PolyLog[5, 1/2])/89600 - 
           (2311*cA*nh*PolyLog[5, 1/2])/81920 + (9417*cR*nh*PolyLog[5, 1/2])/
            20480 - (192064750279*cA^2*Zeta[3])/3567255552000 + 
           (21789278751439*cA*cR*Zeta[3])/1783627776000 + 
           (124453815533*cR^2*Zeta[3])/4128768000 + 
           (13145693363*cA^2*lmmMS*Zeta[3])/9909043200 + 
           (52016953273*cA*cR*lmmMS*Zeta[3])/4954521600 + 
           (284869463*cR^2*lmmMS*Zeta[3])/17694720 + 
           (110251*cA^2*lmmMS^2*Zeta[3])/1179648 + 
           (106243447*cA*cR*lmmMS^2*Zeta[3])/103219200 + 
           (6220579*cR^2*lmmMS^2*Zeta[3])/4300800 - (768534811*cA*nh*Zeta[3])/
            14863564800 + (11233825663*cR*nh*Zeta[3])/19818086400 - 
           (5727101*cA*lmmMS*nh*Zeta[3])/353894400 + 
           (581045183*cR*lmmMS*nh*Zeta[3])/2477260800 - 
           (16177*cA*lmmMS^2*nh*Zeta[3])/11796480 + 
           (21973*cR*lmmMS^2*nh*Zeta[3])/983040 + (110251*cA^2*Pi^2*Zeta[3])/
            14155776 + (106243447*cA*cR*Pi^2*Zeta[3])/1238630400 + 
           (6220579*cR^2*Pi^2*Zeta[3])/51609600 - (16177*cA*nh*Pi^2*Zeta[3])/
            141557760 + (21973*cR*nh*Pi^2*Zeta[3])/11796480 + 
           nl*((310213473683*cA)/6721263360000 + (3473703361291*cR)/
              44808422400000 + (43634939*cA*lmmMS)/7112448000 - 
             (2451868697*cR*lmmMS)/640120320000 + (280781*cA*lmmMS^2)/
              304819200 + (46612039*cR*lmmMS^2)/3048192000 + 
             (2419*cA*lmmMS^3)/4354560 + (2461*cR*lmmMS^3)/1741824 + 
             (857*cR*lmmMS^4)/1382400 + (5336503*cA*lmuH)/261273600 + 
             (7051871*cR*lmuH)/522547200 + (10033*cA*lmuH^2)/2721600 + 
             (34663*cR*lmuH^2)/10886400 + (5951*cA*lmuH^3)/21772800 + 
             (1667*cR*lmuH^3)/5443200 - (666803*cA*Pi^2)/3048192000 + 
             (1664161*cR*Pi^2)/1828915200 + (9517*cA*lmmMS*Pi^2)/87091200 + 
             (3337*cR*lmmMS*Pi^2)/12441600 + (857*cR*lmmMS^2*Pi^2)/3225600 - 
             (5951*cA*lmuH*Pi^2)/87091200 - (1667*cR*lmuH*Pi^2)/21772800 - 
             (242531*cR*Pi^4)/580608000 + (76499*cA*Zeta[3])/43545600 + 
             (10711*cR*Zeta[3])/1360800 + (19711*cR*lmmMS*Zeta[3])/1209600) + 
           (1915591*cA^2*Zeta[5])/2621440 + (58242593*cA*cR*Zeta[5])/
            6553600 + (11642623*cR^2*Zeta[5])/819200 + (71641*cA*nh*Zeta[5])/
            3145728 - (97309*cR*nh*Zeta[5])/262144)))
 
LogFOS = api5^3*((62629597*cA^3)/3359232 - (10031*cA^2*cR)/864 + 
       (557*cA*cR^2)/96 - (51*cR^3)/16 + (1363*cA^3*lmmOS)/1152 - 
       (379*cA^2*cR*lmmOS)/144 + (33*cA*cR^2*lmmOS)/32 + 
       (77*cA^3*lmmOS^2)/192 - (121*cA^2*cR*lmmOS^2)/192 + 
       (373975*cA^3*lmuH)/93312 - (8375*cA^3*lmuH^2)/10368 - 
       (445*cA^3*lmuH^3)/1296 - (121*cA^3*lmuH^4)/3456 - (107*cA^2*nh)/864 + 
       (9299*cA*cR*nh)/6912 - (23*cR^2*nh)/96 - (55*cA^2*lmmOS*nh)/1152 - 
       (11*cA*cR*lmmOS*nh)/144 + (cA*nh^2)/54 + (113*cR*nh^2)/1728 + 
       ((-1331*cA^3)/5184 + (121*cA^2*nl)/1296 - (11*cA*nl^2)/1296)/ep^4 + 
       (165289*cA^3*Pi^2)/559872 + (3415*cA^3*lmuH*Pi^2)/7776 + 
       (85*cA^3*lmuH^2*Pi^2)/576 + (11*cA^3*lmuH^3*Pi^2)/864 - 
       (2477*cA^3*Pi^4)/311040 - (319*cA^3*lmuH*Pi^4)/17280 - 
       (11*cA^3*lmuH^2*Pi^4)/2880 - (193*cA^3*Pi^6)/204120 + 
       ((535*cA^3)/3888 - (121*cA^3*lmuH)/864 + 
         ((-37*cA)/1944 - (cA*lmuH)/216)*nl^2 + nl^3/648 - 
         (55*cA^3*Pi^2)/5184 + nl*((119*cA^2)/7776 - (cA*cR)/36 + 
           (11*cA^2*lmuH)/216 + (5*cA^2*Pi^2)/2592))/ep^3 - 
       (4*d44[pR1, pA1])/(3*NA) + (11*nh*d44[pR1, pR2])/(6*NA) - 
       (2571193*cA^3*Zeta[3])/248832 + (5105*cA^2*cR*Zeta[3])/512 - 
       (407*cA*cR^2*Zeta[3])/128 - (32*cA^3*lmuH*Zeta[3])/27 + 
       (cA^2*nh*Zeta[3])/768 - (115*cA*cR*nh*Zeta[3])/128 + 
       (13*cR^2*nh*Zeta[3])/64 - (7*cA*nh^2*Zeta[3])/256 - 
       (7*cR*nh^2*Zeta[3])/128 - (77*cA^3*Pi^2*Zeta[3])/576 - 
       (5*cA^3*lmuH*Pi^2*Zeta[3])/144 + (13*d44[pR1, pA1]*Zeta[3])/NA - 
       (4*nh*d44[pR1, pR2]*Zeta[3])/NA - (13*cA^3*Zeta[3]^2)/72 + 
       nl^2*((74795*cA)/104976 + (317*cR)/432 + (5*cA*lmmOS)/576 + 
         (cR*lmmOS)/72 - (cR*lmmOS^2)/24 + (14057*cA*lmuH)/46656 + 
         (13*cR*lmuH)/48 + (29*cA*lmuH^2)/1296 + (cR*lmuH^2)/48 - 
         (5*cA*lmuH^3)/648 - (cA*lmuH^4)/864 + (cA*Pi^2)/864 - 
         (5*cR*Pi^2)/864 + (5*cA*lmuH*Pi^2)/648 + (cA*lmuH^2*Pi^2)/432 + 
         (cA*Pi^4)/15552 - (cR*Pi^4)/6480 + (143*cA*Zeta[3])/486 - 
         (7*cR*Zeta[3])/12 + (2*cA*lmuH*Zeta[3])/27 - (cR*lmuH*Zeta[3])/6) + 
       ((8773*cA^3)/15552 + (1043*cA^3*lmuH)/2592 + (173*cA^3*Pi^2)/31104 - 
         (11*cA^3*lmuH*Pi^2)/864 - (11*cA^3*Pi^4)/12960 + 
         nl^2*((37*cA)/1296 + cR/72 + (5*cA*lmuH)/648 - (cA*Pi^2)/2592) - 
         (55*cA^3*Zeta[3])/864 + nl*((-497*cA^2)/1944 - (77*cA*cR)/1728 - 
           (167*cA^2*lmuH)/1296 - (cA*cR*lmuH)/48 + (13*cA^2*Pi^2)/7776 + 
           (cA^2*lmuH*Pi^2)/432 + (17*cA^2*Zeta[3])/432 - 
           (cA*cR*Zeta[3])/36))/ep^2 + (1111*cA^3*Zeta[5])/288 - 
       (cA^3*lmuH*Zeta[5])/4 + ((-48593*cA^3)/69984 - (245*cA^3*lmuH)/576 + 
         (6109*cA^3*Pi^2)/93312 + (67*cA^3*lmuH*Pi^2)/1296 - 
         (319*cA^3*Pi^4)/51840 - (11*cA^3*lmuH*Pi^4)/4320 + 
         (61*cA^3*Zeta[3])/288 - (11*cA^3*lmuH*Zeta[3])/144 - 
         (5*cA^3*Pi^2*Zeta[3])/432 + nl^2*((-269*cA)/279936 - (11*cR)/1728 + 
           (cA*lmuH)/648 + (5*cA*Pi^2)/7776 - (7*cA*Zeta[3])/648) + 
         nl*((30715*cA^2)/279936 + (1217*cA*cR)/5184 - cR^2/192 + 
           (209*cA^2*lmuH)/2592 + (55*cA*cR*lmuH)/576 - (599*cA^2*Pi^2)/
            46656 - (cA*cR*Pi^2)/576 - (5*cA^2*lmuH*Pi^2)/648 + 
           (41*cA^2*Pi^4)/25920 - (cA*cR*Pi^4)/2160 + (89*cA^2*Zeta[3])/
            1296 - (19*cA*cR*Zeta[3])/216 + (7*cA^2*lmuH*Zeta[3])/72 - 
           (cA*cR*lmuH*Zeta[3])/12) - (cA^3*Zeta[5])/12)/ep + 
       nl*((-15723499*cA^2)/1679616 - (221423*cA*cR)/62208 + (301*cR^2)/384 - 
         (55*cA^2*lmmOS)/576 + (65*cA*cR*lmmOS)/144 - (cR^2*lmmOS)/8 - 
         (7*cA^2*lmmOS^2)/96 + (11*cA*cR*lmmOS^2)/32 - (33259*cA^2*lmuH)/
          11664 - (3833*cA*cR*lmuH)/3456 + (cR^2*lmuH)/32 + 
         (215*cA^2*lmuH^2)/5184 + (11*cA*cR*lmuH^2)/384 + 
         (289*cA^2*lmuH^3)/2592 + (cA*cR*lmuH^3)/96 + (11*cA^2*lmuH^4)/864 + 
         (7*cA*nh)/864 - (29*cR*nh)/576 + (5*cA*lmmOS*nh)/576 + 
         (cR*lmmOS*nh)/72 - (5945*cA^2*Pi^2)/279936 + (65*cA*cR*Pi^2)/6912 - 
         (229*cA^2*lmuH*Pi^2)/1944 - (cA*cR*lmuH*Pi^2)/96 - 
         (cA^2*lmuH^2*Pi^2)/27 - (cA^2*lmuH^3*Pi^2)/432 + 
         (37*cA^2*Pi^4)/25920 - (cA*cR*Pi^4)/1620 + (41*cA^2*lmuH*Pi^4)/
          8640 - (cA*cR*lmuH*Pi^4)/720 + (11*d44[pR1, pR2])/(3*NA) - 
         (15911*cA^2*Zeta[3])/41472 + (27341*cA*cR*Zeta[3])/20736 + 
         (141*cR^2*Zeta[3])/64 - (7*cA^2*lmuH*Zeta[3])/144 + 
         (47*cA*cR*lmuH*Zeta[3])/72 + (cA^2*lmuH^2*Zeta[3])/8 - 
         (cA*cR*lmuH^2*Zeta[3])/8 - (7*cA*nh*Zeta[3])/256 - 
         (7*cR*nh*Zeta[3])/128 - (cA^2*Pi^2*Zeta[3])/96 + 
         (5*cA*cR*Pi^2*Zeta[3])/144 - (8*d44[pR1, pR2]*Zeta[3])/NA + 
         (107*cA^2*Zeta[5])/144 + (19*cA*cR*Zeta[5])/18 - 
         (5*cR^2*Zeta[5])/2) + rhoOS^2*((931525286210119*cA^3)/
          13390585528320000 - (45596411041239749*cA^2*cR)/5021469573120000 - 
         (32616745953599441*cA*cR^2)/2008587829248000 + (8940832244231*cR^3)/
          9299017728000 - (862523231*cA^3*lmmOS)/7962624000 - 
         (29718084163*cA^2*cR*lmmOS)/27869184000 - (150640831*cA*cR^2*lmmOS)/
          99532800 - (24557*cA^3*lmmOS^2)/6220800 + (3123373*cA^2*cR*lmmOS^2)/
          174182400 + (557951*cA^3*lmuH)/2709504000 + (131*cA^2*cR*lmuH)/
          907200 + (271*cA^3*lmmOS*lmuH)/806400 + (cA^3*lmuH^2)/33600 + 
         (279660447817170163*cA^2*nh)/2227122185070182400 + 
         (9103946467641007*cA*cR*nh)/44188932243456000 - 
         (28767198935359*cR^2*nh)/23176013414400 + (9131021771*cA^2*lmmOS*nh)/
          2341011456000 - (131366449*cA*cR*lmmOS*nh)/2388787200 - 
         (83*cR^2*lmmOS*nh)/10368 + (13*cA^2*lmmOS^2*nh)/193536 - 
         (11*cA*cR*lmmOS^2*nh)/5760 - (1079069*cA^2*lmuH*nh)/406425600 + 
         (3661*cA*cR*lmuH*nh)/207360 + (83*cR^2*lmuH*nh)/10368 + 
         (37*cA^2*lmmOS*lmuH*nh)/161280 - (41*cA^2*lmuH^2*nh)/138240 + 
         (11*cA*cR*lmuH^2*nh)/5760 - (1567460838089*cA*nh^2)/
          430411677696000 + (75256328657*cR*nh^2)/1655429529600 - 
         (cA*lmmOS*nh^2)/345600 + (cA*lmuH*nh^2)/345600 + 
         (101*cA^3*Pi^2)/38707200 + (1922923*cA^2*cR*Pi^2)/174182400 - 
         (258943*cA*cR^2*Pi^2)/9676800 + (252587*cR^3*Pi^2)/3225600 - 
         (9427*cA^2*cR*lmmOS*Pi^2)/3628800 + (9427*cA*cR^2*lmmOS*Pi^2)/
          967680 - (7*cA^2*nh*Pi^2)/138240 + (364169*cA*cR*nh*Pi^2)/
          14515200 + (142571*cR^2*nh*Pi^2)/10886400 + 
         (9427*cA*cR*lmmOS*nh*Pi^2)/3628800 - (857*cR*nh^2*Pi^2)/6804000 - 
         (3097193206561*cA^3*Pi^4)/23187161088000 - 
         (880122001001*cA^2*cR*Pi^4)/6072827904000 + 
         (5392881328883*cA*cR^2*Pi^4)/7970586624000 + (81915006449*cR^3*Pi^4)/
          531372441600 - (120805964623*cA^2*nh*Pi^4)/19619905536000 + 
         (1134984511*cA*cR*nh*Pi^4)/15571353600 + (3216113*cR^2*nh*Pi^4)/
          11468800 + (3165526496521*d44[pR1, pA1])/(1162377216000*NA) - 
         (19*lmmOS*d44[pR1, pA1])/(13824*NA) + (19*lmuH*d44[pR1, pA1])/
          (13824*NA) - (300156346307*Pi^4*d44[pR1, pA1])/(1328431104000*NA) + 
         (324710282317*nh*d44[pR1, pR2])/(929901772800*NA) - 
         (1725431*nh*Pi^4*d44[pR1, pR2])/(123863040*NA) + 
         (83087*cA^2*cR*Pi^2*Log[2])/3628800 + (127229*cA*cR^2*Pi^2*Log[2])/
          3628800 - (97801*cR^3*Pi^2*Log[2])/604800 + 
         (9427*cA^2*cR*lmmOS*Pi^2*Log[2])/1209600 - 
         (9427*cA*cR^2*lmmOS*Pi^2*Log[2])/604800 - (857*cA*cR*nh*Pi^2*Log[2])/
          28350 - (857*cR^2*nh*Pi^2*Log[2])/113400 - 
         (23618467*cA^3*Pi^4*Log[2])/323481600 + 
         (5457286201*cA^2*cR*Pi^4*Log[2])/20756736000 - 
         (369704849*cA*cR^2*Pi^4*Log[2])/1729728000 + 
         (1373543*cR^3*Pi^4*Log[2])/61776000 - (485097181*Pi^4*d44[pR1, pA1]*
           Log[2])/(1297296000*NA) - (80826668141*cA^3*Pi^2*Log[2]^2)/
          193226342400 - (44871123707*cA^2*cR*Pi^2*Log[2]^2)/70849658880 + 
         (5391768463*cA*cR^2*Pi^2*Log[2]^2)/2075673600 + 
         (17258184961*cR^3*Pi^2*Log[2]^2)/22140518400 - 
         (3592767901*cA^2*nh*Pi^2*Log[2]^2)/163499212800 + 
         (231425759*cA*cR*nh*Pi^2*Log[2]^2)/908328960 + 
         (15332977*cR^2*nh*Pi^2*Log[2]^2)/15482880 - 
         (350426957*Pi^2*d44[pR1, pA1]*Log[2]^2)/(615014400*NA) - 
         (968179*nh*Pi^2*d44[pR1, pR2]*Log[2]^2)/(25804800*NA) - 
         (6212767*cA^3*Pi^2*Log[2]^3)/56609280 + 
         (191437759*cA^2*cR*Pi^2*Log[2]^3)/518918400 - 
         (1163557*cA*cR^2*Pi^2*Log[2]^3)/5405400 - (14111*cR^3*Pi^2*Log[2]^3)/
          193050 - (9152777*Pi^2*d44[pR1, pA1]*Log[2]^3)/(16216200*NA) + 
         (80826668141*cA^3*Log[2]^4)/193226342400 + 
         (73864929869*cA^2*cR*Log[2]^4)/118082764800 - 
         (5359414999*cA*cR^2*Log[2]^4)/2075673600 - 
         (17258184961*cR^3*Log[2]^4)/22140518400 + 
         (3592767901*cA^2*nh*Log[2]^4)/163499212800 - 
         (231425759*cA*cR*nh*Log[2]^4)/908328960 - 
         (15332977*cR^2*nh*Log[2]^4)/15482880 + 
         (350426957*d44[pR1, pA1]*Log[2]^4)/(615014400*NA) + 
         (968179*nh*d44[pR1, pR2]*Log[2]^4)/(25804800*NA) + 
         (6212767*cA^3*Log[2]^5)/94348800 - (191437759*cA^2*cR*Log[2]^5)/
          864864000 + (1163557*cA*cR^2*Log[2]^5)/9009000 + 
         (14111*cR^3*Log[2]^5)/321750 + (9152777*d44[pR1, pA1]*Log[2]^5)/
          (27027000*NA) + (80826668141*cA^3*PolyLog[4, 1/2])/8051097600 + 
         (73864929869*cA^2*cR*PolyLog[4, 1/2])/4920115200 - 
         (5359414999*cA*cR^2*PolyLog[4, 1/2])/86486400 - 
         (17258184961*cR^3*PolyLog[4, 1/2])/922521600 + 
         (3592767901*cA^2*nh*PolyLog[4, 1/2])/6812467200 - 
         (231425759*cA*cR*nh*PolyLog[4, 1/2])/37847040 - 
         (15332977*cR^2*nh*PolyLog[4, 1/2])/645120 + 
         (350426957*d44[pR1, pA1]*PolyLog[4, 1/2])/(25625600*NA) + 
         (968179*nh*d44[pR1, pR2]*PolyLog[4, 1/2])/(1075200*NA) - 
         (6212767*cA^3*PolyLog[5, 1/2])/786240 + 
         (191437759*cA^2*cR*PolyLog[5, 1/2])/7207200 - 
         (1163557*cA*cR^2*PolyLog[5, 1/2])/75075 - 
         (56444*cR^3*PolyLog[5, 1/2])/10725 - (9152777*d44[pR1, pA1]*
           PolyLog[5, 1/2])/(225225*NA) + (15347420321246009*cA^3*Zeta[3])/
          1785411403776000 + (54510327986573*cA^2*cR*Zeta[3])/3381460992000 - 
         (427621025497439*cA*cR^2*Zeta[3])/16531587072000 - 
         (465559397791*cR^3*Zeta[3])/52985856000 + 
         (1212761*cA^3*lmmOS*Zeta[3])/14155776 + 
         (32977087*cA^2*cR*lmmOS*Zeta[3])/35389440 + 
         (397903*cA*cR^2*lmmOS*Zeta[3])/294912 + 
         (3246617496176063*cA^2*nh*Zeta[3])/13093016961024000 - 
         (317500796298971*cA*cR*nh*Zeta[3])/72738983116800 - 
         (8707412954179*cR^2*nh*Zeta[3])/572247244800 - 
         (177947*cA^2*lmmOS*nh*Zeta[3])/141557760 + 
         (241703*cA*cR*lmmOS*nh*Zeta[3])/11796480 + 
         (2148537701*cA*nh^2*Zeta[3])/708496588800 - 
         (1478719843*cR*nh^2*Zeta[3])/40874803200 - 
         (14569*cA^2*cR*Pi^2*Zeta[3])/1075200 + (16283*cA*cR^2*Pi^2*Zeta[3])/
          806400 + (857*cR^3*Pi^2*Zeta[3])/806400 - 
         (857*cA*cR*nh*Pi^2*Zeta[3])/806400 + (33464929535239*d44[pR1, pA1]*
           Zeta[3])/(2324754432000*NA) + (1109196184493*nh*d44[pR1, pR2]*
           Zeta[3])/(1859803545600*NA) + 
         nl^2*((-1989409217*cA)/1097349120000 + (1831796039*cR)/
            1920360960000 - (1571*cA*lmmOS)/7776000 + (2560037*cR*lmmOS)/
            4572288000 - (623*cA*lmmOS^2)/12441600 + (29147*cR*lmmOS^2)/
            43545600 - (577*cA*lmuH)/907200 - (1253*cR*lmuH)/1866240 - 
           (5951*cA*lmuH^2)/87091200 - (1667*cR*lmuH^2)/21772800 + 
           (5951*cA*Pi^2)/522547200 + (68513*cR*Pi^2)/130636800 + 
           (857*cR*lmmOS*Pi^2)/3628800 - (137*cA*Zeta[3])/967680 + 
           (137*cR*Zeta[3])/483840) + nl*((54807884540179*cA^2)/
            421382062080000 + (113580183403511*cA*cR)/163870801920000 + 
           (77524529267533*cR^2)/61451550720000 + (261500519*cA^2*lmmOS)/
            11943936000 + (55995653461*cA*cR*lmmOS)/292626432000 + 
           (2480818159*cR^2*lmmOS)/9144576000 + (43079*cA^2*lmmOS^2)/
            49766400 - (2563091*cA*cR*lmmOS^2)/348364800 - 
           (26177*cR^2*lmmOS^2)/174182400 + (49595513*cA^2*lmuH)/
            18289152000 + (10175423*cA*cR*lmuH)/5225472000 + 
           (44700659*cR^2*lmuH)/36578304000 + (33781*cA^2*lmmOS*lmuH)/
            174182400 + (20693*cA*cR*lmmOS*lmuH)/24883200 + 
           (26177*cR^2*lmmOS*lmuH)/87091200 + (84613*cA^2*lmuH^2)/348364800 + 
           (41*cA*cR*lmuH^2)/7741440 - (26177*cR^2*lmuH^2)/174182400 - 
           (731731430573*cA*nh)/491612405760000 + (93497666729*cR*nh)/
            7023034368000 - (447198721*cA*lmmOS*nh)/1170505728000 + 
           (78041573*cR*lmmOS*nh)/8360755200 - (cA*lmmOS^2*nh)/30240 + 
           (cR*lmmOS^2*nh)/2880 + (1807*cA*lmuH*nh)/11612160 - 
           (739*cR*lmuH*nh)/290304 + (cA*lmuH^2*nh)/30240 - 
           (cR*lmuH^2*nh)/2880 - (84937*cA^2*Pi^2)/1045094400 - 
           (133699*cA*cR*Pi^2)/49766400 - (971171*cR^2*Pi^2)/104509440 - 
           (857*cA*cR*lmmOS*Pi^2)/1036800 - (857*cR^2*lmmOS*Pi^2)/483840 - 
           (11141*cR*nh*Pi^2)/21772800 - (857*cR*lmmOS*nh*Pi^2)/1814400 + 
           (33966659*cA^2*Pi^4)/222953472000 + (126918157*cA*cR*Pi^4)/
            22295347200 + (23480339*cR^2*Pi^4)/2786918400 - 
           (113239*cA*nh*Pi^4)/12740198400 + (153811*cR*nh*Pi^4)/1061683200 + 
           (4956899*d44[pR1, pR2])/(9797760*NA) - (1271*Pi^4*d44[pR1, pR2])/
            (81000*NA) - (9427*cA*cR*Pi^2*Log[2])/1814400 + 
           (9427*cR^2*Pi^2*Log[2])/907200 - (857*cA*cR*lmmOS*Pi^2*Log[2])/
            604800 + (857*cR^2*lmmOS*Pi^2*Log[2])/302400 + 
           (1211*cA^2*Pi^2*Log[2]^2)/17694720 + (1094417*cA*cR*Pi^2*Log[2]^2)/
            928972800 - (305393*cR^2*Pi^2*Log[2]^2)/116121600 - 
           (2311*cA*nh*Pi^2*Log[2]^2)/106168320 + (3139*cR*nh*Pi^2*Log[2]^2)/
            8847360 - (1211*cA^2*Log[2]^4)/17694720 + (6341*cA*cR*Log[2]^4)/
            26542080 - (677*cR^2*Log[2]^4)/3317760 + (2311*cA*nh*Log[2]^4)/
            106168320 - (3139*cR*nh*Log[2]^4)/8847360 - 
           (1211*cA^2*PolyLog[4, 1/2])/737280 + (6341*cA*cR*PolyLog[4, 1/2])/
            1105920 - (677*cR^2*PolyLog[4, 1/2])/138240 + 
           (2311*cA*nh*PolyLog[4, 1/2])/4423680 - 
           (3139*cR*nh*PolyLog[4, 1/2])/368640 - (259770031*cA^2*Zeta[3])/
            2378170368 - (1167497711*cA*cR*Zeta[3])/1101004800 - 
           (6450012461*cR^2*Zeta[3])/3715891200 - (110251*cA^2*lmmOS*Zeta[3])/
            7077888 - (2997917*cA*cR*lmmOS*Zeta[3])/17694720 - 
           (36173*cR^2*lmmOS*Zeta[3])/147456 + (8146879*cA*nh*Zeta[3])/
            4246732800 - (13982407*cR*nh*Zeta[3])/707788800 + 
           (16177*cA*lmmOS*nh*Zeta[3])/70778880 - (21973*cR*lmmOS*nh*Zeta[3])/
            5898240 + (16013*d44[pR1, pR2]*Zeta[3])/(18900*NA)) + 
         (39770717*cA^3*Zeta[5])/4792320 - (29765319937*cA^2*cR*Zeta[5])/
          922521600 + (5514434459*cA*cR^2*Zeta[5])/230630400 + 
         (40782799*cR^3*Zeta[5])/16473600 - (169*cA*cR*nh*Zeta[5])/4608 + 
         (836718319*d44[pR1, pA1]*Zeta[5])/(19219200*NA)) + 
       rhoOS*((-63634073593*cA^3)/45984153600 - (108540610979*cA^2*cR)/
          11496038400 - (5923723*cA*cR^2)/1126400 + (40350869*cR^3)/
          19353600 - (1189273*cA^3*lmmOS)/1105920 - (17759*cA^2*cR*lmmOS)/
          3888 - (125939*cA*cR^2*lmmOS)/30720 - (1759*cA^3*lmmOS^2)/51840 + 
         (37147*cA^2*cR*lmmOS^2)/207360 - (14923*cA^3*lmuH)/691200 - 
         (31*cA^2*cR*lmuH)/1920 - (3*cA^3*lmmOS*lmuH)/320 - 
         (cA^3*lmuH^2)/960 + (46164184187*cA^2*nh)/263363788800 - 
         (422469503371*cA*cR*nh)/1448500838400 - (3738667*cR^2*nh)/1935360 - 
         (93407*cA^2*lmmOS*nh)/9953280 - (47243*cA*cR*lmmOS*nh)/155520 + 
         (cA^2*lmmOS^2*nh)/288 - (551*cA^2*lmuH*nh)/115200 - 
         (cA*cR*lmuH*nh)/144 - (cA^2*lmmOS*lmuH*nh)/320 - 
         (cA^2*lmuH^2*nh)/2880 - (7456979*cA*nh^2)/627056640 + 
         (5672797*cR*nh^2)/39191040 - (cA^3*Pi^2)/11520 + 
         (15509*cA^2*cR*Pi^2)/207360 - (1921*cA*cR^2*Pi^2)/11520 + 
         (39*cR^3*Pi^2)/80 - (77*cA^2*cR*lmmOS*Pi^2)/4320 + 
         (77*cA*cR^2*lmmOS*Pi^2)/1152 + (cA^2*nh*Pi^2)/1440 + 
         (997*cA*cR*nh*Pi^2)/5760 + (397*cR^2*nh*Pi^2)/5184 + 
         (77*cA*cR*lmmOS*nh*Pi^2)/4320 - (7*cR*nh^2*Pi^2)/8100 + 
         (9152173421*cA^3*Pi^4)/30656102400 + (53694337*cA^2*cR*Pi^4)/
          1703116800 - (1575010747*cA*cR^2*Pi^4)/1277337600 + 
         (6391789*cR^3*Pi^4)/58060800 - (21382733*cA^2*nh*Pi^4)/1393459200 + 
         (18633947*cA*cR*nh*Pi^4)/696729600 + (3713*cR^2*nh*Pi^4)/20736 - 
         (34050439*d44[pR1, pA1])/(13305600*NA) + 
         (76339381*Pi^4*d44[pR1, pA1])/(63866880*NA) + 
         (22518469*nh*d44[pR1, pR2])/(15966720*NA) + 
         (1489*nh*Pi^4*d44[pR1, pR2])/(17280*NA) + (691*cA^2*cR*Pi^2*Log[2])/
          4320 + (337*cA*cR^2*Pi^2*Log[2])/1728 - (1483*cR^3*Pi^2*Log[2])/
          1440 + (77*cA^2*cR*lmmOS*Pi^2*Log[2])/1440 - 
         (77*cA*cR^2*lmmOS*Pi^2*Log[2])/720 - (28*cA*cR*nh*Pi^2*Log[2])/135 - 
         (7*cR^2*nh*Pi^2*Log[2])/135 - (682603*cA^3*Pi^4*Log[2])/15966720 + 
         (1826267*cA^2*cR*Pi^4*Log[2])/4435200 + (525419*cA*cR^2*Pi^4*Log[2])/
          3326400 - (7249*cR^3*Pi^4*Log[2])/5040 - 
         (911441*Pi^4*d44[pR1, pA1]*Log[2])/(831600*NA) + 
         (292864841*cA^3*Pi^2*Log[2]^2)/255467520 - 
         (1639433*cA^2*cR*Pi^2*Log[2]^2)/14192640 - 
         (13191733*cA*cR^2*Pi^2*Log[2]^2)/2661120 + 
         (169693*cR^3*Pi^2*Log[2]^2)/483840 - (1211281*cA^2*nh*Pi^2*Log[2]^2)/
          23224320 + (558029*cA*cR*nh*Pi^2*Log[2]^2)/5806080 + 
         (1103*cR^2*nh*Pi^2*Log[2]^2)/1728 + (2729191*Pi^2*d44[pR1, pA1]*
           Log[2]^2)/(532224*NA) + (151*nh*Pi^2*d44[pR1, pR2]*Log[2]^2)/
          (360*NA) - (30505*cA^3*Pi^2*Log[2]^3)/399168 + 
         (49673*cA^2*cR*Pi^2*Log[2]^3)/110880 + (9239*cA*cR^2*Pi^2*Log[2]^3)/
          20790 - (113*cR^3*Pi^2*Log[2]^3)/63 - 
         (17197*Pi^2*d44[pR1, pA1]*Log[2]^3)/(10395*NA) - 
         (292864841*cA^3*Log[2]^4)/255467520 + (293507*cA^2*cR*Log[2]^4)/
          4730880 + (2695265*cA*cR^2*Log[2]^4)/532224 - 
         (169693*cR^3*Log[2]^4)/483840 + (1211281*cA^2*nh*Log[2]^4)/
          23224320 - (558029*cA*cR*nh*Log[2]^4)/5806080 - 
         (1103*cR^2*nh*Log[2]^4)/1728 - (2729191*d44[pR1, pA1]*Log[2]^4)/
          (532224*NA) - (151*nh*d44[pR1, pR2]*Log[2]^4)/(360*NA) + 
         (6101*cA^3*Log[2]^5)/133056 - (49673*cA^2*cR*Log[2]^5)/184800 - 
         (9239*cA*cR^2*Log[2]^5)/34650 + (113*cR^3*Log[2]^5)/105 + 
         (17197*d44[pR1, pA1]*Log[2]^5)/(17325*NA) - 
         (292864841*cA^3*PolyLog[4, 1/2])/10644480 + 
         (293507*cA^2*cR*PolyLog[4, 1/2])/197120 + 
         (2695265*cA*cR^2*PolyLog[4, 1/2])/22176 - 
         (169693*cR^3*PolyLog[4, 1/2])/20160 + 
         (1211281*cA^2*nh*PolyLog[4, 1/2])/967680 - 
         (558029*cA*cR*nh*PolyLog[4, 1/2])/241920 - 
         (1103*cR^2*nh*PolyLog[4, 1/2])/72 - (2729191*d44[pR1, pA1]*
           PolyLog[4, 1/2])/(22176*NA) - (151*nh*d44[pR1, pR2]*
           PolyLog[4, 1/2])/(15*NA) - (30505*cA^3*PolyLog[5, 1/2])/5544 + 
         (49673*cA^2*cR*PolyLog[5, 1/2])/1540 + 
         (36956*cA*cR^2*PolyLog[5, 1/2])/1155 - (904*cR^3*PolyLog[5, 1/2])/
          7 - (137576*d44[pR1, pA1]*PolyLog[5, 1/2])/(1155*NA) - 
         (9898132063*cA^3*Zeta[3])/681246720 + (351981443*cA^2*cR*Zeta[3])/
          77414400 + (463053131*cA*cR^2*Zeta[3])/5529600 - 
         (34382291*cR^3*Zeta[3])/4300800 + (128953*cA^3*lmmOS*Zeta[3])/
          147456 + (25267*cA^2*cR*lmmOS*Zeta[3])/6144 + 
         (146531*cA*cR^2*lmmOS*Zeta[3])/36864 + (4761740101*cA^2*nh*Zeta[3])/
          6502809600 - (19932189773*cA*cR*nh*Zeta[3])/11921817600 - 
         (34455263*cR^2*nh*Zeta[3])/3870720 + (847*cA^2*lmmOS*nh*Zeta[3])/
          147456 + (847*cA*cR*lmmOS*nh*Zeta[3])/4608 + 
         (48323*cA*nh^2*Zeta[3])/5160960 - (99703*cR*nh^2*Zeta[3])/967680 - 
         (119*cA^2*cR*Pi^2*Zeta[3])/1280 + (133*cA*cR^2*Pi^2*Zeta[3])/960 + 
         (7*cR^3*Pi^2*Zeta[3])/960 - (7*cA*cR*nh*Pi^2*Zeta[3])/960 - 
         (1075459339*d44[pR1, pA1]*Zeta[3])/(17740800*NA) - 
         (56867891*nh*d44[pR1, pR2]*Zeta[3])/(10644480*NA) + 
         nl^2*((-5706901*cA)/186624000 + (7417*cR)/1944000 - 
           (91*cA*lmmOS)/86400 - (329*cR*lmmOS)/259200 - (31*cA*lmmOS^2)/
            103680 + (13*cR*lmmOS^2)/1920 - (197*cA*lmuH)/17280 - 
           (127*cR*lmuH)/15552 - (121*cA*lmuH^2)/103680 - 
           (11*cR*lmuH^2)/12960 + (121*cA*Pi^2)/622080 + (71*cR*Pi^2)/19440 + 
           (7*cR*lmmOS*Pi^2)/4320 - (11*cA*Zeta[3])/5760 + 
           (11*cR*Zeta[3])/2880) + nl*((217258903*cA^2)/1492992000 - 
           (237007*cA*cR)/14929920 + (232695403*cR^2)/373248000 + 
           (5607103*cA^2*lmmOS)/24883200 + (534161*cA*cR*lmmOS)/622080 + 
           (4450553*cR^2*lmmOS)/6220800 + (2263*cA^2*lmmOS^2)/414720 - 
           (143*cA*cR*lmmOS^2)/1920 - (11*cR^2*lmmOS^2)/6480 + 
           (145579*cA^2*lmuH)/3110400 + (50639*cA*cR*lmuH)/3110400 + 
           (641*cR^2*lmuH)/194400 + (1331*cA^2*lmmOS*lmuH)/207360 + 
           (121*cA*cR*lmmOS*lmuH)/12960 + (11*cR^2*lmmOS*lmuH)/3240 + 
           (1763*cA^2*lmuH^2)/414720 - (11*cR^2*lmuH^2)/6480 - 
           (2084813*cA*nh)/93312000 + (315709*cR*nh)/4665600 + 
           (61217*cA*lmmOS*nh)/24883200 + (4537*cR*lmmOS*nh)/77760 - 
           (cA*lmmOS^2*nh)/2880 + (cA*lmuH*nh)/8640 - (cR*lmuH*nh)/540 + 
           (cA*lmuH^2*nh)/2880 - (1547*cA^2*Pi^2)/1244160 - 
           (241*cA*cR*Pi^2)/12960 - (8849*cR^2*Pi^2)/155520 - 
           (49*cA*cR*lmmOS*Pi^2)/8640 - (7*cR^2*lmmOS*Pi^2)/576 - 
           (91*cR*nh*Pi^2)/25920 - (7*cR*lmmOS*nh*Pi^2)/2160 + 
           (255553*cA^2*Pi^4)/66355200 + (41549*cA*cR*Pi^4)/1658880 + 
           (28693*cR^2*Pi^4)/1105920 + (539*cA*nh*Pi^4)/13271040 + 
           (539*cR*nh*Pi^4)/414720 + (1079*d44[pR1, pR2])/(480*NA) - 
           (17*Pi^4*d44[pR1, pR2])/(270*NA) - (77*cA*cR*Pi^2*Log[2])/2160 + 
           (77*cR^2*Pi^2*Log[2])/1080 - (7*cA*cR*lmmOS*Pi^2*Log[2])/720 + 
           (7*cR^2*lmmOS*Pi^2*Log[2])/360 + (157*cA^2*Pi^2*Log[2]^2)/110592 + 
           (337*cA*cR*Pi^2*Log[2]^2)/69120 - (79*cR^2*Pi^2*Log[2]^2)/5120 + 
           (11*cA*nh*Pi^2*Log[2]^2)/110592 + (11*cR*nh*Pi^2*Log[2]^2)/3456 - 
           (157*cA^2*Log[2]^4)/110592 + (67*cA*cR*Log[2]^4)/13824 - 
           (37*cR^2*Log[2]^4)/9216 - (11*cA*nh*Log[2]^4)/110592 - 
           (11*cR*nh*Log[2]^4)/3456 - (157*cA^2*PolyLog[4, 1/2])/4608 + 
           (67*cA*cR*PolyLog[4, 1/2])/576 - (37*cR^2*PolyLog[4, 1/2])/384 - 
           (11*cA*nh*PolyLog[4, 1/2])/4608 - (11*cR*nh*PolyLog[4, 1/2])/144 - 
           (397837*cA^2*Zeta[3])/1474560 - (2500723*cA*cR*Zeta[3])/1105920 - 
           (2851187*cR^2*Zeta[3])/1105920 - (11723*cA^2*lmmOS*Zeta[3])/
            73728 - (2297*cA*cR*lmmOS*Zeta[3])/3072 - 
           (13321*cR^2*lmmOS*Zeta[3])/18432 + (5747*cA*nh*Zeta[3])/552960 - 
           (7777*cR*nh*Zeta[3])/69120 - (77*cA*lmmOS*nh*Zeta[3])/73728 - 
           (77*cR*lmmOS*nh*Zeta[3])/2304 + (287*d44[pR1, pR2]*Zeta[3])/
            (90*NA)) + (3272351*cA^3*Zeta[5])/709632 - 
         (8467699*cA^2*cR*Zeta[5])/197120 - (6315343*cA*cR^2*Zeta[5])/
          147840 + (221063*cR^3*Zeta[5])/1344 + (55*cA*cR*nh*Zeta[5])/192 + 
         (4961977*d44[pR1, pA1]*Zeta[5])/(36960*NA))) + 
     api5*((5*cA)/4 - (3*cR)/4 - cA/(2*ep^2) - (cA*lmuH^2)/4 + 
       ((-11*cA)/12 - (cA*lmuH)/2 + nl/6)/ep + (cA*Pi^2)/24 + 
       ep*((-11*cA)/6 + (29*cR)/8 + (5*cA*lmmOS)/4 - (3*cR*lmmOS)/4 - 
         (cA*lmuH^3)/12 + (cA*lmuH*Pi^2)/24 + (7*cA*Zeta[3])/6) + 
       ep^2*((8*cA)/9 + (29*cR)/16 - (4*cA*lmmOS)/3 + (29*cR*lmmOS)/8 + 
         (5*cA*lmmOS^2)/8 - (3*cR*lmmOS^2)/8 - (cA*lmuH)/2 - (cA*lmuH^4)/48 + 
         (5*cA*Pi^2)/48 - (cR*Pi^2)/16 + (cA*lmuH^2*Pi^2)/48 + 
         (47*cA*Pi^4)/2880 + (7*cA*lmuH*Zeta[3])/6) + 
       ep^3*((-901*cA)/108 + (413*cR)/32 + (43*cA*lmmOS)/18 + 
         (29*cR*lmmOS)/16 - (2*cA*lmmOS^2)/3 + (29*cR*lmmOS^2)/16 + 
         (5*cA*lmmOS^3)/24 - (cR*lmmOS^3)/8 - (3*cA*lmuH)/2 - (cA*lmuH^2)/4 - 
         (cA*lmuH^5)/240 - (5*cA*Pi^2)/72 + (29*cR*Pi^2)/96 + 
         (5*cA*lmmOS*Pi^2)/48 - (cR*lmmOS*Pi^2)/16 + (cA*lmuH^3*Pi^2)/144 + 
         (47*cA*lmuH*Pi^4)/2880 - (5*cA*Zeta[3])/12 + (cR*Zeta[3])/4 + 
         (7*cA*lmuH^2*Zeta[3])/12 - (7*cA*Pi^2*Zeta[3])/72 + 
         (31*cA*Zeta[5])/10) + ep^4*((1363*cA)/648 + (413*cR)/64 - 
         (523*cA*lmmOS)/108 + (413*cR*lmmOS)/32 + (43*cA*lmmOS^2)/36 + 
         (29*cR*lmmOS^2)/32 - (2*cA*lmmOS^3)/9 + (29*cR*lmmOS^3)/48 + 
         (5*cA*lmmOS^4)/96 - (cR*lmmOS^4)/32 - (7*cA*lmuH)/2 - 
         (3*cA*lmuH^2)/4 - (cA*lmuH^3)/12 - (cA*lmuH^6)/1440 + 
         (35*cA*Pi^2)/108 + (29*cR*Pi^2)/192 - (cA*lmmOS*Pi^2)/9 + 
         (29*cR*lmmOS*Pi^2)/96 + (5*cA*lmmOS^2*Pi^2)/96 - 
         (cR*lmmOS^2*Pi^2)/32 + (cA*lmuH*Pi^2)/24 + (cA*lmuH^4*Pi^2)/576 + 
         (cA*Pi^4)/128 - (3*cR*Pi^4)/640 + (47*cA*lmuH^2*Pi^4)/5760 + 
         (949*cA*Pi^6)/241920 + (29*cA*Zeta[3])/18 - (29*cR*Zeta[3])/24 - 
         (5*cA*lmmOS*Zeta[3])/12 + (cR*lmmOS*Zeta[3])/4 + 
         (7*cA*lmuH^3*Zeta[3])/36 - (7*cA*lmuH*Pi^2*Zeta[3])/72 - 
         (49*cA*Zeta[3]^2)/36 + (31*cA*lmuH*Zeta[5])/10) + 
       rhoOS^2*((-1289*cA)/302400 + (25813*cR)/1209600 + 
         ep*((213757*cA)/127008000 + (1657343*cR)/36288000 - 
           (1289*cA*lmmOS)/302400 + (25813*cR*lmmOS)/1209600) + 
         ep^2*((-7931297*cA)/2963520000 + (1425229*cR)/13440000 + 
           (213757*cA*lmmOS)/127008000 + (1657343*cR*lmmOS)/36288000 - 
           (1289*cA*lmmOS^2)/604800 + (25813*cR*lmmOS^2)/2419200 - 
           (1289*cA*Pi^2)/3628800 + (25813*cR*Pi^2)/14515200) + 
         ep^3*((26541781157*cA)/5601052800000 + (7349209537*cR)/32659200000 - 
           (7931297*cA*lmmOS)/2963520000 + (1425229*cR*lmmOS)/13440000 + 
           (213757*cA*lmmOS^2)/254016000 + (1657343*cR*lmmOS^2)/72576000 - 
           (1289*cA*lmmOS^3)/1814400 + (25813*cR*lmmOS^3)/7257600 + 
           (213757*cA*Pi^2)/1524096000 + (1657343*cR*Pi^2)/435456000 - 
           (1289*cA*lmmOS*Pi^2)/3628800 + (25813*cR*lmmOS*Pi^2)/14515200 + 
           (1289*cA*Zeta[3])/907200 - (25813*cR*Zeta[3])/3628800) + 
         ep^4*((-17343922860563*cA)/1176221088000000 + (117999553139*cR)/
            244944000000 + (26541781157*cA*lmmOS)/5601052800000 + 
           (7349209537*cR*lmmOS)/32659200000 - (7931297*cA*lmmOS^2)/
            5927040000 + (1425229*cR*lmmOS^2)/26880000 + (213757*cA*lmmOS^3)/
            762048000 + (1657343*cR*lmmOS^3)/217728000 - (1289*cA*lmmOS^4)/
            7257600 + (25813*cR*lmmOS^4)/29030400 - (7931297*cA*Pi^2)/
            35562240000 + (1425229*cR*Pi^2)/161280000 + 
           (213757*cA*lmmOS*Pi^2)/1524096000 + (1657343*cR*lmmOS*Pi^2)/
            435456000 - (1289*cA*lmmOS^2*Pi^2)/7257600 + 
           (25813*cR*lmmOS^2*Pi^2)/29030400 - (1289*cA*Pi^4)/48384000 + 
           (25813*cR*Pi^4)/193536000 - (213757*cA*Zeta[3])/381024000 - 
           (1657343*cR*Zeta[3])/108864000 + (1289*cA*lmmOS*Zeta[3])/907200 - 
           (25813*cR*lmmOS*Zeta[3])/3628800 + (857*cR*Zeta[5])/168000)) + 
       rhoOS*((-19*cA)/360 + (307*cR)/1440 + ep*((1841*cA)/21600 + 
           (163*cR)/960 - (19*cA*lmmOS)/360 + (307*cR*lmmOS)/1440) + 
         ep^2*((-6473*cA)/72000 + (39533*cR)/51840 + (1841*cA*lmmOS)/21600 + 
           (163*cR*lmmOS)/960 - (19*cA*lmmOS^2)/720 + (307*cR*lmmOS^2)/2880 - 
           (19*cA*Pi^2)/4320 + (307*cR*Pi^2)/17280) + 
         ep^3*((2830159*cA)/19440000 + (78379*cR)/62208 - 
           (6473*cA*lmmOS)/72000 + (39533*cR*lmmOS)/51840 + 
           (1841*cA*lmmOS^2)/43200 + (163*cR*lmmOS^2)/1920 - 
           (19*cA*lmmOS^3)/2160 + (307*cR*lmmOS^3)/8640 + 
           (1841*cA*Pi^2)/259200 + (163*cR*Pi^2)/11520 - (19*cA*lmmOS*Pi^2)/
            4320 + (307*cR*lmmOS*Pi^2)/17280 + (19*cA*Zeta[3])/1080 - 
           (307*cR*Zeta[3])/4320) + ep^4*((-171906283*cA)/583200000 + 
           (383179*cR)/124416 + (2830159*cA*lmmOS)/19440000 + 
           (78379*cR*lmmOS)/62208 - (6473*cA*lmmOS^2)/144000 + 
           (39533*cR*lmmOS^2)/103680 + (1841*cA*lmmOS^3)/129600 + 
           (163*cR*lmmOS^3)/5760 - (19*cA*lmmOS^4)/8640 + (307*cR*lmmOS^4)/
            34560 - (6473*cA*Pi^2)/864000 + (39533*cR*Pi^2)/622080 + 
           (1841*cA*lmmOS*Pi^2)/259200 + (163*cR*lmmOS*Pi^2)/11520 - 
           (19*cA*lmmOS^2*Pi^2)/8640 + (307*cR*lmmOS^2*Pi^2)/34560 - 
           (19*cA*Pi^4)/57600 + (307*cR*Pi^4)/230400 - (1841*cA*Zeta[3])/
            64800 - (163*cR*Zeta[3])/2880 + (19*cA*lmmOS*Zeta[3])/1080 - 
           (307*cR*lmmOS*Zeta[3])/4320 + (7*cR*Zeta[5])/200))) + 
     api5^2*((15727*cA^2)/5184 - (55*cA*cR)/48 + (9*cR^2)/16 + 
       (7*cA^2*lmmOS)/16 - (11*cA*cR*lmmOS)/16 - (5*cA^2*lmuH)/27 - 
       (67*cA^2*lmuH^2)/144 - (11*cA^2*lmuH^3)/144 - (5*cA*nh)/192 - 
       (cR*nh)/24 + ((11*cA^2)/32 - (cA*nl)/16)/ep^3 + (67*cA^2*Pi^2)/576 + 
       (11*cA^2*lmuH*Pi^2)/144 + (cA^2*lmuH^2*Pi^2)/48 + 
       ((3*cA^2)/16 + (11*cA^2*lmuH)/48 + ((-17*cA)/144 - (cA*lmuH)/24)*nl + 
         nl^2/72 + (cA^2*Pi^2)/96)/ep^2 - (143*cA^2*Zeta[3])/144 + 
       (cA^2*lmuH*Zeta[3])/8 + ((-173*cA^2)/216 - (67*cA^2*lmuH)/144 + 
         (11*cA^2*Pi^2)/576 + (cA^2*lmuH*Pi^2)/48 + 
         nl*((4*cA)/27 + cR/16 + (5*cA*lmuH)/72 - (cA*Pi^2)/288) + 
         (cA^2*Zeta[3])/16)/ep + nl*((-2255*cA)/2592 - (41*cR)/48 + 
         (cR*lmmOS)/4 - (13*cA*lmuH)/108 - (cR*lmuH)/8 + (5*cA*lmuH^2)/72 + 
         (cA*lmuH^3)/72 - (5*cA*Pi^2)/288 - (cA*lmuH*Pi^2)/72 - 
         (23*cA*Zeta[3])/72 + (cR*Zeta[3])/2) + 
       ep*((474899*cA^2)/62208 - (4793*cA*cR)/1152 - (115*cR^2)/64 + 
         (29*cA^2*lmmOS)/32 + (33*cA*cR*lmmOS)/32 + (9*cR^2*lmmOS)/8 + 
         (97*cA^2*lmmOS^2)/96 - (33*cA*cR*lmmOS^2)/32 + 
         (4511*cA^2*lmuH)/1296 - (5*cA^2*lmuH^2)/27 - (67*cA^2*lmuH^3)/216 - 
         (11*cA^2*lmuH^4)/192 - (1423*cA*nh)/3456 - (959*cR*nh)/576 - 
         (5*cA*lmmOS*nh)/96 - (cR*lmmOS*nh)/12 + (347*cA^2*Pi^2)/1728 - 
         (43*cA*cR*Pi^2)/192 + (5*cR^2*Pi^2)/8 + (67*cA^2*lmuH*Pi^2)/288 + 
         (55*cA^2*lmuH^2*Pi^2)/576 + (cA^2*lmuH^3*Pi^2)/72 + (cR*nh*Pi^2)/6 - 
         (11*cA^2*Pi^4)/640 + (cA*cR*Pi^2*Log[2])/2 - cR^2*Pi^2*Log[2] - 
         (36043*cA^2*Zeta[3])/13824 + (3627*cA*cR*Zeta[3])/256 - 
         (189*cR^2*Zeta[3])/64 - (11*cA^2*lmuH*Zeta[3])/12 + 
         (cA^2*lmuH^2*Zeta[3])/8 + (63*cA*nh*Zeta[3])/256 + 
         (63*cR*nh*Zeta[3])/128 - (5*cA^2*Pi^2*Zeta[3])/288 + 
         nl*((-53219*cA)/15552 - (47*cR)/16 - (5*cA*lmmOS)/48 - 
           (11*cR*lmmOS)/12 - (5*cA*lmmOS^2)/48 + (5*cR*lmmOS^2)/16 - 
           (431*cA*lmuH)/324 - (67*cR*lmuH)/48 - (13*cA*lmuH^2)/108 - 
           (cR*lmuH^2)/8 + (5*cA*lmuH^3)/108 + (cA*lmuH^4)/96 - 
           (cA*Pi^2)/54 - (11*cR*Pi^2)/288 - (5*cA*lmuH*Pi^2)/144 - 
           (5*cA*lmuH^2*Pi^2)/288 - (53*cA*Pi^4)/8640 + (cR*Pi^4)/108 - 
           (151*cA*Zeta[3])/108 + (23*cR*Zeta[3])/12 - (5*cA*lmuH*Zeta[3])/
            6 + cR*lmuH*Zeta[3]) + (39*cA^2*Zeta[5])/16) + 
       ep^2*((8812621*cA^2)/186624 + (73847*cA*cR)/3456 - (2483*cR^2)/192 - 
         (7385*cA^2*lmmOS)/3456 - (959*cA*cR*lmmOS)/144 - 
         (115*cR^2*lmmOS)/32 + (85*cA^2*lmmOS^2)/288 + (517*cA*cR*lmmOS^2)/
          192 + (9*cR^2*lmmOS^2)/8 + (83*cA^2*lmmOS^3)/96 - 
         (77*cA*cR*lmmOS^3)/96 + (141677*cA^2*lmuH)/7776 + 
         (2107*cA^2*lmuH^2)/648 - (10*cA^2*lmuH^3)/81 - 
         (67*cA^2*lmuH^4)/432 - (77*cA^2*lmuH^5)/2880 + (9533*cA*nh)/20736 - 
         (13831*cR*nh)/1728 - (1423*cA*lmmOS*nh)/1728 - 
         (959*cR*lmmOS*nh)/288 - (5*cA*lmmOS^2*nh)/96 - (cR*lmmOS^2*nh)/12 + 
         (2645*cA^2*Pi^2)/10368 - (271*cA*cR*Pi^2)/384 + (113*cR^2*Pi^2)/32 + 
         (97*cA^2*lmmOS*Pi^2)/576 - (97*cA*cR*lmmOS*Pi^2)/192 + 
         (5*cR^2*lmmOS*Pi^2)/4 + (71*cA^2*lmuH*Pi^2)/216 + 
         (67*cA^2*lmuH^2*Pi^2)/288 + (121*cA^2*lmuH^3*Pi^2)/1728 + 
         (cA^2*lmuH^4*Pi^2)/144 - (5*cA*nh*Pi^2)/1152 + 
         (119*cR*nh*Pi^2)/144 + (cR*lmmOS*nh*Pi^2)/3 + (7411*cA^2*Pi^4)/
          138240 - (2287*cA*cR*Pi^4)/2560 + (139*cR^2*Pi^4)/1920 - 
         (671*cA^2*lmuH*Pi^4)/34560 - (51*cA*nh*Pi^4)/2560 - 
         (51*cR*nh*Pi^4)/1280 + (2623*cA^2*Pi^6)/241920 + 
         3*cA*cR*Pi^2*Log[2] - 6*cR^2*Pi^2*Log[2] + cA*cR*lmmOS*Pi^2*Log[2] - 
         2*cR^2*lmmOS*Pi^2*Log[2] - cR*nh*Pi^2*Log[2] + 
         (263*cA^2*Pi^2*Log[2]^2)/256 - (509*cA*cR*Pi^2*Log[2]^2)/128 + 
         (123*cR^2*Pi^2*Log[2]^2)/32 - (9*cA*nh*Pi^2*Log[2]^2)/128 - 
         (9*cR*nh*Pi^2*Log[2]^2)/64 - (263*cA^2*Log[2]^4)/256 + 
         (317*cA*cR*Log[2]^4)/128 - (27*cR^2*Log[2]^4)/32 + 
         (9*cA*nh*Log[2]^4)/128 + (9*cR*nh*Log[2]^4)/64 - 
         (789*cA^2*PolyLog[4, 1/2])/32 + (951*cA*cR*PolyLog[4, 1/2])/16 - 
         (81*cR^2*PolyLog[4, 1/2])/4 + (27*cA*nh*PolyLog[4, 1/2])/16 + 
         (27*cR*nh*PolyLog[4, 1/2])/8 - (2331649*cA^2*Zeta[3])/82944 + 
         (85471*cA*cR*Zeta[3])/1536 + (647*cR^2*Zeta[3])/64 + 
         (15*cA^2*lmmOS*Zeta[3])/256 + (3627*cA*cR*lmmOS*Zeta[3])/128 - 
         (189*cR^2*lmmOS*Zeta[3])/32 - (1139*cA^2*lmuH*Zeta[3])/216 - 
         (55*cA^2*lmuH^2*Zeta[3])/144 + (cA^2*lmuH^3*Zeta[3])/12 + 
         (1799*cA*nh*Zeta[3])/1536 + (1561*cR*nh*Zeta[3])/256 + 
         (63*cA*lmmOS*nh*Zeta[3])/128 + (63*cR*lmmOS*nh*Zeta[3])/64 - 
         (11*cA^2*Pi^2*Zeta[3])/108 - (5*cA^2*lmuH*Pi^2*Zeta[3])/144 + 
         (235*cA^2*Zeta[3]^2)/48 - (341*cA^2*Zeta[5])/240 + 
         (39*cA^2*lmuH*Zeta[5])/8 + nl*((-1039409*cA)/93312 - 
           (38905*cR)/1728 - (685*cA*lmmOS)/864 + (31*cR*lmmOS)/36 + 
           (cA*lmmOS^2)/144 - (39*cR*lmmOS^2)/32 - (5*cA*lmmOS^3)/48 + 
           (11*cR*lmmOS^3)/48 - (24103*cA*lmuH)/3888 - (2027*cR*lmuH)/288 - 
           (835*cA*lmuH^2)/648 - (67*cR*lmuH^2)/48 - (13*cA*lmuH^3)/162 - 
           (cR*lmuH^3)/12 + (5*cA*lmuH^4)/216 + (7*cA*lmuH^5)/1440 + 
           (47*cA*Pi^2)/5184 - (427*cR*Pi^2)/1728 - (5*cA*lmmOS*Pi^2)/288 - 
           (11*cR*lmmOS*Pi^2)/96 - (cA*lmuH*Pi^2)/27 + (7*cR*lmuH*Pi^2)/144 - 
           (5*cA*lmuH^2*Pi^2)/144 - (11*cA*lmuH^3*Pi^2)/864 - 
           (257*cA*Pi^4)/10368 + (23*cR*Pi^4)/648 - (259*cA*lmuH*Pi^4)/
            17280 + (cR*lmuH*Pi^4)/54 - (2521*cA*Zeta[3])/648 + 
           (83*cR*Zeta[3])/9 - (151*cA*lmuH*Zeta[3])/54 + 
           (23*cR*lmuH*Zeta[3])/6 - (67*cA*lmuH^2*Zeta[3])/72 + 
           cR*lmuH^2*Zeta[3] + (17*cA*Pi^2*Zeta[3])/108 - (5*cR*Pi^2*Zeta[3])/
            36 - (209*cA*Zeta[5])/120 + 2*cR*Zeta[5])) + 
       rhoOS*((-532639*cA^2)/921600 - (133883*cA*cR)/51840 - 
         (11449*cR^2)/5120 - (91*cA^2*lmmOS)/2160 + (3377*cA*cR*lmmOS)/
          17280 - (cA^2*lmuH)/160 - (64097*cA*nh)/8294400 - 
         (4393*cR*nh)/25920 + (cA*lmmOS*nh)/480 - (cA*lmuH*nh)/480 - 
         (7*cA*cR*Pi^2)/720 + (7*cR^2*Pi^2)/192 + (7*cR*nh*Pi^2)/720 + 
         nl*((269*cA)/7200 + (7337*cR)/259200 + (31*cA*lmmOS)/17280 - 
           (13*cR*lmmOS)/320 + (121*cA*lmuH)/17280 + (11*cR*lmuH)/2160 - 
           (7*cR*Pi^2)/1440) + (7*cA*cR*Pi^2*Log[2])/240 - 
         (7*cR^2*Pi^2*Log[2])/120 + (11723*cA^2*Zeta[3])/24576 + 
         (2297*cA*cR*Zeta[3])/1024 + (13321*cR^2*Zeta[3])/6144 + 
         (77*cA*nh*Zeta[3])/24576 + (77*cR*nh*Zeta[3])/768 + 
         ep*((419893529*cA^2)/99532800 + (215533621*cA*cR)/24883200 - 
           (2105*cR^2)/4096 - (853699*cA^2*lmmOS)/829440 - 
           (103879*cA*cR*lmmOS)/20736 - (11449*cR^2*lmmOS)/2560 - 
           (191*cA^2*lmmOS^2)/2880 + (3377*cA*cR*lmmOS^2)/11520 - 
           (559*cA^2*lmuH)/11520 - (cA^2*lmuH^2)/160 + (10145057*cA*nh)/
            124416000 - (62839*cR*nh)/82944 - (64097*cA*lmmOS*nh)/4147200 - 
           (4393*cR*lmmOS*nh)/12960 + (cA*lmmOS^2*nh)/320 - 
           (cA*lmmOS*lmuH*nh)/480 - (cA*lmuH^2*nh)/960 - (31*cA^2*Pi^2)/
            10368 - (1643*cA*cR*Pi^2)/41472 + (91*cR^2*Pi^2)/384 - 
           (7*cA*cR*lmmOS*Pi^2)/360 + (7*cR^2*lmmOS*Pi^2)/96 + 
           (cA*nh*Pi^2)/2880 + (7*cR*nh*Pi^2)/120 + (7*cR*lmmOS*nh*Pi^2)/
            360 - (3721*cA^2*Pi^4)/147456 - (3151*cA*cR*Pi^4)/30720 - 
           (4499*cR^2*Pi^4)/36864 - (187*cA*nh*Pi^4)/737280 - 
           (187*cR*nh*Pi^4)/23040 + nl*((381067*cA)/1944000 - 
             (2200553*cR)/7776000 - (539*cA*lmmOS)/259200 - 
             (271*cR*lmmOS)/43200 + (107*cA*lmmOS^2)/17280 - 
             (1009*cR*lmmOS^2)/17280 + (649*cA*lmuH)/10368 + 
             (1793*cR*lmuH)/51840 + (121*cA*lmuH^2)/17280 + 
             (11*cR*lmuH^2)/2160 - (cA*Pi^2)/2304 - (2663*cR*Pi^2)/103680 - 
             (7*cR*lmmOS*Pi^2)/720) + (49*cA*cR*Pi^2*Log[2])/240 - 
           (49*cR^2*Pi^2*Log[2])/120 + (7*cA*cR*lmmOS*Pi^2*Log[2])/120 - 
           (7*cR^2*lmmOS*Pi^2*Log[2])/60 - (7*cR*nh*Pi^2*Log[2])/120 - 
           (157*cA^2*Pi^2*Log[2]^2)/12288 - (337*cA*cR*Pi^2*Log[2]^2)/7680 + 
           (711*cR^2*Pi^2*Log[2]^2)/5120 - (11*cA*nh*Pi^2*Log[2]^2)/12288 - 
           (11*cR*nh*Pi^2*Log[2]^2)/384 + (157*cA^2*Log[2]^4)/12288 - 
           (67*cA*cR*Log[2]^4)/1536 + (37*cR^2*Log[2]^4)/1024 + 
           (11*cA*nh*Log[2]^4)/12288 + (11*cR*nh*Log[2]^4)/384 + 
           (157*cA^2*PolyLog[4, 1/2])/512 - (67*cA*cR*PolyLog[4, 1/2])/64 + 
           (111*cR^2*PolyLog[4, 1/2])/128 + (11*cA*nh*PolyLog[4, 1/2])/512 + 
           (11*cR*nh*PolyLog[4, 1/2])/16 - (483385*cA^2*Zeta[3])/294912 + 
           (342011*cA*cR*Zeta[3])/122880 + (1263209*cR^2*Zeta[3])/122880 + 
           (11723*cA^2*lmmOS*Zeta[3])/12288 + (2297*cA*cR*lmmOS*Zeta[3])/
            512 + (13321*cR^2*lmmOS*Zeta[3])/3072 - (19537*cA*nh*Zeta[3])/
            368640 + (82579*cR*nh*Zeta[3])/92160 + (77*cA*lmmOS*nh*Zeta[3])/
            12288 + (77*cR*lmmOS*nh*Zeta[3])/384) + 
         ep^2*((-54099302549*cA^2)/2488320000 - (4205023867*cA*cR)/
            124416000 - (17890157*cR^2)/552960 + (2137608781*cA^2*lmmOS)/
            248832000 + (74743627*cA*cR*lmmOS)/4147200 - (2105*cR^2*lmmOS)/
            2048 - (1368829*cA^2*lmmOS^2)/1382400 - (1022653*cA*cR*lmmOS^2)/
            207360 - (11449*cR^2*lmmOS^2)/2560 - (271*cA^2*lmmOS^3)/5184 + 
           (23639*cA*cR*lmmOS^3)/103680 - (16291*cA^2*lmuH)/69120 - 
           (559*cA^2*lmuH^2)/11520 - (cA^2*lmuH^3)/240 + (450958441*cA*nh)/
            3732480000 - (2429251*cR*nh)/933120 + (10015457*cA*lmmOS*nh)/
            62208000 - (62839*cR*lmmOS*nh)/41472 - (64097*cA*lmmOS^2*nh)/
            4147200 - (4393*cR*lmmOS^2*nh)/12960 + (7*cA*lmmOS^3*nh)/2880 + 
           (cA*lmuH*nh)/480 - (cA*lmmOS^2*lmuH*nh)/960 - (cA*lmmOS*lmuH^2*nh)/
            960 - (cA*lmuH^3*nh)/2880 - (813451*cA^2*Pi^2)/9953280 - 
           (765851*cA*cR*Pi^2)/1244160 + (54413*cR^2*Pi^2)/92160 - 
           (191*cA^2*lmmOS*Pi^2)/17280 - (4351*cA*cR*lmmOS*Pi^2)/69120 + 
           (91*cR^2*lmmOS*Pi^2)/192 - (7*cA*cR*lmmOS^2*Pi^2)/360 + 
           (7*cR^2*lmmOS^2*Pi^2)/96 + (cA^2*lmuH*Pi^2)/960 - 
           (64097*cA*nh*Pi^2)/49766400 + (30383*cR*nh*Pi^2)/155520 + 
           (cA*lmmOS*nh*Pi^2)/1440 + (7*cR*lmmOS*nh*Pi^2)/60 + 
           (7*cR*lmmOS^2*nh*Pi^2)/360 + (1066873*cA^2*Pi^4)/14745600 - 
           (330301*cA*cR*Pi^4)/3686400 - (1202201*cR^2*Pi^4)/2211840 - 
           (3721*cA^2*lmmOS*Pi^4)/73728 - (3151*cA*cR*lmmOS*Pi^4)/15360 - 
           (4499*cR^2*lmmOS*Pi^4)/18432 + (47447*cA*nh*Pi^4)/11059200 - 
           (59383*cR*nh*Pi^4)/921600 - (187*cA*lmmOS*nh*Pi^4)/368640 - 
           (187*cR*lmmOS*nh*Pi^4)/11520 + (49*cA*cR*Pi^2*Log[2])/60 - 
           (49*cR^2*Pi^2*Log[2])/30 + (49*cA*cR*lmmOS*Pi^2*Log[2])/120 - 
           (49*cR^2*lmmOS*Pi^2*Log[2])/60 + (7*cA*cR*lmmOS^2*Pi^2*Log[2])/
            120 - (7*cR^2*lmmOS^2*Pi^2*Log[2])/60 - (7*cR*nh*Pi^2*Log[2])/
            20 - (7*cR*lmmOS*nh*Pi^2*Log[2])/60 + (2669*cA^2*Pi^4*Log[2])/
            122880 - (2297*cA*cR*Pi^4*Log[2])/46080 + (1181*cR^2*Pi^4*Log[2])/
            92160 + (187*cA*nh*Pi^4*Log[2])/122880 + (187*cR*nh*Pi^4*Log[2])/
            3840 - (7261*cA^2*Pi^2*Log[2]^2)/81920 - 
           (11227*cA*cR*Pi^2*Log[2]^2)/36864 + (177619*cR^2*Pi^2*Log[2]^2)/
            184320 - (157*cA^2*lmmOS*Pi^2*Log[2]^2)/6144 - 
           (337*cA*cR*lmmOS*Pi^2*Log[2]^2)/3840 + 
           (711*cR^2*lmmOS*Pi^2*Log[2]^2)/2560 + (2791*cA*nh*Pi^2*Log[2]^2)/
            184320 - (3733*cR*nh*Pi^2*Log[2]^2)/46080 - 
           (11*cA*lmmOS*nh*Pi^2*Log[2]^2)/6144 - (11*cR*lmmOS*nh*Pi^2*
             Log[2]^2)/192 + (157*cA^2*Pi^2*Log[2]^3)/6144 + 
           (337*cA*cR*Pi^2*Log[2]^3)/3840 - (711*cR^2*Pi^2*Log[2]^3)/2560 + 
           (11*cA*nh*Pi^2*Log[2]^3)/6144 + (11*cR*nh*Pi^2*Log[2]^3)/192 + 
           (7261*cA^2*Log[2]^4)/81920 - (56761*cA*cR*Log[2]^4)/184320 + 
           (48173*cR^2*Log[2]^4)/184320 + (157*cA^2*lmmOS*Log[2]^4)/6144 - 
           (67*cA*cR*lmmOS*Log[2]^4)/768 + (37*cR^2*lmmOS*Log[2]^4)/512 - 
           (2791*cA*nh*Log[2]^4)/184320 + (11797*cR*nh*Log[2]^4)/46080 + 
           (11*cA*lmmOS*nh*Log[2]^4)/6144 + (11*cR*lmmOS*nh*Log[2]^4)/192 - 
           (157*cA^2*Log[2]^5)/10240 + (67*cA*cR*Log[2]^5)/1280 - 
           (111*cR^2*Log[2]^5)/2560 - (11*cA*nh*Log[2]^5)/10240 - 
           (11*cR*nh*Log[2]^5)/320 + (21783*cA^2*PolyLog[4, 1/2])/10240 - 
           (56761*cA*cR*PolyLog[4, 1/2])/7680 + (48173*cR^2*PolyLog[4, 1/2])/
            7680 + (157*cA^2*lmmOS*PolyLog[4, 1/2])/256 - 
           (67*cA*cR*lmmOS*PolyLog[4, 1/2])/32 + 
           (111*cR^2*lmmOS*PolyLog[4, 1/2])/64 - (2791*cA*nh*PolyLog[4, 1/2])/
            7680 + (11797*cR*nh*PolyLog[4, 1/2])/1920 + 
           (11*cA*lmmOS*nh*PolyLog[4, 1/2])/256 + 
           (11*cR*lmmOS*nh*PolyLog[4, 1/2])/8 + (471*cA^2*PolyLog[5, 1/2])/
            256 - (201*cA*cR*PolyLog[5, 1/2])/32 + (333*cR^2*PolyLog[5, 1/2])/
            64 + (33*cA*nh*PolyLog[5, 1/2])/256 + (33*cR*nh*PolyLog[5, 1/2])/
            8 + (99472123*cA^2*Zeta[3])/26542080 + (53333471*cA*cR*Zeta[3])/
            6635520 + (29099471*cR^2*Zeta[3])/737280 - 
           (483385*cA^2*lmmOS*Zeta[3])/147456 + (342011*cA*cR*lmmOS*Zeta[3])/
            61440 + (1263209*cR^2*lmmOS*Zeta[3])/61440 + 
           (11723*cA^2*lmmOS^2*Zeta[3])/12288 + (2297*cA*cR*lmmOS^2*Zeta[3])/
            512 + (13321*cR^2*lmmOS^2*Zeta[3])/3072 - (3706813*cA*nh*Zeta[3])/
            8847360 + (2069221*cR*nh*Zeta[3])/552960 - 
           (19537*cA*lmmOS*nh*Zeta[3])/184320 + (82579*cR*lmmOS*nh*Zeta[3])/
            46080 + (77*cA*lmmOS^2*nh*Zeta[3])/12288 + 
           (77*cR*lmmOS^2*nh*Zeta[3])/384 + (11723*cA^2*Pi^2*Zeta[3])/
            147456 + (14173*cA*cR*Pi^2*Zeta[3])/30720 + 
           (34349*cR^2*Pi^2*Zeta[3])/184320 + (77*cA*nh*Pi^2*Zeta[3])/
            147456 + (77*cR*nh*Pi^2*Zeta[3])/4608 + 
           nl*((202511*cA)/291600 + (12994699*cR)/77760000 + 
             (6623*cA*lmmOS)/103680 - (1631639*cR*lmmOS)/1944000 - 
             (119*cA*lmmOS^2)/12960 - (3529*cR*lmmOS^2)/172800 + 
             (29*cA*lmmOS^3)/5184 - (155*cR*lmmOS^3)/3456 + (106733*cA*lmuH)/
              311040 + (9097*cR*lmuH)/62208 + (649*cA*lmuH^2)/10368 + 
             (1793*cR*lmuH^2)/51840 + (121*cA*lmuH^3)/25920 + 
             (11*cR*lmuH^3)/3240 - (1397*cA*Pi^2)/259200 - (233611*cR*Pi^2)/
              3110400 + (107*cA*lmmOS*Pi^2)/103680 - (1109*cR*lmmOS*Pi^2)/
              20736 - (7*cR*lmmOS^2*Pi^2)/720 - (121*cA*lmuH*Pi^2)/103680 - 
             (11*cR*lmuH*Pi^2)/12960 - (77*cR*Pi^4)/8640 + (229*cA*Zeta[3])/
              51840 - (8249*cR*Zeta[3])/25920) + (103153*cA^2*Zeta[5])/
            16384 + (98705*cA*cR*Zeta[5])/2048 + (133323*cR^2*Zeta[5])/4096 - 
           (1705*cA*nh*Zeta[5])/16384 - (1705*cR*nh*Zeta[5])/512)) + 
       rhoOS^2*((-745550009*cA^2)/13005619200 - (2739575273*cA*cR)/
          4644864000 - (13694621*cR^2)/16588800 - (7481*cA^2*lmmOS)/1814400 + 
         (283943*cA*cR*lmmOS)/14515200 + (29*cA^2*lmuH)/134400 + 
         (265053121*cA*nh)/390168576000 - (8108339*cR*nh)/398131200 + 
         (cA*lmmOS*nh)/5040 - (cR*lmmOS*nh)/480 - (cA*lmuH*nh)/5040 + 
         (cR*lmuH*nh)/480 - (857*cA*cR*Pi^2)/604800 + (857*cR^2*Pi^2)/
          161280 + (857*cR*nh*Pi^2)/604800 + nl*((45617*cA)/18144000 + 
           (509813*cR)/1524096000 + (623*cA*lmmOS)/2073600 - 
           (29147*cR*lmmOS)/7257600 + (5951*cA*lmuH)/14515200 + 
           (1667*cR*lmuH)/3628800 - (857*cR*Pi^2)/1209600) + 
         (857*cA*cR*Pi^2*Log[2])/201600 - (857*cR^2*Pi^2*Log[2])/100800 + 
         (110251*cA^2*Zeta[3])/2359296 + (2997917*cA*cR*Zeta[3])/5898240 + 
         (36173*cR^2*Zeta[3])/49152 - (16177*cA*nh*Zeta[3])/23592960 + 
         (21973*cR*nh*Zeta[3])/1966080 + ep*((-183218082652883*cA^2)/
            327741603840000 - (84561406530271*cA*cR)/23410114560000 - 
           (503073197969*cR^2)/83607552000 - (11241763927*cA^2*lmmOS)/
            97542144000 - (7927033451*cA*cR*lmmOS)/6967296000 - 
           (13694621*cR^2*lmmOS)/8294400 - (14701*cA^2*lmmOS^2)/2419200 + 
           (283943*cA*cR*lmmOS^2)/9676800 + (1481*cA^2*lmuH)/691200 + 
           (29*cA^2*lmuH^2)/134400 + (304887364129*cA*nh)/81935400960000 - 
           (682587461*cR*nh)/5308416000 + (497296321*cA*lmmOS*nh)/
            195084288000 - (9744179*cR*lmmOS*nh)/199065600 + 
           (cA*lmmOS^2*nh)/3360 - (cR*lmmOS^2*nh)/320 - (cA*lmuH*nh)/840 + 
           (71*cR*lmuH*nh)/8640 - (cA*lmmOS*lmuH*nh)/5040 + 
           (cR*lmmOS*lmuH*nh)/480 - (cA*lmuH^2*nh)/10080 + 
           (cR*lmuH^2*nh)/960 - (3149*cA^2*Pi^2)/8709120 - 
           (241853*cA*cR*Pi^2)/34836480 + (37*cR^2*Pi^2)/1024 - 
           (857*cA*cR*lmmOS*Pi^2)/302400 + (857*cR^2*lmmOS*Pi^2)/80640 + 
           (cA*nh*Pi^2)/30240 + (5189*cR*nh*Pi^2)/604800 + 
           (857*cR*lmmOS*nh*Pi^2)/302400 - (283499*cA^2*Pi^4)/117964800 - 
           (673601*cA*cR*Pi^4)/27525120 - (660827*cR^2*Pi^4)/17203200 + 
           (39287*cA*nh*Pi^4)/707788800 - (53363*cR*nh*Pi^4)/58982400 + 
           nl*((2089506271*cA)/160030080000 - (430642823*cR)/14224896000 + 
             (808831*cA*lmmOS)/762048000 - (342991*cR*lmmOS)/33868800 + 
             (9517*cA*lmmOS^2)/14515200 - (84107*cR*lmmOS^2)/14515200 + 
             (10033*cA*lmuH)/2721600 + (34663*cR*lmuH)/10886400 + 
             (5951*cA*lmuH^2)/14515200 + (1667*cR*lmuH^2)/3628800 - 
             (53*cA*Pi^2)/5806080 - (36517*cR*Pi^2)/9676800 - 
             (857*cR*lmmOS*Pi^2)/604800) + (391*cA*cR*Pi^2*Log[2])/12600 - 
           (391*cR^2*Pi^2*Log[2])/6300 + (857*cA*cR*lmmOS*Pi^2*Log[2])/
            100800 - (857*cR^2*lmmOS*Pi^2*Log[2])/50400 - 
           (857*cR*nh*Pi^2*Log[2])/100800 - (1211*cA^2*Pi^2*Log[2]^2)/
            1966080 - (1094417*cA*cR*Pi^2*Log[2]^2)/103219200 + 
           (305393*cR^2*Pi^2*Log[2]^2)/12902400 + (2311*cA*nh*Pi^2*Log[2]^2)/
            11796480 - (3139*cR*nh*Pi^2*Log[2]^2)/983040 + 
           (1211*cA^2*Log[2]^4)/1966080 - (6341*cA*cR*Log[2]^4)/2949120 + 
           (677*cR^2*Log[2]^4)/368640 - (2311*cA*nh*Log[2]^4)/11796480 + 
           (3139*cR*nh*Log[2]^4)/983040 + (1211*cA^2*PolyLog[4, 1/2])/81920 - 
           (6341*cA*cR*PolyLog[4, 1/2])/122880 + (677*cR^2*PolyLog[4, 1/2])/
            15360 - (2311*cA*nh*PolyLog[4, 1/2])/491520 + 
           (3139*cR*nh*PolyLog[4, 1/2])/40960 + (13145693363*cA^2*Zeta[3])/
            19818086400 + (51367911353*cA*cR*Zeta[3])/9909043200 + 
           (10172621029*cR^2*Zeta[3])/1238630400 + 
           (110251*cA^2*lmmOS*Zeta[3])/1179648 + (2997917*cA*cR*lmmOS*
             Zeta[3])/2949120 + (36173*cR^2*lmmOS*Zeta[3])/24576 - 
           (5727101*cA*nh*Zeta[3])/707788800 + (103817353*cR*nh*Zeta[3])/
            707788800 - (16177*cA*lmmOS*nh*Zeta[3])/11796480 + 
           (21973*cR*lmmOS*nh*Zeta[3])/983040) + 
         ep^2*((337522928518761407*cA^2)/137651473612800000 + 
           (20561014487502607*cA*cR)/9832248115200000 - (2775091342063*cR^2)/
            278691840000 - (185597033147219*cA^2*lmmOS)/163870801920000 - 
           (83423594911327*cA*cR*lmmOS)/11705057280000 - 
           (503073197969*cR^2*lmmOS)/41803776000 - (413574869*cA^2*lmmOS^2)/
            3612672000 - (41170303*cA*cR*lmmOS^2)/36864000 - 
           (13694621*cR^2*lmmOS^2)/8294400 - (20477*cA^2*lmmOS^3)/4354560 + 
           (283943*cA*cR*lmmOS^3)/12441600 + (280177*cA^2*lmuH)/23224320 + 
           (1481*cA^2*lmuH^2)/691200 + (29*cA^2*lmuH^3)/201600 + 
           (858511212074791*cA*nh)/34412868403200000 - (9581664748613*cR*nh)/
            20065812480000 + (412928836129*cA*lmmOS*nh)/40967700480000 - 
           (80769629*cR*lmmOS*nh)/294912000 + (613417921*cA*lmmOS^2*nh)/
            195084288000 - (10562099*cR*lmmOS^2*nh)/199065600 + 
           (cA*lmmOS^3*nh)/4320 - (7*cR*lmmOS^3*nh)/2880 - 
           (319*cA*lmuH*nh)/120960 + (433*cR*lmuH*nh)/25920 - 
           (cA*lmmOS*lmuH*nh)/840 + (71*cR*lmmOS*lmuH*nh)/8640 - 
           (cA*lmmOS^2*lmuH*nh)/10080 + (cR*lmmOS^2*lmuH*nh)/960 - 
           (cA*lmuH^2*nh)/1680 + (71*cR*lmuH^2*nh)/17280 - 
           (cA*lmmOS*lmuH^2*nh)/10080 + (cR*lmmOS*lmuH^2*nh)/960 - 
           (cA*lmuH^3*nh)/30240 + (cR*lmuH^3*nh)/2880 - 
           (11450762647*cA^2*Pi^2)/1170505728000 - (1506454013*cA*cR*Pi^2)/
            11943936000 + (9155053*cR^2*Pi^2)/696729600 - 
           (14701*cA^2*lmmOS*Pi^2)/14515200 - (101647*cA*cR*lmmOS*Pi^2)/
            8294400 + (37*cR^2*lmmOS*Pi^2)/512 - (857*cA*cR*lmmOS^2*Pi^2)/
            302400 + (857*cR^2*lmmOS^2*Pi^2)/80640 - (29*cA^2*lmuH*Pi^2)/
            806400 + (729539521*cA*nh*Pi^2)/2341011456000 + 
           (507942811*cR*nh*Pi^2)/16721510400 + (cA*lmmOS*nh*Pi^2)/15120 + 
           (5189*cR*lmmOS*nh*Pi^2)/302400 + (857*cR*lmmOS^2*nh*Pi^2)/302400 - 
           (576499319*cA^2*Pi^4)/16986931200 - (15104653219*cA*cR*Pi^4)/
            59454259200 - (15357415907*cR^2*Pi^4)/37158912000 - 
           (283499*cA^2*lmmOS*Pi^4)/58982400 - (673601*cA*cR*lmmOS*Pi^4)/
            13762560 - (660827*cR^2*lmmOS*Pi^4)/8601600 + 
           (97360717*cA*nh*Pi^4)/148635648000 - (1589381401*cR*nh*Pi^4)/
            148635648000 + (39287*cA*lmmOS*nh*Pi^4)/353894400 - 
           (53363*cR*lmmOS*nh*Pi^4)/29491200 + (737*cA*cR*Pi^2*Log[2])/5760 - 
           (737*cR^2*Pi^2*Log[2])/2880 + (391*cA*cR*lmmOS*Pi^2*Log[2])/6300 - 
           (391*cR^2*lmmOS*Pi^2*Log[2])/3150 + (857*cA*cR*lmmOS^2*Pi^2*
             Log[2])/100800 - (857*cR^2*lmmOS^2*Pi^2*Log[2])/50400 - 
           (5399*cR*nh*Pi^2*Log[2])/100800 - (857*cR*lmmOS*nh*Pi^2*Log[2])/
            50400 + (20587*cA^2*Pi^4*Log[2])/19660800 - 
           (69817*cA*cR*Pi^4*Log[2])/619315200 - (306791*cR^2*Pi^4*Log[2])/
            77414400 - (39287*cA*nh*Pi^4*Log[2])/117964800 + 
           (53363*cR*nh*Pi^4*Log[2])/9830400 - (70605557*cA^2*Pi^2*Log[2]^2)/
            9909043200 - (7639963*cA*cR*Pi^2*Log[2]^2)/110100480 + 
           (14800139*cR^2*Pi^2*Log[2]^2)/88473600 - 
           (1211*cA^2*lmmOS*Pi^2*Log[2]^2)/983040 - 
           (1094417*cA*cR*lmmOS*Pi^2*Log[2]^2)/51609600 + 
           (305393*cR^2*lmmOS*Pi^2*Log[2]^2)/6451200 + 
           (5727101*cA*nh*Pi^2*Log[2]^2)/2477260800 - 
           (40632457*cR*nh*Pi^2*Log[2]^2)/2477260800 + 
           (2311*cA*lmmOS*nh*Pi^2*Log[2]^2)/5898240 - 
           (3139*cR*lmmOS*nh*Pi^2*Log[2]^2)/491520 + 
           (1211*cA^2*Pi^2*Log[2]^3)/983040 + (1094417*cA*cR*Pi^2*Log[2]^3)/
            51609600 - (305393*cR^2*Pi^2*Log[2]^3)/6451200 - 
           (2311*cA*nh*Pi^2*Log[2]^3)/5898240 + (3139*cR*nh*Pi^2*Log[2]^3)/
            491520 + (70605557*cA^2*Log[2]^4)/9909043200 - 
           (621397*cA*cR*Log[2]^4)/26214400 + (11709619*cR^2*Log[2]^4)/
            619315200 + (1211*cA^2*lmmOS*Log[2]^4)/983040 - 
           (6341*cA*cR*lmmOS*Log[2]^4)/1474560 + (677*cR^2*lmmOS*Log[2]^4)/
            184320 - (5727101*cA*nh*Log[2]^4)/2477260800 + 
           (103817353*cR*nh*Log[2]^4)/2477260800 - 
           (2311*cA*lmmOS*nh*Log[2]^4)/5898240 + (3139*cR*lmmOS*nh*Log[2]^4)/
            491520 - (1211*cA^2*Log[2]^5)/1638400 + (6341*cA*cR*Log[2]^5)/
            2457600 - (677*cR^2*Log[2]^5)/307200 + (2311*cA*nh*Log[2]^5)/
            9830400 - (3139*cR*nh*Log[2]^5)/819200 + 
           (70605557*cA^2*PolyLog[4, 1/2])/412876800 - 
           (1864191*cA*cR*PolyLog[4, 1/2])/3276800 + 
           (11709619*cR^2*PolyLog[4, 1/2])/25804800 + 
           (1211*cA^2*lmmOS*PolyLog[4, 1/2])/40960 - 
           (6341*cA*cR*lmmOS*PolyLog[4, 1/2])/61440 + 
           (677*cR^2*lmmOS*PolyLog[4, 1/2])/7680 - 
           (5727101*cA*nh*PolyLog[4, 1/2])/103219200 + 
           (103817353*cR*nh*PolyLog[4, 1/2])/103219200 - 
           (2311*cA*lmmOS*nh*PolyLog[4, 1/2])/245760 + 
           (3139*cR*lmmOS*nh*PolyLog[4, 1/2])/20480 + 
           (3633*cA^2*PolyLog[5, 1/2])/40960 - (6341*cA*cR*PolyLog[5, 1/2])/
            20480 + (677*cR^2*PolyLog[5, 1/2])/2560 - 
           (2311*cA*nh*PolyLog[5, 1/2])/81920 + (9417*cR*nh*PolyLog[5, 1/2])/
            20480 - (192064750279*cA^2*Zeta[3])/3567255552000 + 
           (21251587697359*cA*cR*Zeta[3])/1783627776000 + 
           (383505295559*cR^2*Zeta[3])/12386304000 + 
           (13145693363*cA^2*lmmOS*Zeta[3])/9909043200 + 
           (51367911353*cA*cR*lmmOS*Zeta[3])/4954521600 + 
           (10172621029*cR^2*lmmOS*Zeta[3])/619315200 + 
           (110251*cA^2*lmmOS^2*Zeta[3])/1179648 + 
           (2997917*cA*cR*lmmOS^2*Zeta[3])/2949120 + 
           (36173*cR^2*lmmOS^2*Zeta[3])/24576 - (768534811*cA*nh*Zeta[3])/
            14863564800 + (256469651*cR*nh*Zeta[3])/339738624 - 
           (5727101*cA*lmmOS*nh*Zeta[3])/353894400 + 
           (103817353*cR*lmmOS*nh*Zeta[3])/353894400 - 
           (16177*cA*lmmOS^2*nh*Zeta[3])/11796480 + 
           (21973*cR*lmmOS^2*nh*Zeta[3])/983040 + (110251*cA^2*Pi^2*Zeta[3])/
            14155776 + (120723319*cA*cR*Pi^2*Zeta[3])/1238630400 + 
           (5013923*cR^2*Pi^2*Zeta[3])/51609600 - (16177*cA*nh*Pi^2*Zeta[3])/
            141557760 + (21973*cR*nh*Pi^2*Zeta[3])/11796480 + 
           nl*((310213473683*cA)/6721263360000 - (539002769021*cR)/
              11202105600000 + (43634939*cA*lmmOS)/7112448000 - 
             (58709863847*cR*lmmOS)/640120320000 + (280781*cA*lmmOS^2)/
              304819200 - (42470591*cR*lmmOS^2)/3048192000 + 
             (2419*cA*lmmOS^3)/4354560 - (194027*cR*lmmOS^3)/43545600 + 
             (5336503*cA*lmuH)/261273600 + (7051871*cR*lmuH)/522547200 + 
             (10033*cA*lmuH^2)/2721600 + (34663*cR*lmuH^2)/10886400 + 
             (5951*cA*lmuH^3)/21772800 + (1667*cR*lmuH^3)/5443200 - 
             (666803*cA*Pi^2)/3048192000 - (45780367*cR*Pi^2)/3657830400 + 
             (9517*cA*lmmOS*Pi^2)/87091200 - (676451*cR*lmmOS*Pi^2)/
              87091200 - (857*cR*lmmOS^2*Pi^2)/604800 - (5951*cA*lmuH*Pi^2)/
              87091200 - (1667*cR*lmuH*Pi^2)/21772800 - (9427*cR*Pi^4)/
              7257600 + (76499*cA*Zeta[3])/43545600 - (683717*cR*Zeta[3])/
              21772800) + (1915591*cA^2*Zeta[5])/2621440 + 
           (37490503*cA*cR*Zeta[5])/3932160 + (6349337*cR^2*Zeta[5])/491520 + 
           (71641*cA*nh*Zeta[5])/3145728 - (97309*cR*nh*Zeta[5])/262144)))
